/*
 * @(#)CodeNode.java  0.2.0 / 2007-12-18
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.demo.codebrowser;

import java.io.File;
import java.util.ArrayList;
import java.util.Arrays;

import yu.ac.bg.etf.javaqx.qswing.Icon;
import yu.ac.bg.etf.javaqx.qswing.ImageIcon;
import yu.ac.bg.etf.javaqx.qswing.tree.DefaultMutableTreeNode;

/**
 * Code Node.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class CodeNode extends DefaultMutableTreeNode {

/*^**************************************************************************^*/
/*- Private Static Fields.                                                   -*/
/*^**************************************************************************^*/

  private static final Icon FOLDER_ICON;
  private static final Icon CPP_FILE_ICON;
  private static final Icon H_FILE_ICON;
  private static final Icon JAVA_FILE_ICON;
  private static final Icon JAVA_PACKAGE_ICON;
  private static final Icon UNKNOWN_ICON;

/*^**************************************************************************^*/
/*- Static Initialization.                                                   -*/
/*^**************************************************************************^*/

  static {
    Class codeNodeClass = CodeNode.class;
    FOLDER_ICON = new ImageIcon(
                    codeNodeClass.getResource("Folder.png")); //$NON-NLS-1$
    CPP_FILE_ICON = new ImageIcon(
                    codeNodeClass.getResource("CppFile.png")); //$NON-NLS-1$
    H_FILE_ICON = new ImageIcon(
                    codeNodeClass.getResource("HFile.png")); //$NON-NLS-1$
    JAVA_FILE_ICON = new ImageIcon(
                    codeNodeClass.getResource("JavaFile.png")); //$NON-NLS-1$
    JAVA_PACKAGE_ICON = new ImageIcon(
                    codeNodeClass.getResource("JavaPackage.png")); //$NON-NLS-1$
    UNKNOWN_ICON = new ImageIcon(
                    codeNodeClass.getResource("Unknown.png")); //$NON-NLS-1$
  }

/*^**************************************************************************^*/
/*- Private Fields.                                                          -*/
/*^**************************************************************************^*/

  private final String title;
  private Icon icon;
  private final File file;
  private boolean expanded; // NOPMD

/*^**************************************************************************^*/
/*- Public Constructors.                                                     -*/
/*^**************************************************************************^*/

  /**
   * Constructs new CodeNode object.
   *
   * @param sourceFile the source file
   */
  public CodeNode(File sourceFile) {
    this.file = sourceFile;
    title = file.getName();
  }

  /**
   * Constructs new CodeNode object.
   *
   * @param title the node title
   * @param sourceFile the source file
   */
  public CodeNode(String title, String sourceFile) {
    this.title = title;
    this.file = new File(sourceFile);
  }

/*^**************************************************************************^*/
/*- Public Method.                                                           -*/
/*^**************************************************************************^*/

  /**
   * Returns source file.
   *
   * @return source file
   */
  public File getSourceFile() {
    return file;
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public String toString() {
    return title;
  }

  /**
   * {@inheritDoc}
   */
  public int getChildCount() {
    if (!expanded) {
      expanded = true;
      if (file.isDirectory()) {
        String[] rawFiles = file.list();
        Arrays.sort(rawFiles);
        ArrayList folders = new ArrayList(rawFiles.length);
        ArrayList files = new ArrayList(rawFiles.length);
        for (int i = 0; i < rawFiles.length; i++) {
          if (rawFiles[i].charAt(0) != '.' &&
              !rawFiles[i].endsWith(".png")) { //$NON-NLS-1$
            File currentFile = new File(file, rawFiles[i]);
            if (currentFile.isDirectory()) {
              folders.add(currentFile);
            } else {
              files.add(currentFile);
            }
          }
        }
        rawFiles = null;
        for (int i = 0; i < folders.size(); i++) {
          add(new CodeNode((File)folders.get(i)));
        }
        folders = null;
        for (int i = 0; i < files.size(); i++) {
          add(new CodeNode((File)files.get(i)));
        }
        String absolutePath = file.getAbsolutePath();
        if ((absolutePath.indexOf("java") > 0) && //$NON-NLS-1$
            (absolutePath.indexOf("yu") > 0)) { //$NON-NLS-1$
          icon = JAVA_PACKAGE_ICON;
        } else {
          icon = FOLDER_ICON;
        }
      } else {
        if (title.endsWith(".java")) { //$NON-NLS-1$
          icon = JAVA_FILE_ICON;
        } else if (title.endsWith(".h")) { //$NON-NLS-1$
          icon = H_FILE_ICON;
        } else if (title.endsWith(".cpp")) { //$NON-NLS-1$
          icon = CPP_FILE_ICON;
        } else {
          icon = UNKNOWN_ICON;
        }
      }
    }
    return super.getChildCount();
  }

  /**
   * {@inheritDoc}
   */
  public Icon getIcon() {
    return icon;
  }

}

/*^*****************************************************************************
  File History:

 - 2007-12-18 21:34:20 Slobodan
   Initial version

*****************************************************************************^*/
