/*
 * @(#)QNotepad.java  0.2.0 / 2007-05-04
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.demo.qnotepad;

import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Date;
import java.util.Locale;

import yu.ac.bg.etf.javaqx.qswing.JQCheckBoxMenuItem;
import yu.ac.bg.etf.javaqx.qswing.JQFileChooser;
import yu.ac.bg.etf.javaqx.qswing.JQFontChooser;
import yu.ac.bg.etf.javaqx.qswing.JQFrame;
import yu.ac.bg.etf.javaqx.qswing.JQMenu;
import yu.ac.bg.etf.javaqx.qswing.JQMenuBar;
import yu.ac.bg.etf.javaqx.qswing.JQMenuItem;
import yu.ac.bg.etf.javaqx.qswing.JQOptionPane;
import yu.ac.bg.etf.javaqx.qswing.JQRadioButtonMenuItem;
import yu.ac.bg.etf.javaqx.qswing.JQStatusBar;
import yu.ac.bg.etf.javaqx.qswing.JQTextArea;
import yu.ac.bg.etf.javaqx.qswing.KeyStroke;
import yu.ac.bg.etf.javaqx.qswing.QSwing;
import yu.ac.bg.etf.javaqx.qswing.SelectableGroup;
import yu.ac.bg.etf.javaqx.qswing.events.ActionEvent;
import yu.ac.bg.etf.javaqx.qswing.events.ActionListener;
import yu.ac.bg.etf.javaqx.qswing.events.WindowEvent;
import yu.ac.bg.etf.javaqx.qswing.graphics.Font;
import yu.ac.bg.etf.javaqx.qswing.print.Printer;
import yu.ac.bg.etf.javaqx.qswingx.JQStyleMenu;
import yu.ac.bg.etf.javaqx.qswingx.JQThemeMenu;
import yu.ac.bg.etf.javaqx.qswingx.actions.AboutQSwingAction;
import yu.ac.bg.etf.javaqx.qswingx.actions.AboutQtAction;
import yu.ac.bg.etf.javaqx.qswingx.actions.ExitAction;
import yu.ac.bg.etf.javaqx.qswingx.actions.NewAction;
import yu.ac.bg.etf.javaqx.qswingx.actions.OpenAction;
import yu.ac.bg.etf.javaqx.qswingx.actions.PageSetupAction;
import yu.ac.bg.etf.javaqx.qswingx.actions.PrintAction;
import yu.ac.bg.etf.javaqx.qswingx.actions.SaveAction;
import yu.ac.bg.etf.javaqx.qswingx.actions.SaveAsAction;
import yu.ac.bg.etf.javaqx.qswingx.actions.TextComponentCopyAction;
import yu.ac.bg.etf.javaqx.qswingx.actions.TextComponentCutAction;
import yu.ac.bg.etf.javaqx.qswingx.actions.TextComponentDeleteAction;
import yu.ac.bg.etf.javaqx.qswingx.actions.TextComponentPasteAction;
import yu.ac.bg.etf.javaqx.qswingx.actions.TextComponentRedoAction;
import yu.ac.bg.etf.javaqx.qswingx.actions.TextComponentSelectAllAction;
import yu.ac.bg.etf.javaqx.qswingx.actions.TextComponentUndoAction;

/**
 * Simple Notepad.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public final class QNotepad extends JQFrame {

/*^**************************************************************************^*/
/*- Private Fields.                                                          -*/
/*^**************************************************************************^*/

  private JQRadioButtonMenuItem rbmiEnglish;
  private JQRadioButtonMenuItem rbmiSerbian;
  private final JQTextArea textArea;
  private final JQStatusBar statusBar;
  private File currentFile;
  private Printer printer;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new QNotepad object.
   */
  public QNotepad() {
    super("Untitled - QNotepad"); //$NON-NLS-1$
    setIconImage(QSwing.crateImage(
                         getClass().getResource("QNotepad.png"))); //$NON-NLS-1$
    setDefaultCloseOperation(DO_NOTHING_ON_CLOSE);
    setSize(640, 480);
    textArea = new JQTextArea();
    add(textArea);
    buildMenuBar();
    statusBar = setStatusBar(new JQStatusBar());
    statusBar.setVisible(false);
    Locale.setDefault(Locale.US);
    QSwing.setLocale(Locale.US);
    setDefaultResourceBundleName();
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected void processWindowEvent(WindowEvent event) {
    super.processWindowEvent(event);
    if (event.getID() == WindowEvent.WINDOW_CLOSING) {
      exit();
    }
  }

/*^**************************************************************************^*/
/*- Packge-Private Methods.                                                  -*/
/*^**************************************************************************^*/

  void performNew() {
    if (textArea.isModified()) {
      switch (warn()) {
        case JQOptionPane.YES_OPTION:
          if (currentFile == null) {
            if (!saveAs()) { // NOPMD
              return;
            }
          }
          store();
          break;
        case JQOptionPane.NO_OPTION:
          break;
        default:
          return;
      }
    }
    textArea.clearText();
    setCurrentFile(null);
  }

  void performOpen() {
    if (textArea.isModified()) {
      switch (warn()) {
        case JQOptionPane.YES_OPTION:
          if (currentFile == null) {
            if (!saveAs()) { // NOPMD
              return;
            }
          }
          store();
          break;
        case JQOptionPane.NO_OPTION:
          break;
        default:
          return;
      }
    }
    String fileName = JQFileChooser.getOpenFileName(QNotepad.this, null,
                          null, "Text Documents (*.txt)", null); //$NON-NLS-1$
    if (fileName != null) {
      setCurrentFile(fileName);
      load();
    }
  }

  void performSave() {
    if (currentFile == null) {
      if (!saveAs()) { // NOPMD
        return;
      }
    }
    store();
  }

  void performSaveAs() {
    if (saveAs()) {
      store();
    }
  }

  void performPageSetup() {
    if (printer == null) {
      printer = new Printer();
    }
    printer.pageDialog();
  }

  void performPrint() {
    if (printer == null) {
      printer = new Printer();
    }
    if (printer.printerDialog()) {
      textArea.print(printer);
    }
  }

  void performExit() {
    exit();
  }

  void performTimeDate() {
    textArea.insertText(new Date().toString());
  }

  void performWordWrap() {
    textArea.setWrapText(!textArea.isWrapText());
  }

  void performFont() {
    Font font = JQFontChooser.getFont(QNotepad.this, textArea.getFont());
    if (font != null) {
      textArea.setFont(font);
    }
  }

  void performStatusBar() {
    statusBar.setVisible(!statusBar.isVisible());
  }

  void performEnglish() {
    if (rbmiEnglish.isSelected()) {
      QSwing.removeTranslation();
      QSwing.setLocale(Locale.US);
      updateLocalization();
    }
  }

  void performSerbian() {
    if (rbmiSerbian.isSelected()) {
      QSwing.setTranslation("../trans/yu-ac-bg-etf-javaqx_sr.qm"); //$NON-NLS-1$
      QSwing.setLocale(new Locale("sr")); //$NON-NLS-1$
      updateLocalization();
    }
  }

/*^**************************************************************************^*/
/*- Private Methods.                                                         -*/
/*^**************************************************************************^*/

  private void buildMenuBar() {
    JQMenuBar menuBar = setMenuBar(new JQMenuBar());
    JQMenu menu = menuBar.add(new JQMenu("&File")); //$NON-NLS-1$
    menu.add(new JQMenuItem(new NewAction() {
      public void actionPerformed(ActionEvent e) {
        performNew();
      }
    }));
    menu.add(new JQMenuItem(new OpenAction() {
      public void actionPerformed(ActionEvent e) {
        performOpen();
      }
    }));
    menu.add(new JQMenuItem(new SaveAction() {
      public void actionPerformed(ActionEvent e) {
        performSave();
      }
    }));
    menu.add(new JQMenuItem(new SaveAsAction() {
      public void actionPerformed(ActionEvent e) {
        performSaveAs();
      }
    }));
    menu.addSeparator();
    menu.add(new JQMenuItem(new PageSetupAction() {
      public void actionPerformed(ActionEvent e) {
        performPageSetup();
      }
    }));
    menu.add(new JQMenuItem(new PrintAction() {
      public void actionPerformed(ActionEvent e) {
        performPrint();
      }
    }));
    menu.addSeparator();
    menu.add(new JQMenuItem(new ExitAction() {
      public void actionPerformed(ActionEvent e) {
        performExit();
      }
    }));
    // Edit Menu
    menu = menuBar.add(new JQMenu("&Edit")); //$NON-NLS-1$
    menu.add(new JQMenuItem(new TextComponentUndoAction(textArea)));
    menu.add(new JQMenuItem(new TextComponentRedoAction(textArea)));
    menu.addSeparator();
    menu.add(new JQMenuItem(new TextComponentCutAction(textArea)));
    menu.add(new JQMenuItem(new TextComponentCopyAction(textArea)));
    menu.add(new JQMenuItem(new TextComponentPasteAction(textArea)));
    menu.add(new JQMenuItem(new TextComponentDeleteAction(textArea)));
    menu.addSeparator();
    menu.add(new JQMenuItem(new TextComponentSelectAllAction(textArea)));
    JQMenuItem menuItem = menu.add(new JQMenuItem("Time/&Date")); //$NON-NLS-1$
    menuItem.setAccelerator(KeyStroke.getKeyStroke("F5")); //$NON-NLS-1$
    menuItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        performTimeDate();
      }
    });
    // Format Menu
    menu = menuBar.add(new JQMenu("F&ormat")); //$NON-NLS-1$
    menuItem = menu.add(new JQCheckBoxMenuItem("&Wrap Word")); //$NON-NLS-1$
    menuItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        performWordWrap();
      }
    });
    menuItem = menu.add(new JQMenuItem("&Font...")); //$NON-NLS-1$
    menuItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        performFont();
      }
    });
    // View Menu
    menu = menuBar.add(new JQMenu("&View")); //$NON-NLS-1$
    menuItem = menu.add(new JQCheckBoxMenuItem("&Status Bar")); //$NON-NLS-1$
    menuItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        performStatusBar();
      }
    });
    // Settings Menu
    menu = menuBar.add(new JQMenu("&Settings")); //$NON-NLS-1$
    menu.add(new JQStyleMenu());
    menu.add(new JQThemeMenu());
    SelectableGroup sgLanguages = new SelectableGroup();
    menu = menu.add(new JQMenu("&Language")); //$NON-NLS-1$
    rbmiEnglish = new JQRadioButtonMenuItem("&English"); //$NON-NLS-1$
    rbmiEnglish.setSelected(true);
    sgLanguages.add(rbmiEnglish);
    menuItem = menu.add(rbmiEnglish);
    menuItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        performEnglish();
      }
    });
    rbmiSerbian = new JQRadioButtonMenuItem("&Српски"); //$NON-NLS-1$
    sgLanguages.add(rbmiSerbian);
    menuItem = menu.add(rbmiSerbian);
    menuItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        performSerbian();
      }
    });
    // Help Menu
    menuBar.addSeparator();
    menu = menuBar.add(new JQMenu("&Help")); //$NON-NLS-1$
    menu.add(new JQMenuItem(new AboutQSwingAction()));
    menu.add(new JQMenuItem(new AboutQtAction()));
  }

  private void setCurrentFile(String fileName) {
    if (fileName == null) {
      currentFile = null;
      setTitle("Untitled - QNotepad"); //$NON-NLS-1$
    } else {
      currentFile = new File(fileName);
      setTitle(currentFile.getName() + " - QNotepad"); //$NON-NLS-1$
    }
  }

  private void load() {
    FileReader fr = null;
    try {
      fr = new FileReader(currentFile);
      textArea.read(fr);
    } catch (IOException ioe) {
      JQOptionPane.showErrorMessage(this, "Error loading file", //$NON-NLS-1$
                                    "QNotepad", //$NON-NLS-1$
                                    JQOptionPane.OK_OPTION);
    } finally {
      if (fr != null) {
        try {
          fr.close();
        } catch (IOException ioe) { // NOPMD
          // empty catch block
        }
      }
    }
  }

  private void store() {
    FileWriter fw = null;
    try {
      fw = new FileWriter(currentFile);
      textArea.write(fw);
    } catch (IOException ioe) {
      JQOptionPane.showErrorMessage(this, "Error storing file", //$NON-NLS-1$
                                    "QNotepad", //$NON-NLS-1$
                                    JQOptionPane.OK_OPTION);
    } finally {
      if (fw != null) {
        try {
          fw.close();
        } catch (IOException ioe) { // NOPMD
          // empty catch block
        }
      }
    }
  }

  private boolean saveAs() {
    String dir = null;
    if (currentFile != null) {
      dir = currentFile.toString();
    }
    String fileName = JQFileChooser.getSaveFileName(this,
                                  "Save As", dir, //$NON-NLS-1$
                                  "Text Documents (*.txt)", null); //$NON-NLS-1$
    if (fileName != null) {
      setCurrentFile(fileName);
      return true;
    }
    return false;
  }

  private int warn() {
    StringBuffer sb = new StringBuffer(localizeString(
                                         "The text in the ")); //$NON-NLS-1$
    if (currentFile == null) {
      sb.append("Untitled"); //$NON-NLS-1$
    } else {
      sb.append(currentFile.getName());
    }
    sb.append(localizeString(
                " has changed.\n\nDo you want to save changes?")); //$NON-NLS-1$
    return JQOptionPane.showWarningMessage(this, sb.toString(),
                                           "QNotepad", //$NON-NLS-1$
                                           JQOptionPane.YES_NO_CANCEL_OPTIONS);
  }

  private void exit() {
    if (textArea.isModified()) {
      switch (warn()) {
        case JQOptionPane.YES_OPTION:
          if (currentFile == null) {
            if (!saveAs()) { // NOPMD
              return;
            }
          }
          store();
          break;
        case JQOptionPane.NO_OPTION:
          break;
        default:
          return;
      }
    }
    QSwing.stopEventLoop();
  }

/*^**************************************************************************^*/
/*- Main Method.                                                             -*/
/*^**************************************************************************^*/

  /**
   * Starts QNotepad.
   *
   * @param args the application arguments
   */
  public static void main(String[] args) {
    QNotepad notepad = new QNotepad();
    notepad.setVisible(true);
    QSwing.startEventLoop();
  }

}

/*^*****************************************************************************
  File History:

 - 2007-05-04 19:37:14 Slobodan
   Initial version

*****************************************************************************^*/
