/*
 * @(#)ButtonsDemo.java  0.2.0 / 2007-11-21
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.demo.qswingset;

import yu.ac.bg.etf.javaqx.qswing.Icon;
import yu.ac.bg.etf.javaqx.qswing.ImageIcon;
import yu.ac.bg.etf.javaqx.qswing.JQButton;
import yu.ac.bg.etf.javaqx.qswing.JQCheckBox;
import yu.ac.bg.etf.javaqx.qswing.JQColorChooser;
import yu.ac.bg.etf.javaqx.qswing.JQComponent;
import yu.ac.bg.etf.javaqx.qswing.JQContainer;
import yu.ac.bg.etf.javaqx.qswing.JQFontChooser;
import yu.ac.bg.etf.javaqx.qswing.JQMenu;
import yu.ac.bg.etf.javaqx.qswing.JQMenuItem;
import yu.ac.bg.etf.javaqx.qswing.JQRadioButton;
import yu.ac.bg.etf.javaqx.qswing.JQScrollPane;
import yu.ac.bg.etf.javaqx.qswing.JQSeparator;
import yu.ac.bg.etf.javaqx.qswing.JQToggleButton;
import yu.ac.bg.etf.javaqx.qswing.JQToolButton;
import yu.ac.bg.etf.javaqx.qswing.SelectableGroup;
import yu.ac.bg.etf.javaqx.qswing.events.ActionEvent;
import yu.ac.bg.etf.javaqx.qswing.events.ActionListener;
import yu.ac.bg.etf.javaqx.qswing.graphics.Color;
import yu.ac.bg.etf.javaqx.qswing.graphics.Font;
import yu.ac.bg.etf.javaqx.qswing.layouts.formlayout.CellConstraints;
import yu.ac.bg.etf.javaqx.qswing.layouts.formlayout.FormLayout;
import yu.ac.bg.etf.javaqx.qswingx.actions.AboutQSwingAction;
import yu.ac.bg.etf.javaqx.qswingx.actions.AboutQtAction;

/**
 * Demonstration of the JQButon, JQToggleButon, JQToolButon, JQCheckBox and
 * JQRadioButton classes.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class ButtonsDemo extends DemoModule {

/*^**************************************************************************^*/
/*- Private Fields.                                                          -*/
/*^**************************************************************************^*/

  private JQComponent coloredPushButton;
  private JQComponent coloredToggleButton;
  private JQComponent coloredToolButton;
  private JQComponent coloredCheckButton;
  private JQComponent coloredRadioButton;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new ButtonsDemo object.
   */
  public ButtonsDemo() {
    super("Buttons Demo", "Demonstration of the JQButon, JQToggleButon, " +
                          "JQToolButon, JQCheckBox and JQRadioButton classes.");
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected JQComponent buildDemoComponent() {
    FormLayout layout = new FormLayout(
                          "p, 4dlu, p, 4dlu, p, 4dlu, p, r:24px," +
                          "c:p, l:24px, 18dlu, p, 4dlu, p, 4dlu, p",
                          "p, 2dlu, p, 4dlu, p, 2dlu, p, 4dlu, p," +
                          " 2dlu, p, 4dlu, p, 2dlu, p, 4dlu, p, 2dlu, p, 4dlu");
    JQContainer panel = new JQContainer(layout);
    panel.setInsets(16, 16, 16, 16);
    CellConstraints cc = new CellConstraints();
    buildJQButtons(panel, cc);
    buildJQToggleButtons(panel, cc);
    buildJQToolButtons(panel, cc);
    buildJQCheckBoxs(panel, cc);
    buildJQRadioButtons(panel, cc);
    buildSettings(panel, cc);
    setColor(Color.RED);
    return new JQScrollPane(panel);
  }

/*^**************************************************************************^*/
/*- Private Methods.                                                         -*/
/*^**************************************************************************^*/

  private void buildJQButtons(JQContainer panel, CellConstraints cc) {
    panel.add(new JQSeparator("JQButtons"), cc.xyw(1, 1, 10));
    panel.add(new JQButton("Enabled"), cc.xy(1, 3));
    panel.add(new JQButton("Disabled"), cc.xy(3, 3)).setEnabled(false);
    JQButton button = new JQButton("Default");
    button.setDefaultCapable(true);
    panel.add(button, cc.xy(5, 3));
    coloredPushButton = panel.add(new JQButton("ColoRED"), cc.xy(7, 3));
    button = new JQButton(createIcon("Button.png"));
    button.setRolloverIcon(createIcon("ButtonRollover.png"));
    button.setPressedIcon(createIcon("ButtonPressed.png"));
    panel.add(button, cc.xy(9, 3));
  }

  private void buildJQToggleButtons(JQContainer panel, CellConstraints cc) {
    panel.add(new JQSeparator("JQToggleButtons"), cc.xyw(1, 5, 10));
    panel.add(new JQToggleButton("Enabled"), cc.xy(1, 7));
    panel.add(new JQToggleButton("Disabled"), cc.xy(3, 7)).setEnabled(false);
    JQToggleButton toggleButton = new JQToggleButton("Selected");
    toggleButton.setSelected(true);
    panel.add(toggleButton, cc.xy(5, 7));
    coloredToggleButton = panel.add(new JQToggleButton("ColoRED"), cc.xy(7, 7));
    toggleButton = new JQToggleButton(createIcon("ToggleButton.png"));
    toggleButton.setPressedIcon(createIcon("ToggleButtonSelected.png"));
    toggleButton.setSelectedIcon(createIcon("ToggleButtonSelected.png"));
    panel.add(toggleButton, cc.xy(9, 7));
  }

  private void buildJQToolButtons(JQContainer panel, CellConstraints cc) {
    panel.add(new JQSeparator("JQToolButtons"), cc.xyw(1, 9, 10));
    panel.add(new JQToolButton("Enabled"), cc.xy(1, 11));
    panel.add(new JQToolButton("Disabled"), cc.xy(3, 11)).setEnabled(false);
    JQToolButton toolButton = new JQToolButton("Menu");
    JQMenu menu = new JQMenu();
    JQMenuItem menuItem = menu.add(new JQMenuItem(new AboutQSwingAction()));
    menuItem.setIcon(createIcon("GreenTeaCup.png"));
    menuItem.setRolloverIcon(createIcon("GreenTeaCupRollover.png"));
    menu.addSeparator();
    menuItem = menu.add(new JQMenuItem(new AboutQtAction()));
    menuItem.setIcon(createIcon("QtLogo.png"));
    toolButton.setMenu(menu);
    panel.add(toolButton, cc.xy(5, 11));
    coloredToolButton = panel.add(new JQToolButton("ColoRED"), cc.xy(7, 11));
    toolButton = new JQToolButton(createIcon("ToolButton.png"));
    toolButton.setRolloverIcon(createIcon("ToolButtonRollover.png"));
    toolButton.setPressedIcon(createIcon("ToolButtonPressed.png"));
    panel.add(toolButton, cc.xy(9, 11));
  }

  private void buildJQCheckBoxs(JQContainer panel, CellConstraints cc) {
    panel.add(new JQSeparator("JQCheckBox"), cc.xyw(1, 13, 10));
    panel.add(new JQCheckBox("Enabled"), cc.xy(1, 15));
    panel.add(new JQCheckBox("Disabled"), cc.xy(3, 15)).setEnabled(false);
    JQCheckBox checkBox = new JQCheckBox("Selected");
    checkBox.setSelected(true);
    panel.add(checkBox, cc.xy(5, 15));
    coloredCheckButton = panel.add(new JQCheckBox("ColoRED"), cc.xy(7, 15));
    checkBox = new JQCheckBox(createIcon("CheckBox.png"));
    checkBox.setSelectedIcon(createIcon("CheckBoxSelected.png"));
    checkBox.setRolloverIcon(createIcon("CheckBoxRollover.png"));
    checkBox.setRolloverSelectedIcon(createIcon(
                                              "CheckBoxRolloverSelected.png"));
    panel.add(checkBox, cc.xy(9, 15));
  }

  private void buildJQRadioButtons(JQContainer panel, CellConstraints cc) {
    panel.add(new JQSeparator("JQRadioButton"), cc.xyw(1, 17, 10));
    panel.add(new JQRadioButton("Enabled"), cc.xy(1, 19));
    panel.add(new JQRadioButton("Disabled"), cc.xy(3, 19)).setEnabled(false);
    JQRadioButton radioButton = new JQRadioButton("Selected");
    radioButton.setSelected(true);
    panel.add(radioButton, cc.xy(5, 19));
    coloredRadioButton = panel.add(new JQRadioButton("ColoRED"), cc.xy(7, 19));
    Icon icon = createIcon("RadioButton.png");
    Icon iconPressed = createIcon("RadioButtonPressed.png");
    Icon iconSelected = createIcon("RadioButtonSelected.png");
    Icon iconRollover = createIcon("RadioButtonRollover.png");
    Icon iconRolloverSelected = createIcon("RadioButtonRolloverSelected.png");
    SelectableGroup sg = new SelectableGroup();
    radioButton = new JQRadioButton(icon);
    radioButton.setPressedIcon(iconPressed);
    radioButton.setSelectedIcon(iconSelected);
    radioButton.setRolloverIcon(iconRollover);
    radioButton.setRolloverSelectedIcon(iconRolloverSelected);
    panel.add(radioButton, cc.xy(8, 19));
    sg.add(radioButton);
    radioButton = new JQRadioButton(icon);
    radioButton.setPressedIcon(iconPressed);
    radioButton.setSelectedIcon(iconSelected);
    radioButton.setRolloverIcon(iconRollover);
    radioButton.setRolloverSelectedIcon(iconRolloverSelected);
    radioButton.setSelected(true);
    panel.add(radioButton, cc.xy(9, 19));
    sg.add(radioButton);
    radioButton = new JQRadioButton(icon);
    radioButton.setPressedIcon(iconPressed);
    radioButton.setSelectedIcon(iconSelected);
    radioButton.setRolloverIcon(iconRollover);
    radioButton.setRolloverSelectedIcon(iconRolloverSelected);
    panel.add(radioButton, cc.xy(10, 19));
    sg.add(radioButton);
  }

  private void buildSettings(final JQContainer panel, CellConstraints cc) {
    panel.add(new JQSeparator(JQSeparator.VERTICAL), cc.xyh(12, 1, 20));
    JQButton colorSettings = new JQButton("Color");
    colorSettings.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        setColor(JQColorChooser.getColor(panel,
                                         coloredPushButton.getForeground()));
      }
    });
    panel.add(colorSettings, cc.xy(14, 3, "c, t"));
    JQButton fontSettings = new JQButton("Font");
    fontSettings.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        setFont(JQFontChooser.getFont(panel, coloredPushButton.getFont()));
      }
    });
    panel.add(fontSettings, cc.xy(16, 3, "c, t"));
  }

  private void setColor(Color color) {
    if (color != null) {
      coloredPushButton.setForeground(color);
      coloredToggleButton.setForeground(color);
      coloredToolButton.setForeground(color);
      coloredCheckButton.setForeground(color);
      coloredRadioButton.setForeground(color);
    }
  }

  private void setFont(Font font) {
    if (font != null) {
      coloredPushButton.setFont(font);
      coloredToggleButton.setFont(font);
      coloredToolButton.setFont(font);
      coloredCheckButton.setFont(font);
      coloredRadioButton.setFont(font);
    }
  }

  private ImageIcon createIcon(String iconName) {
    return new ImageIcon(loadResource("resources/images/buttons/" + iconName));
  }

/*^**************************************************************************^*/
/*- Main Method.                                                             -*/
/*^**************************************************************************^*/

  /**
   * Starts demo as standalone appliation.
   *
   * @param args the application arguments
   */
  public static void main(String[] args) {
    new ButtonsDemo().show();
  }

}

/*^*****************************************************************************
  File History:

 - 2007-11-21 15:36:30 Slobodan
   Initial version

*****************************************************************************^*/
