/*
 * @(#)DialogsDemo.java  0.2.0 / 2007-11-29
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.demo.qswingset;

import yu.ac.bg.etf.javaqx.qswing.JQButton;
import yu.ac.bg.etf.javaqx.qswing.JQColorChooser;
import yu.ac.bg.etf.javaqx.qswing.JQComponent;
import yu.ac.bg.etf.javaqx.qswing.JQContainer;
import yu.ac.bg.etf.javaqx.qswing.JQFileChooser;
import yu.ac.bg.etf.javaqx.qswing.JQFontChooser;
import yu.ac.bg.etf.javaqx.qswing.JQLabel;
import yu.ac.bg.etf.javaqx.qswing.JQOptionPane;
import yu.ac.bg.etf.javaqx.qswing.JQScrollPane;
import yu.ac.bg.etf.javaqx.qswing.JQSeparator;
import yu.ac.bg.etf.javaqx.qswing.events.ActionEvent;
import yu.ac.bg.etf.javaqx.qswing.events.ActionListener;
import yu.ac.bg.etf.javaqx.qswing.graphics.Color;
import yu.ac.bg.etf.javaqx.qswing.graphics.Font;
import yu.ac.bg.etf.javaqx.qswing.layouts.formlayout.CellConstraints;
import yu.ac.bg.etf.javaqx.qswing.layouts.formlayout.FormLayout;

/**
 * Demonstration of the JQDialog classes.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class DialogsDemo extends DemoModule {

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new DialogsDemo object.
   */
  public DialogsDemo() {
    super("Dialogs Demo", "Demonstration of the JQDialog classes.");
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected JQComponent buildDemoComponent() {
    FormLayout layout = new FormLayout(
              "p:g, p, 8dlu, p, 8dlu, p, 8dlu, p, 8dlu, p, p:g",
              "p, 6dlu, p, 6dlu, p, 6dlu, p, 12dlu, p," +
              "6dlu, p, 12dlu, p, 6dlu, p, 12dlu, p, 6dlu, p");
    layout.setColumnGroups(new int[][] {{2, 4, 6, 8, 10}});
    final JQContainer panel = new JQContainer(layout);
    panel.setInsets(16, 16, 16, 16);
    CellConstraints cc = new CellConstraints();

    panel.add(new JQSeparator("File Chooser"), cc.xyw(2, 1, 9));

    final PanelLabel openFileNameLabel = new PanelLabel();
    final JQButton openFileNameButton = new JQButton("Open File");
    openFileNameButton.addActionListener(new ActionListener() {
       public void actionPerformed(ActionEvent e) {
         openFileNameLabel.setText(JQFileChooser.getOpenFileName(panel));
       }
     });
    panel.add(openFileNameButton, cc.xy(2, 3));
    panel.add(openFileNameLabel, cc.xyw(4, 3, 7));

    final PanelLabel saveFileNameLabel = new PanelLabel();
    final JQButton saveFileNameButton = new JQButton("Save File");
    panel.add(saveFileNameButton, cc.xy(2, 5));
    panel.add(saveFileNameLabel, cc.xyw(4, 5, 7));
    saveFileNameButton.addActionListener(new ActionListener() {
       public void actionPerformed(ActionEvent e) {
         saveFileNameLabel.setText(JQFileChooser.getSaveFileName(panel));
       }
     });

     final PanelLabel selectDirectoryLabel = new PanelLabel();
     final JQButton selectDirectoryButton = new JQButton("Select Directory");
     panel.add(selectDirectoryButton, cc.xy(2, 7));
     panel.add(selectDirectoryLabel, cc.xyw(4, 7, 7));
     selectDirectoryButton.addActionListener(new ActionListener() {
        public void actionPerformed(ActionEvent e) {
          selectDirectoryLabel.setText(
              JQFileChooser.getExistingDirectoryName(panel,
                                                     "Select Directory", null));
        }
      });

    panel.add(new JQSeparator("Color Chooser"), cc.xyw(2, 9, 9));

    final PanelLabel colorLabel = new PanelLabel();
    final JQButton colorButton = new JQButton("Select Color");
    panel.add(colorButton, cc.xy(2, 11));
    panel.add(colorLabel, cc.xyw(4, 11, 7));
    colorButton.addActionListener(new ActionListener() {
       public void actionPerformed(ActionEvent e) {
         colorLabel.setBackground(JQColorChooser.getColor(panel,
                                                   colorLabel.getBackground()));
       }
     });

     panel.add(new JQSeparator("Font Chooser"), cc.xyw(2, 13, 9));

     final PanelLabel fontLabel = new PanelLabel(
                                "The quick brown fox jumps over the lazy dog");
     final JQButton fontButton = new JQButton("Select Font");
     panel.add(fontButton, cc.xy(2, 15));
     panel.add(fontLabel, cc.xyw(4, 15, 7));
     fontButton.addActionListener(new ActionListener() {
        public void actionPerformed(ActionEvent e) {
          fontLabel.setFont(JQFontChooser.getFont(panel, fontLabel.getFont()));
        }
      });

    panel.add(new JQSeparator("Message Box"), cc.xyw(2, 17, 9));

    final String title = "QSwingSet";
    final JQButton aboutButton = new JQButton("About Message");
    panel.add(aboutButton, cc.xy(2, 19));
    aboutButton.addActionListener(new ActionListener() {
       public void actionPerformed(ActionEvent e) {
         JQOptionPane.showAboutMessage(panel, "About Message.", title);
       }
     });
     final JQButton infoButton = new JQButton("Info Message");
     panel.add(infoButton, cc.xy(4, 19));
     infoButton.addActionListener(new ActionListener() {
        public void actionPerformed(ActionEvent e) {
          JQOptionPane.showInformationMessage(panel, "Info Message.", title);
        }
      });
      final JQButton warningButton = new JQButton("Warning Message");
      panel.add(warningButton, cc.xy(6, 19));
      warningButton.addActionListener(new ActionListener() {
         public void actionPerformed(ActionEvent e) {
           JQOptionPane.showWarningMessage(panel, "Warning Message!", title,
                                           JQOptionPane.SAVE_OPTION |
                                           JQOptionPane.DISCARD_OPTION);
         }
       });
       final JQButton questionButton = new JQButton("Question Message");
       panel.add(questionButton, cc.xy(8, 19));
       questionButton.addActionListener(new ActionListener() {
          public void actionPerformed(ActionEvent e) {
            JQOptionPane.showQuestionMessage(panel, "Question Message?", title,
                                             JQOptionPane.
                                                         YES_NO_CANCEL_OPTIONS);
          }
        });
        final JQButton errorButton = new JQButton("Error Message");
        panel.add(errorButton, cc.xy(10, 19));
        errorButton.addActionListener(new ActionListener() {
           public void actionPerformed(ActionEvent e) {
             JQOptionPane.showErrorMessage(panel, "Error Message!", title,
                                           JQOptionPane.
                                                    ABORT_RETRY_IGNORE_OPTIONS);
           }
         });

    return new JQScrollPane(panel);
  }

/*^**************************************************************************^*/
/*- Inner Class.                                                             -*/
/*^**************************************************************************^*/

  /**
   * Panel Label.
   */
  static class PanelLabel extends JQLabel {
    public PanelLabel() {
      this(" ");
    }
    public PanelLabel(String text) {
      super(text);
      setBorderType(JQLabel.BORDER_TYPE_STYLED);
      setBorderStyle(JQLabel.BORDER_STYLE_SUNKEN);
    }
    public void setText(String text) {
      if (text == null) {
        super.setText(" ");
      } else {
        super.setText(text);
      }
    }
    public void setBackground(Color background) {
      if (background != null) {
        super.setBackground(background);
      }
    }
    public void setFont(Font font) {
      if (font != null) {
        super.setFont(font);
      }
    }
  }

/*^**************************************************************************^*/
/*- Main Method.                                                             -*/
/*^**************************************************************************^*/

  /**
   * Starts demo as standalone appliation.
   *
   * @param args the application arguments
   */
  public static void main(String[] args) {
    new DialogsDemo().show();
  }

}

/*^*****************************************************************************
  File History:

 - 2007-11-29 21:07:31 Slobodan
   Initial version

*****************************************************************************^*/
