/*
 * @(#)InternalFramesDemo.java  0.2.0 / 2007-11-20
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.demo.qswingset;

import yu.ac.bg.etf.javaqx.qswing.AbstractAction;
import yu.ac.bg.etf.javaqx.qswing.ImageIcon;
import yu.ac.bg.etf.javaqx.qswing.JQButton;
import yu.ac.bg.etf.javaqx.qswing.JQCheckBox;
import yu.ac.bg.etf.javaqx.qswing.JQComponent;
import yu.ac.bg.etf.javaqx.qswing.JQDesktopPane;
import yu.ac.bg.etf.javaqx.qswing.JQInternalFrame;
import yu.ac.bg.etf.javaqx.qswing.JQLabel;
import yu.ac.bg.etf.javaqx.qswing.JQScrollPane;
import yu.ac.bg.etf.javaqx.qswing.JQTextField;
import yu.ac.bg.etf.javaqx.qswing.events.ActionEvent;
import yu.ac.bg.etf.javaqx.qswing.graphics.Color;
import yu.ac.bg.etf.javaqx.qswing.layouts.formlayout.CellConstraints;
import yu.ac.bg.etf.javaqx.qswing.layouts.formlayout.FormLayout;

/**
 * Demonstration of the JQInternalFrame class.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class InternalFramesDemo extends DemoModule {

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new InternalFramesDemo object.
   */
  public InternalFramesDemo() {
    super("InternalFrame Demo", "Demonstration of the JQInternalFrame class.");
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected JQComponent buildDemoComponent() {
    return new InternalFramesPane();
  }

/*^**************************************************************************^*/
/*- Inner Classes.                                                           -*/
/*^**************************************************************************^*/

  /**
   * InternalFrames Pane.
   */
  class InternalFramesPane extends JQDesktopPane {

    private int frameNumber;
    private JQCheckBox frameResizeable;
    private JQCheckBox frameCloseable;
    private JQCheckBox frameIconifiable;
    private JQCheckBox frameMaximizeable;
    private JQTextField frameTitle;

    public InternalFramesPane() {
      JQInternalFrame frameGenerator = add(buildFrameGenerator());
      frameGenerator.pack();
      frameGenerator.setLocation(375, 20);
      JQInternalFrame frame0 = add(createFrame("fish.png"));
      frame0.setBounds(15, 260, 320, 230);
      addFrame("fish.png");
      addFrame("sun.png");
      addFrame("cab.png");
      addFrame("moon.png");
      setSelectedComponent(frameGenerator);
    }

    // private methods

    private void addFrame(String imageName) {
      JQInternalFrame frame = createFrame(imageName);
      int frameBorder = JQInternalFrame.BORDER_TITLE;
      if (frameCloseable.isSelected()) {
        frameBorder = frameBorder | JQInternalFrame.BORDER_SYSTEM_MENU;
      }
      if (frameIconifiable.isSelected()) {
        frameBorder = frameBorder | JQInternalFrame.BORDER_MINIMIZE_BUTTON;
      }
      if (frameMaximizeable.isSelected()) {
        frameBorder = frameBorder | JQInternalFrame.BORDER_MAXIMIZE_BUTTON;
      }
      frame.setBorderDecoration(frameBorder);
      int framePosition = frameNumber - 1;
      frame.setBounds(20 * (framePosition % 10), 20 * (framePosition % 10), 225,
                      150);
      if (!frameResizeable.isSelected()) {
        frame.setFixedSize(frame.getSize());
      }
      add(frame);
    }

    private JQInternalFrame buildFrameGenerator() {
      frameResizeable = new JQCheckBox("Resizeable");
      frameResizeable.setSelected(true);
      frameCloseable = new JQCheckBox("Closeable");
      frameCloseable.setSelected(true);
      frameIconifiable = new JQCheckBox("Iconifiable");
      frameIconifiable.setSelected(true);
      frameMaximizeable = new JQCheckBox("Maximizeable");
      frameMaximizeable.setSelected(true);
      frameTitle = new JQTextField("Frame");
      FormLayout layout = new FormLayout(
                          "p:g, max(60dlu;p), 14dlu, 9dlu, max(72dlu;p), p:g",
                          "p, 9dlu, p, 9dlu, p, 4dlu, p, 8dlu, p");
      JQInternalFrame jqif = new JQInternalFrame(layout,
                                                 "Internal Frame Generator");
      jqif.setBorderDecoration(JQInternalFrame.BORDER_TITLE);
      jqif.setInsets(10, 10, 10, 10);
      CellConstraints cc = new CellConstraints();
      jqif.add(new JQButton(new GeneratorAction("fish")), cc.xyw(2, 1, 2));
      jqif.add(new JQButton(new GeneratorAction("moon")), cc.xy(5, 1));
      jqif.add(new JQButton(new GeneratorAction("sun")), cc.xyw(2, 3, 2));
      jqif.add(new JQButton(new GeneratorAction("cab")), cc.xy(5, 3));
      jqif.add(frameResizeable, cc.xyw(2, 5, 2));
      jqif.add(frameCloseable, cc.xy(5, 5));
      jqif.add(frameIconifiable, cc.xyw(2, 7, 2));
      jqif.add(frameMaximizeable, cc.xy(5, 7));
      jqif.add(new JQLabel("Frame title:"), cc.xy(2, 9));
      jqif.add(frameTitle, cc.xyw(3, 9, 3));
      return jqif;
    }

    private JQInternalFrame createFrame(String imageName) {
      String title = frameTitle.getText();
      if ("Frame".equals(title)) {
        title = "Frame " + frameNumber;
      }
      ++frameNumber;
      JQInternalFrame jqif = new JQInternalFrame(title);
      String imagePath = "resources/images/image_club/misc/" + imageName;
      ImageIcon image = new ImageIcon(loadResource(imagePath));
      JQLabel imageLabel = new JQLabel(image);
      imageLabel.setBackground(Color.WHITE);
      JQScrollPane imageScrollPane = new JQScrollPane(imageLabel);
      jqif.add(imageScrollPane);
      return jqif;
    }

    /**
     * Generator Action Class.
     */
    private class GeneratorAction extends AbstractAction {
      private final String imageName;
      GeneratorAction(String imageName) {
        this.imageName = imageName + ".png";
        String iconName = "resources/images/image_club/misc/" + imageName +
                          "_small.png";
        setSmallIcon(new ImageIcon(loadResource(iconName)));
      }
      public void actionPerformed(ActionEvent e) {
        addFrame(imageName);
      }
    }

  }

/*^**************************************************************************^*/
/*- Main Method.                                                             -*/
/*^**************************************************************************^*/

  /**
   * Starts demo as standalone application.
   *
   * @param args the application arguments
   */
  public static void main(String[] args) {
    new InternalFramesDemo().show();
  }

}

/*^*****************************************************************************
  File History:

 - 2007-11-20 21:09:06 Slobodan
   Initial version

*****************************************************************************^*/
