/*
 * @(#)QSwingSet.java  0.2.0 / 2007-10-10
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.demo.qswingset;

import java.util.ArrayList;
import java.util.HashMap;

import yu.ac.bg.etf.javaqx.qswing.JQCheckBoxMenuItem;
import yu.ac.bg.etf.javaqx.qswing.JQContainer;
import yu.ac.bg.etf.javaqx.qswing.JQFrame;
import yu.ac.bg.etf.javaqx.qswing.JQMenu;
import yu.ac.bg.etf.javaqx.qswing.JQMenuBar;
import yu.ac.bg.etf.javaqx.qswing.JQMenuItem;
import yu.ac.bg.etf.javaqx.qswing.JQStatusBar;
import yu.ac.bg.etf.javaqx.qswing.JQTabbedPane;
import yu.ac.bg.etf.javaqx.qswing.JQToggleToolButton;
import yu.ac.bg.etf.javaqx.qswing.JQToolBar;
import yu.ac.bg.etf.javaqx.qswing.QSwing;
import yu.ac.bg.etf.javaqx.qswing.SplashScreen;
import yu.ac.bg.etf.javaqx.qswing.events.ActionEvent;
import yu.ac.bg.etf.javaqx.qswing.events.ActionListener;
import yu.ac.bg.etf.javaqx.qswing.layouts.BorderLayout;
import yu.ac.bg.etf.javaqx.qswingx.JQStyleMenu;
import yu.ac.bg.etf.javaqx.qswingx.JQThemeMenu;
import yu.ac.bg.etf.javaqx.qswingx.actions.AboutQtAction;
import yu.ac.bg.etf.javaqx.qswingx.text.code.CodeViewer;
import yu.ac.bg.etf.javaqx.qswingx.text.code.JavaDocument;

/**
 * QSwingSet.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
final class QSwingSet extends JQFrame {

/*^**************************************************************************^*/
/*- Private Fields.                                                          -*/
/*^**************************************************************************^*/

  private JQToolBar toolBar;
  private JQTabbedPane tabbedPane;
  private JQStatusBar statusBar;
  private ArrayList demos;
  private DemoModule currentDemo;
  private JQContainer demoPanel;
  private CodeViewer sourceCode;
  private final HashMap sourceCodeCache;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new QSwingSet object.
   */
  public QSwingSet() {
    super("QSwingSet"); //$NON-NLS-1$
    sourceCodeCache = new HashMap();
    setDefaultCloseOperation(QUIT_ON_CLOSE);
    setSize(720, 640);
    setLocationRelativeTo(null);
    buildMenuBar();
    buildToolBar();
    buildContent();
    buildStatusBar();
    addDemos();
    ((JQToggleToolButton)toolBar.getComponent(0)).setSelected(true);
    setCurrentDemo(0);
    setDefaultResourceBundleName();
  }

/*^**************************************************************************^*/
/*- Pakcage-Private Methods.                                                 -*/
/*^**************************************************************************^*/

  void performToolBar() {
    toolBar.setVisible(!toolBar.isVisible());
  }

  void performStatusBar() {
    statusBar.setVisible(!statusBar.isVisible());
  }

  void setCurrentDemo(int index) {
    DemoModule demo = (DemoModule)demos.get(index);
    if (currentDemo != demo) { // NOPMD
      tabbedPane.setTitleAt(0, demo.getName());
      if (currentDemo != null) {
        demoPanel.remove(currentDemo.getComponent());
      }
      demoPanel.add(demo.getComponent());
      JavaDocument javaDocument = (JavaDocument)sourceCodeCache.get(demo);
      if (javaDocument == null) {
        javaDocument = new JavaDocument(demo.getSourceCode());
      }
      sourceCode.setDocument(javaDocument);
      currentDemo = demo;
    }
  }

/*^**************************************************************************^*/
/*- Private Methods.                                                         -*/
/*^**************************************************************************^*/

  private void buildMenuBar() {
    JQMenuBar menuBar = new JQMenuBar();
    JQMenu menu = menuBar.add(new JQMenu("&File")); //$NON-NLS-1$
    JQMenuItem menuItem = menu.add(new JQMenuItem(
                                               "About Q&Swing")); //$NON-NLS-1$
    menuItem.setStatusTipText(
                           "Displays information about QSwing."); //$NON-NLS-1$
    menuItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        QSwing.about();
      }
    });
    menu.add(new JQMenuItem(new AboutQtAction()));
    menu.addSeparator();
    menuItem = menu.add(new JQMenuItem("&Open")); //$NON-NLS-1$
    menuItem.setStatusTipText("Disabled menu item."); //$NON-NLS-1$
    menuItem.setEnabled(false);
    menuItem = menu.add(new JQMenuItem("&Save")); //$NON-NLS-1$
    menuItem.setEnabled(false);
    menuItem = menu.add(new JQMenuItem("Save &As...")); //$NON-NLS-1$
    menuItem.setEnabled(false);
    menu.addSeparator();
    menuItem = menu.add(new JQMenuItem("E&xit")); //$NON-NLS-1$
    menuItem.setStatusTipText("Exits demonstration."); //$NON-NLS-1$
    menuItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        QSwing.stopEventLoop();
      }
    });
    menu = menuBar.add(new JQMenu("&View")); //$NON-NLS-1$
    JQCheckBoxMenuItem checkBoxMenuItem =
                             new JQCheckBoxMenuItem("&Tool Bar"); //$NON-NLS-1$
    checkBoxMenuItem.setChecked(true);
    checkBoxMenuItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        performToolBar();
      }
    });
    menu.add(checkBoxMenuItem);
    checkBoxMenuItem = new JQCheckBoxMenuItem("&Status Bar"); //$NON-NLS-1$
    checkBoxMenuItem.setChecked(true);
    checkBoxMenuItem.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        performStatusBar();
      }
    });
    menu.add(checkBoxMenuItem);
    menuBar.add(new JQStyleMenu());
    menuBar.add(new JQThemeMenu());
    setMenuBar(menuBar);
  }

  private void buildToolBar() {
    toolBar = addToolBar(new JQToolBar("Demos")); //$NON-NLS-1$
  }

  private void buildContent() {
    tabbedPane = new JQTabbedPane();
    demoPanel = new JQContainer(new BorderLayout());
    demoPanel.setInsets(1, 1, 1, 1);
    sourceCode = new CodeViewer();
    tabbedPane.addTab("Demo", demoPanel); //$NON-NLS-1$
    tabbedPane.addTab("Source Code", sourceCode); //$NON-NLS-1$
    add(tabbedPane);
  }

  private void buildStatusBar() {
    statusBar = setStatusBar(new JQStatusBar());
  }

  private void addDemo(DemoModule demo) {
    demos.add(demo);
    JQToggleToolButton demoSelector = new JQToggleToolButton(demo.getIcon());
    demoSelector.setToolTipText(demo.getName());
    demoSelector.setStatusTipText(demo.getDescription());
    demoSelector.addActionListener(new DemoSelectAction(demos.size() - 1));
    toolBar.add(demoSelector);
  }

  private void addDemos() {
    demos = new ArrayList(17);
    SplashScreen.update("Adding InternalFrames Demo"); //$NON-NLS-1$
    addDemo(new InternalFramesDemo());
    SplashScreen.update("Adding Buttons Demo"); //$NON-NLS-1$
    addDemo(new ButtonsDemo());
    SplashScreen.update("Adding Dialogs Demo"); //$NON-NLS-1$
    addDemo(new DialogsDemo());
    SplashScreen.update("Adding ProgressBar Demo"); //$NON-NLS-1$
    addDemo(new ProgressBarDemo());
    SplashScreen.update("Adding ScrollPane Demo"); //$NON-NLS-1$
    addDemo(new ScrollPaneDemo());
    SplashScreen.update("Adding Slider Demo"); //$NON-NLS-1$
    addDemo(new SliderDemo());
    SplashScreen.update("Adding SplitPane Demo"); //$NON-NLS-1$
    addDemo(new SplitPaneDemo());
    SplashScreen.update("Adding TabbedPane Demo"); //$NON-NLS-1$
    addDemo(new TabbedPaneDemo());
    SplashScreen.update("Adding ToolTip Demo"); //$NON-NLS-1$
    addDemo(new ToolTipDemo());
    SplashScreen.update("Adding Tree Demo"); //$NON-NLS-1$
    addDemo(new TreeDemo());
  }

/*^**************************************************************************^*/
/*- Inner Classes.                                                           -*/
/*^**************************************************************************^*/

  /**
   * Demo Select Action.
   */
  private final class DemoSelectAction implements ActionListener {
    private final int demoIndex;
    DemoSelectAction(int demoIndex) {
      this.demoIndex = demoIndex;
    }
    public void actionPerformed(ActionEvent e) {
      setCurrentDemo(demoIndex);
    }
  }

}

/*^*****************************************************************************
  File History:

 - 2007-10-10 23:32:46 Slobodan
   Initial version

*****************************************************************************^*/
