/*
 * @(#)SliderDemo.java  0.2.0 / 2007-11-28
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.demo.qswingset;

import yu.ac.bg.etf.javaqx.qswing.JQComponent;
import yu.ac.bg.etf.javaqx.qswing.JQContainer;
import yu.ac.bg.etf.javaqx.qswing.JQLabel;
import yu.ac.bg.etf.javaqx.qswing.JQScrollPane;
import yu.ac.bg.etf.javaqx.qswing.JQSeparator;
import yu.ac.bg.etf.javaqx.qswing.JQSlider;
import yu.ac.bg.etf.javaqx.qswing.events.ChangeEvent;
import yu.ac.bg.etf.javaqx.qswing.events.ChangeListener;
import yu.ac.bg.etf.javaqx.qswing.layouts.formlayout.CellConstraints;
import yu.ac.bg.etf.javaqx.qswing.layouts.formlayout.FormLayout;

/**
 * Demonstration of the JQSlider class.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class SliderDemo extends DemoModule {

/*^**************************************************************************^*/
/*- Private Field.                                                           -*/
/*^**************************************************************************^*/

  private JQLabel sliderValue;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new SliderDemo object.
   */
  public SliderDemo() {
    super("Slider Demo", "Demonstration of the JQSlider class.");
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected JQComponent buildDemoComponent() {
    FormLayout layout = new FormLayout(
                  "200dlu, 20dlu, 4dlu, p, 8dlu, p, 8dlu, p",
                  "p, 6dlu, p, 12dlu, p, 6dlu, p, 12dlu, p, 6dlu, p, 24dlu, p");
    JQContainer panel = new JQContainer(layout);
    panel.setInsets(16, 16, 16, 16);
    SliderListener sliderListener = new SliderListener();
    CellConstraints cc = new CellConstraints();

    panel.add(new JQSeparator("Horizontal"), cc.xy(1, 1));
    JQSlider slider = new JQSlider();
    slider.addChangeListener(sliderListener);
    panel.add(slider, cc.xy(1, 3));

    panel.add(new JQSeparator("Disabled"), cc.xy(1, 5));
    slider = new JQSlider();
    slider.setEnabled(false);
    panel.add(slider, cc.xy(1, 7));

    panel.add(new JQSeparator("Ticks"), cc.xy(1, 9));
    slider = new JQSlider();
    slider.addChangeListener(sliderListener);
    slider.setPaintTicks(true);
    panel.add(slider, cc.xy(1, 11));

    panel.add(new JQSeparator("Vertical"), cc.xy(4, 1));
    slider = new JQSlider(JQSlider.VERTICAL);
    slider.addChangeListener(sliderListener);
    panel.add(slider, cc.xyh(4, 3, 9, "c, f"));

    panel.add(new JQSeparator("Disabled"), cc.xy(6, 1));
    slider = new JQSlider(JQSlider.VERTICAL);
    slider.setEnabled(false);
    panel.add(slider, cc.xyh(6, 3, 9, "c, f"));

    panel.add(new JQSeparator("Ticks"), cc.xy(8, 1));
    slider = new JQSlider(JQSlider.VERTICAL);
    slider.addChangeListener(sliderListener);
    slider.setPaintTicks(true);
    panel.add(slider, cc.xyh(8, 3, 9, "c, f"));

    panel.add(new JQLabel("Slider Value:"), cc.xyw(1, 13, 2, "r, b"));
    sliderValue = new JQLabel("50");
    panel.add(sliderValue, cc.xy(4, 13, "l, b"));

    return new JQScrollPane(panel);
  }

/*^**************************************************************************^*/
/*- Inner Class.                                                             -*/
/*^**************************************************************************^*/

  /**
   * Slider Listener.
   */
  class SliderListener implements ChangeListener {
    public void stateChanged(ChangeEvent e) {
      JQSlider slider = (JQSlider)e.getSource();
      sliderValue.setText(String.valueOf(slider.getValue()));
    }
  }


/*^**************************************************************************^*/
/*- Main Method.                                                             -*/
/*^**************************************************************************^*/

  /**
   * Starts demo as standalone appliation.
   *
   * @param args the application arguments
   */
  public static void main(String[] args) {
    new SliderDemo().show();
  }

}

/*^*****************************************************************************
  File History:

 - 2007-11-28 21:10:37 Slobodan
   Initial version

*****************************************************************************^*/
