/*
 * @(#)TabbedPaneDemo.java  0.2.0 / 2007-11-28
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.demo.qswingset;

import yu.ac.bg.etf.javaqx.qswing.ImageIcon;
import yu.ac.bg.etf.javaqx.qswing.JQComponent;
import yu.ac.bg.etf.javaqx.qswing.JQContainer;
import yu.ac.bg.etf.javaqx.qswing.JQLabel;
import yu.ac.bg.etf.javaqx.qswing.JQRadioButton;
import yu.ac.bg.etf.javaqx.qswing.JQScrollPane;
import yu.ac.bg.etf.javaqx.qswing.JQTabbedPane;
import yu.ac.bg.etf.javaqx.qswing.SelectableGroup;
import yu.ac.bg.etf.javaqx.qswing.events.ActionEvent;
import yu.ac.bg.etf.javaqx.qswing.events.ActionListener;
import yu.ac.bg.etf.javaqx.qswing.layouts.formlayout.CellConstraints;
import yu.ac.bg.etf.javaqx.qswing.layouts.formlayout.FormLayout;

/**
 * Demonstration of the JQTabbedPane class.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class TabbedPaneDemo extends DemoModule {

/*^**************************************************************************^*/
/*- Private Fields.                                                          -*/
/*^**************************************************************************^*/

  private JQTabbedPane tabPane;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new TabbedPaneDemo object.
   */
  public TabbedPaneDemo() {
    super("TabbedPane Demo", "Demonstration of the JQTabbedPane class.");
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected JQComponent buildDemoComponent() {
    FormLayout layout = new FormLayout(
              "p:g, 20dlu, r:p, 6dlu, p, 4dlu, p, 4dlu, p, 4dlu, p, 20dlu, p:g",
              "p, 24dlu, f:220dlu");
    JQContainer panel = new JQContainer(layout);
    panel.setInsets(16, 16, 16, 16);
    CellConstraints cc = new CellConstraints();

    panel.add(new JQLabel("Tab Placement:"), cc.xy(3, 1));
    RadioButtonActionListener actionListener = new RadioButtonActionListener();
    SelectableGroup sg = new SelectableGroup();
    JQRadioButton radioButton = new JQRadioButton("Top");
    radioButton.addActionListener(actionListener);
    radioButton.setSelected(true);
    sg.add(radioButton);
    panel.add(radioButton, cc.xy(5, 1));
    radioButton = new JQRadioButton("Left");
    radioButton.addActionListener(actionListener);
    sg.add(radioButton);
    panel.add(radioButton, cc.xy(7, 1));
    radioButton = new JQRadioButton("Bottom");
    radioButton.addActionListener(actionListener);
    sg.add(radioButton);
    panel.add(radioButton, cc.xy(9, 1));
    radioButton = new JQRadioButton("Right");
    radioButton.addActionListener(actionListener);
    sg.add(radioButton);
    panel.add(radioButton, cc.xy(11, 1));

    tabPane = new JQTabbedPane();
    JQLabel enabledTab = new JQLabel("Enabled Tab");
    enabledTab.setHorizontalAlignment(JQLabel.CENTER);
    tabPane.addTab("Enabled", enabledTab);
    tabPane.addTab("Disabled", new JQLabel("Tab 2"));
    tabPane.setEnabledAt(1, false);
    ImageIcon icon = new ImageIcon(loadResource(
                               "resources/images/tabbedpane/GreenTeaCup.png"));
    JQLabel iconTab = new JQLabel("Tab with Icon and ToolTip");
    iconTab.setHorizontalAlignment(JQLabel.CENTER);
    tabPane.addTab("Icon", icon, iconTab, "Icon");
        tabPane.addTab("Disabled Icon", icon, new JQLabel("Icon"));
    tabPane.setEnabledAt(3, false);
    panel.add(tabPane, cc.xyw(2, 3, 11));

    return new JQScrollPane(panel);
  }

/*^**************************************************************************^*/
/*- Inner Class.                                                             -*/
/*^**************************************************************************^*/

  /**
   * RadioButton ActionListener.
   */
  class RadioButtonActionListener implements ActionListener {
    public void actionPerformed(ActionEvent e) {
      String actionCommand = e.getActionCommand();
      if ("Top".equals(actionCommand)) {
        tabPane.setTabPlacement(JQTabbedPane.TOP);
      } else if ("Left".equals(actionCommand)) {
        tabPane.setTabPlacement(JQTabbedPane.LEFT);
      } else if ("Bottom".equals(actionCommand)) {
        tabPane.setTabPlacement(JQTabbedPane.BOTTOM);
      } else if ("Right".equals(actionCommand)) {
        tabPane.setTabPlacement(JQTabbedPane.RIGHT);
      }
    }
  }

/*^**************************************************************************^*/
/*- Main Method.                                                             -*/
/*^**************************************************************************^*/

  /**
   * Starts demo as standalone appliation.
   *
   * @param args the application arguments
   */
  public static void main(String[] args) {
    new TabbedPaneDemo().show();
  }

}

/*^*****************************************************************************
  File History:

 - 2007-11-28 22:50:15 Slobodan
   Initial version

*****************************************************************************^*/
