/*
 * @(#)Example7Threads.java  0.2.0 / 2007-09-19
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.examples;

import java.util.Random;

import yu.ac.bg.etf.javaqx.qswing.JQButton;
import yu.ac.bg.etf.javaqx.qswing.JQContainer;
import yu.ac.bg.etf.javaqx.qswing.JQProgressBar;
import yu.ac.bg.etf.javaqx.qswing.QSwing;
import yu.ac.bg.etf.javaqx.qswing.events.ActionEvent;
import yu.ac.bg.etf.javaqx.qswing.events.ActionListener;

/**
 * Threads Example.
 */
public class Example9Threads extends JQContainer {

  final JQProgressBar progressBar1;
  final JQProgressBar progressBar2;
  final JQButton button;
  final RandomThread randomThread11;
  final RandomThread randomThread12;
  final RandomThread randomThread21;
  final RandomThread randomThread22;

  /**
   * GUI Building.
   */
  public Example9Threads() {
    super(null);
    setName("Threads");
    setFixedSize(300, 100);
    progressBar1 = new JQProgressBar();
    progressBar1.setValue(50);
    add(progressBar1);
    progressBar1.setBounds(10, 10, 274, 20);
    progressBar2 = new JQProgressBar();
    progressBar2.setValue(50);
    add(progressBar2);
    progressBar2.setBounds(10, 40, 274, 20);
    button = new JQButton("Pause");
    add(button);
    button.setBounds(120, 70, 60, 25);
    button.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        if (randomThread11.isWorking()) {
          randomThread11.pauseTimer();
          randomThread12.pauseTimer();
          randomThread21.pauseTimer();
          randomThread22.pauseTimer();
          button.setText("Resume");
        } else {
          randomThread11.resumeTimer();
          randomThread12.resumeTimer();
          randomThread21.resumeTimer();
          randomThread22.resumeTimer();
          button.setText("Pause");
        }
      }
    });
    randomThread11 = new RandomThread(progressBar1);
    randomThread12 = new RandomThread(progressBar1);
    randomThread21 = new RandomThread(progressBar2);
    randomThread22 = new RandomThread(progressBar2);
  }

  /**
   * Non-GUI Thread.
   */
  static class RandomThread extends Thread {
    private static final Random random = new Random();
    private boolean pause;
    private final JQProgressBar progressBar;
    public RandomThread(JQProgressBar progressBar) {
      this.progressBar = progressBar;
      setDaemon(true);
      start();
    }
    public synchronized boolean isWorking() {
      return !pause;
    }
    public synchronized void pauseTimer() {
      pause = true;
      notifyAll();
    }
    public synchronized void resumeTimer() {
      pause = false;
      notifyAll();
    }
    public void run() {
      try {
        while (true) {
          sleep(500 + random.nextInt(1000));
          synchronized (this) {
            while (pause) {
              wait();
            }
          }
          int value = 50 + (int)(40 * random.nextGaussian());
          progressBar.setValue(value); // <-- regular call from non-GUI thread
        }
      } catch (InterruptedException e) {
      }
    }
  }

  public static void main(String[] args) {
    Example9Threads threadsExample = new Example9Threads();
    threadsExample.setVisible(true);
    QSwing.startEventLoop(true);
  }

}

/*^*****************************************************************************
  File History:

 - 2007-09-19 15:04:46 Slobodan
   Initial version

*****************************************************************************^*/
