/*
 * @(#)LoggingAdapter.java  0.2.0 / 2007-02-12
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.logging;

/**
 * Logging API adapter.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public interface LoggingAdapter {

  /**
   * Returns the name of the logging adapter.
   *
   * @return the name of the logging adapter
   */
  public String getName();

  /**
   * Returns <tt>true</tt> if logging on the specified level is enabled.
   *
   * @param level the logging level
   *
   * @return <tt>true</tt> if logging on the specified level is enabled
   */
  public boolean isLoggable(int level);

  /**
   * Returns logging level.
   *
   * @return level the logging level
   */
  public int getLevel();

  /**
   * Sets logging level.
   *
   * @param level the logging level
   */
  public void setLevel(int level);

  /**
   * Logs a message.
   *
   * @param level the logging level
   * @param message the message
   * @param t the throwable
   */
  public void log(int level, String message, Throwable t);

  /**
   * Logs a message.
   *
   * @param level the logging level
   * @param fileName the file name
   * @param lineNumber the line number
   * @param message the message
   * @param t the throwable
   */
  public void log(int level, String fileName, int lineNumber, String message,
                  Throwable t);

}

/*^*****************************************************************************
  File History:

 - 2007-02-12 17:13:39 Slobodan
   Initial version

*****************************************************************************^*/
