/*
 * @(#)Jdk14LoggingAdapter.java  0.2.0 / 2007-02-12
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.logging.adapters;

import java.util.logging.Level;
import java.util.logging.Logger;

import yu.ac.bg.etf.javaqx.JavaQx;
import yu.ac.bg.etf.javaqx.logging.LoggingAdapter;

/**
 * Logging Adapter for Java 1.4 Logging API.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class JavaLoggingAdapter implements LoggingAdapter {

/*^**************************************************************************^*/
/*- Private Static Fields.                                                   -*/
/*^**************************************************************************^*/

  private static final int LOG_METHOD_INDEX = 2;

/*^**************************************************************************^*/
/*- Private Field.                                                           -*/
/*^**************************************************************************^*/

  private final Logger logger; // NOPMD - GC

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new Jdk14LoggingAdapter object.
   */
  public JavaLoggingAdapter() {
    logger = Logger.getLogger(JavaQx.class.getName()); // NOPMD
  }

/*^**************************************************************************^*/
/*- LoggingAdapter Interface Implementation.                                 -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public String getName() {
    return "Java Logging Adapter"; //$NON-NLS-1$
  }

  /**
   * {@inheritDoc}
   */
  public boolean isLoggable(int level) {
    return logger.isLoggable(convertLevel(level));
  }

  /**
   * {@inheritDoc}
   */
  public int getLevel() {
    return convertLevel(logger.getLevel());
  }

  /**
   * {@inheritDoc}
   */
  public void setLevel(int level) {
    logger.setLevel(convertLevel(level));
  }

  /**
   * {@inheritDoc}
   */
  public void log(int level, String message, Throwable t) {
    String className = null;
    String methodName = null;
    Throwable traceException = new Throwable(); // NOPMD - fake exception
    StackTraceElement[] stackTrace = traceException.getStackTrace();
    if ((stackTrace != null) && (stackTrace.length > LOG_METHOD_INDEX)) {
      StackTraceElement ste = stackTrace[LOG_METHOD_INDEX];
      className = ste.getClassName();
      methodName = ste.getMethodName();
    }
    logger.logp(convertLevel(level), className, methodName, message, t);
  }

  /**
   * {@inheritDoc}
   */
  public void log(int level, String fileName, int lineNumber, String message,
                  Throwable t) {
    logger.logp(convertLevel(level), fileName, String.valueOf(lineNumber),
                message, t);
  }

/*^**************************************************************************^*/
/*- Private Method.                                                          -*/
/*^**************************************************************************^*/

  private Level convertLevel(int level) {
    switch (level) {
      case yu.ac.bg.etf.javaqx.logging.Logger.LEVEL_INFO:
        return Level.INFO;
      case yu.ac.bg.etf.javaqx.logging.Logger.LEVEL_WARN:
        return Level.WARNING;
      default:
        return Level.SEVERE;
    }
  }

  private int convertLevel(Level level) {
    int l = level.intValue();
    if (l <= Level.INFO.intValue()) {
      return yu.ac.bg.etf.javaqx.logging.Logger.LEVEL_INFO;
    } else if (l <= Level.WARNING.intValue()) {
      return yu.ac.bg.etf.javaqx.logging.Logger.LEVEL_WARN;
    }
    return yu.ac.bg.etf.javaqx.logging.Logger.LEVEL_ERROR;
  }

}

/*^*****************************************************************************
  File History:

 - 2007-02-12 17:06:52 Slobodan
   Initial version

*****************************************************************************^*/
