/*
 * @(#)Log4JAdapter.java  0.2.0 / 2007-02-13
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.logging.adapters;

import org.apache.log4j.ConsoleAppender;
import org.apache.log4j.Level;
import org.apache.log4j.Logger;
import org.apache.log4j.PatternLayout;

import yu.ac.bg.etf.javaqx.JavaQx;
import yu.ac.bg.etf.javaqx.logging.LoggingAdapter;

/**
 * Logging Adapter for Log4J Logging API.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class Log4JAdapter implements LoggingAdapter { // NOPMD

/*^**************************************************************************^*/
/*- Public Static Final Field.                                               -*/
/*^**************************************************************************^*/

  /**
   * Default conversion pattern.
   */
  public static final String DEFAULT_PATTERN;

/*^**************************************************************************^*/
/*- Static Initialization.                                                   -*/
/*^**************************************************************************^*/

  static {
    DEFAULT_PATTERN = "[%d{yyyy-MM-dd HH:mm:ss}][%p][%l] %m%n"; //$NON-NLS-1$
    if (!Logger.getRootLogger().getAllAppenders().hasMoreElements()) {
      Logger logger = Logger.getLogger(JavaQx.class.getName());
      if (!logger.getAllAppenders().hasMoreElements()) {
        PatternLayout patternLayout = new PatternLayout(DEFAULT_PATTERN);
        logger.addAppender(new ConsoleAppender(patternLayout,
                                               ConsoleAppender.SYSTEM_ERR));
      }
    }
  }

/*^**************************************************************************^*/
/*- Private Static Final Fields.                                             -*/
/*^**************************************************************************^*/

  private static final String FQCN =
                            yu.ac.bg.etf.javaqx.logging.Logger.class.getName();
  private static final String NATIVE_FQCN = Log4JAdapter.class.getName();

/*^**************************************************************************^*/
/*- Private Field.                                                           -*/
/*^**************************************************************************^*/

  private final Logger logger; // NOPMD - GC

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new Log4JAdapter object.
   */
  public Log4JAdapter() {
    logger = Logger.getLogger(JavaQx.class.getName()); // NOPMD
  }

/*^**************************************************************************^*/
/*- LoggingAdapter Interface Implementation.                                 -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public String getName() {
    return "Log4J Logging Adapter"; //$NON-NLS-1$
  }

  /**
   * {@inheritDoc}
   */
  public boolean isLoggable(int level) {
    return logger.isEnabledFor(convertLevel(level));
  }

  /**
   * {@inheritDoc}
   */
  public int getLevel() {
    return convertLevel(logger.getLevel());
  }

  /**
   * {@inheritDoc}
   */
  public void setLevel(int level) {
    logger.setLevel(convertLevel(level));
  }

  /**
   * {@inheritDoc}
   */
  public void log(int level, String message, Throwable t) {
    logger.log(FQCN, convertLevel(level), message, t);
  }

  /**
   * {@inheritDoc}
   */
  public void log(int level, String fileName, int lineNumber, String message,
                  Throwable t) {
    String nativeMessage = "[" + fileName + ":" + //$NON-NLS-1$ //$NON-NLS-2$
                           lineNumber + "] " + message; //$NON-NLS-1$
    logger.log(NATIVE_FQCN, convertLevel(level), nativeMessage, t);
  }

/*^**************************************************************************^*/
/*- Private Method.                                                          -*/
/*^**************************************************************************^*/

  private Level convertLevel(int level) {
    switch (level) {
      case yu.ac.bg.etf.javaqx.logging.Logger.LEVEL_INFO:
        return Level.INFO;
      case yu.ac.bg.etf.javaqx.logging.Logger.LEVEL_WARN:
        return Level.WARN;
      default:
        return Level.ERROR;
    }
  }

  private int convertLevel(Level level) {
    int l = level.toInt();
    if (l <= Level.INFO.toInt()) {
      return yu.ac.bg.etf.javaqx.logging.Logger.LEVEL_INFO;
    } else if (l <= Level.WARN.toInt()) {
      return yu.ac.bg.etf.javaqx.logging.Logger.LEVEL_WARN;
    }
    return yu.ac.bg.etf.javaqx.logging.Logger.LEVEL_ERROR;
  }

}

/*^*****************************************************************************
  File History:

 - 2007-02-13 00:44:16 Slobodan
   Initial version

*****************************************************************************^*/
