/*
 * @(#)BasicLogger.java  0.2.0 / 2007-02-12
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.logging.simple;

import java.io.OutputStream;
import java.io.PrintStream;

import yu.ac.bg.etf.javaqx.logging.Logger;
import yu.ac.bg.etf.javaqx.logging.LoggingAdapter;

/**
 * Very basic logging adapter implementation.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class BasicLogger implements LoggingAdapter {

/*^**************************************************************************^*/
/*- Private Fields.                                                          -*/
/*^**************************************************************************^*/

  private final PrintStream out;

/*^**************************************************************************^*/
/*- Public Constructors.                                                     -*/
/*^**************************************************************************^*/

  /**
   * Constructs new BasicLoggingAdapter object.
   */
  public BasicLogger() {
    this(System.err);
  }

  /**
   * Constructs new BasicLoggingAdapter object.
   *
   * @param printStream the print stream
   */
  public BasicLogger(PrintStream printStream) {
    if (printStream == null) {
      throw new IllegalArgumentException("Null print stream"); //$NON-NLS-1$
    }
    out = printStream;
  }

  /**
   * Constructs new BasicLoggingAdapter object.
   *
   * @param outputStream the output stream
   */
  public BasicLogger(OutputStream outputStream) {
    if (outputStream == null) {
      throw new IllegalArgumentException("Null output stream"); //$NON-NLS-1$
    }
    out = new PrintStream(outputStream);
  }

/*^**************************************************************************^*/
/*- LoggingAdapter Interface Implementation.                                 -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public String getName() {
    return "Basic Logger"; //$NON-NLS-1$
  }

  /**
   * {@inheritDoc}
   */
  public boolean isLoggable(int level) {
    return true;
  }

  /**
   * {@inheritDoc}
   */
  public int getLevel() {
    return Logger.LEVEL_INFO;
  }

  /**
   * {@inheritDoc}
   */
  public void setLevel(int level) {
    // empty method body
  }

  /**
   * {@inheritDoc}
   */
  public void log(int level, String message, Throwable t) {
    if (message != null) {
      out.println(message);
    }
    if (t != null) {
      t.printStackTrace(out);
    }
  }

  /**
   * {@inheritDoc}
   */
  public void log(int level, String fileName, int lineNumber, String message,
                  Throwable t) {
    log(level, message, t);
  }

}

/*^*****************************************************************************
  File History:

 - 2007-02-12 17:09:21 Slobodan
   Initial version

*****************************************************************************^*/
