/*
 * @(#)FileLogger.java  0.2.0 / 2007-02-12
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.logging.simple; // NOPMD

import java.io.FileNotFoundException;
import java.io.FileOutputStream;

/**
 * Simple file logging.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class SimpleFileLogger extends SimpleLogger {

/*^**************************************************************************^*/
/*- Public Constructors.                                                     -*/
/*^**************************************************************************^*/

  /**
   * Constructs new FileLogger object.
   *
   * @throws FileNotFoundException if the log file could not be created
   */
  public SimpleFileLogger() throws FileNotFoundException {
    this(getLogFileName());
  }

  /**
   * Constructs new FileLogger object.
   *
   * @param fileName the log file name
   *
   * @throws FileNotFoundException if the log file could not be created
   */
  public SimpleFileLogger(String fileName) throws FileNotFoundException {
    this(fileName, true);
  }

  /**
   * Constructs new FileLogger object.
   *
   * @param fileName the log file name
   * @param append whether or not to append logs to the log file
   *
   * @throws FileNotFoundException if the log file could not be created
   */
  public SimpleFileLogger(String fileName, boolean append) throws
                                                        FileNotFoundException {
    super(new FileOutputStream(fileName, append));
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public String getName() {
    return "Simple File Logger"; //$NON-NLS-1$
  }

/*^**************************************************************************^*/
/*- Private Static Method.                                                   -*/
/*^**************************************************************************^*/

  private static String getLogFileName() {
    return System.getProperty("javaqx.logging.file", //$NON-NLS-1$
                              "javaqx.log"); //$NON-NLS-1$
  }

}

/*^*****************************************************************************
  File History:

 - 2007-02-12 17:10:30 Slobodan
   Initial version

*****************************************************************************^*/
