/*
 * @(#)CommonConstants.java  0.2.0 / 2007-09-05
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.util;

import java.util.Iterator;
import java.util.NoSuchElementException;

/**
 * Common Constants.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public interface CommonConstants {

/*^**************************************************************************^*/
/*- String Constants.                                                        -*/
/*^**************************************************************************^*/

  /**
   * Empty string (the value is {@value}).
   */
  public static final String STRING_EMPTY = ""; //$NON-NLS-1$

  /**
   * Space string (the value is {@value}).
   */
  public static final String STRING_SPACE = " "; //$NON-NLS-1$

  /**
   * Dot string (the value is {@value}).
   */
  public static final String STRING_DOT = "."; //$NON-NLS-1$

  /**
   * Comma string (the value is {@value}).
   */
  public static final String STRING_COMMA = ","; //$NON-NLS-1$

  /**
   * Slash string (the value is {@value}).
   */
  public static final String STRING_SLASH = "/"; //$NON-NLS-1$

  /**
   * Tab string (the value is {@value}).
   */
  public static final String STRING_TAB = "t"; //$NON-NLS-1$

  /**
   * Default line separator string (the value is {@value}).
   */
  public static final String STRING_DEFAULT_LINE_SEPARATOR = "n"; //$NON-NLS-1$

  /**
   * Null string (the value is {@value}).
   */
  public static final String STRING_NULL = "null"; //$NON-NLS-1$

  /**
   * True string (value is "true").
   */
  public static final String STRING_TRUE = Boolean.TRUE.toString();

  /**
   * False string (value is "false").
   */
  public static final String STRING_FALSE = Boolean.FALSE.toString();

  /**
   * Text string (the value is {@value}).
   */
  public static final String STRING_TEXT = "text"; //$NON-NLS-1$

  /**
   * Text/HTML string (the value is {@value}).
   */
  public static final String STRING_TEXT_HTML = "text/html"; //$NON-NLS-1$

/*^**************************************************************************^*/
/*- Array Constants.                                                         -*/
/*^**************************************************************************^*/

  /**
   * Empty array of objects (the value is Object[0]).
   */
  public static final Object[] EMPTY_OBJECT_ARRAY = new Object[0];

  /**
   * Empty array of strings (the value is String[0]).
   */
  public static final String[] EMPTY_STRING_ARRAY = new String[0];

  /**
   * Empty array of ints (the value is int[0]).
   */
  public static final int[] EMPTY_INT_ARRAY = new int[0];

  /**
   * Empty array of bytes (the value is byte[0]).
   */
  public static final byte[] EMPTY_BYTE_ARRAY = new byte[0];

  /**
   * Empty array of floats (the value is float[0]).
   */
  public static final float[] EMPTY_FLOAT_ARRAY = new float[0];

/*^**************************************************************************^*/
/*- Constant Objects.                                                        -*/
/*^**************************************************************************^*/

  /**
   * Empty iterator.
   */
  public static final EmptyIterator EMPTY_ITERATOR = new EmptyIterator();

/*^**************************************************************************^*/
/*- Inner Class.                                                             -*/
/*^**************************************************************************^*/

  /**
   * Empty Iterator.
   */
  static final class EmptyIterator implements Iterator {
    public boolean hasNext() {
      return false;
    }
    public Object next() {
      throw new NoSuchElementException("No more elements"); //$NON-NLS-1$
    }
    public void remove() {
      throw new UnsupportedOperationException();
    }
  }

}

/*^*****************************************************************************
  File History:

 - 2007-09-05 01:19:17 Slobodan
   Initial version

*****************************************************************************^*/
