/*
 * @(#)SimpleCondition.java  0.2.0 / 2007-08-11
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.util;

/**
 * Simple Condition Synchronizer.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class SimpleCondition {

/*^**************************************************************************^*/
/*- Private Fields.                                                          -*/
/*^**************************************************************************^*/

  private final Object lock;
  private boolean signaled;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new SimpleCondition object.
   */
  public SimpleCondition() {
    lock = new Object();
  }

/*^**************************************************************************^*/
/*- Public Methods.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Returns <tt>true</tt> if the condition is signaled.
   *
   * @return <tt>true</tt> if the condition is signaled
   */
  public boolean isSignaled() {
    synchronized (lock) {
      return signaled;
    }
  }

  /**
   * Waits for condition.
   */
  public void waitFor() {
    synchronized (lock) {
      try {
        while (!signaled) {
          lock.wait();
        }
      } catch (InterruptedException ex) {
        // empty catch block
      }
    }
  }

  /**
   * Signals the condition.
   */
  public void signal() {
    synchronized (lock) {
      signaled = true;
      lock.notifyAll();
    }
  }

}

/*^*****************************************************************************
  File History:

 - 2007-08-11 11:05:49 Slobodan
   Initial version

*****************************************************************************^*/
