/*
 * @(#)NativeTestCase.java  0.2.0 / 2007-02-02
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.nunit;

import junit.framework.TestCase;

import yu.ac.bg.etf.javaqx.JavaQx;

/**
 * Native Test Case.
 *
 * @javaqx.native
 *    generate="header"
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class NativeTestCase extends TestCase {

/*^**************************************************************************^*/
/*- Static Initialization.                                                   -*/
/*^**************************************************************************^*/

  static {
    JavaQx.initialize();
    _initialize();
  }

/*^**************************************************************************^*/
/*- Pacakge-Private Field.                                                   -*/
/*^**************************************************************************^*/

  long _testObject;

/*^**************************************************************************^*/
/*- Protected Methods.                                                       -*/
/*^**************************************************************************^*/

  /**
   * Fails native test.
   *
   * @param condition the condition
   * @param fileName the file name
   * @param lineNumber the line number
   */
  protected void failCondition(String condition, String fileName,
                               int lineNumber) {
    fail(formatMessage(condition, fileName, lineNumber));
  }

  /**
   * Formats error message.
   *
   * @param condition the condition
   * @param fileName the file name
   * @param lineNumber the line number
   *
   * @return formatted error message.
   */
  protected String formatMessage(String condition, String fileName,
                                 int lineNumber) {
    StringBuffer sb;
    if (condition == null) {
      sb = new StringBuffer("Native condition failed"); //$NON-NLS-1$
    } else {
      sb = new StringBuffer("Native condition \""); //$NON-NLS-1$
      sb = sb.append(condition);
      sb.append("\" failed"); //$NON-NLS-1$
    }
    if (fileName != null) {
      sb.append("\n in file: "); //$NON-NLS-1$
      sb.append(fileName);
    }
    if (lineNumber >= 0) {
      sb.append("\n at line: "); //$NON-NLS-1$
      sb.append(lineNumber);
    }
    return sb.toString();
  }

/*^**************************************************************************^*/
/*- Overridden Methods.                                                      -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected void setUp() throws Exception {
    _testObject = _createTestObject();
    if (_testObject == 0) {
      fail("Could not create test object"); //$NON-NLS-1$
    }
  }

  /**
   * {@inheritDoc}
   */
  protected void tearDown() throws Exception {
    _deleteTestObject(_testObject);
  }

/*^**************************************************************************^*/
/*- Protected Native Methods.                                                -*/
/*^**************************************************************************^*/

  /**
   * Creates native test object.
   * <p>
   *   <tt>NOTE: You must override this method!</tt>
   * </p>
   *
   * @return test object.
   */
  protected native long _createTestObject();

  /**
   * Deletes native object.
   *
   * @param testObject the test object
   */
  protected native void _deleteTestObject(long testObject);

/*^**************************************************************************^*/
/*- Private Static Method.                                                   -*/
/*^**************************************************************************^*/

  private static native void _initialize();

}

/*^*****************************************************************************
  File History:

 - 2007-02-02 12:45:23 Slobodan
   Initial version

*****************************************************************************^*/
