/*
 * @(#)GLJQComponent.java  0.2.0 / 2007-09-05
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.opengl;

import yu.ac.bg.etf.javaqx.qswing.JQComponent;

/**
 * OpenGL Component.
 *
 * @javaqx.native
 *    generate="header"
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public abstract class GLJQComponent extends JQComponent
                                    implements GLConstants {

/*^**************************************************************************^*/
/*- Static Initialization.                                                   -*/
/*^**************************************************************************^*/

  static {
    if (QOpenGL.SUPPORTED) {
      _initialize();
    }
  }

/*^**************************************************************************^*/
/*- Package-Private Field.                                                   -*/
/*^**************************************************************************^*/

  long _bridgeGL;

/*^**************************************************************************^*/
/*- Protected Constructor.                                                   -*/
/*^**************************************************************************^*/

  /**
   * Constructs new GLJQComponent object.
   */
  protected GLJQComponent() {
    super(false);
    if (!QOpenGL.SUPPORTED) {
      throw new GLException("OpenGL not supported"); //$NON-NLS-1$
    }
    _bridgeGL = _createGL(); // NOPMD
    if (_bridgeGL == 0) {
      throw new OutOfMemoryError("GLJQComponent creation failed"); //$NON-NLS-1$
    }
  }

/*^**************************************************************************^*/
/*- Public Method.                                                           -*/
/*^**************************************************************************^*/

  /**
   * Updates the component.
   */
  public void updateGL() {
    disposedCheck();
    _updateGL(_bridgeGL);
  }

/*^**************************************************************************^*/
/*- Protected Abstract Mehtods.                                              -*/
/*^**************************************************************************^*/

// CS:OFF

  protected abstract void initializeGL();

  protected abstract void resizeGL(int width, int height);

  protected abstract void paintGL();

/*^**************************************************************************^*/
/*- Protected OpenGL Methods.                                                -*/
/*^**************************************************************************^*/

  protected void glVertex3f(float x, float y, float z) {
    QOpenGL._glVertex3f(x, y, z);
  }

  protected void glColor3f(float r, float g, float b) {
    QOpenGL._glColor3f(r, g, b);
  }

  protected void glClearColor(float r, float g, float b, float a) {
    QOpenGL._glClearColor(r, g, b, a);
  }

  protected void glShadeModel(int mode) {
    QOpenGL._glShadeModel(mode);
  }

  protected void glClearDepth(float depth) {
    QOpenGL._glClearDepth(depth);
  }

  protected void glHint(int target, int mode) {
    QOpenGL._glHint(target, mode);
  }

  protected void glEnable(int cap) {
    QOpenGL._glEnable(cap);
  }

  protected void glDepthFunc(int func) {
    QOpenGL._glDepthFunc(func);
  }

  protected void glClear(int mask) {
    QOpenGL._glClear(mask);
  }

  protected void glLoadIdentity() {
    QOpenGL._glLoadIdentity();
  }

  protected void glTranslatef(float x, float y, float z) {
    QOpenGL._glTranslatef(x, y, z);
  }

  protected void glRotatef(float angle, float x, float y, float z) {
    QOpenGL._glRotatef(angle, x, y, z);
  }

  protected void glBegin(int mode) {
    QOpenGL._glBegin(mode);
  }

  protected void glEnd() {
    QOpenGL._glEnd();
  }

  protected void glViewport(int x, int y, int width, int height) {
    QOpenGL._glViewport(x, y, width, height);
  }

  protected void glMatrixMode(int mode) {
    QOpenGL._glMatrixMode(mode);
  }

  protected void gluPerspective(double fovy, double aspect, double zNear,
                                double zFar) {
    QOpenGL._gluPerspective(fovy, aspect, zNear, zFar);
  }

// CS:ON

/*^**************************************************************************^*/
/*- Package-Private Native Methods.                                          -*/
/*^**************************************************************************^*/

  native long _createGL();

  native void _updateGL(long bridge);

/*^**************************************************************************^*/
/*- Private Static Native Method.                                            -*/
/*^**************************************************************************^*/

  private static native void _initialize();

}

/*^*****************************************************************************
  File History:

 - 2007-09-05 01:04:11 Slobodan
   Initial version

*****************************************************************************^*/
