/*
 * @(#)Action.java  0.2.0 / 2007-09-27
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing;

import java.beans.PropertyChangeListener;

import yu.ac.bg.etf.javaqx.qswing.events.ActionListener;

/**
 * Action Interface.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public interface Action extends ActionListener {

/*^**************************************************************************^*/
/*- Property Names.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Default property.
   */
  public static final String DEFAULT = "Default"; //$NON-NLS-1$

  /**
   * Name property.
   */
  public static final String NAME = "Name"; //$NON-NLS-1$

  /**
   * Short description property.
   */
  public static final String SHORT_DESCRIPTION =
                                              "ShortDescription"; //$NON-NLS-1$

  /**
   * Long description property.
   */
  public static final String LONG_DESCRIPTION = "LongDescription"; //$NON-NLS-1$

  /**
   * Help description property.
   */
  public static final String HELP_DESCRIPTION = "HelpDescription"; //$NON-NLS-1$

  /**
   * Small icon property.
   */
  public static final String SMALL_ICON = "SmallIcon"; //$NON-NLS-1$

  /**
   * Small icon name property.
   */
  public static final String SMALL_ICON_NAME = "SmallIconName"; //$NON-NLS-1$

  /**
   * Action command key property.
   */
  public static final String ACTION_COMMAND_KEY =
                                              "ActionCommandKey"; //$NON-NLS-1$

  /**
   * Accelerator key property.
   */
  public static final String ACCELERATOR_KEY = "AcceleratorKey"; //$NON-NLS-1$

  /**
   * Accelerator key property.
   */
  public static final String ACCELERATOR_KEY_NAME =
                                            "AcceleratorKeyName"; //$NON-NLS-1$

  /**
   * Mnemonic key property.
   */
  public static final String MNEMONIC_KEY = "MnemonicKey"; //$NON-NLS-1$

/*^**************************************************************************^*/
/*- Interface Methods.                                                       -*/
/*^**************************************************************************^*/

  /**
   * Returns the value of the property specified by the key.
   *
   * @param key the property key
   *
   * @return the value of this property or <tt>null</tt> if there is no such
   *         property
   */
  public Object getValue(String key);

  /**
   * Sets the value of the property specified by the key.
   *
   * @param key the property key
   * @param value the new property value
   */
  public void putValue(String key, Object value);

  /**
   * Returns enabled state of the action.
   *
   * @return enabled state of the action
   */
  public boolean isEnabled();

  /**
   * Sets enabled state of the action.
   *
   * @param b the new enabled state
   */
  public void setEnabled(boolean b);

  /**
   * Returns selected state of the action.
   *
   * @return selected state of the action
   */
  public boolean isSelected();

  /**
   * Sets selected state of the action.
   *
   * @param b the new selected state
   */
  public void setSelected(boolean b);

  /**
   * Adds property chage listener.
   *
   * @param listener the property chage listener
   */
  public void addPropertyChangeListener(PropertyChangeListener listener);

  /**
   * Removes property chage listener.
   *
   * @param listener the property chage listener
   */
  public void removePropertyChangeListener(PropertyChangeListener listener);

}

/*^*****************************************************************************
  File History:

 - 2007-09-27 22:46:23 Slobodan
   Initial version

*****************************************************************************^*/
