/*
 * @(#)BoundedRangeModel.java  0.2.0 / 2007-09-18
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing;

import yu.ac.bg.etf.javaqx.qswing.events.ChangeListener;

/**
 * Bounded Range Model. (Model for JQProgressBar and JQSlider)
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public interface BoundedRangeModel {

  /**
   * Returns the current value for the model.
   *
   * @return The current value for the model.
   */
  public int getValue();

  /**
   * Sets the current value for the model.
   *
   * @param value the value
   */
  public void setValue(int value);

  /**
   * Returns the minimum value for the model.
   *
   * @return the minimum value for the model
   */
  public int getMinimum();

  /**
   * Sets the minimum value for the model.
   *
   * @param minimum the minimum value
   */
  public void setMinimum(int minimum);

  /**
   * Returns the maximum value for the model.
   *
   * @return the maximum value for the model
   */
  public int getMaximum();

  /**
   * Sets the maximum value for the model.
   *
   * @param maximum the maximum value
   */
  public void setMaximum(int maximum);

  /**
   * Returns the current extent.
   *
   * @return the extent
   */
  public int getExtent();

  /**
   * Sets the current extent.
   *
   * @param extent the extent
   */
  public void setExtent(int extent);

  /**
   * Returns the value of the <tt>valueIsAdjusting</tt> property.
   *
   * @return the value of the <tt>valueIsAdjusting</tt> property
   */
  public boolean getValueIsAdjusting();

  /**
   * Sets the value of the <tt>valueIsAdjusting</tt> property.
   *
   * @param adjusting the value of the <tt>valueIsAdjusting</tt> property
   */
  public void setValueIsAdjusting(boolean adjusting);

  /**
   * Sets all the properties for the model.
   *
   * @param value the value
   * @param extent the extent
   * @param minimum the minimum value
   * @param maximum the maximum value
   * @param adjusting the adjusting flag
   */
  public void setRangeProperties(int value, int extent, int minimum,
                                 int maximum, boolean adjusting);

  /**
   * Adds change listener.
   *
   * @param listener the change listener
   */
  public void addChangeListener(ChangeListener listener);

  /**
   * Removes change listener.
   *
   * @param listener the change listener
   */
  public void removeChangeListener(ChangeListener listener);

}

/*^*****************************************************************************
  File History:

 - 2007-09-18 20:06:54 Slobodan
   Initial version

*****************************************************************************^*/
