/*
 * @(#)ButtonModel.java  0.2.0 / 2007-11-16
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing;

import yu.ac.bg.etf.javaqx.qswing.events.ChangeListener;

/**
 * Button Model.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public interface ButtonModel {

  /**
   * Returns <tt>true</tt> if the button is enabled.
   *
   * @return <tt>true</tt> if the button is enabled
   */
  public boolean isEnabled();

  /**
   * Returns <tt>true</tt> if the button is pressed.
   *
   * @return <tt>true</tt> if the button is pressed
   */
  public boolean isPressed();

  /**
   * Returns <tt>true</tt> if the button is selected.
   *
   * @return <tt>true</tt> if the button is selected
   */
  public boolean isSelected();

  /**
   * Enables/ disables the button.
   *
   * @param enabled <tt>true</tt> if enabled
   */
  public void setEnabled(boolean enabled);

  /**
   * Pressed/unpressed the button.
   *
   * @param pressed <tt>true</tt> if pressed
   */
  public void setPressed(boolean pressed);

  /**
   * Selects/deselects the button.
   *
   * @param selected <tt>true</tt> if selected
   */
  public void setSelected(boolean selected);

  /**
   * Adds change listener.
   *
   * @param listener the change listener
   */
  public void addChangeListener(ChangeListener listener);

  /**
   * Removes change listener.
   *
   * @param listener the component listener
   */
  public void removeChangeListener(ChangeListener listener);

}

/*^*****************************************************************************
  File History:

 - 2007-11-16 20:55:27 Slobodan
   Initial version

*****************************************************************************^*/
