/*
 * @(#)DefaultComboBoxModel.java  0.2.0 / 2007-05-04
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing;

import java.util.ArrayList;
import java.util.Vector;

import yu.ac.bg.etf.javaqx.qswing.list.AbstractListModel;

/**
 * Default ComboBox Model.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class DefaultComboBoxModel extends AbstractListModel
                                  implements MutableComboBoxModel {

/*^**************************************************************************^*/
/*- Protected Fields.                                                        -*/
/*^**************************************************************************^*/

  protected ArrayList items;
  protected Object selectedItem;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new DefaultComboBoxModel object.
   *
   * @param objects the objects
   */
  public DefaultComboBoxModel(Object[] objects) {
    if (objects == null) {
      throw new IllegalArgumentException("Null objects"); //$NON-NLS-1$
    }
    int ol = objects.length;
    items = new ArrayList(ol);
    for (int i = 0; i < ol; i++) {
      items.add(objects[i]);
    }
    if (ol > 0) {
      selectedItem = objects[0];
    }
  }

  /**
   * Constructs new DefaultComboBoxModel object.
   *
   * @param vector the vector
   */
  public DefaultComboBoxModel(Vector vector) { // NOPMD
    if (vector == null) {
      throw new IllegalArgumentException("Null vector"); //$NON-NLS-1$
    }
    items = new ArrayList(vector);
    if (vector.size() > 0) {
      selectedItem = vector.get(0);
    }
  }

  /**
   * Constructs new DefaultComboBoxModel object.
   *
   * @param items the items
   */
  public DefaultComboBoxModel(ArrayList items) {
    if (items == null) {
      throw new IllegalArgumentException("Null items"); //$NON-NLS-1$
    }
    this.items = items;
    if (items.size() > 0) {
      selectedItem = items.get(0);
    }
  }

  /**
   * Constructs new DefaultComboBoxModel object.
   */
  public DefaultComboBoxModel() {
    items = new ArrayList();
  }

/*^**************************************************************************^*/
/*- Public Methods.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Returns the index of the specified element.
   *
   * @param object the element
   *
   * @return the index of the specified element
   */
  public int getIndexOf(Object object) {
    return items.indexOf(object);
  }

  /**
   * Removes all elements.
   */
  public void removeAllElements() {
    int size = items.size();
    if (size > 0) {
      selectedItem = null;
      items.clear();
      fireIntervalRemoved(this, 0, size - 1);
    }
  }

/*^**************************************************************************^*/
/*- MutableComboBoxModel Implementation.                                     -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public int getSize() {
    return items.size();
  }

  /**
   * {@inheritDoc}
   */
  public Object getElementAt(int index) {
    if ((index >= 0) && (index < items.size())) {
      return items.get(index);
    }
    return null;
  }

  /**
   * {@inheritDoc}
   */
  public void addElement(Object object) {
    items.add(object);
    int ci = items.size() - 1;
    fireIntervalAdded(this, ci, ci);
    if (ci == 0) {
      setSelectedItem(object);
    }
  }

  /**
   * {@inheritDoc}
   */
  public void insertElementAt(Object object, int index) {
    items.add(index, object);
    fireIntervalAdded(this, index, index);
  }

  /**
   * {@inheritDoc}
   */
  public void removeElementAt(int index) {
    Object removedItem = items.remove(index);
    if (removedItem == selectedItem) { // NOPMD
      if (index == 0) {
        selectedItem = items.get(0);
      } else {
        selectedItem = items.get(index - 1);
      }
    }
    fireIntervalRemoved(this, index, index);
  }

  /**
   * {@inheritDoc}
   */
  public void removeElement(Object object) {
    int index = items.indexOf(object);
    if (index != -1) {
      removeElementAt(index);
    }
  }

  /**
   * {@inheritDoc}
   */
  public Object getSelectedItem() {
    return selectedItem;
  }

  /**
   * {@inheritDoc}
   */
  public void setSelectedItem(Object item) {
    if (selectedItem == null) {
      if (item == null) {
         return;
      }
    } else {
      if (selectedItem.equals(item)) {
        return;
      }
    }
    selectedItem = item;
    fireContentsChanged(this, -1, -1);
  }

}

/*^*****************************************************************************
  File History:

 - 2007-05-04 18:45:15 Slobodan
   Initial version

*****************************************************************************^*/
