/*
 * @(#)ImageIcon.java  0.2.0 / 2007-05-04
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing;

import java.net.URL;

import yu.ac.bg.etf.javaqx.qswing.graphics.Graphics;
import yu.ac.bg.etf.javaqx.qswing.graphics.Image;

/**
 * Image Icon.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class ImageIcon implements Icon {

/*^**************************************************************************^*/
/*- Static Initialization.                                                   -*/
/*^**************************************************************************^*/

  static {
    QSwing.initialize();
  }

/*^**************************************************************************^*/
/*- Package-Private Field.                                                   -*/
/*^**************************************************************************^*/

  final Image image;

/*^**************************************************************************^*/
/*- Public Constructors.                                                     -*/
/*^**************************************************************************^*/

  /**
   * Constructs new ImageIcon object.
   *
   * @param image the image
   */
  public ImageIcon(Image image) {
    this.image = image;
  }

  /**
   * Constructs new ImageIcon object.
   *
   * @param fileName the file name
   */
  public ImageIcon(String fileName) {
    this(QSwing.crateImage(fileName));
  }

  /**
   * Constructs new ImageIcon object.
   *
   * @param location the location
   */
  public ImageIcon(URL location) {
    this(QSwing.crateImage(location));
  }

  /**
   * Constructs new ImageIcon object.
   *
   * @param imageData the image data
   */
  public ImageIcon(byte[] imageData) {
    this(QSwing.crateImage(imageData));
  }

/*^**************************************************************************^*/
/*- Public Methods.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Returns image.
   *
   * @return image
   */
  public Image getImage() {
    return image;
  }

/*^**************************************************************************^*/
/*- Icon Interface Implementation.                                           -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public int getIconWidth() {
    return image.getWidth();
  }

  /**
   * {@inheritDoc}
   */
  public int getIconHeight() {
    return image.getHeight();
  }

  /**
   * {@inheritDoc}
   */
  public void paintIcon(JQComponent component, Graphics g, int x, int y) {
    g.drawImage(image, x, y);
  }

/*^**************************************************************************^*/
/*- Overridden Methods.                                                      -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public boolean equals(Object obj) {
    if (obj == this) {
      return true;
    }
    if ((obj != null) && (obj.getClass() == getClass())) {
      ImageIcon imageIcon = (ImageIcon)obj;
      return image.equals(imageIcon.image);
    }
    return false;
  }

  /**
   * {@inheritDoc}
   */
  public int hashCode() {
    return image.hashCode();
  }

}

/*^*****************************************************************************
  File History:

 - 2007-05-04 18:46:20 Slobodan
   Initial version

*****************************************************************************^*/
