/*
 * @(#)JQButton.java  0.2.0 / 2007-05-04
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing;

import yu.ac.bg.etf.javaqx.qswing.properties.JQButtonProperties;

/**
 * Button Component.
 *
 * @javaqx.native
 *    generate="header"
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class JQButton extends JQAbstractButton implements JQButtonProperties {

/*^**************************************************************************^*/
/*- Private Static Fields.                                                   -*/
/*^**************************************************************************^*/

  private static final Object CLASS_LOCK;
  private static boolean useAutoDefaultButtons;

/*^**************************************************************************^*/
/*- Static Initialization.                                                   -*/
/*^**************************************************************************^*/

  static {
    CLASS_LOCK = new Object();
  }

/*^**************************************************************************^*/
/*- Private Fields.                                                          -*/
/*^**************************************************************************^*/

  private boolean defaultCapable;
  private boolean autoDefault;

/*^**************************************************************************^*/
/*- Public Constructors.                                                     -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JQButton object.
   */
  public JQButton() {
    this(null, null);
  }

  /**
   * Constructs new JQAbstractButton object.
   *
   * @param action the action
   */
  public JQButton(Action action) {
    this(null, null);
    setAction(action); // NOPMD
  }

  /**
   * Constructs new JQButton object.
   *
   * @param text the button text
   */
  public JQButton(String text) {
    this(text, null);
  }

  /**
   * Constructs new JQButton object.
   *
   * @param icon the icon
   */
  public JQButton(Icon icon) {
    this(null, icon);
  }

  /**
   * Constructs new JQButton object.
   *
   * @param text the button text
   * @param icon the icon
   */
  public JQButton(String text, Icon icon) {
    super(text, icon);
    synchronized (CLASS_LOCK) {
      if (useAutoDefaultButtons) {
        autoDefault = true;
        _setAutoDefault(_bridge, true); // NOPMD
      }
    }
  }

/*^**************************************************************************^*/
/*- Public Static Methods.                                                   -*/
/*^**************************************************************************^*/

  /**
   * Returns <tt>true</tt> if new buttons are auto default.
   *
   * @return <tt>true</tt> if new buttons are auto default
   */
  public static boolean isUsingAutoDefaultButtons() {
    synchronized (CLASS_LOCK) {
      return useAutoDefaultButtons;
    }
  }

  /**
   * Sets whether or not new buttons are auto default.
   *
   * @param useAutoDefaultButtons if <tt>true</tt> new buttons are auto default
   */
  public static void setUseAutoDefaultButtons(boolean useAutoDefaultButtons) {
    synchronized (CLASS_LOCK) {
      JQButton.useAutoDefaultButtons = useAutoDefaultButtons;
    }
  }

/*^**************************************************************************^*/
/*- Public Methods.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Returns default capable status.
   *
   * @return <tt>true</tt> if the button is default
   */
  public boolean isDefaultCapable() {
    if (autoDefault) {
      disposedCheck();
      return _isDefault(_bridge);
    }
    return defaultCapable;
  }

  /**
   * Sets button's <tt>defaultCapable</tt> property.
   *
   * @param defaultCapable if <tt>true</tt> this button will be the default
   *                       button
   */
  public void setDefaultCapable(boolean defaultCapable) {
    disposedCheck();
    boolean oldDefaultCapable;
    if (autoDefault) {
      oldDefaultCapable = _isDefault(_bridge);
    } else {
      oldDefaultCapable = this.defaultCapable;
    }
    if (oldDefaultCapable != defaultCapable) {
      _setDefaultCapable(_bridge, defaultCapable);
      this.defaultCapable = defaultCapable;
      firePropertyChange(PROPERTY_DEFAULT_CAPABLE, oldDefaultCapable,
                         defaultCapable);
    }
  }

  /**
   * Returns button's auto default status.
   *
   * @return auto default status
   */
  public boolean isAutoDefault() {
    return autoDefault;
  }

  /**
   * Sets button's <tt>autoDefault</tt> property.
   *
   * @param autoDefault if <tt>true</tt> the button automatically changes its
   *                    default state.
   */
  public void setAutoDefault(boolean autoDefault) {
    boolean oldAutoDefault = this.autoDefault;
    if (oldAutoDefault != autoDefault) {
      disposedCheck();
      _setAutoDefault(_bridge, autoDefault);
      this.autoDefault = autoDefault;
      firePropertyChange(PROPERTY_AUTO_DEFAULT, oldAutoDefault, autoDefault);
    }
  }

/*^**************************************************************************^*/
/*- Package-Private Native Method.                                           -*/
/*^**************************************************************************^*/

  native long _create();

  native boolean _isDefault(long bridge);

  native void _setDefaultCapable(long bridge, boolean defaultCapable);

  native void _setAutoDefault(long bridge, boolean autoDefault);

}

/*^*****************************************************************************
  File History:

 - 2007-05-04 18:47:17 Slobodan
   Initial version

*****************************************************************************^*/
