/*
 * @(#)JQColorChooser.java  0.2.0 / 2007-11-29
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing;

import yu.ac.bg.etf.javaqx.qswing.graphics.Color;

/**
 * Color Chooser Component.
 *
 * <p>
 *   <tt>NOTE: This class is not compatible with
 *             <em>javax.swing.JColorChooser</em> class!</tt>
 * </p>
 *
 * @javaqx.native
 *    generate="header"
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public final class JQColorChooser extends JQDialog {

/*^**************************************************************************^*/
/*- Private Constructor.                                                     -*/
/*^**************************************************************************^*/

 /**
  * Class has no instances.
  */
  private JQColorChooser() {
    // empty constructor body
  }

/*^**************************************************************************^*/
/*- Public Static Mehtods.                                                   -*/
/*^**************************************************************************^*/

  /**
   * Returns color selected by the user.
   *
   * @param parent the parent component
   *
   * @return color selected by the user
   */
  public static Color getColor(JQComponent parent) {
    return getColor(parent, null);
  }

  /**
   * Returns color selected by the user.
   *
   * @param parent the parent component
   * @param initialColor the initial color
   *
   * @return color selected by the user
   */
  public static Color getColor(JQComponent parent, Color initialColor) {
    int argb;
    if (initialColor == null) {
      argb = 0xFFFFFFFF;
    } else {
      argb = initialColor.getARGB();
    }
    if (parent != null) {
      return _getColor(parent._bridge, argb);
    }
    return _getColor(0, argb);
  }

/*^**************************************************************************^*/
/*- Package-Private Static Native Method.                                    -*/
/*^**************************************************************************^*/

  static native Color _getColor(long parentBridge, int initialColor);

}

/*^*****************************************************************************
  File History:

 - 2007-11-29 18:43:29 Slobodan
   Initial version

*****************************************************************************^*/
