/*
 * @(#)JQDesktop.java  0.2.0 / 2007-05-04
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing;

import yu.ac.bg.etf.javaqx.qswing.graphics.Dimension;
import yu.ac.bg.etf.javaqx.qswing.graphics.Image;
import yu.ac.bg.etf.javaqx.qswing.graphics.Rectangle;

/**
 * Desktop Class.
 *
 * @javaqx.native
 *    generate="header"
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public final class JQDesktop {

/*^**************************************************************************^*/
/*- Private Static Fields.                                                   -*/
/*^**************************************************************************^*/

  private static Dimension screenSize;
  private static int screenResolution;
  private static Rectangle desktopBounds;

/*^**************************************************************************^*/
/*- Static Initialization.                                                   -*/
/*^**************************************************************************^*/

  static {
    QSwing.initialize();
  }

/*^**************************************************************************^*/
/*- Private Constructor.                                                     -*/
/*^**************************************************************************^*/

 /**
  * Class has no instances.
  */
  private JQDesktop() {
    // empty constructor body
  }

/*^**************************************************************************^*/
/*- Public Static Methods.                                                   -*/
/*^**************************************************************************^*/

  /**
   * Returns the size of default screen.
   *
   * @return the size of default screen
   */
  public static Dimension getScreenSize() {
    synchronized (QSwing.CLASS_LOCK) {
      if (screenSize == null) {
        QSwing.disposedCheck();
        screenSize = _getScreenSize();
      }
      return screenSize;
    }
  }

  /**
   * Returns screen resolution.
   *
   * @return screen resolution
   */
  public static int getScreenResolution() {
    synchronized (QSwing.CLASS_LOCK) {
      QSwing.disposedCheck();
      if (screenResolution == 0) {
        screenResolution = _getScreenResolution();
      }
      return screenResolution;
    }
  }

  /**
   * Returns desktop bounds.
   *
   * @return desktop bounds
   */
  public static Rectangle getDesktopBounds() {
    synchronized (QSwing.CLASS_LOCK) {
      if (desktopBounds == null) {
        QSwing.disposedCheck();
        desktopBounds = _getDesktopBounds();
      }
      return desktopBounds;
    }
  }

  /**
   * Takes a screenshot of the specified component. If the component is
   * <tt>null</tt>, desktop screenshot is taken.
   *
   * @param component the component
   *
   * @return screen shot of the specified component
   */
  public static Image takeScreenShot(JQComponent component) {
    return takeScreenShot(component, "PNG"); //$NON-NLS-1$
  }

  /**
   * Takes a screenshot of the specified component. If the component is
   * <tt>null</tt> desktop screenshot is taken.
   *
   * @param component the component
   * @param imageFormat the image format
   *
   * @return screen shot of the specified component
   */
  public static Image takeScreenShot(JQComponent component,
                                     String imageFormat) {
    if ((component != null) && (component.isDisposed())) {
      throw new IllegalArgumentException("Component disposed"); //$NON-NLS-1$
    }
    if (imageFormat == null) {
      throw new IllegalArgumentException("Null image format"); //$NON-NLS-1$
    }
    QSwing.disposedCheck();
    if (component == null) {
      return _takeScreenshot(0, imageFormat);
    }
    return _takeScreenshot(component._bridge, imageFormat);
  }

/** @todo  add other desktop methods like browse, launch etc... */

/*^**************************************************************************^*/
/*- Package-Private Native Methods.                                          -*/
/*^**************************************************************************^*/

  static native Dimension _getScreenSize();

  static native int _getScreenResolution();

  static native Rectangle _getDesktopBounds();

  static native QSwingImage _takeScreenshot(long componentBridge,
                                            String imageFormat);

}

/*^*****************************************************************************
  File History:

 - 2007-05-04 18:48:50 Slobodan
   Initial version

*****************************************************************************^*/
