/*
 * @(#)JQDesktopPane.java  0.2.0 / 2007-05-04
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing;

import yu.ac.bg.etf.javaqx.qswing.layouts.LayoutManager;

/**
 * DesktopPane Component.
 *
 * @javaqx.native
 *    generate="header"
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class JQDesktopPane extends JQContainer {

/*^**************************************************************************^*/
/*- Private Field.                                                           -*/
/*^**************************************************************************^*/

  private JQComponent selectedComponent;

/*^**************************************************************************^*/
/*- Static Initialization.                                                   -*/
/*^**************************************************************************^*/

  static {
    _initialize();
  }

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JQDesktopPane object.
   */
  public JQDesktopPane() {
    super(null);
  }

/*^**************************************************************************^*/
/*- Public Methods.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Appends the specified component to the end of this container.
   *
   * @param component the component to be added
   *
   * @return the component argument
   */
  public JQInternalFrame add(JQInternalFrame component) {
    addImpl(component, null, -1);
    return component;
  }

  /**
   * Returns currently selected (active) component.
   *
   * @return currently selected (active) component
   */
  public JQComponent getSelectedComponent() {
    return selectedComponent;
  }

  /**
   * Sets currently selected (active) component.
   *
   * @param component the component to be selected
   */
  public void setSelectedComponent(JQComponent component) {
    if (selectedComponent != component) { // NOPMD
      if (getComponentIndex(component) == -1) {
        throw new IllegalArgumentException("Invalid component"); //$NON-NLS-1$
      }
      disposedCheck();
      selectedComponent = component;
      if (component == null) {
        _setCurrentComponent(_bridge, 0);
      } else {
        _setCurrentComponent(_bridge, component._bridge);
      }
    }
  }

  /**
   * Selects next component.
   */
  public void selectNextComponent() {
    if (componentCount > 0) {
      disposedCheck();
      _selectNextComponent(_bridge);
    }
  }

  /**
   * Selects previous component.
   */
  public void selectPreviousComponent() {
    if (componentCount > 0) {
      disposedCheck();
      _selectPreviousComponent(_bridge);
    }
  }

  /**
   * Closes the current component.
   */
  public void closeCurrentComponent() {
    if (componentCount > 0) {
      disposedCheck();
      _closeCurrentComponent(_bridge);
    }
  }

  /**
   * Closes all components.
   */
  public void closeAllComponents() {
    if (componentCount > 0) {
      disposedCheck();
      _closeAllComponents(_bridge);
    }
  }

  /**
   * Cascades the components.
   */
  public void cascadeComponents() {
    if (componentCount > 0) {
      disposedCheck();
      _cascadeComponents(_bridge);
    }
  }

  /**
   * Tiles the components.
   */
  public void tileComponents() {
    if (componentCount > 0) {
      disposedCheck();
      _tileComponents(_bridge);
    }
  }

/*^**************************************************************************^*/
/*- Overridden Methods.                                                      -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public JQComponent add(JQComponent component) {
    return add(component, null, -1);
  }

  /**
   * {@inheritDoc}
   */
  public JQComponent add(JQComponent component, int index) {
    return add(component, null, -1);
  }

  /**
   * {@inheritDoc}
   */
  public JQComponent add(JQComponent component, Object constraints) {
    return add(component, null, -1);
  }

  /**
   * {@inheritDoc}
   */
  public JQComponent add(JQComponent component, Object constraints, int index) {
    if (component == null) {
      throw new IllegalArgumentException("Adding null component"); //$NON-NLS-1$
    }
    JQInternalFrame internalFrame;
    if (constraints instanceof String) {
      internalFrame = new JQInternalFrame((String)constraints);
    } else {
      internalFrame = new JQInternalFrame(component.getName());
    }
    internalFrame.addImpl(component, null, index);
    addImpl(internalFrame, null, index);
    return internalFrame;
  }

  /**
   * {@inheritDoc}
   */
  public void setLayout(LayoutManager layoutManager) {
    // empty method
  }

  /**
   * {@inheritDoc}
   */
  public void invalidate() {
    if (valid) {
      valid = false;
      if (visible) {
        disposedCheck();
        _validate(_bridge);
      }
    }
  }

  /**
   * {@inheritDoc}
   */
  public void validate() {
    if (!valid) {
      disposedCheck();
      valid = true;
      final JQComponent[] components = this.components;
      for (int i = componentCount; --i >= 0;) {
        components[i].validate();
      }
    }
  }

  /**
   * {@inheritDoc}
   */
  protected JQComponent addImpl(JQComponent component, Object constraints,
                                int index) {
    return super.addImpl(component, constraints, index);
  }

  void checkChild(JQComponent child) {
    if (child == null) {
      throw new IllegalArgumentException("Adding null child"); //$NON-NLS-1$
    }
    if (child.isDisposed()) {
      throw new IllegalArgumentException("Adding disposed child"); //$NON-NLS-1$
    }
    if (child instanceof JQContainer) {
      for (JQContainer cont = this; cont != null; cont = cont.parent) {
        if (cont == child) { // NOPMD
          throw new IllegalArgumentException(
                          "Adding container's parent to itself"); //$NON-NLS-1$
        }
      }
    }
  }

/*^**************************************************************************^*/
/*- Native Callback.                                                         -*/
/*^**************************************************************************^*/

  void _activeComponentChanged(JQComponent component) {
    selectedComponent = component;
  }

/*^**************************************************************************^*/
/*- Package-Private Native Methods.                                          -*/
/*^**************************************************************************^*/

  native long _create();

  native void _insertChild(long bridge, long childBridge, int index);

  native void _removeChild(long bridge, long childBridge);

  native void _setCurrentComponent(long bridge, long componentBridge);

  native void _selectNextComponent(long bridge);

  native void _selectPreviousComponent(long bridge);

  native void _closeCurrentComponent(long bridge);

  native void _closeAllComponents(long bridge);

  native void _cascadeComponents(long bridge);

  native void _tileComponents(long bridge);

/*^**************************************************************************^*/
/*- Private Static Native Method.                                            -*/
/*^**************************************************************************^*/

  private static native void _initialize();

}

/*^*****************************************************************************
  File History:

 - 2007-05-04 18:48:37 Slobodan
   Initial version

*****************************************************************************^*/
