/*
 * @(#)JQDialog.java  0.2.0 / 2007-05-04
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing;

import yu.ac.bg.etf.javaqx.qswing.layouts.BorderLayout;

/**
 * Dialog Component.
 * <p>
 *   <tt>NOTE: This class is not compatible with
 *             <em>javax.swing.JDialog</em> class!</tt>
 * </p>
 *
 * @javaqx.native
 *    generate="header"
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class JQDialog extends JQWindow {

/*^**************************************************************************^*/
/*- Public Static Final Fields.                                              -*/
/*^**************************************************************************^*/

  /**
   * Rejected dialog result (the value is {@value}).
   */
  public static final int REJECTED = 0;

  /**
   * Accepted dialog result (the value is {@value}).
   */
  public static final int ACCEPTED = 1;

/*^**************************************************************************^*/
/*- Package-Private Fields.                                                  -*/
/*^**************************************************************************^*/

  boolean modal;
  boolean modalVisible;
  int result;

/*^**************************************************************************^*/
/*- Protected Constructor.                                                   -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JQDialog object.
   */
  public JQDialog() {
    this(null);
  }

  /**
   * Constructs new JQDialog object.
   *
   * @param title the dialog title
   */
  public JQDialog(String title) {
    super(new BorderLayout(), title);
  }

  /**
   * Constructs new JQDialog object.
   *
   * @param owner the dialog owner
   * @param title the dialog title
   */
  public JQDialog(JQWindow owner, String title) {
    super(new BorderLayout(), title);
    if (owner != null) {
      owner.acquireWindow(this);
    }
  }

/*^**************************************************************************^*/
/*- Public Methods.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Sets whether or not the dialog is modal.
   *
   * @param modal <tt>true</tt> if modal
   */
  public void setModal(boolean modal) {
    if (modal) {
      if (owner == null) {
        setModalityType(APPLICATION_MODAL);
      } else {
        setModalityType(WINDOW_MODAL);
      }
    } else {
      setModalityType(NON_MODAL);
    }
  }

  /**
   * Returns dialog result.
   *
   * @return dialog result
   */
  public int getDialogResult() {
    return result;
  }

  /**
   * Returns <tt>true</tt> if the dialog is accepted.
   *
   * @return <tt>true</tt> if the dialog is accepted
   */
  public boolean isAccepted() {
    return (result == ACCEPTED);
  }

  /**
   * Returns <tt>true</tt> if the dialog is rejected.
   *
   * @return <tt>true</tt> if the dialog is rejected
   */
  public boolean isRejected() {
    return (result == REJECTED);
  }

  /**
   * Accepts/rejects the dialog.
   *
   * @param accepted <tt>true</tt> if accepted; <tt>false</tt> if rejected
   */
  public void setAccepted(boolean accepted) {
    if (accepted) {
      closeDialog(ACCEPTED);
    } else {
      closeDialog(REJECTED);
    }
  }

  /**
   * Shows modal dialog.
   *
   * @return dialog result.
   */
  public int showDialog() {
    if (!modalVisible) {
      disposedCheck();
      modalVisible = true;
      int result = _exec(_bridge);
      modalVisible = false;
      doDefaultCloseOperation();
      return result;
    }
    return REJECTED;
  }

  /**
   * Closes modal dialog.
   *
   * @param result the dialog result
   */
  public void closeDialog(int result) {
    if (modalVisible) {
      disposedCheck();
      _done(_bridge, result);
    }
  }

/*^**************************************************************************^*/
/*- Package-Private Native Method.                                           -*/
/*^**************************************************************************^*/

  native long _create();

  native int _exec(long bridge);

  native void _done(long bridge, int result);

}

/*^*****************************************************************************
  File History:

 - 2007-05-04 18:48:28 Slobodan
   Initial version

*****************************************************************************^*/
