/*
 * @(#)JQFileChooser.java  0.2.0 / 2007-05-04
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing;

import java.io.File;

/**
 * File Chooser Component.
 * <p>
 *   <tt>NOTE: This class is not compatible with
 *             <em>javax.swing.JFileChooser</em> class!</tt>
 * </p>
 *
 * @javaqx.native
 *    generate="header"
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public final class JQFileChooser extends JQDialog {

/*^**************************************************************************^*/
/*- Private Constructor.                                                     -*/
/*^**************************************************************************^*/

 /**
  * Class has no instances.
  */
  private JQFileChooser() {
    // empty constructor body
  }

/*^**************************************************************************^*/
/*- Public Static Method.                                                    -*/
/*^**************************************************************************^*/

  /**
   * Returns directory selected by the user.
   *
   * @param parent the parent component
   *
   * @return directory selected by the user
   */
  public static String getExistingDirectoryName(JQComponent parent) {
    return getExistingDirectoryName(parent, null, null);
  }

  /**
   * Returns directory selected by the user.
   *
   * @param parent the parent component
   * @param caption the dialog caption
   * @param directory the directory
   *
   * @return directory selected by the user
   */
  public static String getExistingDirectoryName(JQComponent parent,
                                                String caption,
                                                String directory) {
    if (parent != null) {
      return _getExistingDirectoryName(parent._bridge, caption, directory);
    }
    return _getExistingDirectoryName(0, caption, directory);
  }

  /**
   * Returns directory selected by the user.
   *
   * @param parent the parent component
   *
   * @return directory selected by the user
   */
  public static File getExistingDirectory(JQComponent parent) {
    return getExistingDirectory(parent, null, null);
  }

  /**
   * Returns directory selected by the user.
   *
   * @param parent the parent component
   * @param caption the dialog caption
   * @param directory the directory
   *
   * @return directory selected by the user
   */
  public static File getExistingDirectory(JQComponent parent, String caption,
                                          String directory) {
    String fileName = getExistingDirectoryName(parent, caption, directory);
    if (fileName != null) {
      return new File(fileName);
    }
    return null;
  }

  /**
   * Returns file selected by the user.
   *
   * @param parent the parent component
   *
   * @return file selected by the user
   */
  public static String getOpenFileName(JQComponent parent) {
    return getOpenFileName(parent, null, null, null, null);
  }

  /**
   * Returns file selected by the user.
   *
   * @param parent the parent component
   * @param caption the dialog caption
   * @param directory the directory
   * @param filter the file directory
   * @param selectedFilter the selected filter
   *
   * @return file selected by the user
   */
  public static String getOpenFileName(JQComponent parent, String caption,
                                       String directory, String filter,
                                       String selectedFilter) {
    if (parent != null) {
      return _getOpenFileName(parent._bridge, caption, directory, filter,
                              selectedFilter);
    }
    return _getOpenFileName(0, caption, directory, filter, selectedFilter);
  }

  /**
   * Returns file selected by the user.
   *
   * @param parent the parent component
   *
   * @return file selected by the user
   */
  public static File getOpenFile(JQComponent parent) {
    return getOpenFile(parent, null, null, null, null);
  }

  /**
   * Returns file selected by the user.
   *
   * @param parent the parent component
   * @param caption the dialog caption
   * @param directory the directory
   * @param filter the file directory
   * @param selectedFilter the selected filter
   *
   * @return file selected by the user
   */
  public static File getOpenFile(JQComponent parent, String caption,
                                 String directory, String filter,
                                 String selectedFilter) {
    String fileName = getOpenFileName(parent, caption, directory, filter,
                                      selectedFilter);
    if (fileName != null) {
      return new File(fileName);
    }
    return null;
  }

  /**
   * Returns file selected by the user.
   *
   * @param parent the parent component
   *
   * @return file selected by the user
   */
  public static String getSaveFileName(JQComponent parent) {
    return getSaveFileName(parent, null, null, null, null);
  }

  /**
   * Returns file selected by the user.
   *
   * @param parent the parent component
   * @param caption the dialog caption
   * @param directory the directory
   * @param filter the file directory
   * @param selectedFilter the selected filter
   *
   * @return file selected by the user
   */
  public static String getSaveFileName(JQComponent parent, String caption,
                                       String directory, String filter,
                                       String selectedFilter) {
    if (parent != null) {
      return _getSaveFileName(parent._bridge, caption, directory, filter,
                             selectedFilter);
    }
    return _getSaveFileName(0, caption, directory, filter, selectedFilter);
  }

  /**
   * Returns file selected by the user.
   *
   * @param parent the parent component
   *
   * @return file selected by the user
   */
  public static File getSaveFile(JQComponent parent) {
    return getSaveFile(parent, null, null, null, null);
  }

  /**
   * Returns file selected by the user.
   *
   * @param parent the parent component
   * @param caption the dialog caption
   * @param directory the directory
   * @param filter the file directory
   * @param selectedFilter the selected filter
   *
   * @return file selected by the user
   */
  public static File getSaveFile(JQComponent parent, String caption,
                                 String directory, String filter,
                                 String selectedFilter) {
    String fileName = getSaveFileName(parent, caption, directory, filter,
                                      selectedFilter);
    if (fileName != null) {
      return new File(fileName);
    }
    return null;
  }

/*^**************************************************************************^*/
/*- Package-Private Static Native Methods.                                   -*/
/*^**************************************************************************^*/

  static native String _getExistingDirectoryName(long parentBridge,
                                                 String caption,
                                                 String directory);

  static native String _getOpenFileName(long parentBridge, String caption,
                                        String directory, String filter,
                                        String selectedFilter);

  static native String _getSaveFileName(long parentBridge, String caption,
                                        String directory, String filter,
                                        String selectedFilter);

}

/*^*****************************************************************************
  File History:

 - 2007-05-04 18:48:08 Slobodan
   Initial version

*****************************************************************************^*/
