/*
 * @(#)JQInternalFrame.java  0.2.0 / 2007-05-04
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing;

import yu.ac.bg.etf.javaqx.qswing.graphics.Dimension;
import yu.ac.bg.etf.javaqx.qswing.layouts.LayoutManager;

/**
 * InternalFrame Component.
 *
 * @javaqx.native
 *    generate="header"
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class JQInternalFrame extends JQWindow {

/*^**************************************************************************^*/
/*- Static Initialization.                                                   -*/
/*^**************************************************************************^*/

  static {
    _initialize();
  }

/*^**************************************************************************^*/
/*- Private Field.                                                           -*/
/*^**************************************************************************^*/

  private Dimension layoutPreferredSize;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JQInternalFrame object.
   *
   * @param title the frame title
   */
  public JQInternalFrame(String title) {
    super(title);
  }

  /**
   * Constructs new JQInternalFrame object.
   *
   * @param layoutManager the layout manager
   * @param title the frame title
   */
  public JQInternalFrame(LayoutManager layoutManager, String title) {
    super(layoutManager, title);
  }

/*^**************************************************************************^*/
/*- Overridden Methods.                                                      -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public Dimension getPreferredSize() {
    if (!preferredSizeSet && (!valid || (preferredSize == null))) {
      disposedCheck();
      preferredSize = _getPreferredSize(_bridge);
      if (insets != null) {
        preferredSize = preferredSize.enlarge(insets.getLeft() +
                                              insets.getRight(),
                                              insets.getTop() +
                                              insets.getBottom());
      }
    }
    return preferredSize;
  }

  void clearCache() {
    layoutPreferredSize = null;
    super.clearCache();
  }

/*^**************************************************************************^*/
/*- Native Callback.                                                         -*/
/*^**************************************************************************^*/

  Dimension _getLayoutPreferredSize() {
    if (!valid || (layoutPreferredSize == null)) {
      if (layoutManager == null) {
        layoutPreferredSize = Dimension.ZERO_DIMESNION;
      } else {
        layoutPreferredSize = layoutManager.preferredLayoutSize(this);
      }
    }
    return layoutPreferredSize;
  }

/*^**************************************************************************^*/
/*- Package-Private Native Methods.                                          -*/
/*^**************************************************************************^*/

  native long _create();

  native void _insertChild(long bridge, long childBridge, int index);

/*^**************************************************************************^*/
/*- Private Static Native Method.                                            -*/
/*^**************************************************************************^*/

  private static native void _initialize();

}

/*^*****************************************************************************
  File History:

 - 2007-05-04 18:51:11 Slobodan
   Initial version

*****************************************************************************^*/
