/*
 * @(#)JQPanel.java  0.2.0 / 2007-05-04
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing;

import yu.ac.bg.etf.javaqx.qswing.layouts.FlowLayout;
import yu.ac.bg.etf.javaqx.qswing.layouts.LayoutManager;
import yu.ac.bg.etf.javaqx.qswing.properties.JQPanelProperties;

/**
 * Panel Component.
 *
 * @javaqx.native
 *    generate="header"
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class JQPanel extends JQContainer implements JQPanelProperties {

/*^**************************************************************************^*/
/*- Public Static Final Fields.                                              -*/
/*^**************************************************************************^*/

  /**
   * Flat panel type (the value is {@value}).
   */
  public static final int PANEL_TYPE_FLAT = 0;

  /**
   * Box panel type (the value is {@value}).
   */
  public static final int PANEL_TYPE_BOX = 1;

  /**
   * Standard panel type (the value is {@value}).
   */
  public static final int PANEL_TYPE_STANDARD = 2;

  /**
   * Classic panel type (the value is {@value}).
   */
  public static final int PANEL_TYPE_CLASSIC = 3;

  /**
   * Styled panel type (the value is {@value}).
   */
  public static final int PANEL_TYPE_STYLED = 6;

  /**
   * Plain panel border (the value is {@value}).
   */
  public static final int BORDER_STYLE_PLAIN = 16;

  /**
   * Raised panel border (the value is {@value}).
   */
  public static final int BORDER_STYLE_RAISED = 32;

  /**
   * Sunken panel border (the value is {@value}).
   */
  public static final int BORDER_STYLE_SUNKEN = 48;

/*^**************************************************************************^*/
/*- Private Fields.                                                          -*/
/*^**************************************************************************^*/

  private int panelType;
  private int borderStyle;
  private int borderWidth;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JQPanel object.
   */
  public JQPanel() {
    this(new FlowLayout());
  }

  /**
   * Constructs new JQPanel object.
   *
   * @param layoutManager the layout manager
   */
  public JQPanel(LayoutManager layoutManager) {
    super(layoutManager);
    borderStyle = BORDER_STYLE_PLAIN;
    setOpaque(true);
  }

/*^**************************************************************************^*/
/*- Public Methods.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Returns panel type.
   *
   * @return panel type
   */
  public int getPanelType() {
    return panelType;
  }

  /**
   * Sets panel type.
   *
   * @param panelType the panel type
   */
  public void setPanelType(int panelType) {
    if ((panelType != PANEL_TYPE_FLAT) && (panelType != PANEL_TYPE_BOX) &&
        (panelType != PANEL_TYPE_STANDARD) &&
        (panelType != PANEL_TYPE_CLASSIC) &&
        (panelType != PANEL_TYPE_STYLED)) {
      throw new IllegalArgumentException("Invalid panel type"); //$NON-NLS-1$
    }
    final int oldPanelType = this.panelType;
    if (oldPanelType != panelType) {
      disposedCheck();
      _setPanelType(_bridge, panelType);
      this.panelType = panelType;
      firePropertyChange(PROPERTY_PANEL_TYPE, oldPanelType, panelType);
    }
  }

  /**
   * Returns border style.
   *
   * @return border style
   */
  public int getBorderStyle() {
    return borderStyle;
  }

  /**
   * Sets border style.
   *
   * @param borderStyle the border style
   */
  public void setBorderStyle(int borderStyle) {
    if ((borderStyle != BORDER_STYLE_PLAIN) &&
        (borderStyle != BORDER_STYLE_RAISED) &&
        (borderStyle != BORDER_STYLE_SUNKEN)) {
      throw new IllegalArgumentException("Invalid border style"); //$NON-NLS-1$
    }
    final int oldBorderStyle = this.borderStyle;
    if (oldBorderStyle != borderStyle) {
      disposedCheck();
      _setBorderStyle(_bridge, borderStyle);
      this.borderStyle = borderStyle;
      firePropertyChange(PROPERTY_BORDER_STYLE, oldBorderStyle, borderStyle);
    }
  }

  /**
   * Returns border width.
   *
   * @return border width
   */
  public int getBorderWidth() {
    return borderWidth;
  }

  /**
   * Sets border width.
   *
   * @param borderWidth int
   */
  public void setBorderWidth(int borderWidth) {
    if (borderWidth < 0) {
      throw new IllegalArgumentException("Invalid border width"); //$NON-NLS-1$
    }
    final int oldBorderWidth = this.borderWidth;
    if (oldBorderWidth != borderWidth) {
      disposedCheck();
      _setBorderWidth(_bridge, borderWidth);
      this.borderWidth = borderWidth;
      firePropertyChange(PROPERTY_BORDER_WIDTH, oldBorderWidth, borderWidth);
    }
  }

/*^**************************************************************************^*/
/*- Package-Private Native Methods.                                          -*/
/*^**************************************************************************^*/

  native long _create();

  native void _setPanelType(long bridge, int panelType);

  native void _setBorderStyle(long bridge, int borderStyle);

  native void _setBorderWidth(long bridge, int borderWidth);

}

/*^*****************************************************************************
  File History:

 - 2007-05-04 18:55:02 Slobodan
   Initial version

*****************************************************************************^*/
