/*
 * @(#)JQScrollPane.java  0.2.0 / 2007-11-20
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing;

/**
 * Scroll Pane Component.
 *
 * @javaqx.native
 *    generate="header"
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class JQScrollPane extends JQComponent {

/** @todo  add other scroll pane methods */

/*^**************************************************************************^*/
/*- Private Field.                                                           -*/
/*^**************************************************************************^*/

  private JQComponent view;

/*^**************************************************************************^*/
/*- Public Constructors.                                                     -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JQScrollPane object.
   */
  public JQScrollPane() {
    // empty constructor body
  }

  /**
   * Constructs new JQScrollPane object.
   *
   * @param view the view component
   */
  public JQScrollPane(JQComponent view) {
    if (view != null) {
      acquireComponent(view);
      _setView(_bridge, view._bridge); // NOPMD
      this.view = view;
      view.setSize(view.getPreferredSize());
    }
  }

/*^**************************************************************************^*/
/*- Public Methods.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Returns view component.
   *
   * @return view component
   */
  public JQComponent getView() {
    return view;
  }

  /**
   * Sets new view component.
   *
   * @param view the view component
   *
   * @return returns old view component
   */
  public JQComponent setView(JQComponent view) {
    final JQComponent oldView = this.view;
    if (oldView != view) { // NOPMD
      disposedCheck();
      releaseComponent(oldView);
      if (view != null) {
        if (view.isDisposed()) { // NOPMD
          throw new IllegalArgumentException(
                                      "View component disposed"); //$NON-NLS-1$
        }
        acquireComponent(view);
        _setView(_bridge, view._bridge);
        this.view = view;
        view.setSize(view.getPreferredSize());
      }
    }
    return oldView;
  }

/*^**************************************************************************^*/
/*- Overridden Methods.                                                      -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public void setComponentOrientation(ComponentOrientation orientation) {
    super.setComponentOrientation(orientation);
    if (view != null) {
      view.setComponentOrientation(orientation);
    }
  }

  /**
   * {@inheritDoc}
   */
  public void validate() {
    if (!valid) {
      disposedCheck();
      valid = true;
      if (view != null) {
        view.validate();
      }
    }
  }

  /**
   * {@inheritDoc}
   */
  public void updateLocalization() {
    super.updateLocalization();
    if (view != null) {
      view.updateLocalization();
    }
  }

  /**
   * {@inheritDoc}
   */
  public JQComponent[] getOwnedComponents() {
    if (view != null) {
      return new JQComponent[] {view};
    }
    return EMPTY_COMPONENT_ARRAY; // NOFB NOPMD
  }

  void releaseComponent(JQComponent component) {
    if ((component != null) && (component == view)) { // NOFB NOPMD
      _setView(_bridge, 0);
      view = null;
      component.owner = null;
    }
  }

  /*!
   * @javaqx.native
   *    overridden="true"
   */
  void _styleChanged() {
    super._styleChanged();
    if (view != null) {
      view._styleChanged();
    }
  }

  /*!
   * @javaqx.native
   *    overridden="true"
   */
  void _styleSheetChanged(boolean removed) {
    super._styleSheetChanged(removed);
    if (view != null) {
      view._styleSheetChanged(removed);
    }
  }

/*^**************************************************************************^*/
/*- Package-Private Native Methods.                                          -*/
/*^**************************************************************************^*/

  native long _create();

  native void _setView(long bridge, long viewBridge);

}

/*^*****************************************************************************
  File History:

 - 2007-11-20 19:15:42 Slobodan
   Initial version

*****************************************************************************^*/
