/*
 * @(#)JQSeparator.java  0.2.0 / 2007-11-07
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing;

import yu.ac.bg.etf.javaqx.qswing.properties.JQSeparatorProperties;

/**
 * Separator Component.
 *
 * @javaqx.native
 *    generate="header"
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class JQSeparator extends JQComponent
                         implements QSwingConstants, JQSeparatorProperties {

/*^**************************************************************************^*/
/*- Static Initialization.                                                   -*/
/*^**************************************************************************^*/

  static {
    _initialize();
  }

/*^**************************************************************************^*/
/*- Pacakge-Private Static Final Field.                                      -*/
/*^**************************************************************************^*/

  static final int DEFAULT_ORIENTATION = HORIZONTAL;

/*^**************************************************************************^*/
/*- Private Fields.                                                          -*/
/*^**************************************************************************^*/

  private int orientation;
  private String text;

/*^**************************************************************************^*/
/*- Public Constructors.                                                     -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JQSeparator object.
   */
  public JQSeparator() {
    this(null, DEFAULT_ORIENTATION);
  }

  /**
   * Constructs new JQSeparator object.
   *
   * @param text the text
   */
  public JQSeparator(String text) {
    this(text, DEFAULT_ORIENTATION);
  }

  /**
   * Constructs new JQSeparator object.
   *
   * @param orientation the orientation of the separator
   */
  public JQSeparator(int orientation) {
    this(null, orientation);
  }

  /**
   * Constructs new JQSeparator object.
   *
   * @param text the text
   * @param orientation the orientation of the separator
   */
  public JQSeparator(String text, int orientation) {
    if ((orientation < HORIZONTAL) || (orientation > VERTICAL)) {
      throw new IllegalArgumentException("Invalid orientation"); //$NON-NLS-1$
    }
    if (orientation != DEFAULT_ORIENTATION) {
      _setOrientation(_bridge, VERTICAL); // NOPMD
    }
    this.orientation = orientation;
    if (text != null) {
      this.text = text;
      _setText(_bridge, text); // NOPMD
    }
  }

/*^**************************************************************************^*/
/*- Public Methods.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Returns orientation of the separator.
   *
   * @return orientation of the separator
   */
  public int getOrientation() {
    return orientation;
  }

  /**
   * Sets orientation.
   *
   * @param orientation the orientation
   */
  public void setOrientation(int orientation) {
    if ((orientation < HORIZONTAL) || (orientation > VERTICAL)) {
      throw new IllegalArgumentException("Invalid orientation"); //$NON-NLS-1$
    }
    final int oldOrientation = this.orientation;
    if (oldOrientation != orientation) {
      disposedCheck();
      _setOrientation(_bridge, orientation);
    }
  }

  /**
   * Returns text.
   *
   * @return text
   */
  public String getText() {
    return text;
  }

  /**
   * Sets text.
   *
   * @param text the text
   */
  public void setText(String text) {
    final String oldText = this.text;
    if (oldText == null) {
      if (text == null) {
        return;
      }
    } else {
      if (oldText.equals(text)) {
        return;
      }
    }
    disposedCheck();
    _setText(_bridge, text);
    this.text = text;
    firePropertyChange(PROPERTY_TEXT, oldText, text);
  }

/*^**************************************************************************^*/
/*- Native Callback.                                                         -*/
/*^**************************************************************************^*/

  void _orientationChanged(int orientation) {
    final int oldOrientation = this.orientation;
    if (oldOrientation != orientation) {
      this.orientation = orientation;
      firePropertyChange(PROPERTY_ORIENTATION, oldOrientation, orientation);
    }
  }

/*^**************************************************************************^*/
/*- Package-Private Native Methods.                                          -*/
/*^**************************************************************************^*/

  native long _create();

  native void _setOrientation(long bridge, int orientation);

  native void _setText(long bridge, String text);

/*^**************************************************************************^*/
/*- Private Static Native Method.                                            -*/
/*^**************************************************************************^*/

  private static native void _initialize();

}

/*^*****************************************************************************
  File History:

 - 2007-11-07 20:47:58 Slobodan
   Initial version

*****************************************************************************^*/
