/*
 * @(#)JQStatusBar.java  0.2.0 / 2007-05-04
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing;

import yu.ac.bg.etf.javaqx.qswing.layouts.LayoutManager;
import yu.ac.bg.etf.javaqx.qswing.properties.JQStatusBarProperties;

/**
 * Status Bar Component.
 *
 * @javaqx.native
 *    generate="header"
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class JQStatusBar extends JQContainer implements JQStatusBarProperties {

/*^**************************************************************************^*/
/*- Public Static Final Fields.                                              -*/
/*^**************************************************************************^*/

  /**
   * Temporary constraint (the value is {@value}).
   */
  public static final String TEMPORARY = "temporary"; //$NON-NLS-1$

  /**
   * Permanent constraint (the value is {@value}).
   */
  public static final String PERMANENT = "permanent"; //$NON-NLS-1$

/*^**************************************************************************^*/
/*- Static Initialization.                                                   -*/
/*^**************************************************************************^*/

  static {
    _initialize();
  }

/*^**************************************************************************^*/
/*- Private Fields.                                                          -*/
/*^**************************************************************************^*/

  private String statusMessage;
  private boolean sizeGripEnabled;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JQStatusBar object.
   */
  public JQStatusBar() {
    super(null);
    sizeGripEnabled = true;
  }

/*^**************************************************************************^*/
/*- Public Methods.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Returns current status message.
   *
   * @return current status message
   */
  public String getStatusMessage() {
    return statusMessage;
  }

  /**
   * Sets status message.
   *
   * @param message the status message
   * @param timeout the message time out
   */
  public void showMessage(String message, int timeout) {
    disposedCheck();
    _showMessage(_bridge, message, timeout);
  }

  /**
   * Sets status message.
   *
   * @param message the status message
   */
  public void showMessage(String message) {
    showMessage(message, 0);
  }

  /**
   * Clears the message.
   */
  public void clearMessage() {
    disposedCheck();
    _clearMessage(_bridge);
  }

  /**
   * Returns <tt>true</tt> if the size grip is enabled.
   *
   * @return <tt>true</tt> if the size grip is enabled
   */
  public boolean isSizeGripEnabled() {
    return sizeGripEnabled;
  }

  /**
   * Enables/disables the size grip.
   *
   * @param enabled <tt>true</tt> is enabled
   */
  public void setSizeGripEnabled(boolean enabled) {
    final boolean oldSizeGripEnabled = sizeGripEnabled;
    if (oldSizeGripEnabled != enabled) {
      disposedCheck();
      _setSizeGripEnabled(_bridge, enabled);
      sizeGripEnabled = enabled;
      firePropertyChange(PROPERTY_SIZEGRIP_ENABLED, oldSizeGripEnabled,
                         enabled);
    }
  }

/*^**************************************************************************^*/
/*- Overridden Methods.                                                      -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public void setLayout(LayoutManager layoutManager) {
    // empty method
  }

  /**
   * {@inheritDoc}
   */
  public void validate() {
    // empty method
  }

  /**
   * {@inheritDoc}
   */
  public void invalidate() {
    // empty method
  }

  /**
   * {@inheritDoc}
   */
  public void revalidate() {
    // empty method
  }

  /**
   * {@inheritDoc}
   */
  protected String paramString() {
    StringBuffer sb = new StringBuffer(super.paramString());
    if (statusMessage != null) {
      sb.append(",statusMessage="); //$NON-NLS-1$
      sb.append(statusMessage);
    }
    return sb.toString();
  }

  void insertChild(JQComponent child, Object constraints, int index) {
    if (TEMPORARY.equals(constraints)) {
      _insertChild(_bridge, child._bridge, index);
    } else {
      _insertPermanentChild(_bridge, child._bridge, index);
    }
  }

/*^**************************************************************************^*/
/*- Native Callback.                                                         -*/
/*^**************************************************************************^*/

  void _statusMessgeChanged(String message) {
    final String oldStatusMessage = statusMessage;
    if (oldStatusMessage == null) {
      if (message == null) {
        return;
      }
    } else {
      if (oldStatusMessage.equals(message)) {
        return;
      }
    }
    statusMessage = message;
    firePropertyChange(PROPERTY_STATUS_MESSAGE, oldStatusMessage, message);
  }

/*^**************************************************************************^*/
/*- Package-Private Native Method.                                           -*/
/*^**************************************************************************^*/

  native long _create();

  native void _showMessage(long bridge, String message, int timeout);

  native void _clearMessage(long bridge);

  native void _insertChild(long bridge, long childBridge, int index);

  native void _insertPermanentChild(long bridge, long childBridge, int index);

  native void _removeChild(long bridge, long childBridge);

  native void _setSizeGripEnabled(long bridge, boolean enabled);

/*^**************************************************************************^*/
/*- Private Static Native Method.                                            -*/
/*^**************************************************************************^*/

  private static native void _initialize();

}

/*^*****************************************************************************
  File History:

 - 2007-05-04 18:54:04 Slobodan
   Initial version

*****************************************************************************^*/
