/*
 * @(#)JQTextArea.java  0.2.0 / 2007-09-13
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing;

import yu.ac.bg.etf.javaqx.qswing.graphics.Graphics;
import yu.ac.bg.etf.javaqx.qswing.properties.JQTextAreaProperties;
import yu.ac.bg.etf.javaqx.qswing.text.PlainDocument;

/**
 * Text Area Component.
 * <p>
 *   <tt>NOTE: This class is not compatible with
 *             <em>javax.swing.JTextPane</em> class!</tt>
 * </p>
 * @javaqx.native
 *    generate="header"
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class JQTextArea extends JQTextComponent
                        implements JQTextAreaProperties {

  /** @todo  add scrollbar support */

/*^**************************************************************************^*/
/*- Static Initialization.                                                   -*/
/*^**************************************************************************^*/

  static {
    _initialize();
  }

/*^**************************************************************************^*/
/*- Private Fields.                                                          -*/
/*^**************************************************************************^*/

  private boolean wrapText;
  private QSwingGraphics _viewGraphics;

/*^**************************************************************************^*/
/*- Public Constructors.                                                     -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JQTextArea object.
   */
  public JQTextArea() {
    this((String)null);
  }

  /**
   * Constructs new JQTextArea object.
   *
   * @param text the text
   */
  public JQTextArea(String text) {
    super(new PlainDocument(text));
    documentOwner = true;
  }

  /**
   * Constructs new JQTextArea object.
   *
   * @param document the document
   */
  public JQTextArea(PlainDocument document) {
    super(document);
  }

/*^**************************************************************************^*/
/*- Public Methods.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Returns document.
   *
   * @return document
   */
  public PlainDocument getDocument() {
    return (PlainDocument)document;
  }

  /**
   * Sets document.
   *
   * @param document the document
   */
  public void setDocument(PlainDocument document) { // NOPMD
    super.setDocument(document);
  }

  /**
   * Returns <tt>true</tt> if the text area is wrapping text.
   *
   * @return <tt>true</tt> if the text area is wrapping text
   */
  public boolean isWrapText() {
    return wrapText;
  }

  /**
   * Sets wrap text status.
   *
   * @param wrapText if <tt>true</tt> the text area will wrap text
   */
  public void setWrapText(boolean wrapText) {
    boolean oldWrapText = this.wrapText;
    if (oldWrapText != wrapText) {
      disposedCheck();
      _setWrapText(_bridge, wrapText);
      this.wrapText = wrapText;
      firePropertyChange(PROPERTY_WRAP_TEXT, oldWrapText, wrapText);
    }
  }

/*^**************************************************************************^*/
/*- Protected Methods.                                                       -*/
/*^**************************************************************************^*/

  /**
   * Paints view.
   *
   * @param g the graphics object
   * @param x the x-coordinate of the view
   * @param y the y-coordinate of the view
   * @param width the width of the view
   * @param height the height of the view
   *
   * @throws IllegalStateException if method is called outside paint event
   *         handling
   */
  protected void paintComponentView(Graphics g, int x, int y, int width,
                                    int height) {
    QSwingGraphics graphics = _viewGraphics;
    if ((graphics != null) && (graphics == g)) { // NOPMD
      _paintComponentView(_bridge, graphics._graphicsPointer);
    }
  }

/*^**************************************************************************^*/
/*- Package-Private Method.                                                  -*/
/*^**************************************************************************^*/

  void _paintView(long graphicsPointer, int x, int y, int width, int height) {
    QSwingGraphics graphics = new QSwingGraphics(graphicsPointer);
    _viewGraphics = graphics;
    paintComponentView(graphics, x, y, width, height);
    _viewGraphics = null;
    graphics.dispose();
  }

/*^**************************************************************************^*/
/*- Package-Private Native Methods.                                          -*/
/*^**************************************************************************^*/

  native long _create();

  native void _setWrapText(long bridge, boolean wrapText);

  native void _paintComponentView(long bridge, long graphicsPointer);

/*^**************************************************************************^*/
/*- Private Static Native Method.                                            -*/
/*^**************************************************************************^*/

  private static native void _initialize();

}

/*^*****************************************************************************
  File History:

 - 2007-09-13 18:56:22 Slobodan
   Initial version

*****************************************************************************^*/
