/*
 * @(#)JQToolTip.java  0.2.0 / 2007-12-01
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing;

import yu.ac.bg.etf.javaqx.qswing.graphics.Color;
import yu.ac.bg.etf.javaqx.qswing.graphics.Font;

/**
 * ToolTip Class.
 * <p>
 *    <tt>NOTE: This class is not compatible with
 *              <em>javax.swing.JToolTip</em> class!</tt>
 * </p>
 *
 * @javaqx.native
 *    generate="header"
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public final class JQToolTip extends JQComponent {

/*^**************************************************************************^*/
/*- Private Static Field.                                                    -*/
/*^**************************************************************************^*/

  private static boolean toolTipsEnabled = true;

/*^**************************************************************************^*/
/*- Private Constructor.                                                     -*/
/*^**************************************************************************^*/

 /**
  * Class has no instances.
  */
  private JQToolTip() {
    // empty constructor body
  }

/*^**************************************************************************^*/
/*- Public Static Methods.                                                   -*/
/*^**************************************************************************^*/

  /**
   * Returns <tt>true</tt> if the tooltips are enabled.
   *
   * @return <tt>true</tt> if the tooltips are enabled
   */
  public static boolean areToolTipsEnabled() {
    return toolTipsEnabled;
  }

  /**
   * Enables/disables tooltips.
   *
   * @param enabled <tt>true</tt> if enabled
   */
  public static void setToolTipsEnabled(boolean enabled) {
    if (toolTipsEnabled != enabled) {
      synchronized (QSwing.CLASS_LOCK) {
        QSwing.disposedCheck();
        _setEnabled(enabled);
        toolTipsEnabled = enabled;
      }
    }
  }

  /**
   * Shows tooltip at specified location.
   *
   * @param text the tooltip text
   * @param x the x-coordinate of the tooltip
   * @param y the y-coordinate of the tooltip
   */
  public static void showToolTip(String text, int x, int y) {
    showToolTip(text, x, y, null);
  }

  /**
   * Shows tooltip at specified location.
   *
   * @param text the tooltip text
   * @param x the x-coordinate of the tooltip
   * @param y int y-coordinate of the tooltip
   * @param component the component for which tooltip is provided
   */
  public static void showToolTip(String text, int x, int y,
                                 JQComponent component) {
    if (text != null) {
      synchronized (QSwing.CLASS_LOCK) {
        QSwing.disposedCheck();
        if (component == null) {
          _showText(text, x, y, 0);
        } else {
          _showText(text, x, y, component._bridge);
        }
      }
    }
  }

  /**
   * Hides tooltip.
   */
  public static void hideToolTip() {
    synchronized (QSwing.CLASS_LOCK) {
      QSwing.disposedCheck();
      _hideText();
    }
  }

  /**
   * Sets background color for the tooltips.
   *
   * @param background the background color
   */
  public static void setToolTipsBackground(Color background) {
    synchronized (QSwing.CLASS_LOCK) {
      QSwing.disposedCheck();
      if (background == null) {
        _setNullBackground();
      } else {
        _setBackground(background.getARGB());
      }
    }
  }

  /**
   * Sets foreground color for the tooltips.
   *
   * @param foreground the foreground color
   */
  public static void setToolTipsForeground(Color foreground) {
    synchronized (QSwing.CLASS_LOCK) {
      QSwing.disposedCheck();
      if (foreground == null) {
        _setNullForeground();
      } else {
        _setForeground(foreground.getARGB());
      }
    }
  }

/*^**************************************************************************^*/
/*- Package-Private Native Method.                                           -*/
/*^**************************************************************************^*/

  static native void _setEnabled(boolean enabled);

  static native void _setFont(Font font);

  static native void _setBackground(int argb);

  static native void _setNullBackground();

  static native void _setForeground(int argb);

  static native void _setNullForeground();

  static native void _showText(String text, int x, int y, long componentBridge);

  static native void _hideText();

}

/*^*****************************************************************************
  File History:

 - 2007-12-01 11:18:21 Slobodan
   Initial version

*****************************************************************************^*/
