/*
 * @(#)JQTree.java  0.2.0 / 2007-05-04
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing;

import yu.ac.bg.etf.javaqx.qswing.events.TreeModelEvent;
import yu.ac.bg.etf.javaqx.qswing.events.TreeModelListener;
import yu.ac.bg.etf.javaqx.qswing.events.TreeSelectionEvent;
import yu.ac.bg.etf.javaqx.qswing.events.TreeSelectionListener;
import yu.ac.bg.etf.javaqx.qswing.tree.DefaultMutableTreeNode;
import yu.ac.bg.etf.javaqx.qswing.tree.TreeModel;
import yu.ac.bg.etf.javaqx.qswing.tree.TreeNode;
import yu.ac.bg.etf.javaqx.qswing.tree.TreePath;

/**
 * Tree Component.
 * <p>
 *   <tt>NOTE: This class is not complete!</tt>
 * </p>
 *
 * @javaqx.native
 *    generate="header"
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class JQTree extends JQComponent {

/*^**************************************************************************^*/
/*- Static Initialization.                                                   -*/
/*^**************************************************************************^*/

  static {
    _initialize(TreeNode.class);
  }

/*^**************************************************************************^*/
/*- Private Fields.                                                          -*/
/*^**************************************************************************^*/

  private QSwingIconSet iconSet;
  private TreeModel model;
  private ModelListener modelListener;

/*^**************************************************************************^*/
/*- Public Constructors.                                                     -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JQTree object.
   */
  public JQTree() {
    this(null);
  }

  /**
   * Constructs new JQTree object.
   *
   * @param model the tree model
   */
  public JQTree(TreeModel model) {
    iconSet = new QSwingIconSet(this);
    modelListener = new ModelListener(this);
    _createIcon(_bridge, iconSet); // NOPMD
    this.model = model;
    if (model != null) {
      _setUseModel(_bridge, true); // NOPMD
      model.addTreeModelListener(modelListener);
    }
  }

/*^**************************************************************************^*/
/*- Public Methods.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Returns tree model.
   *
   * @return tree model
   */
  public TreeModel getModel() {
    return model;
  }

  /**
   * Sets tree model.
   *
   * @param model the tree model
   */
  public void setModel(TreeModel model) {
    /** @todo  temp impl. */
    final TreeModel oldModel = this.model;
    if (oldModel != model) { // NOPMD
      disposedCheck();
      if (oldModel != null) {
        oldModel.removeTreeModelListener(modelListener);
      }
      this.model = model;
      if (model == null) {
        _setUseModel(_bridge, false);
      } else {
        _setUseModel(_bridge, true);
        model.addTreeModelListener(modelListener);
      }
      //firePropertyChange(PROPERTY_MODEL, oldModel, model);
    }
  }

  /**
   * Adds tree selection listener.
   *
   * @param listener the tree selection listener
   */
  public void addChangeListener(TreeSelectionListener listener) {
    listenerList.add(TreeSelectionListener.class, listener);
  }

  /**
   * Removes tree selection listener.
   *
   * @param listener the tree selection listener
   */
  public void removeChangeListener(TreeSelectionListener listener) {
    listenerList.remove(TreeSelectionListener.class, listener);
  }

  /**
   * Returns tree selection listeners.
   *
   * @return tree selection listeners
   */
  public TreeSelectionListener[] getChangeListeners() {
    int count = listenerList.getListenerCount(TreeSelectionListener.class);
    TreeSelectionListener[] listeners = new TreeSelectionListener[count];
    if (count > 0) {
      System.arraycopy(
                listenerList.getListenersArray(TreeSelectionListener.class), 0,
                listeners,  0, count);
    }
    return listeners;
  }

/*^**************************************************************************^*/
/*- Protected Methods.                                                       -*/
/*^**************************************************************************^*/

  /**
   * Fires value changed event.
   *
   * @param event the selection event
   */
  protected void fireValueChanged(TreeSelectionEvent event) {
    int count = listenerList.getListenerCount(TreeSelectionListener.class);
    if (count > 0) {
      TreeSelectionListener[] listeners =
          (TreeSelectionListener[])listenerList.
                                 getListenersArray(TreeSelectionListener.class);
      for (int i = count; --i >= 0;) {
        listeners[i].valueChanged(event);
      }
    }
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  void componentDestroyed() {
    super.componentDestroyed();
    if (model != null) {
      model.removeTreeModelListener(modelListener);
    }
  }

/*^**************************************************************************^*/
/*- Native Callbacks.                                                        -*/
/*^**************************************************************************^*/

  TreeNode _getRootNode() {
    if (model != null) {
      Object root = model.getRoot();
      if (root instanceof TreeNode) {
        return (TreeNode)root;
      }
    }
    return null;
  }

  boolean _setNodeIcon(TreeNode node) {
    if (node instanceof DefaultMutableTreeNode) {
      Icon icon = ((DefaultMutableTreeNode)node).getIcon();
      if (icon != null) {
        iconSet.setIcon(icon, null);
        return true;
      }
    }
    iconSet.setIcon(null, null);
    return false;
  }

  void _nodeSelected(TreeNode node) {
    TreePath path = new TreePath(node); /** @todo  make full path to the root */
    fireValueChanged(new TreeSelectionEvent(node, path, true, null, null));
  }

/*^**************************************************************************^*/
/*- Package-Private Native Methods.                                          -*/
/*^**************************************************************************^*/

  native long _create();

  native void _createIcon(long bridge, QSwingIconSet iconSet);

  native void _setUseModel(long bridge, boolean useModel);

/*^**************************************************************************^*/
/*- Private Static Native Method.                                            -*/
/*^**************************************************************************^*/

  private static native void _initialize(Class treeNodeClass);

/*^**************************************************************************^*/
/*- Inner Classes.                                                           -*/
/*^**************************************************************************^*/

  /**
   * Tree Model Listener.
   */
  static class ModelListener implements TreeModelListener {
    final JQTree tree;
    public ModelListener(JQTree tree) {
      this.tree = tree;
    }
    public void treeNodesChanged(TreeModelEvent event) {
      /** @todo  implement */
    }
    public void treeNodesInserted(TreeModelEvent event) {
      /** @todo  implement */
    }
    public void treeNodesRemoved(TreeModelEvent event) {
      /** @todo  implement */
    }
    public void treeStructureChanged(TreeModelEvent event) {
      /** @todo  implement */
    }
  }

}

/*^*****************************************************************************
  File History:

 - 2007-05-04 18:55:38 Slobodan
   Initial version

*****************************************************************************^*/
