/*
 * @(#)WhatsThisManager.java  0.2.0 / 2007-12-01
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing;

/**
 * What's This Manager.
 *
 * @javaqx.native
 *    generate="header"
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public final class WhatsThisManager {

/*^**************************************************************************^*/
/*- Private Static Field.                                                    -*/
/*^**************************************************************************^*/

  private static boolean enabled;

/*^**************************************************************************^*/
/*- Static Initialization.                                                   -*/
/*^**************************************************************************^*/

  static {
    enabled = true;
    QSwing.initialize();
  }

/*^**************************************************************************^*/
/*- Private Constructor.                                                     -*/
/*^**************************************************************************^*/

 /**
  * Class has no instances.
  */
  private WhatsThisManager() {
    // empty constructor body
  }

/*^**************************************************************************^*/
/*- Public Static Methods.                                                   -*/
/*^**************************************************************************^*/

  /**
   * Returns <tt>true</tt> if the what's this help is enabled.
   *
   * @return <tt>true</tt> if the what's this help is enabled
   */
  public static boolean isWhatsThisEnabled() {
    return enabled;
  }

  /**
   * Enables/disables what's this help.
   *
   * @param enabled <tt>true</tt> if enabled
   */
  public static void setWhatsThisEnabled(boolean enabled) {
    if (WhatsThisManager.enabled != enabled) {
      synchronized (QSwing.CLASS_LOCK) {
        QSwing.disposedCheck();
        _setEnabled(enabled);
      }
      WhatsThisManager.enabled = enabled;
    }
  }

  /**
   * Shows <tt>what's this</tt> help location.
   *
   * @param text the what's this help
   * @param x the x-coordinate of the <tt>what's this</tt> help
   * @param y int y-coordinate of the <tt>what's this</tt> help
   */
  public static void showWhatsThis(String text, int x, int y) {
    showWhatsThis(text, x, y, null);
  }

  /**
   * Displays <tt>what's this</tt> help at specified location.
   *
   * @param text the what's this help
   * @param x the x-coordinate of the <tt>what's this</tt> help
   * @param y int y-coordinate of the <tt>what's this</tt> help
   * @param component the component for which <tt>what's this</tt> help is
   *                  provided
   */
  public static void showWhatsThis(String text, int x, int y,
                                   JQComponent component) {
    if (text != null) {
      synchronized (QSwing.CLASS_LOCK) {
        QSwing.disposedCheck();
        if (component == null) {
          _showText(text, x, y, 0);
        } else {
          _showText(text, x, y, component._bridge);
        }
      }
    }
  }

  /**
   * Hides <tt>what's this</tt> help.
   */
  public static void hideWhatsThis() {
    synchronized (QSwing.CLASS_LOCK) {
      QSwing.disposedCheck();
      _hideText();
    }
  }

  /**
   * Returns <tt>true</tt> if the <tt>what's this</tt> mode is active.
   *
   * @return <tt>true</tt> if the <tt>what's this</tt> mode is active
   */
  public static boolean isInWhatsThisMode() {
    synchronized (QSwing.CLASS_LOCK) {
      QSwing.disposedCheck();
      return _isInWhatsThisMode();
    }
  }

  /**
   * Enters/leaves <tt>what's this</tt> mode.
   */
  public static void enterWhatsThisMode() {
    synchronized (QSwing.CLASS_LOCK) {
      QSwing.disposedCheck();
      _enterWhatsThisMode();
    }
  }

  /**
   * Enters/leaves <tt>what's this</tt> mode.
   */
  public static void exitWhatsThisMode() {
    synchronized (QSwing.CLASS_LOCK) {
      QSwing.disposedCheck();
      _exitWhatsThisMode();
    }
  }

/*^**************************************************************************^*/
/*- Package-Private Native Method.                                           -*/
/*^**************************************************************************^*/

  static native void _setEnabled(boolean enabled);

  static native void _showText(String text, int x, int y, long componentBridge);

  static native void _hideText();

  static native boolean _isInWhatsThisMode();

  static native  void _enterWhatsThisMode();

  static native void _exitWhatsThisMode();

}

/*^*****************************************************************************
  File History:

 - 2007-12-01 16:28:47 Slobodan
   Initial version

*****************************************************************************^*/
