/*
 * @(#)ActionEvent.java  0.2.0 / 2007-09-26
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing.events;

/**
 * Action Event.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class ActionEvent extends QSwingEvent {

/*^**************************************************************************^*/
/*- Public Static Fields.                                                    -*/
/*^**************************************************************************^*/

  /**
   * The shift event mask.
   */
  public static final long SHIFT_MASK = InputEvent.SHIFT_MASK;

  /**
   * The ctrl event mask.
   */
  public static final long CTRL_MASK = InputEvent.CTRL_MASK;

  /**
   * The meta event mask.
   */
  public static final long META_MASK = InputEvent.META_MASK;

  /**
   * The alt event mask.
   */
  public static final long ALT_MASK = InputEvent.ALT_MASK;

  /**
   * Action performed id.
   */
  public static final int ACTION_PERFORMED = 1001;

/*^**************************************************************************^*/
/*- Private Static Final Field.                                              -*/
/*^**************************************************************************^*/

  private static final long serialVersionUID = 5639398982850235615L;

/*^**************************************************************************^*/
/*- Private Fields.                                                          -*/
/*^**************************************************************************^*/

  private String actionCommand;
  private long when;
  private int modifiers;

/*^**************************************************************************^*/
/*- Public Constructors.                                                     -*/
/*^**************************************************************************^*/

  /**
   * Constructs new ActionEvent object.
   *
   * @param source the source of the event
   *
   * @throws IllegalArgumentException if the source is <tt>null</tt>
   */
  public ActionEvent(Object source) {
    this(source, ACTION_PERFORMED, 0);
  }

  /**
   * Constructs new ActionEvent object.
   *
   * @param source the source of the event
   * @param modifiers the keyboard modifiers
   *
   * @throws IllegalArgumentException if the source is <tt>null</tt>
   */
  public ActionEvent(Object source, int modifiers) {
    this(source, ACTION_PERFORMED, modifiers);
  }

  /**
   * Constructs new ActionEvent object.
   *
   * @param source the source of the event
   * @param id the event id
   * @param modifiers the keyboard modifiers
   *
   * @throws IllegalArgumentException if the source is <tt>null</tt>
   */
  public ActionEvent(Object source, int id, int modifiers) {
    this(source, id, null, 0, modifiers);
  }

  /**
   * Constructs new ActionEvent object.
   *
   * @param source the source of the event
   * @param id the event id
   * @param actionCommand the command string for the action
   *
   * @throws IllegalArgumentException if the source is <tt>null</tt>
   */
  public ActionEvent(Object source, int id, String actionCommand) {
    this(source, id, actionCommand, 0, 0);
  }

  /**
   * Constructs new ActionEvent object.
   *
   * @param source the source of the event
   * @param id the event id
   * @param actionCommand the command string for the action
   * @param modifiers the keyboard modifiers
   *
   * @throws IllegalArgumentException if the source is <tt>null</tt>
   */
  public ActionEvent(Object source, int id, String actionCommand,
                     int modifiers) {
    this(source, id, actionCommand, 0, modifiers);
  }

  /**
   * Constructs new ActionEvent object.
   *
   * @param source the source of the event
   * @param id the event id
   * @param actionCommand the command string for the action
   * @param when the time the event occurred
   * @param modifiers the keyboard modifiers
   *
   * @throws IllegalArgumentException if the source is <tt>null</tt>
   */
  public ActionEvent(Object source, int id, String actionCommand, long when,
                     int modifiers) {
    super(source, id);
    this.actionCommand = actionCommand;
    this.when = when;
    this.modifiers = modifiers;
  }

/*^**************************************************************************^*/
/*- Public Method.                                                           -*/
/*^**************************************************************************^*/

  /**
   * Returns the command string associated with this action.
   *
   * @return the command string associated with this action
   */
  public String getActionCommand() {
    return actionCommand;
  }

  /**
   * Returns the timestamp of when this event occurred.
   *
   * @return the timestamp of when this event occurred
   */
  public long getWhen() {
    return when;
  }

  /**
   * Returns keyboard modifiers.
   *
   * @return keyboard modifiers
   */
  public int getModifiers() {
    return modifiers;
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public String paramString() {
    String idString;
    if (id == ACTION_PERFORMED) {
      idString = "ACTION_PERFORMED,cmd="; //$NON-NLS-1$
    } else {
      idString = "unknown type,cmd="; //$NON-NLS-1$
    }
    return idString + getActionCommand() + ",when=" + getWhen() + //$NON-NLS-1$
           ",modifiers=" + //$NON-NLS-1$
           InputEvent.getModifiersText(getModifiers());
  }

}

/*^*****************************************************************************
  File History:

 - 2007-09-26 13:10:13 Slobodan
   Initial version

*****************************************************************************^*/
