/*
 * @(#)QSwingEvent.java  0.2.0 / 2007-09-26
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing.events;

import java.util.EventObject;

import yu.ac.bg.etf.javaqx.qswing.JQComponent;
import yu.ac.bg.etf.javaqx.util.CommonConstants;

/**
 * QSwing Event.
 *
 * @javaqx.native
 *    generate="header"
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class QSwingEvent extends EventObject {

/*^**************************************************************************^*/
/*- Public Static Fields.                                                    -*/
/*^**************************************************************************^*/

  /**
   * The component event mask.
   */
  public static final long COMPONENT_EVENT_MASK = 0x00001;

  /**
   * The key event mask.
   */
  public static final long FOCUS_EVENT_MASK = 0x00004;

  /**
   * The key event mask.
   */
  public static final long KEY_EVENT_MASK = 0x00008;

 /**
  * The mouse event mask.
  */
  public static final long MOUSE_EVENT_MASK = 0x00010;

  /**
   * The mouse motion event mask.
   */
  public static final long MOUSE_MOTION_EVENT_MASK = 0x00020;

  /**
   * The window event mask.
   */
  public static final long WINDOW_EVENT_MASK = 0x00040;

  /**
   * The action event mask.
   */
  public static final long ACTION_EVENT_MASK = 0x00080;

  /**
   * The paint event mask.
   */
  public static final long PAINT_EVENT_MASK = 0x02000;

  /**
   * The mouse wheel event mask.
   */
  public static final long MOUSE_WHEEL_EVENT_MASK = 0x20000;

  /**
   * The mouse wheel event mask.
   */
  public static final long LOCATION_TOOL_TIP_MASK = 0x400000;

  /**
   * The context event mask.
   */
  public static final long CONTEXT_MENU_EVENT_MASK = 0x100000;

  /**
   * The custom context event mask.
   */
  public static final long CUSTOM_CONTEXT_MENU_EVENT_MASK = 0x200000;

  /**
   * The paint view event mask.
   */
  public static final long PAINT_VIEW_EVENT_MASK = 0x400000;

/*^**************************************************************************^*/
/*- Private Static Final Field.                                              -*/
/*^**************************************************************************^*/

  private static final long serialVersionUID = 4086376757255785071L;

/*^**************************************************************************^*/
/*- Protected Fields.                                                        -*/
/*^**************************************************************************^*/

  protected int id;
  protected boolean consumed;

/*^**************************************************************************^*/
/*- Public Constructors.                                                     -*/
/*^**************************************************************************^*/

  /**
   * Constructs new QSwingEvent object.
   *
   * @param source the source of the event
   *
   * @throws IllegalArgumentException if the source is <tt>null</tt>
   */
  public QSwingEvent(Object source) {
    super(source);
  }

  /**
   * Constructs new QSwingEvent object.
   *
   * @param source the source of the event
   * @param id the event type
   *
   * @throws IllegalArgumentException if the source is <tt>null</tt>
   */
  public QSwingEvent(Object source, int id) {
    super(source);
    this.id = id;
  }

/*^**************************************************************************^*/
/*- Public Methods.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Returns the event type.
   *
   * @return the event type
   */
  public int getID() {
    return id;
  }

  /**
   * Returns string representation of the event.
   *
   * @return string representation of the event
   */
  public String paramString() {
    return CommonConstants.STRING_EMPTY;
  }

/*^**************************************************************************^*/
/*- Protected Methods.                                                       -*/
/*^**************************************************************************^*/

  /**
   * Returns <tt>true</tt> if the event is consumed.
   *
   * @return <tt>true</tt> if the event is consumed
   */
  protected boolean isConsumed() {
    return consumed;
  }

  /**
   * Consumes the event.
   */
  protected void consume() {
    consumed = true;
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public String toString() {
    String sourceName = null;
    if (source instanceof JQComponent) {
      sourceName = ((JQComponent)source).getName();
    }
    if ((sourceName == null) && (source != null)) {
      sourceName = source.toString();
    }
    return getClass().getName() + "[" + paramString() +  //$NON-NLS-1$
           "] on " + sourceName; //$NON-NLS-1$
  }

}

/*^*****************************************************************************
  File History:

 - 2007-09-26 13:02:22 Slobodan
   Initial version

*****************************************************************************^*/
