/*
 * @(#)TableModelEvent.java  0.2.0 / 2007-09-04
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing.events;

import java.util.EventObject;

import yu.ac.bg.etf.javaqx.qswing.table.TableModel;

/**
 * Table Model Event.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class TableModelEvent extends EventObject {

/*^**************************************************************************^*/
/*- Public Static Fields.                                                    -*/
/*^**************************************************************************^*/

  /**
   * All columns.
   */
  public static final int ALL_COLUMNS = -1;

  /**
   * Header row.
   */
  public static final int HEADER_ROW = -1;

  /**
   * Delete event type.
   */
  public static final int DELETE = -1;

  /**
   * Update event type.
   */
  public static final int UPDATE = 0;

  /**
   * Insert event type.
   */
  public static final int INSERT = 1;

/*^**************************************************************************^*/
/*- Private Static Final Field.                                              -*/
/*^**************************************************************************^*/

  private static final long serialVersionUID = 7661269018906094131L;

/*^**************************************************************************^*/
/*- Protected Fields.                                                        -*/
/*^**************************************************************************^*/

  protected int type;
  protected int column;
  protected int firstRow;
  protected int lastRow;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new TableModelEvent object.
   *
   * @param source the source
   * @param firstRow the first row
   * @param lastRow the last row
   * @param column the column.
   * @param type the type
   */
  public TableModelEvent(TableModel source, int firstRow, int lastRow,
                         int column, int type) {
    super(source);
    this.firstRow = firstRow;
    this.lastRow = lastRow;
    this.column = column;
    this.type = type;
  }

  /**
   * Constructs new TableModelEvent object.
   *
   * @param source the source
   * @param firstRow the first row
   * @param lastRow the last row
   * @param column the column.
   */
  public TableModelEvent(TableModel source, int firstRow, int lastRow,
                         int column) {
    this(source, firstRow, lastRow, column, UPDATE);
  }

  /**
   * Constructs new TableModelEvent object.
   *
   * @param source the source
   * @param firstRow the first row
   * @param lastRow the last row
   */
  public TableModelEvent(TableModel source, int firstRow, int lastRow) {
    this(source, firstRow, lastRow, ALL_COLUMNS, UPDATE);
  }

  /**
   * Constructs new TableModelEvent object.
   *
   * @param source the source
   * @param row the row
   */
  public TableModelEvent(TableModel source, int row) {
    this(source, row, row, ALL_COLUMNS, UPDATE);
  }

  /**
   * Constructs new TableModelEvent object.
   *
   * @param source the source
   */
  public TableModelEvent(TableModel source) {
    this(source, 0, Integer.MAX_VALUE, ALL_COLUMNS, UPDATE);
  }

/*^**************************************************************************^*/
/*- Public Methods.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Returns column.
   *
   * @return column
   */
  public int getColumn() {
    return column;
  }

  /**
   * Returns first row.
   *
   * @return first row
   */
  public int getFirstRow() {
    return firstRow;
  }

  /**
   * Returns last row.
   *
   * @return last row
   */
  public int getLastRow() {
    return lastRow;
  }

  /**
   * Returns type.
   *
   * @return type.
   */
  public int getType() {
    return type;
  }

}

/*^*****************************************************************************
  File History:

 - 2007-09-04 10:51:22 Slobodan
   Initial version

*****************************************************************************^*/
