/*
 * @(#)TreeModelEvent.java  0.2.0 / 2007-09-27
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing.events;

import java.util.EventObject;

import yu.ac.bg.etf.javaqx.qswing.tree.TreePath;
import yu.ac.bg.etf.javaqx.util.CommonConstants;

/**
 * Tree Model Event.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class TreeModelEvent extends EventObject {

/*^**************************************************************************^*/
/*- Private Static Final Field.                                              -*/
/*^**************************************************************************^*/

  private static final long serialVersionUID = 4315718942491928353L;

/*^**************************************************************************^*/
/*- Protected Fields.                                                        -*/
/*^**************************************************************************^*/

  protected transient TreePath path;
  protected int[] childIndices;
  protected Object[] children;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new TreeModelEvent object.
   *
   * @param source the event source
   * @param path the path
   * @param childIndices the child indices
   * @param children the children
   *
   * @throws IllegalArgumentException if the source is <tt>null</tt>
   */
  public TreeModelEvent(Object source, TreePath path, int[] childIndices,
                        Object[] children) {
    super(source);
    this.path = path;
    if (childIndices != null) {
      this.childIndices = (int[])childIndices.clone();
    }
    if (childIndices != null) {
      this.children = (Object[])children.clone();
    }
  }

  /**
   * Constructs new TreeModelEvent object.
   *
   * @param source the event source
   * @param path the path
   *
   * @throws IllegalArgumentException if the source is <tt>null</tt>
   */
  public TreeModelEvent(Object source, TreePath path) {
    super(source);
    this.path = path;
    childIndices = CommonConstants.EMPTY_INT_ARRAY;
  }

  /**
   * Constructs new TreeModelEvent object.
   *
   * @param source the event source
   * @param path the path
   * @param childIndices the child indices
   * @param children the children
   *
   * @throws IllegalArgumentException if the source is <tt>null</tt>
   */
  public TreeModelEvent(Object source, Object[] path, int[] childIndices,
                        Object[] children) {
    this(source, new TreePath(path), childIndices, children);
  }

  /**
   * Constructs new TreeModelEvent object.
   *
   * @param source the event source
   * @param path the path
   *
   * @throws IllegalArgumentException if the source is <tt>null</tt>
   */
  public TreeModelEvent(Object source, Object[] path) {
    this(source, new TreePath(path));
  }

/*^**************************************************************************^*/
/*- Public Methods.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Returns three path.
   *
   * @return three path
   */
  public TreePath getTreePath() {
    return path;
  }

  /**
   * Returns path.
   *
   * @return path
   */
  public Object[] getPath() {
    if (path == null) {
      return CommonConstants.EMPTY_OBJECT_ARRAY;
    }
    return path.getPath();
  }

  /**
   * Returns children.
   *
   * @return children
   */
  public Object[] getChildren() {
    if (children == null) {
      return CommonConstants.EMPTY_OBJECT_ARRAY;
    }
    return (Object[])children.clone();
  }

  /**
   * Return child indices.
   *
   * @return child indices
   */
  public int[] getChildIndices() {
    if (childIndices == null) {
      return CommonConstants.EMPTY_INT_ARRAY;
    }
    return (int[])childIndices.clone();
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public String toString() {
    StringBuffer sb = new StringBuffer(120);
    sb.append(getClass().getName());
    sb.append(CommonConstants.STRING_SPACE);
    sb.append(hashCode());
    if (path != null) {
      sb.append(" path "); //$NON-NLS-1$
      sb.append(path);
    }
    if (childIndices != null) {
      sb.append(" indices [ "); //$NON-NLS-1$
      int cil = childIndices.length;
      for (int i = 0; i < cil; i++) {
        sb.append(childIndices[i]);
        sb.append(CommonConstants.STRING_SPACE);
      }
      sb.append(']');
    }
    if (children != null) {
      sb.append(" children [ "); //$NON-NLS-1$
      int clen = children.length;
      for (int i = 0; i < clen; i++) {
        sb.append(children[i]);
        sb.append(CommonConstants.STRING_SPACE);
      }
      sb.append(']');
    }
    return sb.toString();
  }

}

/*^*****************************************************************************
  File History:

 - 2007-09-27 18:09:26 Slobodan
   Initial version

*****************************************************************************^*/
