/*
 * @(#)WindowListener.java  0.2.0 / 2007-09-26
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing.events;

import java.util.EventListener;

/**
 * Window Listener.
 * <p>
 *   <tt>NOTE: This class is not full compatible with
 *             <em>java.awt.event.WindowListener</em> class!</tt>
 * </p>
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public interface WindowListener extends EventListener {

  /**
   * Notifies listener that the window is made visible.
   *
   * @param e the window event
   */
  public void windowOpened(WindowEvent e);

  /**
   * Notifies listener that the window is closing.
   *
   * @param e the window event
   */
  public void windowClosing(WindowEvent e);

  /**
   * Notifies listener that the window is closed.
   *
   * @param e the window event
   */
  public void windowClosed(WindowEvent e);

  /**
   * Notifies listener that the window is activated.
   *
   * @param e the window event
   */
  public void windowActivated(WindowEvent e);

  /**
   * Notifies listener that the window is deactivated.
   *
   * @param e the window event
   */
  public void windowDeactivated(WindowEvent e);

  /**
   * Notifies listener that the window has gained focus.
   *
   * @param e the window event
   */
  public void windowGainedFocus(WindowEvent e);

  /**
   * Notifies listener that the window has lost focus.
   *
   * @param e the window event
   */
  public void windowLostFocus(WindowEvent e);

  /**
   * Notifies listener that the window state is changed.
   *
   * @param e the window event
   */
  public void windowStateChanged(WindowEvent e);

}

/*^*****************************************************************************
  File History:

 - 2007-09-26 15:38:12 Slobodan
   Initial version

*****************************************************************************^*/
