/*
 * @(#)Image.java  0.2.0 / 2007-10-01
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing.graphics;

/**
 * Abstract Image.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public abstract class Image {

/*^**************************************************************************^*/
/*- Public Static Final Fields.                                              -*/
/*^**************************************************************************^*/

  /**
   * Fast image scaling (the value is {@value}).
   */
  public static final int SCALE_FAST = 2;

  /**
   * Smoot image scaling (the value is {@value}).
   */
  public static final int SCALE_SMOOTH = 4;

/*^**************************************************************************^*/
/*- Public Abstract Methods.                                                 -*/
/*^**************************************************************************^*/

  /**
   * Returns width of the image.
   *
   * @return width of the image
   */
  public abstract int getWidth();

  /**
   * Returns height of the image.
   *
   * @return height of the image
   */
  public abstract int getHeight();

  /**
   * Returns image producer.
   *
   * @return image producer
   */
  public abstract ImageProducer getSource();

  /**
   * Returns scaled image.
   *
   * @param width the width
   * @param height the height
   * @param hints the hints
   *
   * @return scaled image
   */
  public abstract Image getScaledInstance(int width, int height, int hints);

  /**
   * Flushes the resources.
   */
  public abstract void flush();

}

/*^*****************************************************************************
  File History:

 - 2007-10-01 21:06:42 Slobodan
   Initial version

*****************************************************************************^*/
