/*
 * @(#)LayoutManager.java  0.2.0 / 2007-09-29
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing.layouts;

import yu.ac.bg.etf.javaqx.qswing.JQComponent;
import yu.ac.bg.etf.javaqx.qswing.JQContainer;
import yu.ac.bg.etf.javaqx.qswing.graphics.Dimension;

/**
 * Layout Manager.
 * <p>
 *   <tt>NOTE: This class is not full compatible with
 *             <em>java.awt.LayoutManager</em> class!</tt>
 * </p>
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public interface LayoutManager {

  /**
   * Adds the specified component to the layout.
   *
   * @param component the component to be added
   * @param constraints the layout constraints
   */
  public void addLayoutComponent(JQComponent component, Object constraints);

  /**
   * Removes the specified component from the layout.
   *
   * @param component the component to be removed
   */
  public void removeLayoutComponent(JQComponent component);

  /**
   * Calculates the preferred size dimensions for the specified container.
   *
   * @param target the container to be laid out
   *
   * @return the preferred size of the specified container
   */
  public Dimension preferredLayoutSize(JQContainer target);

  /**
   * Calculates the maximum size dimensions for the specified container.
   *
   * @param target the component to be laid out
   *
   * @return the maximum size of the specified container
   */
  public Dimension maximumLayoutSize(JQContainer target);

  /**
   * Calculates the minimum size dimensions for the specified containers.
   *
   * @param target the component to be laid out
   *
   * @return the minimum size of the specified container
   */
  public Dimension minimumLayoutSize(JQContainer target);

  /**
   * Lays out the specified container.
   *
   * @param target the container to be laid out
   */
  public void layoutContainer(JQContainer target);

  /**
   * Invalidates the layout.
   *
   * @param target the container to be laid out
   */
  public void invalidateLayout(JQContainer target);

}

/*^*****************************************************************************
  File History:

 - 2007-09-29 02:17:34 Slobodan
   Initial version

*****************************************************************************^*/
