/*
 * @(#)Size.java  0.1.0 / 2007-11-02
 * Copyright (c) 2002-2007 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 * Copyright (c) 2002-2007 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing.layouts.formlayout;

import java.util.List;

import yu.ac.bg.etf.javaqx.qswing.JQContainer;

/**
 * An interface that describes sizes as used by the {@link FormLayout}:
 * component measuring sizes, constant sizes with value and unit, and bounded
 * sizes that provide lower and upper bounds for a size.<p>
 *
 * You can find a motivation for the different <code>Size</code> types in
 * the Forms whitepaper that is part of the product documentation and that is
 * available online too, see
 * <a href="http://www.jgoodies.com/articles/forms.pdf" >
 * http://www.jgoodies.com/articles/forms.pdf</a>.
 *
 * <p>
 *   <tt>NOTE: This code is part of the
 *       <a href="http://www.jgoodies.org">JGoodies Forms</a> port.</tt>
 * </p>
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.4 $
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public interface Size {

  /**
   * Computes and returns this Size's maximum pixel size applied to the given
   * list of components using the specified measures.<p>
   *
   * Invoked by {@link FormSpec} to determine the size
   * of a column or row. This method is not intended to be called by API users,
   * and it uses API invisible parameter types.
   *
   * @param container       the layout container
   * @param components      the list of components used to compute the size
   * @param minMeasure      the measure that determines the minimum sizes
   * @param prefMeasure     the measure that determines the preferred sizes
   * @param defaultMeasure  the measure that determines the default sizes
   *
   * @return the maximum size in pixels for the given list of components
   */
  public int maximumSize(JQContainer container, List components,
                         FormLayout.Measure minMeasure,
                         FormLayout.Measure prefMeasure,
                         FormLayout.Measure defaultMeasure);

  /**
   * Describes if this Size can be compressed, if container space gets scarce.
   * Used by the FormLayout size computations in <code>#compressedSizes</code>
   * to check whether a column or row can be compressed or not.<p>
   *
   * The ComponentSize <em>default</em> is compressible, as well as BoundedSizes
   * that are based on the <em>default</em> size.
   *
   * @return <code>true</code> for compressible Sizes
   */
  public boolean compressible();

}

/*^*****************************************************************************
  File History:

 - 2007-09-07 Karsten
   Original version 1.1.0

 - 2007-11-02 00:42:59 Slobodan
   QSwing port

*****************************************************************************^*/
