/*
 * @(#)UnitConverter.java  0.2.0 / 2007-10-30
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 * Copyright (c) 2002-2007 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing.layouts.formlayout.util;

import yu.ac.bg.etf.javaqx.qswing.JQComponent;

/**
 * An interface that describes how to convert general sizes to pixel sizes.
 * For example, <em>dialog units</em> require a conversion that honors the font
 * and resolution. The
 * {@link yu.ac.bg.etf.javaqx.qswing.layouts.formlayout.Sizes} class delegates
 * all size conversions to an implementation of this interface.
 *
 * <p>
 *   <tt>NOTE: This code is part of the
 *       <a href="http://www.jgoodies.org">JGoodies Forms</a> port.</tt>
 * </p>
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.2 $
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public interface UnitConverter {

  /**
   * Converts Inches and returns pixels using the specified resolution.
   *
   * @param in         the Inches
   * @param component  the component that provides the graphics object
   *
   * @return the given Inches as pixels
   */
  public int inchAsPixel(double in, JQComponent component);

  /**
   * Converts Millimeters and returns pixels using the resolution of the
   * given component's graphics object.
   *
   * @param mm         Millimeters
   * @param component  the component that provides the graphics object
   *
   * @return the given Millimeters as pixels
   */
  public int millimeterAsPixel(double mm, JQComponent component);

  /**
   * Converts Centimeters and returns pixels using the resolution of the
   * given component's graphics object.
   *
   * @param cm         Centimeters
   * @param component  the component that provides the graphics object
   *
   * @return the given Centimeters as pixels
   */
  public int centimeterAsPixel(double cm, JQComponent component);

  /**
   * Converts DTP Points and returns pixels using the resolution of the
   * given component's graphics object.
   *
   * @param pt          DTP Points
   * @param component   the component that provides the graphics object
   *
   * @return the given Points as pixels
   */
  public int pointAsPixel(int pt, JQComponent component);

  /**
   * Converts horizontal dialog units and returns pixels.
   * Honors the resolution, dialog font size, platform and style.
   *
   * @param dluX       the horizontal dialog units
   * @param component  a component that provides the font and graphics
   *
   * @return the given horizontal dialog units as pixels
   */
  public int dialogUnitXAsPixel(int dluX, JQComponent component);

  /**
   * Converts vertical dialog units and returns pixels.
   * Honors the resolution, dialog font size, platform and style.
   *
   * @param dluY       the vertical dialog units
   * @param component  a component that provides the font and graphics
   *
   * @return the given vertical dialog units as pixels
   */
  public int dialogUnitYAsPixel(int dluY, JQComponent component);

}

/*^*****************************************************************************
  File History:

 - 2007-09-07 Karsten
   Original version 1.1.0

 - 2007-10-30 16:11:59 Slobodan
   QSwing port

*****************************************************************************^*/
