/*
 * @(#)Printer.java  0.2.0 / 2007-09-13
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing.print;

import yu.ac.bg.etf.javaqx.core.AbstractDisposable;
import yu.ac.bg.etf.javaqx.qswing.QSwing;

/**
 * Printer.
 *
 * @javaqx.native
 *    generate="header"
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class Printer extends AbstractDisposable {

/*^**************************************************************************^*/
/*- Static Initialization.                                                   -*/
/*^**************************************************************************^*/

  static {
    QSwing.initialize();
    _initialize();
  }

/*^**************************************************************************^*/
/*- Package-Private Fields.                                                  -*/
/*^**************************************************************************^*/

  long _bridge;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new Printer object.
   */
  public Printer() {
    _bridge = _create(); // NOPMD
    if (_bridge == 0) {
      throw new OutOfMemoryError("Printer creation failed"); //$NON-NLS-1$
    }
  }

/*^**************************************************************************^*/
/*- Public Methods.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Displays page setup dialog.
   */
  public void pageDialog() {
    disposedCheck();
    _pageDialog(_bridge);
  }

  /**
   * Displays printer dialog.
   *
   * @return <tt>true</tt> if dialog is accepted by the user
   */
  public boolean printerDialog() {
    disposedCheck();
    return _printerDialog(_bridge);
  }

/*^**************************************************************************^*/
/*- Overridden Methods.                                                      -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected final void disposeObject() {
    if (_bridge != 0) {
     _destroy(_bridge);
     _bridge = 0;
    }
  }

/*^**************************************************************************^*/
/*- Package-Private Native Methods.                                          -*/
/*^**************************************************************************^*/

  native long _create();

  native void _destroy(long bridge);

  native void _pageDialog(long bridge);

  native boolean _printerDialog(long bridge);

/*^**************************************************************************^*/
/*- Private Static Native Method.                                            -*/
/*^**************************************************************************^*/

  private static native void _initialize();

}

/*^*****************************************************************************
  File History:

 - 2007-09-13 16:11:48 Slobodan
   Initial version

*****************************************************************************^*/
