/*
 * @(#)AbstractStyle.java  0.2.0 / 2007-10-11
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing.styles;

import yu.ac.bg.etf.javaqx.qswing.Style;

/**
 * Abstract Style.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public abstract class AbstractStyle extends Style { // NOPMD - it is abstract

/*^**************************************************************************^*/
/*- Private Fields.                                                          -*/
/*^**************************************************************************^*/

  private final String name;
  private final String description;
  private final Theme theme;
  private int hashCode; // NOPMD

/*^**************************************************************************^*/
/*- Protected Constructor.                                                   -*/
/*^**************************************************************************^*/

  /**
   * Abstract Style.
   *
   * @param name the name
   * @param description the description
   * @param theme the theme
   *
   * @throws IllegalArgumentException if the name is <tt>null</tt>
   */
  protected AbstractStyle(String name, String description, Theme theme) {
    if (name == null) {
      throw new IllegalArgumentException("Null name"); //$NON-NLS-1$
    }
    this.name = name;
    this.description = description;
    this.theme = theme;
  }

/*^**************************************************************************^*/
/*- Overridden Methods.                                                      -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public int hashCode() { // NOPMD
    if (hashCode == 0) {
      hashCode = super.hashCode();
    }
    return hashCode; // NOFB
  }

  /**
   * {@inheritDoc}
   */
  public String getName() {
    return name;
  }

  /**
   * {@inheritDoc}
   */
  public String getDescription() {
    return description;
  }

  /**
   * {@inheritDoc}
   */
  public Theme getTheme() {
    return theme;
  }

}

/*^*****************************************************************************
  File History:

 - 2007-10-11 13:59:11 Slobodan
   Initial version

*****************************************************************************^*/
