/*
 * @(#)AbstractTheme.java  0.2.0 / 2007-10-11
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing.styles;

/**
 * Abstract Theme.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public abstract class AbstractTheme extends Theme { // NOPMD - it is abstract

/*^**************************************************************************^*/
/*- Private Fields.                                                          -*/
/*^**************************************************************************^*/

  private final String name;
  private final ColorPalette colorPalette;
  private final FontSet fontSet;
  private int hashCode; // NOPMD

/*^**************************************************************************^*/
/*- Protected Constructors.                                                  -*/
/*^**************************************************************************^*/

  /**
   * Constructs new AbstractTheme object.
   *
   * @param colorPalette the color palette
   * @param fontSet the font set
   */
  protected AbstractTheme(ColorPalette colorPalette, FontSet fontSet) {
    this(null, colorPalette, fontSet);
  }

  /**
   * Constructs new AbstractTheme object.
   *
   * @param name the name
   * @param colorPalette the color palette
   * @param fontSet the font set
   */
  protected AbstractTheme(String name, ColorPalette colorPalette,
                          FontSet fontSet) {
    this.name = name;
    this.colorPalette = colorPalette;
    this.fontSet = fontSet;
  }

/*^**************************************************************************^*/
/*- Overridden Methods.                                                      -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public int hashCode() { // NOPMD
    if (hashCode == 0) {
      hashCode = super.hashCode();
    }
    return hashCode; // NOFB
  }

  /**
   * {@inheritDoc}
   */
  public String getName() {
    return name;
  }

  /**
   * {@inheritDoc}
   */
  public ColorPalette getColorPalette() {
    return colorPalette;
  }

  /**
   * {@inheritDoc}
   */
  public FontSet getFontSet() {
    return fontSet;
  }

}

/*^*****************************************************************************
  File History:

 - 2007-10-11 14:27:31 Slobodan
   Initial version

*****************************************************************************^*/
