/*
 * @(#)SystemFontSet.java  0.2.0 / 2007-10-13
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing.styles;

import java.util.WeakHashMap;

import yu.ac.bg.etf.javaqx.qswing.graphics.Font;

/**
 * System Font Set.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public final class SystemFontSet extends FontSet {

/*^**************************************************************************^*/
/*- Private Static Field.                                                    -*/
/*^**************************************************************************^*/

  private static WeakHashMap fontSetCache;

/*^**************************************************************************^*/
/*- Static Initialization.                                                   -*/
/*^**************************************************************************^*/

  static {
    fontSetCache = new WeakHashMap();
  }

/*^**************************************************************************^*/
/*- Package-Private Field.                                                   -*/
/*^**************************************************************************^*/

  final String name;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new SystemFontSet object.
   */
  public SystemFontSet() {
    this("System"); //$NON-NLS-1$
  }

/*^**************************************************************************^*/
/*- Pacakge-Private Constructor.                                             -*/
/*^**************************************************************************^*/

  SystemFontSet(String name) {
    if (name == null) {
      throw new IllegalArgumentException("Null name"); //$NON-NLS-1$
    }
    this.name = name;
  }

/*^**************************************************************************^*/
/*- Overridden Methods                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public boolean equals(Object obj) {
    if (obj == this) {
      return true;
    }
    if ((obj != null) && (obj.getClass() == getClass())) {
      SystemFontSet fontSet = (SystemFontSet)obj;
      return name.equals(fontSet.name);
    }
    return false;
  }

  /**
   * {@inheritDoc}
   */
  public int hashCode() {
    return getFontSet().hashCode();
  }

  /**
   * {@inheritDoc}
   */
  public String getName() {
    return name;
  }

  /**
   * {@inheritDoc}
   */
  public Font getDefaultFont() {
    return getFontSet().getDefaultFont();
  }

  /**
   * {@inheritDoc}
   */
  public Font getFixedFont() {
    return getFontSet().getFixedFont();
  }

  /**
   * {@inheritDoc}
   */
  public Font getComponentFont() {
    return getFontSet().getComponentFont();
  }

  /**
   * {@inheritDoc}
   */
  public Font getButtonFont() {
    return getFontSet().getButtonFont();
  }

  /**
   * {@inheritDoc}
   */
  public Font getMenuFont() {
    return getFontSet().getMenuFont();
  }

  /**
   * {@inheritDoc}
   */
  public Font getMenuBarFont() {
    return getFontSet().getMenuBarFont();
  }

  /**
   * {@inheritDoc}
   */
  public Font getTextFont() {
    return getFontSet().getTextFont();
  }

  /**
   * {@inheritDoc}
   */
  public Font getToolTipFont() {
    return getFontSet().getToolTipFont();
  }

/*^**************************************************************************^*/
/*- Private Method.                                                          -*/
/*^**************************************************************************^*/

  private CustomFontSet getFontSet() {
    synchronized (fontSetCache) {
      CustomFontSet fontSet = (CustomFontSet)fontSetCache.get(name);
      if (fontSet == null) {
        fontSet = new CustomFontSet(name);
        fontSetCache.put(name, fontSet);
      }
      return fontSet;
    }
  }

}

/*^*****************************************************************************
  File History:

 - 2007-10-13 13:41:36 Slobodan
   Initial version

*****************************************************************************^*/
