/*
 * @(#)SystemStyle.java  0.2.0 / 2007-10-12
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing.styles;

import yu.ac.bg.etf.javaqx.qswing.QSwing;

/**
 * System Style.
 *
 * @javaqx.native
 *    generate="header"
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public final class SystemStyle extends AbstractStyle {

/*^**************************************************************************^*/
/*- Public Static Fields.                                                    -*/
/*^**************************************************************************^*/

  /**
   * System style name.
   */
  public static final String STYLE_NAME;

  /**
   * System style description.
   */
  public static final String STYLE_DESCRIPTION;

/*^**************************************************************************^*/
/*- Static Initialization.                                                   -*/
/*^**************************************************************************^*/

  static {
    QSwing.initialize();
    STYLE_NAME = _getSystemStyleName();
    STYLE_DESCRIPTION = _getSystemStyleDescription();
  }

/*^**************************************************************************^*/
/*- Private Field.                                                           -*/
/*^**************************************************************************^*/

  private final boolean platformStyle;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new SystemStyle object.
   */
  public SystemStyle() {
    super(STYLE_NAME, STYLE_DESCRIPTION, new SystemTheme());
    platformStyle = true;
  }

/*^**************************************************************************^*/
/*- Pacakge-Private Constructor.                                             -*/
/*^**************************************************************************^*/

  SystemStyle(String name, String description, boolean platformStyle) {
    super(name, description, new SystemTheme(name));
    this.platformStyle = platformStyle;
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public boolean isSupported() {
    return true;
  }

  /**
   * {@inheritDoc}
   */
  public boolean isPlatformStyle() {
    return platformStyle;
  }

/*^**************************************************************************^*/
/*- Private Static Native Method.                                            -*/
/*^**************************************************************************^*/

  private static native String _getSystemStyleName();

  private static native String _getSystemStyleDescription();

}

/*^*****************************************************************************
  File History:

 - 2007-10-12 00:59:11 Slobodan
   Initial version

*****************************************************************************^*/
