/*
 * @(#)Theme.java  0.2.0 / 2007-10-11
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing.styles;

import yu.ac.bg.etf.javaqx.util.Utilities;

/**
 * The font and color theme of the style.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public abstract class Theme {

/*^**************************************************************************^*/
/*- Public Methods.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Returns the name of the theme.
   *
   * @return the name of the theme
   */
  public abstract String getName();

  /**
   * Returns <tt>true</tt> if the theme is supported on the platform.
   *
   * @return <tt>true</tt> if the theme is supported on the platform
   */
  public abstract boolean isSupported();

  /**
   * Returns color palette.
   *
   * @return color palette
   */
  public abstract ColorPalette getColorPalette();

  /**
   * Returns font set.
   *
   * @return font set
   */
  public abstract FontSet getFontSet();

/*^**************************************************************************^*/
/*- Overridden Methods.                                                      -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public boolean equals(Object obj) {
    if (obj == this) {
      return true;
    }
    if ((obj != null) && (obj.getClass() == getClass())) {
      Theme theme = (Theme)obj;
      return (isSupported() == theme.isSupported()) &&
              Utilities.equals(getName(), theme.getName()) &&
              Utilities.equals(getColorPalette(), theme.getColorPalette()) &&
              Utilities.equals(getFontSet(), theme.getFontSet());
    }
    return false;
  }

  /**
   * {@inheritDoc}
   */
  public int hashCode() {
    int hashCode = 491;
    String name = getName();
    if (name != null) {
      hashCode = 439 * hashCode + name.hashCode();
    }
    ColorPalette colorPalette = getColorPalette();
    if (colorPalette != null) {
      hashCode = 439 * hashCode + colorPalette.hashCode();
    }
    FontSet fontSet = getFontSet();
    if (fontSet != null) {
      hashCode = 439 * hashCode + fontSet.hashCode();
    }
    return hashCode;
  }

  /**
   * {@inheritDoc}
   */
  public String toString() {
    return getName();
  }

}

/*^*****************************************************************************
  File History:

 - 2007-10-11 10:35:16 Slobodan
   Initial version

*****************************************************************************^*/
