/*
 * @(#)TableModel.java  0.2.0 / 2007-09-04
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing.table;

import yu.ac.bg.etf.javaqx.qswing.events.TableModelListener;

/**
 * Table Model Interface.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public interface TableModel {

  /**
   * Returns the number of rows.
   *
   * @return the number of rows
   */
  public int getRowCount();

  /**
   * Returns the number of columns.
   *
   * @return the number of columns
   */
  public int getColumnCount();

  /**
   * Returns the name of the specified column.
   *
   * @param columnIndex the column index
   *
   * @return the name of the specified column
   */
  public String getColumnName(int columnIndex);

  /**
   * Returns the class of the specified column.
   *
   * @param columnIndex the column index
   *
   * @return the class of the specified column
   */
  public Class getColumnClass(int columnIndex);

  /**
   * Returns <tt>true</tt> if the cell is editable.
   *
   * @param rowIndex the row index
   * @param columnIndex the column index
   *
   * @return <tt>true</tt> if the cell is editable
   */
  public boolean isCellEditable(int rowIndex, int columnIndex);

  /**
   * Returns the value of the specified cell.
   *
   * @param rowIndex the row index
   * @param columnIndex the column index
   *
   * @return the value of the specified cell
   */
  public Object getValueAt(int rowIndex, int columnIndex);

  /**
   * Sets the value for the specified cell.
   *
   * @param value the value
   * @param rowIndex the row index
   * @param columnIndex the column index
   */
  public void setValueAt(Object value, int rowIndex, int columnIndex);

  /**
   * Adds listener.
   *
   * @param listener the listener
   */
  public void addTableModelListener(TableModelListener listener);

  /**
   * Removes a listener.
   *
   * @param listener the listener
   */
  public void removeTableModelListener(TableModelListener listener);

}

/*^*****************************************************************************
  File History:

 - 2007-09-04 10:57:58 Slobodan
   Initial version

*****************************************************************************^*/
