/*
 * @(#)CharacterFormat.java  0.2.0 / 2007-12-11
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing.text;

import yu.ac.bg.etf.javaqx.qswing.QSwing;
import yu.ac.bg.etf.javaqx.qswing.graphics.Color;
import yu.ac.bg.etf.javaqx.qswing.graphics.Font;

/**
 * Character Format.
 *
 * @javaqx.native
 *    generate="jni"
 *    includes="QTextCharFormatAdapter.h"
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class CharacterFormat {

/*^**************************************************************************^*/
/*- Static Initialization.                                                   -*/
/*^**************************************************************************^*/

  static {
    QSwing.initialize();
    _initialize();
  }

/*^**************************************************************************^*/
/*- Pacakge-Private Fields.                                                  -*/
/*^**************************************************************************^*/

  Font font;
  boolean fontBold;
  Color color;

/** @todo  add other fields */

/*^**************************************************************************^*/
/*- Public Constructors.                                                     -*/
/*^**************************************************************************^*/

  /**
   * Constructs new CharacterFormat object.
   */
  public CharacterFormat() {
    // empty constructor body
  }

  /**
   * Constructs new CharacterFormat object.
   *
   * @param font the font
   */
  public CharacterFormat(Font font) {
    this.font = font;
  }

  /**
   * Constructs new CharacterFormat object.
   *
   * @param color the color
   */
  public CharacterFormat(Color color) {
    this.color = color;
  }

/*^**************************************************************************^*/
/*- Public Methods.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Returns font.
   *
   * @return font.
   */
  public Font getFont() {
    return font;
  }

  /**
   * Sets font.
   *
   * @param font the font
   */
  public void setFont(Font font) {
    this.font = font;
  }

  /**
   * Returns <tt>true</tt> if the font is bold.
   *
   * @return <tt>true</tt> if the font is bold
   */
  public boolean isFontBold() {
    return fontBold;
  }

  /**
   * Sets whether or not the font is bold.
   *
   * @param fontBold <tt>true</tt> if bold
   */
  public void setFontBold(boolean fontBold) {
    this.fontBold = fontBold;
  }

  /**
   * Returns color.
   *
   * @return color
   */
  public Color getColor() {
    return color;
  }

  /**
   * Sets color.
   *
   * @param color the color
   */
  public void setColor(Color color) {
    this.color = color;
  }

/** @todo  add other getter and setter */

/*^**************************************************************************^*/
/*- Private Static Native Method.                                            -*/
/*^**************************************************************************^*/

  /**
   * @javaqx.native
   *    code="QTextCharFormatAdapter::initialize(env, cls);"
   */
  private static native void _initialize();

}

/*^*****************************************************************************
  File History:

 - 2007-12-11 13:52:26 Slobodan
   Initial version

*****************************************************************************^*/
