/*
 * @(#)TextHighlighter.java  0.2.0 / 2007-12-11
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing.text;

/**
 * Abstract Text Highlighter.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public abstract class TextHighlighter {

/*^**************************************************************************^*/
/*- Private Field.                                                           -*/
/*^**************************************************************************^*/

  private final Object lock;
  private TextDocument currentDocument;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new TextHighlighter object.
   */
  public TextHighlighter() {
    lock = new Object();
  }

/*^**************************************************************************^*/
/*- Protected Methods.                                                       -*/
/*^**************************************************************************^*/

  /**
   * Highlighs specified block of text.
   *
   * @param blockStart the start of the block
   * @param blockText the text of the block
   */
  protected abstract void highlightBlock(int blockStart, String blockText);

  /**
   * Sets the color for the specified text segment.
   *
   * @param start the start of the segment
   * @param length the length of the segment
   * @param format the character format
   */
  protected void setFormat(int start, int length, CharacterFormat format) {
    synchronized (lock) {
      if (currentDocument != null) {
        currentDocument.setFormat(start, length, format);
      }
    }
  }

/*^**************************************************************************^*/
/*- Package-Private Methods.                                                 -*/
/*^**************************************************************************^*/

  void highlightDocumentBlock(TextDocument document, int blockStart,
                              String blockText) {
    synchronized (lock) {
      currentDocument = document;
      highlightBlock(blockStart, blockText);
      currentDocument = null;
    }
  }

}

/*^*****************************************************************************
  File History:

 - 2007-12-11 13:54:22 Slobodan
   Initial version

*****************************************************************************^*/
