/*
 * @(#)TreeNode.java  0.2.0 / 2007-05-04
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing.tree;

import java.util.Iterator;

/**
 * Tree Node Interface.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public interface TreeNode {

  /**
   * Returns parent of the node.
   *
   * @return parent of the node
   */
  public TreeNode getParent();

  /**
   * Returns <tt>true</tt> if the node is leaf.
   *
   * @return <tt>true</tt> if the node is leaf
   */
  public boolean isLeaf();

  /**
   * Returns <tt>true</tt> if the node allows children.
   *
   * @return <tt>true</tt> if the node allows children
   */
  public boolean getAllowsChildren();

  /**
   * Returns the number of children.
   *
   * @return the number of children
   */
  public int getChildCount();

  /**
   * Returns child at the specified index.
   *
   * @param index the child index
   *
   * @return child at the specified index
   */
  public TreeNode getChildAt(int index);

  /**
   * Returns index of specified node or -1 if there is no such node.
   *
   * @param node the node
   *
   * @return index of specified node or -1 if there is no such node
   */
  public int getIndex(TreeNode node);

  /**
   * Returns iterator over the children of the node.
   *
   * @return iterator over the children of the node
   */
  public Iterator children();

}

/*^*****************************************************************************
  File History:

 - 2007-05-04 19:06:34 Slobodan
   Initial version

*****************************************************************************^*/
