/*
 * @(#)JQStyleMenu.java  0.2.0 / 2007-05-04
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswingx;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

import yu.ac.bg.etf.javaqx.qswing.JQMenu;
import yu.ac.bg.etf.javaqx.qswing.JQRadioButtonMenuItem;
import yu.ac.bg.etf.javaqx.qswing.QSwing;
import yu.ac.bg.etf.javaqx.qswing.Style;
import yu.ac.bg.etf.javaqx.qswing.events.ActionEvent;
import yu.ac.bg.etf.javaqx.qswing.events.ActionListener;

/**
 * Style Menu.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class JQStyleMenu extends JQMenu {

/*^**************************************************************************^*/
/*- Package-Private Fields.                                                  -*/
/*^**************************************************************************^*/

  boolean styleChangeEnabled;
  final StyleChangeListener styleChangeListener;

/*^**************************************************************************^*/
/*- Public Constructors.                                                     -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JQStyleMenu object.
   */
  public JQStyleMenu() {
    this("&Style"); //$NON-NLS-1$
  }

  /**
   * Constructs new JQStyleMenu object.
   *
   * @param title the menu title
   */
  public JQStyleMenu(String title) {
    super(title);
    StyleActionListener actionListener = new StyleActionListener(this);
    String currentStyleName = QSwing.getStyleName();
    String[] styleNames = QSwing.getInstalledStyleNames();
    for (int i = 0; i < styleNames.length; i++) {
      JQRadioButtonMenuItem rbmi = new JQRadioButtonMenuItem(styleNames[i]);
      if (currentStyleName.equals(styleNames[i])) {
        rbmi.setSelected(true);
      }
      add(rbmi);
      rbmi.addActionListener(actionListener);
    }
    styleChangeListener = new StyleChangeListener(this);
    QSwing.addPropertyChangeListener(QSwing.PROPERTY_STYLE,
                                     styleChangeListener);
    styleChangeEnabled = true;
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected void disposeComponent() {
    QSwing.removePropertyChangeListener(QSwing.PROPERTY_THEME,
                                        styleChangeListener);
    super.disposeComponent();
  }

/*^**************************************************************************^*/
/*- Inner Classes.                                                           -*/
/*^**************************************************************************^*/

  /**
   * Style Action Listener.
   */
  static final class StyleActionListener implements ActionListener {
    private final JQStyleMenu styleMenu;
    public StyleActionListener(JQStyleMenu styleMenu) {
      this.styleMenu = styleMenu;
    }
    public void actionPerformed(ActionEvent e) {
      if (styleMenu.styleChangeEnabled) {
        JQRadioButtonMenuItem rbmi = (JQRadioButtonMenuItem)e.getSource();
        if (rbmi.isSelected()) {
          QSwing.setStyleSafely(rbmi.getText());
        }
      }
    }
  }

  /**
   * Style Property Change Listener.
   */
  static final class StyleChangeListener implements PropertyChangeListener {
    private final JQStyleMenu styleMenu;
    public StyleChangeListener(JQStyleMenu styleMenu) {
      this.styleMenu = styleMenu;
    }
    public void propertyChange(PropertyChangeEvent e) {
      final JQStyleMenu styleMenu = this.styleMenu;
      styleMenu.styleChangeEnabled = false;
      String styleName = ((Style)e.getNewValue()).getName();
      for (int i = styleMenu.getComponentCount(); --i >= 0;) {
        JQRadioButtonMenuItem rbmi =
                              (JQRadioButtonMenuItem)styleMenu.getComponent(i);
        if (styleName.equals(rbmi.getText())) {
          rbmi.setSelected(true);
          break;
        }
      }
      styleMenu.styleChangeEnabled = true;
    }
  }

}

/*^*****************************************************************************
  File History:

 - 2007-05-04 19:05:08 Slobodan
   Initial version

*****************************************************************************^*/
