/*
 * @(#)JQThemeMenu.java  0.2.0 / 2007-05-04
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswingx;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

import yu.ac.bg.etf.javaqx.qswing.JQCheckBoxMenuItem;
import yu.ac.bg.etf.javaqx.qswing.JQMenu;
import yu.ac.bg.etf.javaqx.qswing.JQRadioButtonMenuItem;
import yu.ac.bg.etf.javaqx.qswing.QSwing;
import yu.ac.bg.etf.javaqx.qswing.events.ActionEvent;
import yu.ac.bg.etf.javaqx.qswing.events.ActionListener;
import yu.ac.bg.etf.javaqx.qswing.styles.Theme;
import yu.ac.bg.etf.javaqx.qswing.styles.SystemStyle;

/**
 * Theme Menu.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class JQThemeMenu extends JQMenu {

/*^**************************************************************************^*/
/*- Package-Private Fields.                                                  -*/
/*^**************************************************************************^*/

  boolean themeChangeEnabled;
  final ThemeChangeListener themeChangeListener;

/*^**************************************************************************^*/
/*- Public Constructors.                                                     -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JQThemeMenu object.
   */
  public JQThemeMenu() {
    this("&Theme"); //$NON-NLS-1$
  }

  /**
   * Constructs new JQThemeMenu object.
   *
   * @param title the menu title
   */
  public JQThemeMenu(String title) {
    super(title);
    boolean useSystemTheme = QSwing.isUsingSystemTheme();
    AlwaysUseSystemActionListener ausal =
                                       new AlwaysUseSystemActionListener(this);
    JQCheckBoxMenuItem cbmi = new JQCheckBoxMenuItem(
                                           "&Always Use System"); //$NON-NLS-1$
    cbmi.setChecked(useSystemTheme);
    add(cbmi);
    cbmi.addActionListener(ausal);
    addSeparator();
    String currentThemeName = QSwing.getThemeName();
    String[] themes = QSwing.getInstalledThemeNames();
    ThemeActionListener themeActionListener = new ThemeActionListener(this);
    for (int i = 0; i < themes.length; i++) {
      String themeName = themes[i];
      JQRadioButtonMenuItem rbmi = new JQRadioButtonMenuItem(themeName);
      add(rbmi);
      if (themeName.equals(currentThemeName)) {
        rbmi.setSelected(true);
      }
      rbmi.addActionListener(themeActionListener);
    }
    themeChangeListener = new ThemeChangeListener(this);
    QSwing.addPropertyChangeListener(QSwing.PROPERTY_THEME,
                                     themeChangeListener);
    themeChangeEnabled = true;
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected void disposeComponent() {
    QSwing.removePropertyChangeListener(QSwing.PROPERTY_THEME,
                                        themeChangeListener);
    super.disposeComponent();
  }

/*^**************************************************************************^*/
/*- Inner Classes.                                                           -*/
/*^**************************************************************************^*/

  /**
   * Always System Action Listener.
   */
  static final class AlwaysUseSystemActionListener implements ActionListener {
    private final JQThemeMenu themeMenu;
    public AlwaysUseSystemActionListener(JQThemeMenu themeMenu) {
      this.themeMenu = themeMenu;
    }
    public void actionPerformed(ActionEvent e) {
      boolean alwaysUseSystem = ((JQCheckBoxMenuItem)e.getSource()).isChecked();
      QSwing.setUseSystemTheme(alwaysUseSystem);
      alwaysUseSystem = !alwaysUseSystem;
      final JQThemeMenu themeMenu = this.themeMenu;
      for (int i = themeMenu.getComponentCount(); --i > 1;) {
        themeMenu.getComponent(i).setEnabled(alwaysUseSystem);
      }
    }
  }

  /**
   * Theme Action Listener.
   */
  static final class ThemeActionListener implements ActionListener {
    private final JQThemeMenu themeMenu;
    public ThemeActionListener(JQThemeMenu themeMenu) {
      this.themeMenu = themeMenu;
    }
    public void actionPerformed(ActionEvent e) {
      if (themeMenu.themeChangeEnabled) {
        JQRadioButtonMenuItem rbmi = (JQRadioButtonMenuItem)e.getSource();
        if (rbmi.isSelected()) {
          QSwing.setThemeSafely(rbmi.getText());
        }
      }
    }
  }

  /**
   * Theme Property Change Listener.
   */
  static final class ThemeChangeListener implements PropertyChangeListener {
    private final JQThemeMenu themeMenu;
    public ThemeChangeListener(JQThemeMenu themeMenu) {
      this.themeMenu = themeMenu;
    }
    public void propertyChange(PropertyChangeEvent e) {
      final JQThemeMenu themeMenu = this.themeMenu;
      themeMenu.themeChangeEnabled = false;
      String themeName = ((Theme)e.getNewValue()).getName();
      if (themeName.equals(SystemStyle.STYLE_NAME)) { // NOPMD
        themeName = "System"; //$NON-NLS-1$
      }
      for (int i = themeMenu.getComponentCount(); --i > 1;) {
        JQRadioButtonMenuItem rbmi =
                              (JQRadioButtonMenuItem)themeMenu.getComponent(i);
        if (themeName.equals(rbmi.getText())) {
          rbmi.setSelected(true);
          break;
        }
      }
      themeMenu.themeChangeEnabled = true;
    }
  }

}

/*^*****************************************************************************
  File History:

 - 2007-05-04 19:05:13 Slobodan
   Initial version

*****************************************************************************^*/
