/*
 * @(#)TextComponentRedoAction.java  0.2.0 / 2007-12-12
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswingx.actions;

import yu.ac.bg.etf.javaqx.qswing.JQTextComponent;
import yu.ac.bg.etf.javaqx.qswing.events.ActionEvent;
import yu.ac.bg.etf.javaqx.qswing.events.UndoRedoListener;

/**
 * Text Component Redo Action.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class TextComponentRedoAction extends RedoAction
                                     implements UndoRedoListener {

/*^**************************************************************************^*/
/*- Protected Field.                                                         -*/
/*^**************************************************************************^*/

  protected final JQTextComponent textComponent;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
  * Constructs new TextComponentRedoAction object.
  *
  * @param textComponent the text component
  */
  public TextComponentRedoAction(JQTextComponent textComponent) {
    if (textComponent == null) {
      throw new IllegalArgumentException("Null text component"); //$NON-NLS-1$
    }
    this.textComponent = textComponent;
    textComponent.addUndoRedoListener(this);
    setEnabled(textComponent.isRedoAvailable());
  }

/*^**************************************************************************^*/
/*- Public Method.                                                           -*/
/*^**************************************************************************^*/

  /**
   * Unregisters listener.
   */
  public void unregisterListener() {
    textComponent.removeUndoRedoListener(this);
  }

/*^**************************************************************************^*/
/*- Overridden Methods.                                                      -*/
/*^**************************************************************************^*/

  /**
  * {@inheritDoc}
  */
  public void actionPerformed(ActionEvent e) {
    if (isEnabled()) {
      textComponent.redo();
    }
  }

  /**
  * {@inheritDoc}
  */
  public void undoAvailable(boolean available) {
    // empty method
  }

  /**
  * {@inheritDoc}
  */
  public void redoAvailable(boolean available) {
    setEnabled(available);
  }

}

/*^*****************************************************************************
  File History:

 - 2007-12-12 22:03:50 Slobodan
   Initial version

*****************************************************************************^*/
