/*
 * @(#)TextComponentSelectAllAction.java  0.2.0 / 2007-12-14
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswingx.actions;

import yu.ac.bg.etf.javaqx.qswing.JQTextComponent;
import yu.ac.bg.etf.javaqx.qswing.events.ActionEvent;
import yu.ac.bg.etf.javaqx.qswing.events.EditListener;

/**
 * Text Component Select All Action.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class TextComponentSelectAllAction extends SelectAllAction
                                          implements EditListener {

/*^**************************************************************************^*/
/*- Protected Field.                                                         -*/
/*^**************************************************************************^*/

  protected final JQTextComponent textComponent;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new TextComponentSelectAllAction object.
   *
   * @param textComponent the text component
   */
  public TextComponentSelectAllAction(JQTextComponent textComponent) {
    if (textComponent == null) {
      throw new IllegalArgumentException("Null text component"); //$NON-NLS-1$
    }
    this.textComponent = textComponent;
    textComponent.addEditListener(this);
    setEnabled(textComponent.isSelectAllAvailable());
  }

/*^**************************************************************************^*/
/*- Public Method.                                                           -*/
/*^**************************************************************************^*/

  /**
   * Unregisters listener.
   */
  public void unregisterListener() {
    textComponent.removeEditListener(this);
  }

/*^**************************************************************************^*/
/*- Overridden Methods.                                                      -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public void actionPerformed(ActionEvent e) {
    if (isEnabled()) {
      textComponent.selectAll();
    }
  }

  /**
   * {@inheritDoc}
   */
  public void cutAvailable(boolean available) {
    // empty method
  }

  /**
   * {@inheritDoc}
   */
  public void copyAvailable(boolean available) {
    // empty method
  }

  /**
   * {@inheritDoc}
   */
  public void pasteAvailable(boolean available) {
    // empty method
  }

  /**
   * {@inheritDoc}
   */
  public void clearAvailable(boolean available) {
    // empty method
  }

  /**
   * {@inheritDoc}
   */
  public void selectAllAvailable(boolean available) {
    setEnabled(available);
  }

}

/*^*****************************************************************************
  File History:

 - 2007-12-14 09:26:18 Slobodan
   Initial version

*****************************************************************************^*/
