/*
 * @(#)CodeViewer.java  0.2.0 / 2007-12-08
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswingx.text.code;

import yu.ac.bg.etf.javaqx.qswing.JQTextArea;
import yu.ac.bg.etf.javaqx.qswing.events.QSwingEvent;
import yu.ac.bg.etf.javaqx.qswing.graphics.Color;
import yu.ac.bg.etf.javaqx.qswing.graphics.Font;
import yu.ac.bg.etf.javaqx.qswing.graphics.Graphics;
import yu.ac.bg.etf.javaqx.qswing.text.TextHighlighter;

/**
 * Code Viewer.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class CodeViewer extends JQTextArea {

/*^**************************************************************************^*/
/*- Private Fields.                                                          -*/
/*^**************************************************************************^*/

  private int marginWidth;
  private int marginLocation;
  private Color marginColor;

/*^**************************************************************************^*/
/*- Public Constructors.                                                     -*/
/*^**************************************************************************^*/

  /**
   * Constructs new CodeViewer object.
   */
  public CodeViewer() {
    this(80);
  }

  /**
   * Constructs new CodeViewer object.
   *
   * @param marginWidth the width of the margin
   */
  public CodeViewer(int marginWidth) {
    this.marginWidth = marginWidth;
    marginColor = Color.LIGHT_GRAY;
    if (marginWidth > 0) {
      enableEvents(QSwingEvent.PAINT_VIEW_EVENT_MASK);
    }
    super.setEditable(false);
  }

  /**
   * Constructs new CodeViewer object.
   *
   * @param highlighter the document highlighter
   */
  public CodeViewer(TextHighlighter highlighter) {
    this(80);
    getDocument().setHighlighter(highlighter);
  }

/*^**************************************************************************^*/
/*- Public Method.                                                           -*/
/*^**************************************************************************^*/

  /**
   * Returns the width of the margin.
   *
   * @return the width of the margin
   */
  public int getMarginWidth() {
    return marginWidth;
  }

  /**
   * Sets the width of the margin.
   *
   * @param marginWidth the width of the margin
   */
  public void setMarginWidth(int marginWidth) {
    if (this.marginWidth != marginWidth) {
      this.marginWidth = marginWidth;
      if (marginWidth > 0) {
        enableEvents(QSwingEvent.PAINT_VIEW_EVENT_MASK);
      } else {
        disableEvents(QSwingEvent.PAINT_VIEW_EVENT_MASK);
      }
    }
  }

  /**
   * Returns the color of the margin.
   *
   * @return the color of the margin
   */
  public Color getMarginColor() {
    return marginColor;
  }

  /**
   * Sets the color of the margin.
   *
   * @param marginColor the color of the margin
   */
  public void setMarginColor(Color marginColor) {
    this.marginColor = marginColor;
    update();
  }

/*^**************************************************************************^*/
/*- Overridden Methods.                                                      -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public void setFont(Font font) {
    super.setFont(font);
    marginLocation = 0;
  }

  /**
   * {@inheritDoc}
   */
  public void setEditable(boolean editable) {
    // forbidden method
  }

  /**
   * {@inheritDoc}
   */
  protected void paintComponentView(Graphics g, int x, int y, int width,
                                    int height) {
    if (marginLocation == 0) {
      marginLocation = (marginWidth *
                        g.getFontMetrics().stringWidth("M")) + 1; //$NON-NLS-1$a
    }
    g.setColor(marginColor);
    g.drawLine(marginLocation, y, marginLocation, y + height);
    super.paintComponentView(g, x, y, width, height);
  }

  /**
   * {@inheritDoc}
   */
  protected void processStyleChange() {
    super.processStyleChange();
    marginLocation = 0;
  }

}

/*^*****************************************************************************
  File History:

 - 2007-12-08 22:52:15 Slobodan
   Initial version

*****************************************************************************^*/
