/*
 * @(#)JavaHighlighter.java  0.2.0 / 2007-12-13
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswingx.text.code;

import yu.ac.bg.etf.javaqx.qswing.graphics.Color;
import yu.ac.bg.etf.javaqx.qswing.text.CharacterFormat;
import yu.ac.bg.etf.javaqx.qswing.text.TextHighlighter;

/**
 * Java Syntax Highlighter.
 * <p>
 *   <tt>NOTE: This is an ad hoc implementation.</tt>
 * </p>
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class JavaHighlighter extends TextHighlighter {

/*^**************************************************************************^*/
/*- Private Fields.                                                          -*/
/*^**************************************************************************^*/

  private final CharacterFormat keywordFormat;
  private final CharacterFormat commentFormat;
  private final CharacterFormat stringFormat;
  private JavaScanner javaScanner;
  private int lastBlockStart;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JavaHighlighter object.
   */
  public JavaHighlighter() {
    keywordFormat = new CharacterFormat();
    keywordFormat.setColor(new Color(0, 0, 113));
    keywordFormat.setFontBold(true);
    commentFormat = new CharacterFormat();
    commentFormat.setColor(new Color(0, 113, 0));
    stringFormat = new CharacterFormat();
    stringFormat.setColor(new Color(0, 0, 208));
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected void highlightBlock(int blockStart, String blockText) {
    if ((javaScanner == null) || (blockStart < lastBlockStart)) {
      javaScanner = new JavaScanner(blockText);
    } else {
      javaScanner.continueScan(blockText);
    }
    try {
      JavaToken javaToken = javaScanner.nextToken();
      while (javaToken != null) {
        switch (javaToken.type) { // NOPMD
          case JavaToken.KEYWORD:
            setFormat(javaToken.start, javaToken.length, keywordFormat);
            break;
          case JavaToken.COMMENT_END:
            setFormat(javaToken.start, javaToken.length, commentFormat);
            break;
          case JavaToken.INLINE_COMMENT:
             // falls through
          case JavaToken.EOCB:
            setFormat(javaToken.start, javaToken.length, commentFormat);
            return;
          case JavaToken.STRING:
             // falls through
          case JavaToken.NUMBER:
            setFormat(javaToken.start, javaToken.length, stringFormat);
            break;
        }
        javaToken = javaScanner.nextToken();
      }
    } catch (Throwable t) { // NOPMD
      // empty catch block
    }
    blockStart = lastBlockStart;
  }

}

/*^*****************************************************************************
  File History:

 - 2007-12-13 22:03:41 Slobodan
   Initial version

*****************************************************************************^*/
