/*
 * @(#)TestAbstractDisposable.java  0.2.0 / 2007-09-07
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.core;

import junit.framework.TestCase;

import yu.ac.bg.etf.javaqx.core.events.DisposeListener;
import yu.ac.bg.etf.javaqx.core.events.DisposeEvent;

/**
 * AbstractDisposable Test.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class TestAbstractDisposable extends TestCase {

/*^**************************************************************************^*/
/*- Private Field.                                                           -*/
/*^**************************************************************************^*/

  private AbstractDisposable abstractDisposable = null;

/*^**************************************************************************^*/
/*- Test Methods.                                                            -*/
/*^**************************************************************************^*/

  /**
   * Tests <tt>dispose</tt> and <tt>isDisposed</tt> methods.
   */
  public void testDispose() {
    abstractDisposable.dispose();
    assertTrue(abstractDisposable.isDisposed());
  }

  /**
   * Tests <tt>dispose</tt> and <tt>checkDisposed</tt> methods.
   */
  public void testCheckDisposed() {
    abstractDisposable.dispose();
    try {
      abstractDisposable.disposedCheck();
      fail();
    } catch (DisposedError de) {
      assertEquals(abstractDisposable.disposedErrorString(), de.getMessage());
    }
  }

  /**
   * Tests <tt>dispose</tt> and <tt>addDisposeListener</tt> methods.
   */
  public void testAddDisposeListener() {
    TestDisposeListener tdl1 = new TestDisposeListener();
    TestDisposeListener tdl2 = new TestDisposeListener();
    TestDisposeListener tdl3 = new TestDisposeListener();
    abstractDisposable.addDisposeListener(tdl1);
    abstractDisposable.addDisposeListener(tdl2);
    abstractDisposable.addDisposeListener(tdl3);
    abstractDisposable.dispose();
    assertTrue(tdl1.isDisposedReceived());
    assertTrue(tdl2.isDisposedReceived());
    assertTrue(tdl3.isDisposedReceived());
  }

  /**
   * Tests <tt>dispose</tt>, <tt>addDisposeListener</tt> and
   * <tt>removeDisposeListener</tt> methods.
   */
  public void testRemoveDisposeListener() {
    TestDisposeListener tdl1 = new TestDisposeListener();
    TestDisposeListener tdl2 = new TestDisposeListener();
    TestDisposeListener tdl3 = new TestDisposeListener();
    abstractDisposable.addDisposeListener(tdl1);
    abstractDisposable.addDisposeListener(tdl2);
    abstractDisposable.addDisposeListener(tdl3);
    abstractDisposable.removeDisposeListener(tdl2);
    abstractDisposable.removeDisposeListener(tdl3);
    abstractDisposable.dispose();
    assertTrue(tdl1.isDisposedReceived());
    assertFalse(tdl2.isDisposedReceived());
    assertFalse(tdl3.isDisposedReceived());
  }

/*^**************************************************************************^*/
/*- Overridden Methods.                                                      -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected void setUp() throws Exception {
    abstractDisposable = new TestDisposable();
  }

  /**
   * {@inheritDoc}
   */
  protected void tearDown() throws Exception {
    abstractDisposable = null;
  }

/*^**************************************************************************^*/
/*- Inner Classes.                                                           -*/
/*^**************************************************************************^*/

  /**
   * Test Disposable.
   */
  static class TestDisposable extends AbstractDisposable {
    protected void disposeObject() {
      // empty implementation
    }
  }

  /**
   * Test Dispose Listener.
   */
  static class TestDisposeListener implements DisposeListener {
    private boolean disposedReceived;
    public boolean isDisposedReceived() {
      return disposedReceived;
    }
    public void objectDisposed(DisposeEvent e) {
      disposedReceived = true;
    }
  }
}

/*^*****************************************************************************
  File History:

 - 2007-09-07 23:45:31 Slobodan
   Initial version

*****************************************************************************^*/
