/*
 * @(#)TestEventListenerList.java  0.2.0 / 2007-09-18
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.core.events;

import java.util.Arrays;
import java.util.EventListener;

import junit.framework.TestCase;

/**
 * EventListenerList Test.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class TestEventListenerList extends TestCase {

/*^**************************************************************************^*/
/*- Private Field.                                                           -*/
/*^**************************************************************************^*/

  private EventListenerList eventListenerList = null;

/*^**************************************************************************^*/
/*- Test Methods.                                                            -*/
/*^**************************************************************************^*/

  /**
   * Test <tt>add</tt> and <tt>getListenerCount</tt> methods.
   */
  public void testAdd() {
    Class telc = TestEventListener.class;
    eventListenerList.add(telc, new TestEventListener());
    assertEquals(1, eventListenerList.getListenerCount(telc));
  }

  /**
   * Test <tt>add</tt>, <tt>remove</tt> and <tt>getListenerCount</tt> methods.
   */
  public void testRemove() {
    Class telc = TestEventListener.class;
    TestEventListener listener = new TestEventListener();
    eventListenerList.add(telc, listener);
    eventListenerList.remove(TestEventListener.class, listener);
    assertEquals(0, eventListenerList.getListenerCount(telc));
  }

  /**
   * Test <tt>add</tt>, <tt>removeAll</tt> and <tt>getListenerCount</tt>
   * methods.
   */
  public void testRemoveAll() {
    Class telc = TestEventListener.class;
    Class telc2 = TestEventListener2.class;
    eventListenerList.add(telc, new TestEventListener());
    eventListenerList.add(telc2, new TestEventListener2());
    eventListenerList.add(telc, new TestEventListener());
    assertEquals(2, eventListenerList.getListenerGroupsCount());
    eventListenerList.removeAll();
    assertEquals(0, eventListenerList.getListenerCount(telc));
    assertEquals(0, eventListenerList.getListenerCount(telc2));
  }

  /**
   * Test <tt>add</tt>, <tt>removeAll</tt> and <tt>getListenerCount</tt>
   * methods.
   */
  public void testRemoveAll1() {
    Class telc = TestEventListener.class;
    Class telc2 = TestEventListener2.class;
    eventListenerList.add(telc, new TestEventListener());
    eventListenerList.add(telc2, new TestEventListener2());
    eventListenerList.add(telc, new TestEventListener());
    eventListenerList.removeAll(telc);
    assertEquals(0, eventListenerList.getListenerCount(telc));
    assertEquals(1, eventListenerList.getListenerCount(telc2));
  }

  /**
   * Test <tt>add</tt> and <tt>getListenersArray</tt> methods.
   */
  public void testGetListenersArray() {
    Class telc = TestEventListener.class;
    EventListener[] listeners = {new TestEventListener(),
                                 new TestEventListener()};
    eventListenerList.add(telc, listeners[0]);
    eventListenerList.add(telc, listeners[1]);
    EventListener[] retListeners = eventListenerList.getListenersArray(telc);
    for (int i = 0; i < listeners.length; i++) {
      assertSame(listeners[i], retListeners[i]);
    }
  }

  /**
   * Test <tt>add</tt> and <tt>getListeners</tt> methods.
   */
  public void testGetListeners() {
    Class telc = TestEventListener.class;
    EventListener[] listeners = {new TestEventListener(),
                                 new TestEventListener()};
    eventListenerList.add(telc, listeners[0]);
    eventListenerList.add(telc, listeners[1]);
    assertTrue(Arrays.equals(listeners, // NOPMD
                             eventListenerList.getListeners(telc)));
  }

  /**
   * Test <tt>add</tt>, <tt>remove</tt>, <tt>removeAll</tt> and
   * <tt>getListenerCount</tt> methods.
   */
  public void testGetListenerCount() {
    Class telc = TestEventListener.class;
    Class telc2 = TestEventListener2.class;
    TestEventListener tel1 = new TestEventListener();
    eventListenerList.add(telc, tel1);
    eventListenerList.add(telc2, new TestEventListener2());
    eventListenerList.add(telc, new TestEventListener());
    assertEquals(3, eventListenerList.getListenerCount());
    eventListenerList.remove(telc, tel1);
    assertEquals(2, eventListenerList.getListenerCount());
    eventListenerList.removeAll(telc2);
    assertEquals(1, eventListenerList.getListenerCount());
    eventListenerList.removeAll();
    assertEquals(0, eventListenerList.getListenerCount());
  }

/*^**************************************************************************^*/
/*- Overridden Methods.                                                      -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected void setUp() throws Exception {
    eventListenerList = new EventListenerList();
  }

  /**
   * {@inheritDoc}
   */
  protected void tearDown() throws Exception {
    eventListenerList = null;
  }

/*^**************************************************************************^*/
/*- Private Classes.                                                         -*/
/*^**************************************************************************^*/

  /**
   * Test EventListener.
   */
  private static class TestEventListener implements EventListener {
  }

  /**
   * Test EventListener2.
   */
  private static class TestEventListener2 implements EventListener {
  }

}

/*^*****************************************************************************
  File History:

 - 2007-09-18 10:28:34 Slobodan
   Initial version

*****************************************************************************^*/
