/*
 * @(#)Screenshots.java  0.2.0 / 2007-12-23
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.test.gui;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.PrintStream;
import java.util.ArrayList;

import yu.ac.bg.etf.javaqx.nunit.TestEnvironment;
import yu.ac.bg.etf.javaqx.qswing.Cursor;
import yu.ac.bg.etf.javaqx.qswing.JQButton;
import yu.ac.bg.etf.javaqx.qswing.JQContainer;
import yu.ac.bg.etf.javaqx.qswing.JQDesktop;
import yu.ac.bg.etf.javaqx.qswing.JQLabel;
import yu.ac.bg.etf.javaqx.qswing.JQOptionPane;
import yu.ac.bg.etf.javaqx.qswing.JQTextField;
import yu.ac.bg.etf.javaqx.qswing.JQWindow;
import yu.ac.bg.etf.javaqx.qswing.QSwing;
import yu.ac.bg.etf.javaqx.qswing.events.ActionEvent;
import yu.ac.bg.etf.javaqx.qswing.events.ActionListener;
import yu.ac.bg.etf.javaqx.qswing.graphics.Color;
import yu.ac.bg.etf.javaqx.qswing.graphics.Image;
import yu.ac.bg.etf.javaqx.qswing.graphics.ImageConsumer;
import yu.ac.bg.etf.javaqx.qswing.layouts.BorderLayout;
import yu.ac.bg.etf.javaqx.qswing.layouts.formlayout.CellConstraints;
import yu.ac.bg.etf.javaqx.qswing.layouts.formlayout.FormLayout;

/**
 * GUI testing.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public final class TestGUI extends JQWindow {

/*^**************************************************************************^*/
/*- Private Fields.                                                          -*/
/*^**************************************************************************^*/

  private final File userDir;
  private final ArrayList tests;
  private int currentTest;
  private int testCount;
  private int currentScreenshot;
  private final JQLabel label;
  private final JQTextField delay;
  private final JQButton screenshootButton;
  private final JQButton nextButton;
  private JVMProcess jvm;
  private final Cursor waitCursor;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new TestGUI object.
   */
  public TestGUI() {
    super("TestGUI"); //$NON-NLS-1$
    Color background = getBackground();
    setBackground(Color.WHITE);
    setDefaultCloseOperation(QUIT_ON_CLOSE);
    FormLayout layout = new FormLayout(
              "l:p:g, 4dlu, r:p, 4dlu, r:p, 2dlu, l:p, " + //$NON-NLS-1$
              "4dlu, p, 4dlu, r:p, 8dlu, r:p", "p");  //$NON-NLS-1$ $NON-NLS-2$
    JQContainer commandPanel = new JQContainer(layout);
    commandPanel.setBackground(background);
    add(commandPanel, BorderLayout.SOUTH);
    commandPanel.setInsets(8, 8, 8, 8);
    userDir = new File(System.getProperty("user.dir")); //$NON-NLS-1$
    tests = new ArrayList();
    waitCursor = Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR);
    addTests();
    CellConstraints cc = new CellConstraints();
    label = new JQLabel();
    commandPanel.add(label, cc.xy(1, 1));
    commandPanel.add(new JQLabel("Delay:"), cc.xy(3, 1)); //$NON-NLS-1$
    delay = new JQTextField("700"); //$NON-NLS-1$
    delay.setEnabled(false);
    delay.setHorizontalAlignment(JQTextField.RIGHT);
    commandPanel.add(delay, cc.xy(5, 1));
    commandPanel.add(new JQLabel("ms"), cc.xy(7, 1)); //$NON-NLS-1$
    JQButton closeButton = new JQButton("Close"); //$NON-NLS-1$
    closeButton.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        QSwing.stopEventLoop();
      }
    });
    commandPanel.add(closeButton, cc.xy(13, 1));
    nextButton = new JQButton("Load Test"); //$NON-NLS-1$
    nextButton.setDefaultCapable(true);
    nextButton.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        loadNextTest();
      }
    });
    commandPanel.add(nextButton, cc.xy(11, 1));
    screenshootButton = new JQButton("Take Screenshot"); //$NON-NLS-1$
    screenshootButton.setEnabled(false);
    screenshootButton.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        takeScreenshot();
      }
    });
    commandPanel.add(screenshootButton, cc.xy(9, 1));
    setState(MAXIMIZED);
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected void disposeComponent() {
    super.disposeComponent();
    if (jvm != null) {
      jvm.destroy();
    }
  }

/*^**************************************************************************^*/
/*- Private Methods.                                                         -*/
/*^**************************************************************************^*/

  private void addTests() {
    tests.add("example1-helloworld"); //$NON-NLS-1$
    tests.add("example2-actionlistener"); //$NON-NLS-1$
    tests.add("example3-customcomponent"); //$NON-NLS-1$
    tests.add("example4-container"); //$NON-NLS-1$
    tests.add("example5-borderlayout"); //$NON-NLS-1$
    tests.add("example6-graphics"); //$NON-NLS-1$
    tests.add("example7-stylesheet"); //$NON-NLS-1$
    tests.add("example8-model"); //$NON-NLS-1$
    tests.add("example9-threads"); //$NON-NLS-1$
    tests.add("demo-qnotepad"); //$NON-NLS-1$
    tests.add("demo-qopengl"); //$NON-NLS-1$
    tests.add("demo-qswingset"); //$NON-NLS-1$
    tests.add("codebrowser"); //$NON-NLS-1$
    testCount = tests.size();
  }

  private void setLabel(int screenshot, int currentTest) {
    label.setText("Test (" + currentTest + "/" + //$NON-NLS-1$ $NON-NLS-2$
                  testCount + "): " + tests.get(currentTest - 1) + //$NON-NLS-1$
                  ".jar; screenshot: " + screenshot); //$NON-NLS-1$
  }

  private void loadNextTest() {
    QSwing.setOverrideCursor(waitCursor);
    nextButton.setEnabled(false);
    QSwing.flushEvents();
    if (jvm != null) {
      jvm.destroy();
      jvm = null;
    }
    currentScreenshot = 0;
    ++currentTest;
    try {
      String command = TestEnvironment.getJavaCommand() +
                       " -jar " + tests.get(currentTest - 1) + //$NON-NLS-1$
                       ".jar"; //$NON-NLS-1$
      jvm = new JVMProcess(command, userDir);
      jvm.start();
      Thread.sleep(700);
    } catch (InterruptedException ie) {
      // empty catch block
    }
    setLabel(0, currentTest);
    if (currentTest < testCount) {
      nextButton.setEnabled(true);
    }
    if (currentTest == 1) {
      nextButton.setText("Next Test >"); //$NON-NLS-1$
      delay.setEnabled(true);
      screenshootButton.setEnabled(true);
    }
    QSwing.restoreOverrideCursor();
    if (!jvm.isRunning()) {
      JQOptionPane.showErrorMessage(this,
                                    "Could not launch test.", //$NON-NLS-1$
                                    getTitle());
    }
  }

  private void takeScreenshot() {
    int sleepInterval;
    try {
      sleepInterval = Integer.parseInt(delay.getText());
      if (sleepInterval < 700) {
        sleepInterval = 700;
        delay.setText(String.valueOf(700));
        QSwing.flushEvents();
      }
    } catch (NumberFormatException nfe) {
      JQOptionPane.showErrorMessage(this,
                                    "Invalid delay interval", //$NON-NLS-1$
                                    getTitle()); //$NON-NLS-1$
      return;
    }
    QSwing.setOverrideCursor(waitCursor);
    screenshootButton.setEnabled(false);
    setState(ICONIFIED);
    QSwing.flushEvents();
    try {
      Thread.sleep(sleepInterval);
      Image screenshot = JQDesktop.takeScreenShot(null);
      currentScreenshot++;
      if (currentScreenshot == 1) {
        storeImage(screenshot, tests.get(currentTest - 1) +
                               ".png"); //$NON-NLS-1$
      } else {
        storeImage(screenshot, tests.get(currentTest - 1) +
                               "-" + currentScreenshot + //$NON-NLS-1$
                               ".png"); //$NON-NLS-1$
      }
      setLabel(currentScreenshot, currentTest);
    } catch (IOException ioe) { // NOPMD
      JQOptionPane.showErrorMessage(this,
                                    "Could not save screenshot", //$NON-NLS-1$
                                    getTitle()); //$NON-NLS-1$
    } catch (InterruptedException ie) { // NOPMD
      // empty catch block
    }
    screenshootButton.setEnabled(true);
    QSwing.restoreOverrideCursor();
    setState(MAXIMIZED);
  }

  private void storeImage(Image image, String imageName) throws IOException {
    FileOutputStream fos = null;
    try {
      File imageDir = new File("screenshots"); //$NON-NLS-1$
      if (!imageDir.exists()) {
        if (!imageDir.mkdirs()) { // NOPMD
          throw new IOException("Folder creation failed"); //$NON-NLS-1$
        }
      }
      fos = new FileOutputStream(new File(imageDir, imageName));
      ImageWriter imageWriter = new ImageWriter(fos);
      image.getSource().startProduction(imageWriter);
      imageWriter.checkException();
    } finally {
      if (fos != null) {
        try {
          fos.close();
        } catch (IOException ioe) { // NOPMD
          // empty catch block
        }
      }
    }
  }

/*^**************************************************************************^*/
/*- Inner Classes.                                                           -*/
/*^**************************************************************************^*/

  /**
   * Image Writer.
   */
  static final class ImageWriter implements ImageConsumer {
    private final FileOutputStream fos;
    private IOException exception;
    public ImageWriter(FileOutputStream fos) {
      this.fos = fos;
    }
    public void checkException() throws IOException {
      if (exception != null) {
        throw exception;
      }
    }
    public void setPixels(byte[] pixels, int length) {
      try {
        fos.write(pixels, 0, length);
      } catch (IOException ioe) {
        exception = ioe;
      }
    }
  }

  /**
   * Background Window.
   */
  static final class BackgroundWindow extends JQWindow {
    public BackgroundWindow() {
      super("TestGUI - Background"); //$NON-NLS-1$
      setBackground(Color.WHITE);
      setState(MAXIMIZED);
    }
  }

  /**
   * JVM Process.
   */
  static class JVMProcess extends Thread {
    private final String command;
    private final File userDir;
    private Process jvm;
    private JVMListener jvmOutputListener;
    private JVMListener jvmErrorListener;
    public JVMProcess(String command, File userDir) {
      this.command = command;
      this.userDir = userDir;
    }
    public boolean isRunning() {
      return (jvm != null);
    }
    public void destroy() {
      if (jvm != null) {
        jvm.destroy();
      }
    }
    public void run() {
      System.out.println(); // NOPMD
      System.out.print("Launching: "); //$NON-NLS-1$ NOPMD
      System.out.println(command); // NOPMD
      System.out.print("In folder: "); //$NON-NLS-1$ NOPMD
      System.out.println(userDir); // NOPMD
      try {
        jvm = TestEnvironment.execProcess(command, userDir);
        jvmOutputListener = new JVMListener(jvm.getInputStream(), System.out);
        jvmErrorListener = new JVMListener(jvm.getErrorStream(), System.err);
        jvmOutputListener.start();
        jvmErrorListener.start();
        jvm.waitFor();
      } catch (InterruptedException ie) {
        // empty catch block
      } catch (Throwable t) {
        t.printStackTrace(); // NOPMD
      } finally {
        if (jvmOutputListener != null) {
          jvmOutputListener.stopListening();
          jvmOutputListener = null;
        }
        if (jvmErrorListener != null) {
          jvmErrorListener.stopListening();
          jvmErrorListener = null;
        }
        jvm = null;
      }
    }
  }

  /**
   * JVM Listener.
   */
  static class JVMListener extends Thread {
    private final BufferedReader isr;
    private final PrintStream printStream;
    private boolean stopListening;
    public JVMListener(InputStream inputStream, PrintStream printStream) {
      setDaemon(true);
      this.isr = new BufferedReader(new InputStreamReader(inputStream));
      this.printStream = printStream;
    }
    public void stopListening() {
      stopListening = true;
      interrupt();
    }
    public void run() {
      try {
        Thread.sleep(500);
        while (true) {
          if (stopListening) {
            return;
          }
          for (String nl = isr.readLine(); nl != null; nl = isr.readLine()) {
            if (stopListening) {
              return;
            }
            printStream.println(nl);
          }
          yield();
        }
      } catch (Throwable t) { // NOPMD
        // empty catch block
      }
    }
  }

/*^**************************************************************************^*/
/*- Main Method.                                                             -*/
/*^**************************************************************************^*/

  /**
   * Starts test.
   *
   * @param args the application arguments
   */
  public static void main(String[] args) {
    QSwing.initialize(args);
    BackgroundWindow background = new BackgroundWindow();
    background.setVisible(true);
    TestGUI testGUI = new TestGUI();
    testGUI.setVisible(true);
    QSwing.startEventLoop();
  }

}

/*^*****************************************************************************
  File History:

 - 2007-12-23 23:58:54 Slobodan
   Initial version

*****************************************************************************^*/
