/*
 * @(#)TestJNIObject.java  0.2.0 / 2007-01-31
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.test.natives.core.jni; // NOPMD

import junit.framework.TestCase;

import yu.ac.bg.etf.javaqx.JavaQx;

/**
 * JNIObject Test.
 *
 * @javaqx.native
 *    generate="header"
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class TestJNIObject extends TestCase {

/*^**************************************************************************^*/
/*- Private Field.                                                           -*/
/*^**************************************************************************^*/

  private JNITestObject testObject = null;

/*^**************************************************************************^*/
/*- Test Methods.                                                            -*/
/*^**************************************************************************^*/

  /**
   * Tests <tt>getObjectField</tt> method.
   */
  public void testExecObjectIntField() {
    Object expected = new Object();
    testObject.setObjectField(expected);
    Object actual = _testGetObjectField(testObject);
    assertEquals(expected, actual);
  }

  /**
   * Tests <tt>getBooleanField</tt> method.
   */
  public void testExecGetBooleanField() {
    boolean expected = true;
    testObject.setBooleanField(expected);
    boolean actual = _testGetBooleanField(testObject);
    assertEquals(expected, actual);
  }

  /**
   * Tests <tt>getByteField</tt> method.
   */
  public void testExecGetByteField() {
    byte expected = Byte.MAX_VALUE >> 1;
    testObject.setByteField(expected);
    byte actual = _testGetByteField(testObject);
    assertEquals(expected, actual);
  }

  /**
   * Tests <tt>getCharField</tt> method.
   */
  public void testExecGetCharField() {
    char expected = 'c';
    testObject.setCharField(expected);
    char actual = _testGetCharField(testObject);
    assertEquals(expected, actual);
  }

  /**
   * Tests <tt>getShortField</tt> method.
   */
  public void testExecGetShortField() {
    short expected = Short.MAX_VALUE >> 1;
    testObject.setShortField(expected);
    short actual = _testGetShortField(testObject);
    assertEquals(expected, actual);
  }

  /**
   * Tests <tt>getIntField</tt> method.
   */
  public void testExecGetIntField() {
    int expected = Integer.MAX_VALUE >> 1;
    testObject.setIntField(expected);
    int actual = _testGetIntField(testObject);
    assertEquals(expected, actual);
  }

  /**
   * Tests <tt>getFloatField</tt> method.
   */
  public void testExecFloatIntField() {
    float expected = Float.MAX_VALUE / 2;
    testObject.setFloatField(expected);
    float actual = _testGetFloatField(testObject);
    assertEquals(expected, actual, 0);
  }

  /**
   * Tests <tt>getDoubleField</tt> method.
   */
  public void testExecGetDoubleField() {
    double expected = Double.MAX_VALUE / 2;
    testObject.setDoubleField(expected);
    double actual = _testGetDoubleField(testObject);
    assertEquals(expected, actual, 0);
  }

  /**
   * Tests <tt>setObjectField</tt> method.
   */
  public void testExecSetObjectField() {
    Object expected = new Object();
    _testSetObjectField(testObject, expected);
    Object actual = testObject.getObjectField();
    assertEquals(expected, actual);
  }

  /**
   * Tests <tt>setBooleanField</tt> method.
   */
  public void testExecSetBooleanField() {
    boolean expected = true;
    _testSetBooleanField(testObject, expected);
    boolean actual = testObject.getBooleanField();
    assertEquals(expected, actual);
  }

  /**
   * Tests <tt>setByteField</tt> method.
   */
  public void testExecSetByteField() {
    byte expected = Byte.MAX_VALUE >> 1;
    _testSetByteField(testObject, expected);
    byte actual = testObject.getByteField();
    assertEquals(expected, actual);
  }

  /**
   * Tests <tt>setCharField</tt> method.
   */
  public void testExecSetCharField() {
    char expected = 'c';
    _testSetCharField(testObject, expected);
    char actual = testObject.getCharField();
    assertEquals(expected, actual);
  }

  /**
   * Tests <tt>setShortField</tt> method.
   */
  public void testExecSetShortField() {
    short expected = Short.MAX_VALUE >> 1;
    _testSetShortField(testObject, expected);
    short actual = testObject.getShortField();
    assertEquals(expected, actual);
  }

  /**
   * Tests <tt>setIntField</tt> method.
   */
  public void testExecSetIntField() {
    int expected = Integer.MAX_VALUE >> 1;
    _testSetIntField(testObject, expected);
    int actual = testObject.getIntField();
    assertEquals(expected, actual);
  }

  /**
   * Tests <tt>setFloatField</tt> method.
   */
  public void testExecSetFloatField() {
    float expected = Float.MAX_VALUE / 2;
    _testSetFloatField(testObject, expected);
    float actual = testObject.getFloatField();
    assertEquals(expected, actual, 0);
  }

  /**
   * Tests <tt>setDoubleField</tt> method.
   */
  public void testExecSetDoubleField() {
    double expected = Double.MAX_VALUE / 2;
    _testSetDoubleField(testObject, expected);
    double actual = testObject.getDoubleField();
    assertEquals(expected, actual, 0);
  }

  /**
   * Tests <tt>isLive</tt> method.
   */
  public void testExecIsLive() {
    assertTrue(_testIsLive(testObject));
  }

  /**
   * Tests <tt>callObjectMethod</tt> method.
   */
  public void testExecCallObjectMethod() {
    Object expected = new Object();
    testObject.setObjectField(expected);
    Object actual = _testCallObjectMethod(testObject);
    assertEquals(expected, actual);
  }

  /**
   * Tests <tt>callBooleanMethod</tt> method.
   */
  public void testExecCallBooleanMethod() {
    boolean expected = true;
    testObject.setBooleanField(expected);
    boolean actual = _testCallBooleanMethod(testObject);
    assertEquals(expected, actual);
  }

  /**
   * Tests <tt>callByteMethod</tt> method.
   */
  public void testExecCallByteMethod() {
    byte expected = Byte.MAX_VALUE >> 1;
    testObject.setByteField(expected);
    byte actual = _testCallByteMethod(testObject);
    assertEquals(expected, actual);
  }

  /**
   * Tests <tt>callCharMethod</tt> method.
   */
  public void testExecCallCharMethod() {
    char expected = 'c';
    testObject.setCharField(expected);
    char actual = _testCallCharMethod(testObject);
    assertEquals(expected, actual);
  }

  /**
   * Tests <tt>callShortMethod</tt> method.
   */
  public void testExecCallShortMethod() {
    short expected = Short.MAX_VALUE >> 1;
    testObject.setShortField(expected);
    short actual = _testCallShortMethod(testObject);
    assertEquals(expected, actual);
  }

  /**
   * Tests <tt>callIntMethod</tt> method.
   */
  public void testExecCallIntMethod() {
    int expected = Integer.MAX_VALUE >> 1;
    testObject.setIntField(expected);
    int actual = _testCallIntMethod(testObject);
    assertEquals(expected, actual);
  }

  /**
   * Tests <tt>callFloatMethod</tt> method.
   */
  public void testExecCallFloatMethod() {
    float expected = Float.MAX_VALUE / 2;
    testObject.setFloatField(expected);
    float actual = _testCallFloatMethod(testObject);
    assertEquals(expected, actual, 0);
  }

  /**
   * Tests <tt>callDoubleMethod</tt> method.
   */
  public void testExecCallDoubleMethod() {
    double expected = Double.MAX_VALUE / 2;
    testObject.setDoubleField(expected);
    double actual = _testCallDoubleMethod(testObject);
    assertEquals(expected, actual, 0);
  }

  /**
   * Tests <tt>callVoidMethod</tt> method.
   */
  public void testExecCallVoidMethod() {
    _testCallVoidMethod(testObject);
    assertTrue(testObject.isVoidMethodCalled());
  }

  /**
   * Tests <tt>toJString</tt> method.
   */
  public void testExecToJStringMethod() {
    String expected = testObject.toString();
    String actual = _testToJStringMethod(testObject);
    assertEquals(expected, actual);
  }

  /**
   * Tests <tt>getObjectClass</tt> method.
   */
  public void testExecGetObjectClassMethod() {
    Class expected = testObject.getClass();
    Class actual = _testGetObjectClassMethod(testObject);
    assertEquals(expected, actual);
  }

  /**
   * Tests <tt>getObjectClass</tt> method.
   */
  public void testExecFailThrowOutOfMemoryError() { // NOPMD
    _testThrowOutOfMemoryError(testObject);
  }

  /**
   * Tests <tt>throwRuntimeExcpetion</tt> method.
   */
  public void testExecFailThrowRuntimeExcpetion() { // NOPMD
    _testThrowRuntimeExcpetion(testObject);
  }

  /**
   * Tests <tt>newString</tt> method.
   */
  public void testExecNewString() {
    String expected = "TestString"; //$NON-NLS-1$
    String actual = _testNewString(testObject);
    assertEquals(expected, actual);
  }

  /**
   * Tests <tt>newStringUTF</tt> method.
   */
  public void testExecNewStringUTF() {
    String expected = "UTFTestString"; //$NON-NLS-1$
    String actual = _testNewStringUTF(testObject);
    assertEquals(expected, actual);
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public void setUp()throws Exception {
    JavaQx.initialize();
    testObject = new JNITestObject();
  }

/*^**************************************************************************^*/
/*- Inner Class.                                                             -*/
/*^**************************************************************************^*/

  /**
   * JNI Test Object.
   */
  private static class JNITestObject {
    private boolean voidCalled;
    private Object objectField;
    private boolean booleanField;
    private byte byteField;
    private char charField;
    private short shortField;
    private int intField;
    private float floatField;
    private double doubleField;
    public boolean isVoidMethodCalled() {
      return voidCalled;
    }
    public Object getObjectField() {
      return objectField;
    }
    public boolean getBooleanField() {
      return booleanField;
    }
    public byte getByteField() {
      return byteField;
    }
    public char getCharField() {
      return charField;
    }
    public short getShortField() {
      return shortField;
    }
    public int getIntField() {
      return intField;
    }
    public float getFloatField() {
      return floatField;
    }
    public double getDoubleField() {
      return doubleField;
    }
    public void setObjectField(Object objectField) {
      this.objectField = objectField;
    }
    public void setBooleanField(boolean booleanField) {
      this.booleanField = booleanField;
    }
    public void setByteField(byte byteField) {
      this.byteField = byteField;
    }
    public void setCharField(char charField) {
      this.charField = charField;
    }
    public void setShortField(short shortField) {
      this.shortField = shortField;
    }
    public void setIntField(int intField) {
      this.intField = intField;
    }
    public void setFloatField(float floatField) {
      this.floatField = floatField;
    }
    public void setDoubleField(double doubleField) {
      this.doubleField = doubleField;
    }
    public void callVoidMethod() {
      voidCalled = true;
    }
  }

/*^**************************************************************************^*/
/*- Package-Private Native Methods.                                          -*/
/*^**************************************************************************^*/

  static native Object _testGetObjectField(Object testObject);

  static native boolean _testGetBooleanField(Object testObject);

  static native byte _testGetByteField(Object testObject);

  static native char _testGetCharField(Object testObject);

  static native short _testGetShortField(Object testObject);

  static native int _testGetIntField(Object testObject);

  static native float _testGetFloatField(Object testObject);

  static native double _testGetDoubleField(Object testObject);

  static native void _testSetObjectField(Object testObject, Object o);

  static native void _testSetBooleanField(Object testObject, boolean b);

  static native void _testSetByteField(Object testObject, byte b);

  static native void _testSetCharField(Object testObject, char c);

  static native void _testSetShortField(Object testObject, short s);

  static native void _testSetIntField(Object testObject, int i);

  static native void _testSetFloatField(Object testObject, float f);

  static native void _testSetDoubleField(Object testObject, double d);

  static native boolean _testIsLive(Object testObject);

  static native Object _testCallObjectMethod(Object testObject);

  static native boolean _testCallBooleanMethod(Object testObject);

  static native byte _testCallByteMethod(Object testObject);

  static native char _testCallCharMethod(Object testObject);

  static native short _testCallShortMethod(Object testObject);

  static native int _testCallIntMethod(Object testObject);

  static native float _testCallFloatMethod(Object testObject);

  static native double _testCallDoubleMethod(Object testObject);

  static native void _testCallVoidMethod(Object testObject);

  static native String _testToJStringMethod(Object testObject);

  static native Class _testGetObjectClassMethod(Object testObject);

  static native void _testThrowInternalError(Object testObject);

  static native void _testThrowOutOfMemoryError(Object testObject);

  static native void _testThrowRuntimeExcpetion(Object testObject);

  static native String _testNewString(Object testObject);

  static native String _testNewStringUTF(Object testObject);

}

/*^*****************************************************************************
  File History:

 - 2007-01-31 13:28:15 Slobodan
   Initial version

*****************************************************************************^*/
