/*
 * @(#)JavaQxCommon.cpp  0.2.0 / 2007-09-07
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "JavaQxCommon.h"

/*^**************************************************************************^*/
/*- JavaQxCommon :: Includes.                                                -*/
/*^**************************************************************************^*/

#ifdef USE_PLATFORM_CODE
  #include "JavaQxPlatform.h"
#else
  #include <QApplication>
  #include <QMessageBox>
#endif // USE_PLATFORM_CODE

BEGIN_NAMESPACE_JAVAQX

/*^**************************************************************************^*/
/*- JavaQxCommon :: Functions.                                               -*/
/*^**************************************************************************^*/

/*!
 * \brief Shows error message.
 *
 * \param title the title
 * \param message the message
 */
void ErrorMessage(const char *title, const char *message)
{
  #ifdef USE_PLATFORM_CODE
    JavaQx::Platform::ErrorMessage(title, message);
  #else
    if (!qApp) {
      int argc = 0;
      QApplication app(argc, 0); // do not optimize - app is on the stack!
      QMessageBox::critical(0, title, message, QMessageBox::Ok, 0);
    } else {
      QMessageBox::critical(0, title, message, QMessageBox::Ok, 0);
    }
  #endif // USE_PLATFORM_CODE
}

/*!
 * \brief Shows warning message.
 *
 * \param title the title
 * \param message the message
 */
void WarningMessage(const char *title, const char *message)
{
  #ifdef USE_PLATFORM_CODE
    JavaQx::Platform::WarningMessage(title, message);
  #else
    if (!qApp) {
      int argc = 0;
      QApplication app(argc, 0); // note: app is on the stack
      QMessageBox::warning(0, title, message, QMessageBox::Ok, 0);
    } else {
      QMessageBox::warning(0, title, message, QMessageBox::Ok, 0);
    }
  #endif // USE_PLATFORM_CODE
}

/*!
 * \brief Shows information message.
 *
 * \param title the title
 * \param message the message
 */
void InformationMessage(const char *title, const char *message)
{
  #ifdef USE_PLATFORM_CODE
    JavaQx::Platform::InformationMessage(title, message);
  #else
    if (!qApp) {
      int argc = 0;
      QApplication app(argc, 0); // note: app is on the stack
      QMessageBox::information(0, title, message, QMessageBox::Ok, 0);
    } else {
      QMessageBox::information(0, title, message, QMessageBox::Ok, 0);
    }
  #endif // USE_PLATFORM_CODE
}

END_NAMESPACE_JAVAQX

/*^*****************************************************************************
  File History:

 - 2007-05-20 10:31:11 Slobodan
   Initial version

*****************************************************************************^*/
