/*
 * @(#)JavaQxCore.cpp  0.2.0 / 2007-09-07
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "JavaQxCore.h"

/*^**************************************************************************^*/
/*- JavaQxCore :: Local Functions.                                           -*/
/*^**************************************************************************^*/

void MessageHandler(QtMsgType type, const char *msg)
{
  switch (type) {
    case QtDebugMsg:
      fprintf(stderr, "[JavaQx][DEBUG] %s\n", msg);
      break;
    case QtWarningMsg: {
      JNILogger::logWarning(msg);
      #ifdef JAVAQX_DEBUG
        JavaQx::WarningMessage("JavaQx Internal - Warning Message", msg);
      #endif // JAVAQX_DEBUG
      break;
    }
    case QtCriticalMsg: {
      JNILogger::logError(msg);
      #ifdef JAVAQX_DEBUG
        JavaQx::ErrorMessage("JavaQx Internal - Critical Error", msg);
      #endif // JAVAQX_DEBUG
      break;
    }
    case QtFatalMsg: {
      JNILogger::logError(msg);
      #ifdef JAVAQX_DEBUG
        JavaQx::ErrorMessage("JavaQx Internal - Fatal Error", msg);
      #endif // JAVAQX_DEBUG
      JVMWrapper::exit();
      break;
    }
  }
}

void InitializeQt()
{
  qInstallMsgHandler(MessageHandler);
  if (!qRegisterMetaType<jboolean>("jboolean") ||
      !qRegisterMetaType<jchar>("jchar") ||
      !qRegisterMetaType<jshort>("jshort") ||
      !qRegisterMetaType<jint>("jint") ||
      !qRegisterMetaType<jlong>("jlong") ||
      !qRegisterMetaType<jfloat>("jfloat") ||
      !qRegisterMetaType<jdouble>("jdouble") ||
      !qRegisterMetaType<jsize>("jsize") ||
      !qRegisterMetaType<jobject>("jobject") ||
      !qRegisterMetaType<jstring>("jstring") ||
      !qRegisterMetaType<jclass>("jclass") ||
      !qRegisterMetaType<jbyteArray>("jbyteArray") ||
      !qRegisterMetaType<jobjectArray *>("jobjectArray *") ||
      !qRegisterMetaType<JNIEnv *>("JNIEnv *")) {
    qFatal("MetaType initialization failed.");
  }
}

/*^**************************************************************************^*/
/*- JavaQxCore :: OnLoad Handler.                                            -*/
/*^**************************************************************************^*/

JNIEXPORT jint JNICALL JNI_OnLoad(JavaVM *jvm, void *)
{
  InitializeQt();
  JVMWrapper::initialize(jvm);
  return JAVAQX_JNI_VERSION;
}

/*^*****************************************************************************
  File History:

 - 2007-05-20 10:35:56 Slobodan
   Initial version

*****************************************************************************^*/
