/*
 * @(#)QStringAdapter.h  0.2.0 / 2007-09-07
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef QSTRINGADAPTER_H
#define QSTRINGADAPTER_H

#include "JavaQxCommon.h"

/*^**************************************************************************^*/
/*- QStringAdapter Class.                                                    -*/
/*^**************************************************************************^*/

/*!
 * \brief QString Adapter.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT QStringAdapter : public QString
{
public:
  QStringAdapter(JNIEnv *env, jstring str);
public:
  inline QStringAdapter(const QStringAdapter &qsa);
  inline QStringAdapter(const QString &qs);
public:
  jstring toJString(JNIEnv *env);
public:
  inline QStringAdapter &operator=(const QStringAdapter &qsa);
  inline QStringAdapter &operator=(const QString &qs);
  inline QStringAdapter &operator+=(const QStringAdapter &qsa);
  inline QStringAdapter &operator+=(const QString &qs);
public:
  static jstring toJString(JNIEnv *env, const QString &str);
private:
  static const QString EMPTY_STRING;
};

/*^**************************************************************************^*/
/*- QStringAdapter :: Public Inline Constructors.                            -*/
/*^**************************************************************************^*/

/*!
 * \brief Copy constructor. Constructs new QStringAdapter object using the
 *        specified QStringAdapter argument.
 *
 * \param qsa the QStringAdapter argument
 */
inline QStringAdapter::QStringAdapter(const QStringAdapter &qsa)
  : QString(qsa)
{
  // empty body
}

/*!
 * \brief Constructs new QStringAdapter object using the specified QString
 *        argument.
 *
 * \param qs the QString argument
 */
inline QStringAdapter::QStringAdapter(const QString &qs)
  : QString(qs)
{
  // empty body
}

/*^**************************************************************************^*/
/*- QStringAdapter :: Public Inline Operators.                               -*/
/*^**************************************************************************^*/

/*!
 * \brief Operator \c = .
 *
 * \param qsa the QStringAdapter argument
 *
 * \return reference to this QStringAdapter object
 */
inline QStringAdapter &QStringAdapter::operator=(const QStringAdapter &qsa)
{
  QString::operator=(qsa);
  return *this;
}

/*!
 * \brief Operator \c = .
 *
 * \param qs the QString argument
 *
 * \return reference to this QStringAdapter object
 */
inline QStringAdapter &QStringAdapter::operator=(const QString &qs)
{
  QString::operator=(qs);
  return *this;
}

/*!
 * \brief Operator \c += .
 *
 * \param qsa the QStringAdapter argument
 *
 * \return reference to this QStringAdapter object
 */
inline QStringAdapter &QStringAdapter::operator+=(const QStringAdapter &qsa)
{
  append(qsa);
  return *this;
}

/*!
 * \brief Operator \c += .
 *
 * \param qs the QString argument
 *
 * \return reference to this QStringAdapter object
 */
inline QStringAdapter &QStringAdapter::operator+=(const QString &qs)
{
  append(qs);
  return *this;
}

/*^**************************************************************************^*/
/*- QStringAdapter :: Related Non-Member.                                    -*/
/*^**************************************************************************^*/

/*!
 * \brief Operator \c + .
 *
 * \param qsa1 the first QStringAdapter argument
 * \param qsa2 the second QStringAdapter argument
 *
 * \return QStringAdapter which is the result of concatenating qsa1 and qsa2
 */
inline const QStringAdapter operator+(const QStringAdapter &qsa1,
                                      const QStringAdapter &qsa2)
{
  QStringAdapter tqsa(qsa1);
  tqsa.append(qsa2);
  return tqsa;
}

#endif // QSTRINGADAPTER_H

/*^*****************************************************************************
  File History:

 - 2007-05-20 18:12:03 Slobodan
   Initial version

*****************************************************************************^*/
