/*
 * @(#)QStringListAdapter.cpp  0.2.0 / 2007-09-07
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "QStringListAdapter.h"

#include "JNIWrapper.h"
#include "QStringAdapter.h"

/*^**************************************************************************^*/
/*- QStringListAdapter :: Public Constructor.                                -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new QStringListAdapter object.
 *
 * \param env the JNIEnv pointer
 * \param stringArray the Java string array
 *
 * \exception OutOfMemoryError java error
 */
QStringListAdapter::QStringListAdapter(JNIEnv *env, jobjectArray stringArray)
  : QStringList()
{
  Q_ASSERT(env);
  Q_ASSERT(stringArray);
  jsize arrayLen = env->GetArrayLength(stringArray);
  for (int i = 0; i < arrayLen; i++) {
    append(QStringAdapter(env,
                          (jstring)env->GetObjectArrayElement(stringArray, i)));
  }
}

/*^**************************************************************************^*/
/*- QStringListAdapter :: Public Static Member Function.                     -*/
/*^**************************************************************************^*/

/*!
 * \brief Creates new Java string array using specified QStringList.
 *
 * \param env the JNIEnv pointer
 * \param stringList the QStringList reference
 *
 * \return Java string array
 *
 * \exception OutOfMemoryError java error
 */
jobjectArray QStringListAdapter::toJStringArray(JNIEnv *env,
                                                const QStringList &stringList)
{
  jobjectArray stringArray = JNIWrapper::newStringArray(env, stringList.size());
  if (stringArray) {
    for (int i = 0; i < stringList.size(); i++) {
      env->SetObjectArrayElement(stringArray, i,
                                 QStringAdapter::toJString(env,
                                                           stringList.at(i)));
    }
  }
  return stringArray;
}

/*^*****************************************************************************
  File History:

 - 2007-09-07 18:03:34 Slobodan
   Initial version

*****************************************************************************^*/
