/*
 * @(#)JNILogger.h  0.2.0 / 2007-09-11
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef JNILOGGER_H
#define JNILOGGER_H

#include "JavaQxCommon.h"

/*^**************************************************************************^*/
/*- JNILogger Class.                                                         -*/
/*^**************************************************************************^*/

/*!
 * \brief JavaQx Logger Wrapper.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT JNILogger
{
public:
  static void logInfo(const char *message, const char *fileName,
                      int lineNumber);
  static void logInfo(const char *message);
  static void logWarning(const char *message, const char *fileName,
                         int lineNumber);
  static void logWarning(const char *message);
  static void logError(const char *message, const char *fileName,
                       int lineNumber);
  static void logError(const char *message);
public:
  static void initialize(JNIEnv *env, jclass cls);
private:
  static void log(int level, const char *message, const char *fileName,
                  int lineNumber);
private:
  static jclass sm_loggerClass;
  static jmethodID sm_logMID;
};

/*^**************************************************************************^*/
/*- JNILogger :: Macro Definitions.                                          -*/
/*^**************************************************************************^*/

#define LOG_INFO(message) JNILogger::logInfo(message, __FILE__, __LINE__)
#define LOG_WARNING(message) JNILogger::logWarning(message, __FILE__, __LINE__)
#define LOG_ERROR(message) JNILogger::logError(message, __FILE__, __LINE__)

#endif // JNILOGGER_H

/*^*****************************************************************************
  File History:

 - 2007-09-11 17:57:48 Slobodan
   Initial version

*****************************************************************************^*/
