/*
 * @(#)JNIReferences.h  0.2.0 / 2007-10-05
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef JNIREFERENCES_H
#define JNIREFERENCES_H

#include "JNIWrapper.h"

/*^**************************************************************************^*/
/*- GlobalReference Template.                                                -*/
/*^**************************************************************************^*/

/*!
 * \brief Global Reference.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
template<typename T>
class GlobalReference
{
public:
  GlobalReference(JNIEnv *env, T t);
  virtual ~GlobalReference();
private:
  GlobalReference(const GlobalReference &);
public:
  inline T ref() const;
protected:
  JNIEnv *m_env;
  T m_obj;
};

/*^**************************************************************************^*/
/*- GlobalReference :: Public Constructor.                                   -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new GlobalReference object.
 *
 * \param env the JNIEnv pointer
 * \param t the reference type
 */
template<typename T>
GlobalReference<T>::GlobalReference(JNIEnv *env, T t)
{
  if (t) {
    m_obj = static_cast<T>(JNIWrapper::newGlobalRef(env, t));
    Q_ASSERT(env);
    m_env = env;
  } else {
    m_obj = 0;
  }
}

/*^**************************************************************************^*/
/*- GlobalReference :: Public Destructor.                                    -*/
/*^**************************************************************************^*/

/*!
 * \brief Destructs GlobalReference object.
 */
template<typename T>
GlobalReference<T>::~GlobalReference()
{
  if (m_obj) {
    m_env->DeleteGlobalRef(m_obj);
  }
}

/*^**************************************************************************^*/
/*- GlobalReference :: Private Constructor.                                  -*/
/*^**************************************************************************^*/

template<typename T>
GlobalReference<T>::GlobalReference(const GlobalReference &)
{
  // Copy constructor is disabled.
}

/*^**************************************************************************^*/
/*- GlobalReference :: Public Inline Member Function.                        -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns global reference.
 *
 * \return global reference
 */
template<typename T>
inline T GlobalReference<T>::ref() const
{
  return m_obj;
}

/*^**************************************************************************^*/
/*- GlobalReference :: Explicit Template Instantiations.                     -*/
/*^**************************************************************************^*/

template class GlobalReference<jobject>;
template class GlobalReference<jstring>;
template class GlobalReference<jclass>;
template class GlobalReference<jbyteArray>;

/*^**************************************************************************^*/
/*- GlobalReference :: Template Specializaions.                              -*/
/*^**************************************************************************^*/

typedef GlobalReference<jobject> GlobalJObject;
typedef GlobalReference<jstring> GlobalJString;
typedef GlobalReference<jclass> GlobalJClass;
typedef GlobalReference<jbyteArray> GlobalJByteArray;

#endif //JNIREFERENCES_H

/*^*****************************************************************************
  File History:

 - 2007-10-05 09:57:10 Slobodan
   Initial version

*****************************************************************************^*/
