/*
 * @(#)JVMWrapper.cpp  0.2.0 / 2007-09-11
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "JVMWrapper.h"

/*^**************************************************************************^*/
/*- JVMWrapper :: Includes.                                                  -*/
/*^**************************************************************************^*/

#include "JNIWrapper.h"

#include "yu_ac_bg_etf_javaqx_JavaQxInfo.h"

/*^**************************************************************************^*/
/*- JVMWrapper :: Public Static Member Functions.                            -*/
/*^**************************************************************************^*/

/*!
 * \brief Initializes JVMWrapper class.
 *
 * \param jvm the JNI JavaVM pointer
 *
 * \return JNIEnv version
 */
void JVMWrapper::initialize(JavaVM *jvm)
{
  Q_ASSERT(jvm);
  if (!sm_jvm) {
    if (jvm) {
      sm_jvm = jvm;
      JNIEnv *env;
      jvm->GetEnv((void **)&env, JAVAQX_JNI_VERSION);
      if (env) {
        jclass cls = env->FindClass("yu/ac/bg/etf/javaqx/JavaQxInfo");
        if (cls) {
          jfieldID fid = env->GetStaticFieldID(cls, "LIBRARY_VERSION", "I");
          if (fid && (env->GetStaticIntField(cls, fid) ==
              yu_ac_bg_etf_javaqx_JavaQxInfo_LIBRARY_VERSION)) {
            JNIWrapper::initialize(env);
          } else {
            qFatal("Invalid library version! \n\nProgram will exit. ");
          }
          env->DeleteLocalRef(cls);
        } else {
          qFatal("Could not find JavaQxInfo class! \n\nProgram will exit.");
        }
      } else {
        qFatal("Null JNIEnv! \n\nProgram will exit. ");
      }
    } else {
      qFatal("Null JVM! \n\nProgram will exit. ");
    }
  }
}

/*!
 * \brief Returns JNIEnv pointer.
 *
 * \return JNIEnv pointer
 */
JNIEnv *JVMWrapper::getEnv()
{
  JNIEnv *env = 0;
  if (sm_jvm) {
    sm_jvm->GetEnv((void **)&env, JAVAQX_JNI_VERSION);
  }
  return env;
}

/*!
 * \brief Exits JVM.
 *
 * \param status the status code
 */
void JVMWrapper::exit(int status)
{
  if (sm_jvm) {
    JNIEnv *env;
    sm_jvm->GetEnv((void **)&env, JAVAQX_JNI_VERSION);
    exitJVM(env, status);
    sm_jvm->DestroyJavaVM();
  }
}

/*!
 * \brief Displays error message and exits JVM.
 *
 * \param status the status code
 */
void JVMWrapper::exitCritical(int status)
{
  if (sm_jvm) {
    JNIEnv *env;
    sm_jvm->GetEnv((void **)&env, JAVAQX_JNI_VERSION);
    if (env && (env->ExceptionCheck())) {
      env->ExceptionDescribe();
      env->ExceptionClear();
    }
    JavaQx::ErrorMessage("JavaQx Internal",
                         "Fatal error occurred. Program will exit. ");
    exitJVM(env, status);
    sm_jvm->DestroyJavaVM();
  }
}

/*!
 * \brief Attaches current thread.
 *
 * \return \c true if succeed
 */
bool JVMWrapper::attachCurrentThread()
{
  JNIEnv *env = 0;
  if (sm_jvm) {
    return (!sm_jvm->AttachCurrentThread((void **)&env, 0));
  }
  return false;
}

/*!
 * \brief Dttaches current thread.
 *
 * \return \c true if succeed
 */
bool JVMWrapper::detachCurrentThread()
{
  if (sm_jvm) {
    return (!sm_jvm->DetachCurrentThread());
  }
  return false;
}

/*^**************************************************************************^*/
/*- JVMWrapper :: Private Static Member Function.                            -*/
/*^**************************************************************************^*/

void JVMWrapper::exitJVM(JNIEnv *env, int status)
{
  if (env) {
    jclass cls = env->FindClass("java/lang/System");
    if (cls) {
      jmethodID exitMID = env->GetStaticMethodID(cls, "exit", "(I)V");
      if (exitMID) {
        env->CallStaticVoidMethod(cls, exitMID, status);
      }
      env->DeleteLocalRef(cls);
    }
  }
}

/*^**************************************************************************^*/
/*- JVMWrapper :: Private Static Data Member.                                -*/
/*^**************************************************************************^*/

JavaVM *JVMWrapper::sm_jvm = 0;

/*^*****************************************************************************
  File History:

 - 2007-09-11 17:59:08 Slobodan
   Initial version

*****************************************************************************^*/
