/*
 * @(#)javaqx-launcher.cpp  0.2.0 / 2007-04-13
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "Launcher.h"

#include <windows.h>

#define JRE_REGISTRY_KEY "Software\\JavaSoft\\Java Runtime Environment"
#define CURRENT_VERSION_KEY "CurrentVersion"
#define JVM_LIB_KEY "RuntimeLib"

typedef jint (JNICALL *FPCreateJavaVM)(JavaVM **jvm, void **env, void *args);

void ShowError(const char *message, const char *title)
{
  if (!title) {
    if (__argc > 0) {
      const char *exeName = __argv[0];
      int len = 0;
      int i = 0;
      while ((exeName[len] != '\0') && (len < MAX_PATH)) {
        if (exeName[len] == '\\') {
          i = len;
        }
        len++;
      }
      char t[MAX_PATH];
      for (int j = ++i; j <= len; j++) {
        t[j - i] = exeName[j];
      }
      title = t;
    } else {
      title = "Error";
    }
  }
  MessageBox(NULL, message, title, (MB_OK | MB_ICONSTOP | MB_APPLMODAL));
}

bool ReadRegistry(HKEY key, const char *name, char *buf, unsigned int bufsize)
{
  DWORD type;
  DWORD size;
  if (RegQueryValueEx(key, name, 0, &type, 0, &size) == 0) {
    if ((type == REG_SZ) && (size < bufsize) &&
        (RegQueryValueEx(key, name, 0, 0, (LPBYTE)buf, &size) == 0)) {
      return true;
    }
  }
  return false;
}

bool GetJRELib(char *buf, unsigned int bufsize)
{
  HKEY jreKey;
  HKEY currentVersionKey;
  char version[MAX_PATH];
  if (RegOpenKeyEx(HKEY_LOCAL_MACHINE, JRE_REGISTRY_KEY, 0, KEY_READ,
                   &jreKey) != 0) {
    return false;
  }
  if (!ReadRegistry(jreKey, CURRENT_VERSION_KEY, version, MAX_PATH)) {
    RegCloseKey(jreKey);
    return false;
  }
  if (RegOpenKeyEx(jreKey, version, 0, KEY_READ, &currentVersionKey) != 0) {
    RegCloseKey(jreKey);
    return false;
  }
  RegCloseKey(jreKey);
  if (!ReadRegistry(currentVersionKey, JVM_LIB_KEY, buf, bufsize)) {
    RegCloseKey(currentVersionKey);
    return false;
  }
  RegCloseKey(currentVersionKey);
  return true;
}

jobjectArray ToJStringArray(JNIEnv *env, char **str, int fromIndex,
                            int toIndex)
{
  jclass strcls = env->FindClass("java/lang/String");
  if (strcls) {
    jobjectArray strarray = env->NewObjectArray(toIndex - fromIndex, strcls,
                                                0);
    if (strarray) {
      for (int i = fromIndex; i < toIndex; i++) {
        jstring jstri = env->NewStringUTF(str[i]);
        if (!jstri) {
          break;
        }
        env->SetObjectArrayElement(strarray, i - fromIndex, jstri);
      }
      return strarray;
    }
  }
  return 0;
}

bool CreateJVM(JavaVM **pjvm, JNIEnv **penv, JavaVMInitArgs *pargs) {
#ifndef JVM_LIB
  char jvmdll[MAX_PATH];
  if (GetJRELib(jvmdll, MAX_PATH)) {
    HINSTANCE hjvm = LoadLibrary(jvmdll);
#else
    HINSTANCE hjvm = LoadLibrary(JVM_LIB);
#endif // JVM_LIB
    if (hjvm) {
      FPCreateJavaVM PCreateJavaVM =
                       (FPCreateJavaVM)GetProcAddress(hjvm, "JNI_CreateJavaVM");
      if (PCreateJavaVM) {
        return (*PCreateJavaVM)(pjvm, (void **)penv, pargs) == 0;
      }
    }
#ifndef JVM_LIB
  }
#endif // JVM_LIB
  return false;
}

bool InvokeMainMethod(JNIEnv *env, jclass mainClass, jobjectArray args) {
  if (env && mainClass && args) {
    jmethodID mainMethod = env->GetStaticMethodID(mainClass, "main",
                                                  "([Ljava/lang/String;)V");
    if (mainMethod) {
      env->CallStaticVoidMethod(mainClass, mainMethod, args);
      if (env->ExceptionOccurred()) {
        env->ExceptionDescribe();
        env->ExceptionClear();
      }
      return true;
    }
  }
  return false;
}

int WINAPI WinMain(HINSTANCE, HINSTANCE, LPSTR, int)
{
  SetThreadLocale(GetSystemDefaultLCID());
#ifdef LIB_PATH
  char fullLibName[4096];
  int fullLibNameLen = GetFullPathName(LIB_PATH, 4096, fullLibName, 0);
  if (fullLibNameLen) {
    fullLibName[fullLibNameLen++] = ';';
    char path[3072];
    int pathLen = GetEnvironmentVariable("PATH", path, 3072);
    for (int i = fullLibNameLen; i <= fullLibNameLen + pathLen; i++) {
      fullLibName[i] = path[i - fullLibNameLen];
    }
    SetEnvironmentVariable("PATH", fullLibName);
  }
#endif // LIB_PATH
  return main(__argc, __argv);
}

/*^*****************************************************************************
  File History:

 - 2007-04-13 14:10:11 Slobodan
   Initial version

*****************************************************************************^*/
