/*
 * @(#)NativeTest.h  0.2.0 / 2007-12-31
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef NATIVETEST_H
#define NATIVETEST_H

#ifdef JAVAQX_TEST

#include "JavaQxCore.h"

/*^**************************************************************************^*/
/*- NativeTest Class.                                                        -*/
/*^**************************************************************************^*/

/*!
 * \brief Native Test.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT NativeTest : public QObject
{
  Q_OBJECT
public:
  jobjectArray getTestMethods(JNIEnv *env);
  void setUp(JNIEnv *env);
  void tearDown(JNIEnv *env);
  bool invokeMethod(JNIEnv *env, jobject obj, jstring methodName);
public:
  static void initialize(JNIEnv *env, jclass cls);
protected:
  virtual void setUp();
  virtual void tearDown();
protected:
  jobject createJObject(const char *className);
  jobject createJObject(const char *className, const char *ctorSig, ...);
  void *nativeObjectPointer(jobject obj);
  void *nativeObjectPointer(jobject obj, const char *fieldName);
  template<typename T> T nativePointer(jobject obj) {
    return reinterpret_cast<T>(nativeObjectPointer(obj));
  }
  template<typename T> T nativePointer(jobject obj, const char *fieldName) {
    return reinterpret_cast<T>(nativeObjectPointer(obj, fieldName));
  }
  void failCondition(const char *condition = 0, const char *fileName = 0,
                     int lineNumber = -1);
protected:
  inline JNIEnv *env() const;
private:
  JNIEnv *m_env;
  jweak m_obj;
private:
  static jmethodID sm_failConditionMID;
};

/*^**************************************************************************^*/
/*- NativeTest :: Protected Inline Member Function.                          -*/
/*^**************************************************************************^*/

/*!
 * \brief JNIEnv pointer.
 *
 * \return JNIEnv pointer
 */
inline JNIEnv *NativeTest::env() const
{
  return m_env;
}

/*^**************************************************************************^*/
/*- Macro Definition.                                                        -*/
/*^**************************************************************************^*/

#define nativeTest (reinterpret_cast<NativeTest *>(testCase))

#endif // JAVAQX_TEST

#endif // NATIVETEST_H

/*^*****************************************************************************
  File History:

 - 2007-12-31 11:15:54 Slobodan
   Initial version

*****************************************************************************^*/
