/*
 * @(#)NativeTestCase.h  0.2.0 / 2007-12-31
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef NATIVETESTCASE_H
#define NATIVETESTCASE_H

#ifdef JAVAQX_TEST

#include "JavaQxCore.h"

/*^**************************************************************************^*/
/*- NativeTestCase Class.                                                    -*/
/*^**************************************************************************^*/

/*!
 * \brief Native Test Case.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT NativeTestCase : public QObject
{
  Q_OBJECT
public:
  NativeTestCase(JNIEnv *env, jobject obj);
  virtual ~NativeTestCase();
public:
  static void initialize(JNIEnv *env, jclass cls);
  static jlong testObject(JNIEnv *env, jobject obj);
protected:
  void failCondition(const char *condition = 0, const char *fileName = 0,
                     int lineNumber = -1);
protected:
  inline JNIEnv *env() const;
  inline jweak obj() const;
private:
  JNIEnv *m_env;
  jweak m_obj;
private:
  static jfieldID sm_testObjectFID;
  static jmethodID sm_failConditionMID;
};

/*^**************************************************************************^*/
/*- NativeTestCase :: Public Inline Member Functions.                        -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns JNIEnv pointer.
 *
 * \return JNIEnv pointer
 */
inline JNIEnv *NativeTestCase::env() const
{
  return m_env;
}

/*!
 * \brief Returns weak reference.
 *
 * \return weak reference
 */
inline jweak NativeTestCase::obj() const
{
  return m_obj;
}

/*^**************************************************************************^*/
/*- Macro Definition.                                                        -*/
/*^**************************************************************************^*/

#define nativeTestCase (reinterpret_cast<NativeTestCase *>(testObject))

#endif // JAVAQX_TEST

#endif // NATIVETESTCASE_H

/*^*****************************************************************************
  File History:

 - 2007-12-31 11:15:54 Slobodan
   Initial version

*****************************************************************************^*/
