/*
 * @(#)NativeTestFactory.h  0.2.0 / 2007-09-07
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef NATIVETESTFACTORY_H
#define NATIVETESTFACTORY_H

#ifdef JAVAQX_TEST

#include "NativeTest.h"

/*^**************************************************************************^*/
/*- AbstractNativeTestFactory Class.                                         -*/
/*^**************************************************************************^*/

/*!
 * \brief Abstract Native Test Factory.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT AbstractNativeTestFactory
{
protected:
  inline AbstractNativeTestFactory(const QString &name);
public:
  inline QString name() const;
public:
  virtual NativeTest *createNativeTest() = 0;
private:
  QString m_name;
};

/*^**************************************************************************^*/
/*- AbstractNativeTestFactory :: Protected Inline Constructor.               -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new abstract native test factory.
 *
 * \name the name of the test factory
 */
inline AbstractNativeTestFactory::AbstractNativeTestFactory(const QString &name)
  : m_name(name)
{
  // empty constructor body
}

/*^**************************************************************************^*/
/*- AbstractNativeTestFactory :: Public Inline Member Function.              -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns the name of the test factory.
 *
 * \return the name of the test factory
 */
inline QString AbstractNativeTestFactory::name() const
{
  return m_name;
}

/*!
 * \brief Native Test Factory.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
template<class T>
class JAVAQX_EXPORT NativeTestFactory : public AbstractNativeTestFactory
{
public:
  NativeTestFactory(const QString &name) : AbstractNativeTestFactory(name) {
    // empty constructor body
  }
public:
  virtual NativeTest *createNativeTest() {
    return new T();
  }
};

#endif // JAVAQX_TEST

#endif // NATIVETESTFACTORY_H

/*^*****************************************************************************
  File History:

 - 2007-09-07 18:25:20 Slobodan
   Initial version

*****************************************************************************^*/
