/*
 * @(#)QSwingNativeTest.cpp  0.2.0 / 2007-12-30
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "QSwingNativeTest.h"

#ifdef JAVAQX_TEST

/*^**************************************************************************^*/
/*- QSwingNativeTest :: Protected Member Functions.                          -*/
/*^**************************************************************************^*/

/*!
 * \brief Initializes QSwing.
 */
void QSwingNativeTest::qswingInitialize()
{
  JNIEnv *env = NativeTest::env();
  if (env) {
    jclass qswingClass = env->FindClass("yu/ac/bg/etf/javaqx/qswing/QSwing");
    if (qswingClass) {
      jmethodID initializeMID = env->GetMethodID(qswingClass, "initialize",
                                                 "()V");
      if (initializeMID) {
        if (JNIWrapper::callStaticVoidMethod(env, qswingClass, initializeMID)) {
          return;
        }
      }
    }
  }
  failCondition("QSwing initialization failed");
}

/*!
 * \brief Disposes QSwing.
 *
 * \param quitOnLastWindowClosed if \c true exits main loop when last window is
 *                               closed
 *
 * \return loop exit code
 */
int QSwingNativeTest::qswingStartEventLoop(bool quitOnLastWindowClosed)
{
  JNIEnv *env = NativeTest::env();
  if (env) {
    jclass qswingClass = env->FindClass("yu/ac/bg/etf/javaqx/qswing/QSwing");
    if (qswingClass) {
      jmethodID startEventLoopMID = env->GetMethodID(qswingClass,
                                                     "startEventLoop", "(Z)I");
      if (startEventLoopMID) {
        jint result;
        if (JNIWrapper::callStaticIntMethod(env, result, qswingClass,
                                            startEventLoopMID,
                                            quitOnLastWindowClosed)) {
          return result;
        }
      }
    }
  }
  failCondition("Could not start QSwing event loop");
  return -1;
}

/*!
 * \brief Exits QSwing event loop.
 *
 * \param extiCode the loop exit code
 */
void QSwingNativeTest::qswingStopEventLoop(int extiCode)
{
  JNIEnv *env = NativeTest::env();
  if (env) {
    jclass qswingClass = env->FindClass("yu/ac/bg/etf/javaqx/qswing/QSwing");
    if (qswingClass) {
      jmethodID stopEventLoopMID = env->GetMethodID(qswingClass,
                                                    "stopEventLoopMID",
                                                    "(I)V");
      if (stopEventLoopMID) {
        if (JNIWrapper::callStaticVoidMethod(env, qswingClass, stopEventLoopMID,
                                             extiCode)) {
          return;
        }
      }
    }
  }
  failCondition("Could not stop QSwing event loop");
}

/*!
 * \brief Disposes QSwing.
 */
void QSwingNativeTest::qswingDispose()
{
  JNIEnv *env = NativeTest::env();
  if (env) {
    jclass qswingClass = env->FindClass("yu/ac/bg/etf/javaqx/qswing/QSwing");
    if (qswingClass) {
      jmethodID disposeMID = env->GetMethodID(qswingClass, "dispose", "()V");
      if (disposeMID) {
        if (JNIWrapper::callStaticVoidMethod(env, qswingClass, disposeMID)) {
          return;
        }
      }
    }
  }
  failCondition("Could not dispose QSwing");
}

#endif // JAVAQX_TEST

/*^*****************************************************************************
  File History:

 - 2007-12-30 19:49:12 Slobodan
   Initial version

*****************************************************************************^*/
