/*
 * @(#)GLJQComponentBridge.cpp  0.2.0 / 2007-08-18
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "GLJQComponentBridge.h"

#include "QGLWidgetAdapter.h"

/*^**************************************************************************^*/
/*- GLJQComponentBridge :: Protected Constructor.                            -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new GLJQComponentBridge object.
 *
 * \param env the JNIEnv pointer
 * \param obj the GLJQComponent object 
 */
GLJQComponentBridge::GLJQComponentBridge(JNIEnv *env, jobject obj)
  : JQComponentBridge(env, obj, new QGLWidgetAdapter(this))
{
  setBridgePointer(reinterpret_cast<jlong>(this));
}

/*^**************************************************************************^*/
/*- GLJQComponentBridge :: Native Calls.                                     -*/
/*^**************************************************************************^*/

/*!
 * \brief Updates GL.
 *
 * \param env the JNIEnv pointer 
 */
void GLJQComponentBridge::updateGL(JNIEnv *env)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(updateGL, QSWING_ENV_ARG)
  qGLWidget()->updateGL();
}

/*^**************************************************************************^*/
/*- GLJQComponentBridge :: Static Native Calls.                              -*/
/*^**************************************************************************^*/

/*!
 * \brief Initializes GLJQComponentBridge class.
 *
 * \param env the JNIEnv pointer
 * \param cls the GLJQComponent class
 *
 * \exception FatalError if failed
 */
void GLJQComponentBridge::initialize(JNIEnv *env, jclass cls)
{
  Q_ASSERT(env);
  Q_ASSERT(cls);
  Q_ASSERT(!sm_createGLMID);
  if (!INIT_UMID(createGL, cls, "()J") || !INIT_MID(initializeGL, cls, "()V") ||
      !INIT_MID(resizeGL, cls, "(II)V") || !INIT_MID(paintGL, cls, "()V")) {
    FATAL_LOGGED_ERROR("GLJQComponentBridge initialization failed");
  }
}

/*!
 * \brief Returns new instance of the bridge object.
 *
 * \param env the JNIEnv pointer 
 * \param obj the QSwing object
 * 
 * \return new instance of the bridge object
 */
jlong GLJQComponentBridge::newInstance(JNIEnv *env, jobject obj)
{
  if (JNIQSwingWrapper::isQSwingThread(env)) {
    return reinterpret_cast<jlong>(new GLJQComponentBridge(env, obj));
  }
  return QSwingUtilitiesBridge::invokeLongAndWait(env, obj, sm_createGLMID);
}

/*^**************************************************************************^*/
/*- GLJQComponentBridge :: Private Static Data Members.                      -*/
/*^**************************************************************************^*/

jmethodID GLJQComponentBridge::sm_createGLMID = 0;
jmethodID GLJQComponentBridge::sm_initializeGLMID = 0;
jmethodID GLJQComponentBridge::sm_resizeGLMID = 0;
jmethodID GLJQComponentBridge::sm_paintGLMID = 0;

/*^*****************************************************************************
  File History:

 - 2007-08-18 14:03:49 JavaQx Native Generator
   Initial version

*****************************************************************************^*/
