/*
 * @(#)GLJQComponentBridge.h  0.2.0 / 2007-08-18
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef GLJQCOMPONENTBRIDGE_H
#define GLJQCOMPONENTBRIDGE_H

#include "JavaQxOpenGL.h"

#include "JQComponentBridge.h"

/*^**************************************************************************^*/
/*- GLJQComponentBridge Class.                                               -*/
/*^**************************************************************************^*/

/*!
 * \brief GLJQComponent Bridge.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT GLJQComponentBridge : public JQComponentBridge
{
  Q_OBJECT
protected:
  GLJQComponentBridge(JNIEnv *env, jobject obj);
public: // native calls
  void updateGL(JNIEnv *env);
public: // native calls
  static void initialize(JNIEnv *env, jclass cls);
  static jlong newInstance(JNIEnv *env, jobject obj);
public:
  inline QGLWidget *qGLWidget() const;
protected:
  friend class QGLWidgetAdapter; // uses all protected methods
  inline void callInitializeGL();
  inline void callResizeGL(int width, int height);
  inline void callPaintGL();
private:
  static jmethodID sm_createGLMID;
  static jmethodID sm_initializeGLMID;
  static jmethodID sm_resizeGLMID;
  static jmethodID sm_paintGLMID;
};

/*^**************************************************************************^*/
/*- GLJQComponentBridge :: Protected Inline Member Functions.                -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns QGLWidget adaptee.
 *
 * \return QGLWidget adaptee
 */
inline QGLWidget *GLJQComponentBridge::qGLWidget() const
{
  return static_cast<QGLWidget *>(qObject());
}

/*!
 * \brief Calls initializeGL method of the JavaQx GLJQComponent object.
 */
inline void GLJQComponentBridge::callInitializeGL()
{
  jniObject()->callVoidMethod(sm_initializeGLMID);
}

/*!
 * \brief Calls resizeGL method of the JavaQx GLJQComponent object.
 *
 * \param width the width
 * \param height the height
 */
inline void GLJQComponentBridge::callResizeGL(int width, int height)
{
  jniObject()->callVoidMethod(sm_resizeGLMID, width, height);
}

/*!
 * \brief Calls paintGL method of the JavaQx GLJQComponent object.
 */
inline void GLJQComponentBridge::callPaintGL()
{
  jniObject()->callVoidMethod(sm_paintGLMID);
}

/*^**************************************************************************^*/
/*- Macro Definition.                                                        -*/
/*^**************************************************************************^*/

#define glJQComponentBridge (reinterpret_cast<GLJQComponentBridge *>(bridge))

#endif //GLJQCOMPONENTBRIDGE_H

/*^*****************************************************************************
  File History:

 - 2007-08-18 14:03:49 JavaQx Native Generator
   Initial version

*****************************************************************************^*/
