/*
 * @(#)JavaQxQSwing.h  0.2.0 / 2007-04-13
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * The contents of this file are subject to the LGPL, version 2.1, license
 * distributed with the source code in the file LICENSE.txt
 */
#ifndef JAVAQXQSWING_H
#define JAVAQXQSWING_H

/*!
 * \brief Common header file for the qswing module.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */

/*^**************************************************************************^*/
/*- JavaQxQSwing :: Includes.                                                -*/
/*^**************************************************************************^*/

#include <QtGui>

#include "JavaQxCore.h"

#include "JNIQSwingWrapper.h"
#include "QSwingString.h"
#include "QColorAdapter.h"
#include "DimensionObject.h"
#include "RectangleObject.h"
#include "QFontAdapter.h"
#include "QEventsAdapter.h"
#include "QSwingMetaObject.h"
#include "QSwingUtilitiesBridge.h"

/*^**************************************************************************^*/
/*- JavaQxQSwing :: Global Functions.                                        -*/
/*^**************************************************************************^*/

template<typename T>
inline T invokeMember(QObject *obj, const char *method, const char *type,
                      QGenericArgument val0 = QGenericArgument(),
                      QGenericArgument val1 = QGenericArgument(),
                      QGenericArgument val2 = QGenericArgument(),
                      QGenericArgument val3 = QGenericArgument(),
                      QGenericArgument val4 = QGenericArgument(),
                      QGenericArgument val5 = QGenericArgument(),
                      QGenericArgument val6 = QGenericArgument(),
                      QGenericArgument val7 = QGenericArgument(),
                      QGenericArgument val8 = QGenericArgument(),
                      QGenericArgument val9 = QGenericArgument())
{
  T t;
  #ifdef JAVAQX_DEBUG
    bool memberInvoked =
  #endif // JAVAQX_DEBUG
      QSwingMetaObject::invokeMember(obj, method, type, static_cast<void *>(&t),
                                     &val0, &val1, &val2, &val3, &val4, &val5,
                                     &val6, &val7, &val8, &val9);
  #ifdef JAVAQX_DEBUG
    Q_ASSERT(memberInvoked);
  #endif // JAVAQX_DEBUG
  return t;
}

template<typename T>
inline T invokeStaticMember(int classID, int methodID, const char *type,
                            QGenericArgument val0 = QGenericArgument(),
                            QGenericArgument val1 = QGenericArgument(),
                            QGenericArgument val2 = QGenericArgument(),
                            QGenericArgument val3 = QGenericArgument(),
                            QGenericArgument val4 = QGenericArgument(),
                            QGenericArgument val5 = QGenericArgument(),
                            QGenericArgument val6 = QGenericArgument(),
                            QGenericArgument val7 = QGenericArgument(),
                            QGenericArgument val8 = QGenericArgument(),
                            QGenericArgument val9 = QGenericArgument())
{
  T t;
  #ifdef JAVAQX_DEBUG
    bool memberInvoked =
  #endif // JAVAQX_DEBUG
      QSwingMetaObject::invokeStaticMember(classID, methodID, type,
                                           static_cast<void *>(&t), &val0,
                                           &val1, &val2, &val3, &val4, &val5,
                                           &val6, &val7, &val8, &val9);
  #ifdef JAVAQX_DEBUG
    Q_ASSERT(memberInvoked);
  #endif // JAVAQX_DEBUG
  return t;
}

/*^**************************************************************************^*/
/*- JavaQxQSwing :: Explicit Function Template Instantiations.               -*/
/*^**************************************************************************^*/

template inline jobject invokeMember<jobject>(
                          QObject *, const char *, const char *,
                          QGenericArgument, QGenericArgument, QGenericArgument,
                          QGenericArgument, QGenericArgument, QGenericArgument,
                          QGenericArgument, QGenericArgument, QGenericArgument,
                          QGenericArgument);
template inline jstring invokeMember<jstring>(
                          QObject *, const char *, const char *,
                          QGenericArgument, QGenericArgument, QGenericArgument,
                          QGenericArgument, QGenericArgument, QGenericArgument,
                          QGenericArgument, QGenericArgument, QGenericArgument,
                          QGenericArgument);
template inline jint invokeMember<jint>(
                          QObject *, const char *, const char *,
                          QGenericArgument, QGenericArgument, QGenericArgument,
                          QGenericArgument, QGenericArgument, QGenericArgument,
                          QGenericArgument, QGenericArgument, QGenericArgument,
                          QGenericArgument);
template inline jboolean invokeMember<jboolean>(
                          QObject *, const char *, const char *,
                          QGenericArgument, QGenericArgument, QGenericArgument,
                          QGenericArgument, QGenericArgument, QGenericArgument,
                          QGenericArgument, QGenericArgument, QGenericArgument,
                          QGenericArgument);

template inline jobject invokeStaticMember<jobject>(
                          int, int, const char *, QGenericArgument,
                          QGenericArgument, QGenericArgument, QGenericArgument,
                          QGenericArgument, QGenericArgument, QGenericArgument,
                          QGenericArgument, QGenericArgument, QGenericArgument);
template inline jstring invokeStaticMember<jstring>(
                          int, int, const char *, QGenericArgument,
                          QGenericArgument, QGenericArgument, QGenericArgument,
                          QGenericArgument, QGenericArgument, QGenericArgument,
                          QGenericArgument, QGenericArgument, QGenericArgument);
template inline jobjectArray invokeStaticMember<jobjectArray>(
                          int, int, const char *, QGenericArgument,
                          QGenericArgument, QGenericArgument, QGenericArgument,
                          QGenericArgument, QGenericArgument, QGenericArgument,
                          QGenericArgument, QGenericArgument, QGenericArgument);
template inline jint invokeStaticMember<jint>(
                          int, int, const char *, QGenericArgument,
                          QGenericArgument, QGenericArgument, QGenericArgument,
                          QGenericArgument, QGenericArgument, QGenericArgument,
                          QGenericArgument, QGenericArgument, QGenericArgument);
template inline jboolean invokeStaticMember<jboolean>(
                          int, int, const char *, QGenericArgument,
                          QGenericArgument, QGenericArgument, QGenericArgument,
                          QGenericArgument, QGenericArgument, QGenericArgument,
                          QGenericArgument, QGenericArgument, QGenericArgument);

/*^**************************************************************************^*/
/*- JavaQxQSwing :: Macro Definitions.                                       -*/
/*^**************************************************************************^*/

#define JBOOLEAN_ARG(boolean) Q_ARG(jboolean, boolean)
#define JCHAR_ARG(char) Q_ARG(jchar, char)
#define JSHORT_ARG(short) Q_ARG(jshort, short)
#define JINT_ARG(int) Q_ARG(jint, int)
#define JLONG_ARG(long) Q_ARG(jlong, long)
#define JFLOAT_ARG(float) Q_ARG(jfloat, float)
#define JDOUBLE_ARG(double) Q_ARG(jdouble, double)
#define JOBJECT_ARG(object) Q_ARG(jobject, GlobalJObject(env, object).ref())
#define JSTRING_ARG(string) Q_ARG(jstring, GlobalJString(env, string).ref())
#define JCLASS_ARG(class) Q_ARG(jclass, GlobalJClass(env, class).ref())
#define JBYTEARRAY_ARG(byteArray) \
    Q_ARG(jbyteArray, GlobalJByteArray(env, byteArray).ref())
#define QSWING_ENV_ARG Q_ARG(JNIEnv *, QSWING_ENV)

#ifndef JAVAQX_DEBUG
  #define QSWING_REENTRANT(method, ...) \
      if (!JNIQSwingWrapper::isQSwingThread(env)) { \
        QMetaObject::invokeMethod(this, #method, \
                                  Qt::BlockingQueuedConnection, \
                                  QGenericReturnArgument(), __VA_ARGS__); \
        return; \
      }
#endif // JAVAQX_DEBUG

#ifndef JAVAQX_DEBUG
  #define QSWING_STATIC_REENTRANT(class, method, ...) \
      if (!JNIQSwingWrapper::isQSwingThread(env)) { \
        QSwingMetaObject::invokeStaticMember( \
                              QSwingMetaObject::class##_classID, \
                              QSwingMetaObject::class##_##method##_methodID, \
                              __VA_ARGS__); \
        return; \
      }
#endif // JAVAQX_DEBUG

#ifdef JAVAQX_DEBUG
  #define QSWING_REENTRANT(method, ...) \
      if (!JNIQSwingWrapper::isQSwingThread(env)) { \
        bool methodInvoked = \
             QMetaObject::invokeMethod(this, #method, \
                                       Qt::BlockingQueuedConnection, \
                                       QGenericReturnArgument(), __VA_ARGS__); \
        Q_ASSERT(methodInvoked); \
        return; \
      }
#endif // JAVAQX_DEBUG

#ifdef JAVAQX_DEBUG
  #define QSWING_STATIC_REENTRANT(class, method, ...) \
      if (!JNIQSwingWrapper::isQSwingThread(env)) { \
        bool methodInvoked = \
          QSwingMetaObject::invokeStaticMember( \
                              QSwingMetaObject::class##_classID, \
                              QSwingMetaObject::class##_##method##_methodID, \
                              __VA_ARGS__); \
        Q_ASSERT(methodInvoked); \
        return; \
      }
#endif // JAVAQX_DEBUG

#define QSWING_REENTRANT_RETURN(method, type, ...) \
    if (!JNIQSwingWrapper::isQSwingThread(env)) { \
      return invokeMember<type>(this, #method, #type, __VA_ARGS__); \
    }

#define QSWING_STATIC_REENTRANT_RETURN(class, method, type, ...) \
    if (!JNIQSwingWrapper::isQSwingThread(env)) { \
      return invokeStaticMember<type>( \
                              QSwingMetaObject::class##_classID, \
                              QSwingMetaObject::class##_##method##_methodID, \
                              #type, __VA_ARGS__); \
    }

#endif // JAVAQX_QSWING_H

/*^*****************************************************************************
  File History:

 - 2007-04-13 16:21:36 Slobodan
   Initial version

*****************************************************************************^*/
