/*
 * @(#)PlainDocument.cpp  0.2.0 / 2007-12-12
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "PlainDocument.h"

#include <QApplication>

/*^**************************************************************************^*/
/*- PlainDocument :: Public Constructor.                                     -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new PlainDocument object.
 *
 * \param documentBridge the document bridge
 */
PlainDocument::PlainDocument(TextDocumentBridge *documentBridge)
  : QTextDocumentAdapter(documentBridge)
{
  setDefaultFont(QApplication::font("QTextArea"));
}

/*^**************************************************************************^*/
/*- PlainDocument :: Overridden Member Functions.                            -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns document's text.
 *
 * \return document's text
 */
QString PlainDocument::getText() const
{
  return QTextDocumentAdapter::toPlainText();
}

/*!
 * \brief Sets document's text.
 *
 * \param text the text to be set
 */
void PlainDocument::setText(const QString &text)
{
  QTextDocumentAdapter::setPlainText(text);
  setModified(false);
  emit textSet();
}

/*!
 * \brief Appends text.
 *
 * \param text the text to be appended
 */
void PlainDocument::appendText(const QString &text)
{
  QTextCursor cursor(this);
  cursor.beginEditBlock();
  cursor.movePosition(QTextCursor::End);
  cursor.insertText(text);
  cursor.endEditBlock();
  emit textAppended();
}

/*^*****************************************************************************
  File History:

 - 2007-12-12 15:03:02 Slobodan
   Initial version

*****************************************************************************^*/
