/*
 * @(#)QColorAdapter.cpp  0.2.0 / 2007-08-28
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "QColorAdapter.h"

#include "JNIQSwingWrapper.h"

/*^**************************************************************************^*/
/*- QColorAdapter :: Public Constructors.                                    -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new QColorAdapter object.
 *
 * \param color the QSwing color
 */
QColorAdapter::QColorAdapter(jobject color)
  : QColor()
{
  jint argb = 0;
  if (JNIQSwingWrapper::callIntMethod(argb, color, sm_getARGBMID)) {
    setRgb(0xFF & (argb >> 16), 0xFF & (argb >> 8), 0xFF & argb,
           0xFF & (argb >> 24));
  }
}

/*!
 * \brief Constructs new QColorAdapter object.
 *
 * \param argb the argb value of the color
 */
QColorAdapter::QColorAdapter(jint argb)
  : QColor(0xFF & (argb >> 16), 0xFF & (argb >> 8), 0xFF & argb,
           0xFF & (argb >> 24))
{
  // empty constructor body
}

/*^**************************************************************************^*/
/*- QColorAdapter :: Public Static Member Functions.                         -*/
/*^**************************************************************************^*/

/*!
 * \brief Initializes QColorAdapter class.
 *
 * \param env the JNIEnv pointer
 * \param cls the QSwing color class
 *
 * \exception FatalError if failed
 */
void QColorAdapter::initialize(JNIEnv *env, jclass cls)
{
  Q_ASSERT(env);
  Q_ASSERT(cls);
  Q_ASSERT(!sm_colorClass);
  if (!INIT_CLASS(color, cls) ||
      !INIT_CONSTRUCTOR(constructor, cls, "(IIII)V") ||
      !INIT_MID(getARGB, cls, "()I")) {
    FATAL_LOGGED_ERROR("QColorAdapter initialization failed");
  }
}

/*!
 * \brief Creates new QSwing color instance.
 *
 * \param env the JNIEnv pointer
 * \param colorClass the QSwing color class
 * \param color the QColor reference
 *
 * \return new QSwing color instance
 *
 * \exception OutOfMemoryError java exception
 */
jobject QColorAdapter::toJColor(JNIEnv *env, jclass colorClass,
                                const QColor &color)
{
  return JNIWrapper::newObject(env, colorClass, sm_constructorMID, color.red(),
                               color.green(), color.blue(), color.alpha());
}

/*!
 * \brief Creates new QSwing color instance.
 *
 * \param color the QColor reference
 *
 * \return new QSwing color instance
 *
 * \exception OutOfMemoryError java exception
 */
jobject QColorAdapter::toJColor(const QColor &color)
{
  return JNIQSwingWrapper::newObject(sm_colorClass, sm_constructorMID,
                                     color.red(), color.green(), color.blue(),
                                     color.alpha());
}

/*^**************************************************************************^*/
/*- QColorAdapter :: Private Static Data Members.                            -*/
/*^**************************************************************************^*/

jclass QColorAdapter::sm_colorClass = 0;
jmethodID QColorAdapter::sm_constructorMID = 0;
jmethodID QColorAdapter::sm_getARGBMID = 0;

/*^*****************************************************************************
  File History:

 - 2007-08-28 09:22:50 Slobodan
   Initial version

*****************************************************************************^*/
