/*
 * @(#)QSplitterAdapter.h  0.2.0 / 2007-12-05
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef QSPLITTERADAPTER_H
#define QSPLITTERADAPTER_H

#include "JavaQxQSwing.h"

/*^**************************************************************************^*/
/*- QSplitterHandleAdapter Class.                                            -*/
/*^**************************************************************************^*/

/*!
 * \brief QSplitterHandle Adapter.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT QSplitterHandleAdapter : public QSplitterHandle
{
public:
  QSplitterHandleAdapter(Qt::Orientation orientation, QSplitter *parent,
                         bool touchExpandable);
public:
  void setTouchExpandable(bool touchExpandable);
protected:
  virtual void resizeEvent(QResizeEvent *e);
  virtual void paintEvent(QPaintEvent *e);
  virtual void enterEvent(QEvent *e);
  virtual void leaveEvent(QEvent *e);
  virtual void mouseMoveEvent(QMouseEvent *e);
  virtual void mousePressEvent(QMouseEvent *e);
  virtual void mouseReleaseEvent(QMouseEvent *e);
private:
  void calculateArrows();
private:
  enum MousePosition { Outside, Over, OverFirst, OverSecond };
  MousePosition m_mousePosition;
  QPoint m_pressedPoint;
  QPoint m_firstArrow[3];
  QPoint m_secondArrow[3];
  QRect m_firstArrowRect;
  QRect m_secondArrowRect;
  bool m_touchExpandable;
};

/*^**************************************************************************^*/
/*- QSplitterAdapter Class.                                                  -*/
/*^**************************************************************************^*/

/*!
 * \brief QSplitter Adapter.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class QSplitterAdapter : public QSplitter
{
public:
  QSplitterAdapter();
public:
  void setHandlePosition(int position);
  void setOneTouchExpandable(bool oneTouchExpandable);
  void setResizeWeight(double resizeWeight);
  void collapseFirst();
  void collapseSecond();
protected:
  QSplitterHandle *createHandle();
private:
  bool m_oneTouchExpandable;
  double m_resizeWeight;
};

#endif // QSPLITTERADAPTER_H

/*^*****************************************************************************
  File History:

 - 2007-12-05 22:04:32 Slobodan
   Initial version

*****************************************************************************^*/
