/*
 * @(#)QSwingGraphics.h  0.2.0 / 2007-09-11
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef QSWINGGRAPHICS_H
#define QSWINGGRAPHICS_H

#include "JavaQxQSwing.h"

/*^**************************************************************************^*/
/*- QSwingGraphics Class.                                                    -*/
/*^**************************************************************************^*/

/*!
 * \brief Extended QPainter.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT QSwingGraphics : public QPainter
{
public:
  QSwingGraphics(QPaintDevice *device);
  QSwingGraphics(QPaintDevice *device, jint x, jint y, jint width, jint height);
public:
  jobject getColor();
  void setColor(jint argb);
  jobject getFont();
  void setFont(jobject font);
  void setLinearGradient(jint x1, jint y1, jint argb1, jint x2, jint y2,
                         jint argb2, jboolean cyclic);
  void setTextureGradient(QPixmap *image);
  void setBasicStroke(jfloat width, jint cap, jint join, jfloat miterLimit,
                      jfloatArray dash, jfloat dashPhase);
  void push();
  void pop();
  void drawImage(jbyteArray imageData, jint length, jint x, jint y);
  void fillRect(jint x, jint y, jint w, jint h);
  void fillOval(jint x, jint y, jint w, jint h);
public:
  inline static bool canPaint(JNIEnv *env, jlong graphicsPointer);
private:
  static const Qt::PenCapStyle PEN_CAP_STYLE[];
  static const Qt::PenJoinStyle PEN_JOIN_STYLE[];
};

/*^**************************************************************************^*/
/*- QSwingGraphics :: Public Static Inline Member Function.                  -*/
/*^**************************************************************************^*/

/*!
 * \brief Tests if specifed graphics can paint.
 *
 * \param env the JNIEnv pointer
 * \param graphicsPointer the graphics pointer
 *
 * \return \c true if graphics object can paint
 */
inline bool QSwingGraphics::canPaint(JNIEnv *env, jlong graphicsPointer)
{
  return (graphicsPointer && JNIQSwingWrapper::isQSwingThread(env));
}

/*^**************************************************************************^*/
/*- Macro Definitions.                                                       -*/
/*^**************************************************************************^*/

#define qSwingGraphics (reinterpret_cast<QSwingGraphics *>(graphicsPointer))
#define qPainterPath (reinterpret_cast<QPainterPath *>(painterPathPointer))
#define qPaintDevice (reinterpret_cast<QPaintDevice *>(paintDevicePointer))

#endif //QSWINGGRAPHICS_H

/*^*****************************************************************************
  File History:

 - 2007-09-11 13:03:16 Slobodan
   Initial version

*****************************************************************************^*/
