/*
 * @(#)QSwingMetaObject.cpp  0.2.0 / 2007-12-03
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "QSwingMetaObject.h"

#include "JQColorChooserBridge.h"
#include "JQDesktopBridge.h"
#include "JQFileChooserBridge.h"
#include "JQFontChooserBridge.h"
#include "JQOptionPaneBridge.h"
#include "JQToolTipBridge.h"
#include "JQWindowBridge.h"
#include "QSwingImageBridge.h"
#include "WhatsThisManagerBridge.h"

/*^**************************************************************************^*/
/*- QSwingMetaObject :: Helper Macros.                                       -*/
/*^**************************************************************************^*/

#define FRAME_RET(type) (*reinterpret_cast<type(*)>(frame->ret->data()))
#define FRAME_ARG(type, num) \
    (*reinterpret_cast<type(*)>(frame->val##num->data()))

/*^**************************************************************************^*/
/*- QSwingMetaObject :: Private Constructors.                                -*/
/*^**************************************************************************^*/

QSwingMetaObject::QSwingMetaObject()
  : QObject(0)
{
  connect(this, SIGNAL(invokeMemberSignal(InvokeMemberFrame *)), this,
          SLOT(invokeMemberSlot(InvokeMemberFrame *)),
          Qt::BlockingQueuedConnection);
  connect(this, SIGNAL(invokeStaticMemberSignal(InvokeStaticMemberFrame *)),
          this, SLOT(invokeStaticMemberSlot(InvokeStaticMemberFrame *)),
          Qt::BlockingQueuedConnection);
}

QSwingMetaObject::QSwingMetaObject(const QSwingMetaObject &)
  : QObject(0)
{
  // disabled
}

/*^**************************************************************************^*/
/*- QSwingMetaObject :: Private Destructor.                                 - */
/*^**************************************************************************^*/

QSwingMetaObject::~QSwingMetaObject()
{
  // disabled
}

/*^**************************************************************************^*/
/*- QSwingMetaObject :: Public Static Member Function.                       -*/
/*^**************************************************************************^*/

/*!
 * \brief Initializes QSwingMetaObject class.
 */
void QSwingMetaObject::initialize()
{
  Q_ASSERT(!sm_instance);
  sm_instance = new QSwingMetaObject();
}

/*!
 * \brief Invokes member function of the specified objet.
 *
 * \param obj the QObject
 * \param member the member name
 * \param type the return type
 * \param ret the return value
 * \param val0 the argument
 * \param val1 the argument
 * \param val2 the argument
 * \param val3 the argument
 * \param val4 the argument
 * \param val5 the argument
 * \param val6 the argument
 * \param val7 the argument
 * \param val8 the argument
 * \param val9 the argument
 *
 * \return \c true if succeed result
 */
bool QSwingMetaObject::invokeMember(QObject *obj, const char *member,
                                    const char *type, void *ret,
                                    QGenericArgument *val0,
                                    QGenericArgument *val1,
                                    QGenericArgument *val2,
                                    QGenericArgument *val3,
                                    QGenericArgument *val4,
                                    QGenericArgument *val5,
                                    QGenericArgument *val6,
                                    QGenericArgument *val7,
                                    QGenericArgument *val8,
                                    QGenericArgument *val9)
{
  Q_ASSERT(obj);
  Q_ASSERT(member);
  QGenericReturnArgument gra(type, ret);
  InvokeMemberFrame frame;
  frame.obj = obj;
  frame.member = member;
  frame.ret = &gra;
  frame.val0 = val0;
  frame.val1 = val1;
  frame.val2 = val2;
  frame.val3 = val3;
  frame.val4 = val4;
  frame.val5 = val5;
  frame.val6 = val6;
  frame.val7 = val7;
  frame.val8 = val8;
  frame.val9 = val9;
  sm_instance->invokeMember(&frame);
  return frame.succeed;
}

/*!
 * \brief Invokes static member function of the specified class.
 *
 * \param classID the class ID
 * \param methodID the method ID
 * \param type the return type
 * \param ret the return value
 * \param val0 the argument
 * \param val1 the argument
 * \param val2 the argument
 * \param val3 the argument
 * \param val4 the argument
 * \param val5 the argument
 * \param val6 the argument
 * \param val7 the argument
 * \param val8 the argument
 * \param val9 the argument
 *
 * \return \c true if succeed result
 */
bool QSwingMetaObject::invokeStaticMember(int classID, int methodID,
                                          const char *type, void *ret,
                                          QGenericArgument *val0,
                                          QGenericArgument *val1,
                                          QGenericArgument *val2,
                                          QGenericArgument *val3,
                                          QGenericArgument *val4,
                                          QGenericArgument *val5,
                                          QGenericArgument *val6,
                                          QGenericArgument *val7,
                                          QGenericArgument *val8,
                                          QGenericArgument *val9)
{
  QGenericReturnArgument gra(type, ret);
  InvokeStaticMemberFrame frame;
  frame.classID = classID;
  frame.methodID = methodID;
  frame.ret = &gra;
  frame.val0 = val0;
  frame.val1 = val1;
  frame.val2 = val2;
  frame.val3 = val3;
  frame.val4 = val4;
  frame.val5 = val5;
  frame.val6 = val6;
  frame.val7 = val7;
  frame.val8 = val8;
  frame.val9 = val9;
  sm_instance->invokeStaticMember(&frame);
  return frame.succeed;
}

/*!
 * \brief Invokes static member function of the specified class.
 *
 * \param classID the class ID
 * \param methodID the method ID
 * \param val0 the argument
 * \param val1 the argument
 * \param val2 the argument
 * \param val3 the argument
 * \param val4 the argument
 * \param val5 the argument
 * \param val6 the argument
 * \param val7 the argument
 * \param val8 the argument
 * \param val9 the argument
 *
 * \return \c true if succeed result
 */
bool QSwingMetaObject::invokeStaticMember(int classID, int methodID,
                                          QGenericArgument val0,
                                          QGenericArgument val1,
                                          QGenericArgument val2,
                                          QGenericArgument val3,
                                          QGenericArgument val4,
                                          QGenericArgument val5,
                                          QGenericArgument val6,
                                          QGenericArgument val7,
                                          QGenericArgument val8,
                                          QGenericArgument val9)
{
  InvokeStaticMemberFrame frame;
  frame.classID = classID;
  frame.methodID = methodID;
  frame.val0 = &val0;
  frame.val1 = &val1;
  frame.val2 = &val2;
  frame.val3 = &val3;
  frame.val4 = &val4;
  frame.val5 = &val5;
  frame.val6 = &val6;
  frame.val7 = &val7;
  frame.val8 = &val8;
  frame.val9 = &val9;
  sm_instance->invokeStaticMember(&frame);
  return frame.succeed;
}

/*^**************************************************************************^*/
/*- QSwingMetaObject :: Private Member Functions.                            -*/
/*^**************************************************************************^*/

void QSwingMetaObject::invokeMember(InvokeMemberFrame *frame)
{
  emit invokeMemberSignal(frame);
}

void QSwingMetaObject::invokeStaticMember(InvokeStaticMemberFrame *frame)
{
  emit invokeStaticMemberSignal(frame);
}

void QSwingMetaObject::invokeMemberSlot(InvokeMemberFrame *frame)
{
  frame->succeed = QMetaObject::invokeMethod(frame->obj, frame->member,
                                             Qt::DirectConnection, *frame->ret,
                                             *frame->val0, *frame->val1,
                                             *frame->val2, *frame->val3,
                                             *frame->val4, *frame->val5,
                                             *frame->val6, *frame->val7,
                                             *frame->val8, *frame->val9); 
}

void QSwingMetaObject::invokeStaticMemberSlot(InvokeStaticMemberFrame *frame)
{
  switch(frame->classID) {
// JQOptionPaneBridge Static Member Functions
    case JQOptionPaneBridge_classID:
      switch(frame->methodID) {
        case JQOptionPaneBridge_showMessage_methodID:
          FRAME_RET(jint) =
                        JQOptionPaneBridge::showMessage(FRAME_ARG(JNIEnv *, 0),
                                                        FRAME_ARG(jclass, 1),
                                                        FRAME_ARG(jint, 2),
                                                        FRAME_ARG(jlong, 3),
                                                        FRAME_ARG(jstring, 4),
                                                        FRAME_ARG(jstring, 5),
                                                        FRAME_ARG(jint, 6),
                                                        FRAME_ARG(jint, 7));
          frame->succeed = true;
          break;
        default:
          frame->succeed = false;
      }
      break;
// JQWindowBridge Static Member Functions
    case JQWindowBridge_classID:
      switch(frame->methodID) {
        case JQWindowBridge_getWindows_methodID:
          FRAME_RET(jobjectArray) =
                             JQWindowBridge::getWindows(FRAME_ARG(JNIEnv *, 0),
                                                        FRAME_ARG(jclass, 1));
          frame->succeed = true;
          break;
        case JQWindowBridge_getActiveWindow_methodID:
          FRAME_RET(jobject) =
                        JQWindowBridge::getActiveWindow(FRAME_ARG(JNIEnv *, 0),
                                                        FRAME_ARG(jclass, 1));
          frame->succeed = true;
          break;
        case JQWindowBridge_setWindowOwner_methodID:
          JQWindowBridge::setWindowOwner(FRAME_ARG(JNIEnv *, 0),
                                         FRAME_ARG(jclass, 1),
                                         FRAME_ARG(jlong, 2),
                                         FRAME_ARG(jlong, 3));
          frame->succeed = true;
          break;
        default:
          frame->succeed = false;
      }
      break;
// JQColorChooserBridge Static Member Functions
    case JQColorChooserBridge_classID:
      switch(frame->methodID) {
        case JQColorChooserBridge_getColor_methodID:
          FRAME_RET(jobject) =
                         JQColorChooserBridge::getColor(FRAME_ARG(JNIEnv *, 0),
                                                        FRAME_ARG(jclass, 1),
                                                        FRAME_ARG(jlong, 2),
                                                        FRAME_ARG(jint, 3));
          frame->succeed = true;
          break;
        default:
          frame->succeed = false;
      }
      break;
// JQFontChooserBridge Static Member Functions
    case JQFontChooserBridge_classID:
      switch(frame->methodID) {
        case JQFontChooserBridge_getFont_methodID:
          FRAME_RET(jobject) =
                           JQFontChooserBridge::getFont(FRAME_ARG(JNIEnv *, 0),
                                                        FRAME_ARG(jclass, 1),
                                                        FRAME_ARG(jlong, 2),
                                                        FRAME_ARG(jobject, 3),
                                                        FRAME_ARG(jstring, 4));
          frame->succeed = true;
          break;
        default:
          frame->succeed = false;
      }
      break;
// JQFileChooserBridge Static Member Functions
    case JQFileChooserBridge_classID:
      switch(frame->methodID) {
        case JQFileChooserBridge_getExistingDirectoryName_methodID:
          FRAME_RET(jstring) =
                          JQFileChooserBridge::getExistingDirectoryName(
                                                  FRAME_ARG(JNIEnv *, 0),
                                                  FRAME_ARG(jclass, 1),
                                                  FRAME_ARG(jlong, 2),
                                                  FRAME_ARG(jstring, 3),
                                                  FRAME_ARG(jstring, 4));
          frame->succeed = true;
          break;
        case JQFileChooserBridge_getOpenFileName_methodID:
          FRAME_RET(jstring) =
                   JQFileChooserBridge::getOpenFileName(FRAME_ARG(JNIEnv *, 0),
                                                        FRAME_ARG(jclass, 1),
                                                        FRAME_ARG(jlong, 2),
                                                        FRAME_ARG(jstring, 3),
                                                        FRAME_ARG(jstring, 4),
                                                        FRAME_ARG(jstring, 5),
                                                        FRAME_ARG(jstring, 6));
          frame->succeed = true;
          break;
        case JQFileChooserBridge_getSaveFileName_methodID:
          FRAME_RET(jstring) =
                   JQFileChooserBridge::getSaveFileName(FRAME_ARG(JNIEnv *, 0),
                                                        FRAME_ARG(jclass, 1),
                                                        FRAME_ARG(jlong, 2),
                                                        FRAME_ARG(jstring, 3),
                                                        FRAME_ARG(jstring, 4),
                                                        FRAME_ARG(jstring, 5),
                                                        FRAME_ARG(jstring, 6));
          frame->succeed = true;
          break;
        default:
          frame->succeed = false;
      }
      break;
// JQToolTipBridge Static Member Functions
    case JQToolTipBridge_classID:
      switch(frame->methodID) {
        case JQToolTipBridge_setFont_methodID:
          JQToolTipBridge::setFont(FRAME_ARG(JNIEnv *, 0), FRAME_ARG(jclass, 1),
                                   FRAME_ARG(jobject, 2));
          frame->succeed = true;
          break;
        case JQToolTipBridge_setBackground_methodID:
          JQToolTipBridge::setBackground(FRAME_ARG(JNIEnv *, 0),
                                         FRAME_ARG(jclass, 1),
                                         FRAME_ARG(jint, 2));
          frame->succeed = true;
          break;
        case JQToolTipBridge_setNullBackground_methodID:
          JQToolTipBridge::setNullBackground(FRAME_ARG(JNIEnv *, 0),
                                             FRAME_ARG(jclass, 1));
          frame->succeed = true;
          break;
        case JQToolTipBridge_setForeground_methodID:
          JQToolTipBridge::setForeground(FRAME_ARG(JNIEnv *, 0),
                                         FRAME_ARG(jclass, 1),
                                         FRAME_ARG(jint, 2));
          frame->succeed = true;
          break;
        case JQToolTipBridge_setNullForeground_methodID:
          JQToolTipBridge::setNullForeground(FRAME_ARG(JNIEnv *, 0),
                                             FRAME_ARG(jclass, 1));
          frame->succeed = true;
          break;
        case JQToolTipBridge_showText_methodID:
          JQToolTipBridge::showText(FRAME_ARG(JNIEnv *, 0),
                                    FRAME_ARG(jclass, 1), FRAME_ARG(jstring, 2),
                                    FRAME_ARG(jint, 3), FRAME_ARG(jint, 4),
                                    FRAME_ARG(jlong, 5));
          frame->succeed = true;
          break;
        case JQToolTipBridge_hideText_methodID:
          JQToolTipBridge::hideText(FRAME_ARG(JNIEnv *, 0),
                                    FRAME_ARG(jclass, 1));
          frame->succeed = true;
          break;
        default:
          frame->succeed = false;
      }
      break;
// WhatsThisManagerBridge Static Member Functions
    case WhatsThisManagerBridge_classID:
      switch(frame->methodID) {
        case WhatsThisManagerBridge_showText_methodID:
          WhatsThisManagerBridge::showText(FRAME_ARG(JNIEnv *, 0),
                                           FRAME_ARG(jclass, 1),
                                           FRAME_ARG(jstring, 2),
                                           FRAME_ARG(jint, 3),
                                           FRAME_ARG(jint, 4),
                                           FRAME_ARG(jlong, 5));
          frame->succeed = true;
          break;
        case WhatsThisManagerBridge_hideText_methodID:
          WhatsThisManagerBridge::hideText(FRAME_ARG(JNIEnv *, 0),
                                           FRAME_ARG(jclass, 1));
          frame->succeed = true;
          break;
        case WhatsThisManagerBridge_isInWhatsThisMode_methodID:
          FRAME_RET(jboolean) =
              WhatsThisManagerBridge::isInWhatsThisMode(FRAME_ARG(JNIEnv *, 0),
                                                        FRAME_ARG(jclass, 1));
          frame->succeed = true;
          break;
        case WhatsThisManagerBridge_enterWhatsThisMode_methodID:
          WhatsThisManagerBridge::enterWhatsThisMode(FRAME_ARG(JNIEnv *, 0),
                                                     FRAME_ARG(jclass, 1));
          frame->succeed = true;
          break;
        case WhatsThisManagerBridge_exitWhatsThisMode_methodID:
          WhatsThisManagerBridge::exitWhatsThisMode(FRAME_ARG(JNIEnv *, 0),
                                                    FRAME_ARG(jclass, 1));
          frame->succeed = true;
          break;
        default:
          frame->succeed = false;
      }
      break;
// QSwingImageBridge Static Member Functions
    case QSwingImageBridge_classID:
      switch(frame->methodID) {
        case QSwingImageBridge_createImage_methodID:
          FRAME_RET(jlong) =
                        QSwingImageBridge::createImage(FRAME_ARG(JNIEnv *, 0));
          frame->succeed = true;
          break;
        case QSwingImageBridge_createImageOBAI_methodID:
          FRAME_RET(jlong) =
                        QSwingImageBridge::createImage(FRAME_ARG(JNIEnv *, 0),
                                                       FRAME_ARG(jobject, 1),
                                                       FRAME_ARG(jbyteArray, 2),
                                                       FRAME_ARG(jint, 3));
          frame->succeed = true;
          break;
        case QSwingImageBridge_createScaled_methodID:
          FRAME_RET(jobject) =
                        QSwingImageBridge::createScaled(FRAME_ARG(JNIEnv *, 0),
                                                        FRAME_ARG(jlong, 1),
                                                        FRAME_ARG(jint, 2),
                                                        FRAME_ARG(jint, 3),
                                                        FRAME_ARG(jint, 4),
                                                        FRAME_ARG(jstring, 5));
          frame->succeed = true;
          break;
        default:
          frame->succeed = false;
      }
      break;
// JQDesktopBridge Static Member Functions
    case JQDesktopBridge_classID:
      switch(frame->methodID) {
        case JQDesktopBridge_getScreenSize_methodID:
          FRAME_RET(jobject) =
                          JQDesktopBridge::getScreenSize(FRAME_ARG(JNIEnv *, 0),
                                                         FRAME_ARG(jclass, 1));
          frame->succeed = true;
          break;
        case JQDesktopBridge_getScreenResolution_methodID:
          FRAME_RET(int) =
                    JQDesktopBridge::getScreenResolution(FRAME_ARG(JNIEnv *, 0),
                                                         FRAME_ARG(jclass, 1));
          frame->succeed = true;
          break;
        case JQDesktopBridge_getDesktopBounds_methodID:
          FRAME_RET(jobject) =
                       JQDesktopBridge::getDesktopBounds(FRAME_ARG(JNIEnv *, 0),
                                                         FRAME_ARG(jclass, 1));
          frame->succeed = true;
          break;
        case JQDesktopBridge_takeScreenshot_methodID:
          FRAME_RET(jobject) =
                         JQDesktopBridge::takeScreenshot(FRAME_ARG(JNIEnv *, 0),
                                                         FRAME_ARG(jclass, 1),
                                                         FRAME_ARG(jlong, 2),
                                                         FRAME_ARG(jstring, 3));
          frame->succeed = true;
          break;
        default:
          frame->succeed = false;
      }
      break;
    default:
      frame->succeed = false;
  }
}

/*^**************************************************************************^*/
/*- QSwingMetaObject :: Private Static Data Member.                          -*/
/*^**************************************************************************^*/

QSwingMetaObject *QSwingMetaObject::sm_instance = 0;

/*^*****************************************************************************
  File History:

 - 2007-12-03 00:28:12 Slobodan
   Initial version

*****************************************************************************^*/
