/*
 * @(#)QSwingMetaObject.h  0.2.0 / 2007-12-03
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef QSWINGMETAOBJECT_H
#define QSWINGMETAOBJECT_H

#include "JavaQxCore.h"

/*^**************************************************************************^*/
/*- QSwingMetaObject Class.                                                  -*/
/*^**************************************************************************^*/

/*!
 * \brief QSwing MetaObject.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT QSwingMetaObject : public QObject
{
  Q_OBJECT
private:
  QSwingMetaObject();
  QSwingMetaObject(const QSwingMetaObject &);
  ~QSwingMetaObject();
public:
  static void initialize();
  static bool invokeMember(QObject *obj, const char *member, const char *type,
                           void *ret, QGenericArgument *val0,
                           QGenericArgument *val1, QGenericArgument *val2,
                           QGenericArgument *val3, QGenericArgument *val4,
                           QGenericArgument *val5, QGenericArgument *val6,
                           QGenericArgument *val7, QGenericArgument *val8,
                           QGenericArgument *val9);
  static bool invokeStaticMember(int classID, int methodID, const char *type,
                                 void *ret, QGenericArgument *val0,
                                 QGenericArgument *val1, QGenericArgument *val2,
                                 QGenericArgument *val3, QGenericArgument *val4,
                                 QGenericArgument *val5, QGenericArgument *val6,
                                 QGenericArgument *val7, QGenericArgument *val8,
                                 QGenericArgument *val9);
  static bool invokeStaticMember(int classID, int methodID,
                                 QGenericArgument val0 = QGenericArgument(),
                                 QGenericArgument val1 = QGenericArgument(),
                                 QGenericArgument val2 = QGenericArgument(),
                                 QGenericArgument val3 = QGenericArgument(),
                                 QGenericArgument val4 = QGenericArgument(),
                                 QGenericArgument val5 = QGenericArgument(),
                                 QGenericArgument val6 = QGenericArgument(),
                                 QGenericArgument val7 = QGenericArgument(),
                                 QGenericArgument val8 = QGenericArgument(),
                                 QGenericArgument val9 = QGenericArgument());
private:
  struct MemberFrame {
    bool succeed;
    QGenericReturnArgument *ret;
    QGenericArgument *val0;
    QGenericArgument *val1;
    QGenericArgument *val2;
    QGenericArgument *val3;
    QGenericArgument *val4;
    QGenericArgument *val5;
    QGenericArgument *val6;
    QGenericArgument *val7;
    QGenericArgument *val8;
    QGenericArgument *val9;
  };
  struct InvokeMemberFrame : MemberFrame {
    QObject *obj;
    const char *member;
  };
  struct InvokeStaticMemberFrame : MemberFrame {
    int classID;
    int methodID;
  };
private:
  void invokeMember(InvokeMemberFrame *frame);
  void invokeStaticMember(InvokeStaticMemberFrame *frame);
private slots:
  void invokeMemberSlot(InvokeMemberFrame *frame);
  void invokeStaticMemberSlot(InvokeStaticMemberFrame *frame);
signals:
  void invokeMemberSignal(InvokeMemberFrame *frame);
  void invokeStaticMemberSignal(InvokeStaticMemberFrame *frame);
private:
  static QSwingMetaObject *sm_instance;
private:
  friend class JQOptionPaneBridge; // uses the following fields
    static const int JQOptionPaneBridge_classID = 0;
    static const int JQOptionPaneBridge_showMessage_methodID = 0;
  friend class JQWindowBridge; // uses the following fields
    static const int JQWindowBridge_classID = 1;
    static const int JQWindowBridge_getWindows_methodID = 0;
    static const int JQWindowBridge_getActiveWindow_methodID = 1;
    static const int JQWindowBridge_setWindowOwner_methodID = 2;
  friend class JQColorChooserBridge; // uses the following fields
    static const int JQColorChooserBridge_classID = 2;
    static const int JQColorChooserBridge_getColor_methodID = 0;
  friend class JQFontChooserBridge; // uses the following fields
    static const int JQFontChooserBridge_classID = 3;
    static const int JQFontChooserBridge_getFont_methodID = 0;
  friend class JQFileChooserBridge; // uses the following fields
    static const int JQFileChooserBridge_classID = 4;
    static const int JQFileChooserBridge_getExistingDirectoryName_methodID = 0;
    static const int JQFileChooserBridge_getOpenFileName_methodID = 1;
    static const int JQFileChooserBridge_getSaveFileName_methodID = 2;
  friend class JQToolTipBridge; // uses the following fields
    static const int JQToolTipBridge_classID = 5;
    static const int JQToolTipBridge_setFont_methodID = 0;
    static const int JQToolTipBridge_setBackground_methodID = 1;
    static const int JQToolTipBridge_setNullBackground_methodID = 2;
    static const int JQToolTipBridge_setForeground_methodID = 3;
    static const int JQToolTipBridge_setNullForeground_methodID = 4;
    static const int JQToolTipBridge_showText_methodID = 5;
    static const int JQToolTipBridge_hideText_methodID = 6;
  friend class WhatsThisManagerBridge; // uses the following fields
    static const int WhatsThisManagerBridge_classID = 6;
    static const int WhatsThisManagerBridge_showText_methodID = 0;
    static const int WhatsThisManagerBridge_hideText_methodID = 1;
    static const int WhatsThisManagerBridge_isInWhatsThisMode_methodID = 2;
    static const int WhatsThisManagerBridge_enterWhatsThisMode_methodID = 3;
    static const int WhatsThisManagerBridge_exitWhatsThisMode_methodID = 4;
  friend class QSwingImageBridge; // uses the following fields
    static const int QSwingImageBridge_classID = 7;
    static const int QSwingImageBridge_createImage_methodID = 0;
    static const int QSwingImageBridge_createImageOBAI_methodID = 1;
    static const int QSwingImageBridge_createScaled_methodID = 2;
  friend class JQDesktopBridge; // uses the following fields
    static const int JQDesktopBridge_classID = 8;
    static const int JQDesktopBridge_getScreenSize_methodID = 0;
    static const int JQDesktopBridge_getScreenResolution_methodID = 1;
    static const int JQDesktopBridge_getDesktopBounds_methodID = 2;
    static const int JQDesktopBridge_takeScreenshot_methodID = 3;
};

#endif // QSWINGMETAOBJECT_H

/*^*****************************************************************************
  File History:

 - 2007-12-03 00:20:07 Slobodan
   Initial version

*****************************************************************************^*/
