/*
 * @(#)QTextCharFormatAdapter.cpp  0.2.0 / 2007-12-13
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "QTextCharFormatAdapter.h"

/*^**************************************************************************^*/
/*- QTextCharFormatAdapter :: Public Constructor.                            -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new QTextCharFormatAdapter object.
 *
 * \param format the QSwing format object
 */
QTextCharFormatAdapter::QTextCharFormatAdapter(jobject format)
  : QTextCharFormat()
{
  if (format) {
    jobject font;
    jboolean fontBold;
    jobject color;
    if (JNIQSwingWrapper::callObjectMethod(font, format, sm_getFontMID) &&
        JNIQSwingWrapper::callBooleanMethod(fontBold, format,
                                            sm_isFontBoldMID) &&
        JNIQSwingWrapper::callObjectMethod(color, format, sm_getColorMID)) {
      if (font) {
        setFont(*QFontAdapter::toQFont(font));
      }
      if (fontBold) {
        setFontWeight(QFont::Bold);
      }
      if (color) {
        setForeground(QColorAdapter(color));
      }
    }
  }
}

/*^**************************************************************************^*/
/*- QTextCharFormatAdapter :: Public Static Member Function.                 -*/
/*^**************************************************************************^*/

/*!
 * \brief Initializes QTextCharFormatAdapter class.
 *
 * \param env the JNIEnv pointer
 * \param cls the QSwing CharacterFormat class
 *
 * \exception FatalError if failed
 */
void QTextCharFormatAdapter::initialize(JNIEnv *env, jclass cls)
{
  Q_ASSERT(env);
  Q_ASSERT(cls);
  Q_ASSERT(!sm_getFontMID);
  if (!INIT_MID(getFont, cls, "()Lyu/ac/bg/etf/javaqx/qswing/graphics/Font;") ||
      !INIT_MID(isFontBold, cls, "()Z") ||
      !INIT_MID(getColor, cls,
                "()Lyu/ac/bg/etf/javaqx/qswing/graphics/Color;")) {
    FATAL_LOGGED_ERROR("QTextCharFormatAdapter initialization failed");
  }
}

/*^**************************************************************************^*/
/*- QTextCharFormatAdapter :: Private Static Data Members.                   -*/
/*^**************************************************************************^*/

jmethodID QTextCharFormatAdapter::sm_getFontMID = 0;
jmethodID QTextCharFormatAdapter::sm_isFontBoldMID = 0;
jmethodID QTextCharFormatAdapter::sm_getColorMID = 0;

/*^*****************************************************************************
  File History:

 - 2007-12-13 13:34:45 Slobodan
   Initial version

*****************************************************************************^*/
