/*
 * @(#)QTextDocumentAdapter.h  0.2.0 / 2007-12-12
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef QTEXTDOCUMENTADAPTER_H
#define QTEXTDOCUMENTADAPTER_H

#include "JavaQxQSwing.h"

/*^**************************************************************************^*/
/*- TextDocumentHighlighter Class.                                           -*/
/*^**************************************************************************^*/

class QTextDocumentAdapter;

/*!
 * \brief TextDocument Highlighter.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT TextDocumentHighlighter : public QSyntaxHighlighter
{
  Q_OBJECT
public:
  TextDocumentHighlighter();
public:
  void setDocument(QTextDocumentAdapter *document);
  void setFormat(int start, int length, const QTextCharFormat &format);
protected slots:
  void contentsChangeSlot(int position, int charsRemoved, int charsAdded);
protected:
  virtual void highlightBlock(const QString &text);
private:
  QTextDocumentAdapter *m_document;
  int m_blockPosition;
  bool m_contentsChanged;
};

/*^**************************************************************************^*/
/*- QTextDocumentAdapter Class.                                              -*/
/*^**************************************************************************^*/

class TextDocumentBridge;

/*!
 * \brief QTextDocument Adapter.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class QTextDocumentAdapter : public QTextDocument
{
  Q_OBJECT
protected:
  QTextDocumentAdapter(TextDocumentBridge *bridge);
  virtual ~QTextDocumentAdapter();
public:
  int length();
  void clear();
  void setDestroying();
  void setUseHighlighter(bool useHighlighter);
  void setFormat(int start, int length, const QTextCharFormat &format);
  void highlightBlock(int blockStart, const QString &blockText);
public:
  virtual QString getText() const = 0;
  virtual void setText(const QString &text) = 0;
  virtual void appendText(const QString &text) = 0;
signals:
  void destroying();
  void textCleared();
  void textSet();
  void textAppended();
  void selectAllAvailable(bool available);
protected slots:
  void contentsChangeSlot(int position, int charsRemoved, int charsAdded);
protected:
  int m_length;
  bool m_destroying;
  TextDocumentBridge *m_bridge;
  TextDocumentHighlighter *m_highlighter;
};

#endif // QTEXTDOCUMENTADAPTER_H

/*^*****************************************************************************
  File History:

 - 2007-12-12 08:42:12 Slobodan
   Initial version

*****************************************************************************^*/
