/*
 * @(#)QTreeViewAdapter.cpp  0.2.0 / 2007-12-18
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "QTreeViewAdapter.h"

#include <QHeaderView>

#include "JQTreeBridge.h"
#include "TreeModel.h"

/*^**************************************************************************^*/
/*- QTreeViewAdapter :: Public Constructor.                                  -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new QTreeViewAdapter object.
 *
 * \param bridge the JQTreeBridge pointer
 */
QTreeViewAdapter::QTreeViewAdapter(JQTreeBridge *bridge)
  : QTreeView(0), m_bridge(bridge)
{
  header()->setVisible(false);
  header()->setStretchLastSection(false);
  setIconSize(QSize(16, 16));
  setSelectionBehavior(SelectItems);
  connect(this, SIGNAL(expanded(const QModelIndex &)),
          SLOT(adjustSize(const QModelIndex &)));
  connect(this, SIGNAL(collapsed(const QModelIndex &)),
          SLOT(adjustSize(const QModelIndex &)));
}

/*^**************************************************************************^*/
/*- QTreeViewAdapter :: Protected Member Function.                           -*/
/*^**************************************************************************^*/

/*!
 * \brief Adjusts tree column size.
 *
 * \param index the model index
 */
void QTreeViewAdapter::adjustSize(const QModelIndex &index)
{
  if (index.isValid()) {
    resizeColumnToContents(0);
  }
}

/*^**************************************************************************^*/
/*- QTreeViewAdapter :: Protected Member Function.                           -*/
/*^**************************************************************************^*/

/*!
 * \inheritDoc
 */
bool QTreeViewAdapter::event(QEvent *e)
{
  bool processed = QTreeView::event(e);
  switch (e->type()) {
    case QEvent::FontChange:
      // falls through
    case QEvent::StyleChange:
      QApplication::postEvent(this, new QEvent(QEvent::User));
      break;
    case QEvent::User:
      resizeColumnToContents(0);
      break;
    default:
      break;
  }
  return processed;
}

/*^*****************************************************************************
  File History:

 - 2007-12-18 09:25:22 Slobodan
   Initial version

*****************************************************************************^*/
