/*
 * @(#)StyledDocument.cpp  0.2.0 / 2007-12-19
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "StyledDocument.h"

/*^**************************************************************************^*/
/*- StyledDocument :: Public Constructor.                                    -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new StyledDocument object.
 *
 * \param documentBridge the document bridge
 */
StyledDocument::StyledDocument(TextDocumentBridge *documentBridge)
  : QTextDocumentAdapter(documentBridge)
{
  // empty constructor body
}

/*^**************************************************************************^*/
/*- StyledDocument :: Overridden Member Functions.                           -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns document's text.
 *
 * \return document's text
 */
QString StyledDocument::getText() const
{
  return QTextDocumentAdapter::toHtml();
}

/*!
 * \brief Sets document's text.
 *
 * \param text the text to be set
 */
void StyledDocument::setText(const QString &text)
{
  QTextDocumentAdapter::setHtml(text);
  setModified(false);
  emit textSet();
}

/*!
 * \brief Appends text.
 *
 * \param text the text to be appended
 */
void StyledDocument::appendText(const QString &text)
{
  QTextCursor cursor(this);
  cursor.beginEditBlock();
  cursor.movePosition(QTextCursor::End);
  cursor.insertHtml(text);
  cursor.endEditBlock();
  emit textAppended();
}

/*!
 * \inheritDoc
 */
QVariant StyledDocument::loadResource(int type, const QUrl &name)
{
  // TODO: implement resource loading
  return QTextDocumentAdapter::loadResource(type, name);
}

/*^*****************************************************************************
  File History:

 - 2007-12-19 19:37:00 Slobodan
   Initial version

*****************************************************************************^*/
