/*
 * @(#)ContentPaneBridge.cpp  0.2.0 / 2007-12-28
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "ContentPaneBridge.h"

#include "ContentPane.h"

/*^**************************************************************************^*/
/*- ContentPaneBridge :: Protected Constructor.                              -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new ContentPaneBridge object.
 *
 * \param env the JNIEnv pointer
 * \param obj the ContentPane object
 */
ContentPaneBridge::ContentPaneBridge(JNIEnv *env, jobject obj)
  : JQContainerBridge(env, obj, new ContentPane(this))
{
  // empty constructor body
}

/*^**************************************************************************^*/
/*- ContentPaneBridge :: Static Native Calls.                                -*/
/*^**************************************************************************^*/

/*!
 * \brief Initializes ContentPaneBridge class.
 *
 * \param env the JNIEnv pointer
 * \param cls the ContentPan class
 *
 * \exception FatalError if failed
 */
void ContentPaneBridge::initialize(JNIEnv *env, jclass cls)
{
  Q_ASSERT(env);
  Q_ASSERT(cls);
  Q_ASSERT(!sm_getLayoutPreferredSizeMID);
  if (!INIT_UMID(getLayoutPreferredSize, cls,
                "()Lyu/ac/bg/etf/javaqx/qswing/graphics/Dimension;")) {
    FATAL_LOGGED_ERROR("ContentPaneBridge initialization failed");
  }
}

/*!
 * \brief Returns new instance of the bridge object
 *
 * \param env the JNIEnv pointer
 * \param obj the QSwing object
 * 
 * \return new instance of the bridge object
 */
jlong ContentPaneBridge::newInstance(JNIEnv *env, jobject obj)
{
  if (JNIQSwingWrapper::isQSwingThread(env)) {
    return reinterpret_cast<jlong>(new ContentPaneBridge(env, obj));
  }
  return QSwingUtilitiesBridge::invokeLongAndWait(env, obj, createMID());
}

/*^**************************************************************************^*/
/*- ContentPaneBridge :: Native Callbacks.                                   -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns layout's preferred size.
 */
QSize ContentPaneBridge::getLayoutPreferredSize()
{
  jobject preferredSize;
  if (jniObject()->callObjectMethod(preferredSize,
                                    sm_getLayoutPreferredSizeMID)) {
    jint preferredWidth;
    jint preferredHeight;
    DimensionObject preferredSizeDimension(jniObject()->env(), preferredSize);
    if (preferredSizeDimension.getWidth(preferredWidth) &&
        preferredSizeDimension.getHeight(preferredHeight)) {
      return QSize(preferredWidth, preferredHeight);
    }
  }
  return QSize();
}

/*^**************************************************************************^*/
/*- ContentPaneBridge :: Private Static Data Members.                        -*/
/*^**************************************************************************^*/

jmethodID ContentPaneBridge::sm_getLayoutPreferredSizeMID = 0;

/*^*****************************************************************************
  File History:

 - 2007-12-28 22:37:50 Slobodan
   Initial version

*****************************************************************************^*/
