/*
 * @(#)FontMetricsBridge.cpp  0.2.0 / 2007-09-13
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "FontMetricsBridge.h"

#include "QSwingUtilitiesBridge.h"

/*^**************************************************************************^*/
/*- FontMetricsBridge :: Static Native Calls.                                -*/
/*^**************************************************************************^*/

/*!
 * \brief Fills the specified QSwing font metrics object.
 *
 * \param env the JNIEnv pointer
 * \param obj the QSwing font metrics object.
 * \param fontMetrics the Qt font metrics object
 */
void FontMetricsBridge::getMetrics(JNIEnv *env, jobject obj,
                                   QFontMetrics *fontMetrics)
{
  JNIWrapper::setIntField(env, obj, sm_ascentFID, fontMetrics->ascent());
  JNIWrapper::setIntField(env, obj, sm_descentFID, fontMetrics->descent());
  JNIWrapper::setIntField(env, obj, sm_heightFID, fontMetrics->height());
  JNIWrapper::setIntField(env, obj, sm_leadingFID, fontMetrics->leading());
}

/*!
 * \brief Returns width of the specified string.
 *
 * \param env the JNIEnv pointer
 * \param obj the QSwing font metrics object
 * \param fontMetrics the Qt font metrics object
 * \param str the string
 * 
 * \return width of the specified string
 */
jint FontMetricsBridge::stringWidth(JNIEnv *env, jobject obj,
                                    QFontMetrics *fontMetrics, jstring str)
{
  if (JNIQSwingWrapper::isQSwingThread(env)) {
    return fontMetrics->width(QStringAdapter(env, str));
  }
  return QSwingUtilitiesBridge::
                   invokeIntAndWait(env, obj, sm_stringWidthMID,
                                    reinterpret_cast<jlong>(fontMetrics), str);
}

/*!
 * \brief Initializes FontMetricsBridge class.
 *
 * \param env the JNIEnv pointer
 * \param cls the QSwing font metrics class
 *
 * \exception FatalError if failed
 */
void FontMetricsBridge::initialize(JNIEnv *env, jclass cls)
{
  Q_ASSERT(env);
  Q_ASSERT(cls);
  Q_ASSERT(!sm_ascentFID);
  if (!INIT_FID(ascent, cls, "I") || !INIT_FID(descent, cls, "I") ||
      !INIT_FID(height, cls, "I") || !INIT_FID(leading, cls, "I") ||
      !INIT_UMID(stringWidth, cls, "(JLjava/lang/String;)I")) {
    FATAL_LOGGED_ERROR("FontMetricsBridge initialization failed");
  }
}

/*^**************************************************************************^*/
/*- FontMetricsBridge :: Private Static Data Members.                        -*/
/*^**************************************************************************^*/

jfieldID FontMetricsBridge::sm_ascentFID = 0;
jfieldID FontMetricsBridge::sm_descentFID = 0;
jfieldID FontMetricsBridge::sm_heightFID = 0;
jfieldID FontMetricsBridge::sm_leadingFID = 0;
jmethodID FontMetricsBridge::sm_stringWidthMID = 0;

/*^*****************************************************************************
  File History:

 - 2007-09-13 10:02:26 Slobodan
   Initial version

*****************************************************************************^*/
