/*
 * @(#)JQAbstractButtonBridge.h  0.2.0 / 2007-08-16
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef JQABSTRACTBUTTONBRIDGE_H
#define JQABSTRACTBUTTONBRIDGE_H

#include "JavaQxQSwing.h"

#include "JQComponentBridge.h"
#include "QIconAdapter.h"

/*^**************************************************************************^*/
/*- JQAbstractButtonBridge Class.                                            -*/
/*^**************************************************************************^*/

/*!
 * \brief JQAbstractButton Bridge.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT JQAbstractButtonBridge : public JQComponentBridge
{
  Q_OBJECT
protected:
  JQAbstractButtonBridge(JNIEnv *env, jobject obj, QAbstractButton *button);
  JQAbstractButtonBridge(JNIEnv *env, jobject obj);
public slots: // native calls
  void setPressed(JNIEnv *env, jboolean pressed);
  void setText(JNIEnv *env, jstring text);
  void setIcon(JNIEnv *env, jobject iconSet);
  void setIconSize(JNIEnv *env, jint width, jint height);
public: // native calls
  static void initialize(JNIEnv *env, jclass cls);
  static jlong newInstance(JNIEnv *env, jobject obj);
public: // native callbacks
  jboolean buttonPressed();
  jboolean buttonReleased();
  void buttonClicked(jint modifiers);
public:
  inline QAbstractButton *qAbstractButton() const;
public:
  virtual jobject getBackground(JNIEnv *env, jclass colorClass);
  virtual void setBackground(JNIEnv *env, jint argb);
  virtual void setNullBackground(JNIEnv *env);
  virtual jobject getForeground(JNIEnv *env, jclass colorClass);
  virtual void setForeground(JNIEnv *env, jint argb);
  virtual void setNullForeground(JNIEnv *env);
protected slots:
  void pressedSlot();
  void releasedSlot();
  void clickedSlot();
protected:
  inline void setIconType(QIconAdapter::IconType iconType);
protected:
  virtual bool filterKeyPressedEvent(QObject *obj, QKeyEvent *e);
  virtual bool filterKeyReleasedEvent(QObject *obj, QKeyEvent *e);
  virtual bool filterMouseEnterEvent(QObject *obj, QMouseEvent *e);
  virtual bool filterMouseLeaveEvent(QObject *obj, QMouseEvent *e);
private:
  Qt::KeyboardModifiers m_modifiers;
  QIconAdapter::IconType m_iconType;
private:
  static jmethodID sm_buttonPressedMID;
  static jmethodID sm_buttonReleasedMID;
  static jmethodID sm_buttonClickedMID;
};

/*^**************************************************************************^*/
/*- JQAbstractButtonBridge :: Public Inline Member Function.                 -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns QAbstractButton adaptee.
 *
 * \return QAbstractButton adaptee
 */
inline QAbstractButton *JQAbstractButtonBridge::qAbstractButton() const
{
  return static_cast<QAbstractButton *>(qObject());
}

/*^**************************************************************************^*/
/*- JQAbstractButtonBridge :: Protected Inline Member Function.              -*/
/*^**************************************************************************^*/

/*!
 * \brief Sets current icon type.
 *
 * \param iconType the icon type
 */
inline void JQAbstractButtonBridge::setIconType(QIconAdapter::IconType iconType)
{
  m_iconType = iconType;
}

/*^**************************************************************************^*/
/*- Macro Definition.                                                        -*/
/*^**************************************************************************^*/

#define jqAbstractButtonBridge \
    (reinterpret_cast<JQAbstractButtonBridge *>(bridge))

#endif //JQABSTRACTBUTTONBRIDGE_H

/*^*****************************************************************************
  File History:

 - 2007-08-16 07:56:37 Slobodan
   Initial version

*****************************************************************************^*/
