/*
 * @(#)JQActionComponentBridge.h  0.2.0 / 2007-11-09
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "JQActionComponentBridge.h"

#include "QCursorAdapter.h"

/*^**************************************************************************^*/
/*- JQActionComponentData :: Protected Constructor.                          -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new JQActionComponentData object.
 */
JQActionComponentData::JQActionComponentData()
  : focusable(false), opaque(true), updatesEnabled(true), orientation(4),
    maximumSize(-1, -1), minimumSize(-1, -1), fixedSize(-1, -1)
{
  // empty constructor body
}

/*^**************************************************************************^*/
/*- JQActionComponentBridge :: Protected Constructors.                       -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new QActionComponentBridge object.
 *
 * \param env the JNIEnv pointer
 * \param obj the JQComponent object
 * \param action the action
 */
JQActionComponentBridge::JQActionComponentBridge(JNIEnv *env, jobject obj,
                                                 QAction *action)
  : JQComponentBridge(env, obj, action), m_makeVisible(false)
{
  // empty constructor body
}

/*!
 * \brief Constructs new QActionComponentBridge object.
 *
 * \param env the JNIEnv pointer
 * \param obj the JQComponent object
 */
JQActionComponentBridge::JQActionComponentBridge(JNIEnv *env, jobject obj)
  : JQComponentBridge(env, obj, (QAction *)0), m_makeVisible(false)
{
  // empty constructor body
}

/*^**************************************************************************^*/
/*- JQActionComponentBridge :: Protected Destructor.                         -*/
/*^**************************************************************************^*/

/*!
 * \brief Destructs JQActionComponentBridge object.
 */
JQActionComponentBridge::~JQActionComponentBridge()
{
  if (m_action) {
    deleteQAction(m_action);
    m_action = 0;
  }
  if (m_widget) {
    deleteQWidget(m_widget);
    m_widget = 0;
  }
}

/*^**************************************************************************^*/
/*- JQActionComponentBridge :: Overridden Native Calls.                      -*/
/*^**************************************************************************^*/

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::setVisible(JNIEnv *env, jboolean visible)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setVisible, QSWING_ENV_ARG, JBOOLEAN_ARG(visible))
  if (isQWidget()) {
    JQComponentBridge::setVisible(env, visible);
  } else {
    action()->setVisible(visible);
    visibleChanged(visible);
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::showWindow(JNIEnv *env)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(showWindow, QSWING_ENV_ARG)
  switchToQWidget();
  JQComponentBridge::showWindow(env);
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::setEnabled(JNIEnv *env, jboolean enabled)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setEnabled, QSWING_ENV_ARG, JBOOLEAN_ARG(enabled))
  if (isQWidget()) {
    JQComponentBridge::setEnabled(env, enabled);
  } else {
    action()->setEnabled(enabled);
    enabledChanged(enabled);
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::setFocusable(JNIEnv *env, jboolean focusable)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setFocusable, QSWING_ENV_ARG, JBOOLEAN_ARG(focusable))
  if (isQWidget()) {
    JQComponentBridge::setFocusable(env, focusable);
  } else {
    actionData()->focusable = focusable;
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::requestFocus(JNIEnv *env)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(requestFocus, QSWING_ENV_ARG)
  if (isQWidget()) {
    JQComponentBridge::requestFocus(env);
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::setLocation(JNIEnv *env, jint x, jint y)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setLocation, QSWING_ENV_ARG, JINT_ARG(x), JINT_ARG(y))
  if (isQWidget()) {
    JQComponentBridge::setLocation(env, x, y);
  }
}

/*!
 * \inheritDoc
 */
jobject JQActionComponentBridge::getPreferredSize(JNIEnv *env)
{
  Q_ASSERT(env);
  QSWING_REENTRANT_RETURN(getPreferredSize, jobject, QSWING_ENV_ARG)
  if (isQWidget()) {
    return JQComponentBridge::getPreferredSize(env);
  } else {
    return DimensionObject::newObject(0, 0);
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::setSize(JNIEnv *env, jint width, jint height)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setSize, QSWING_ENV_ARG, JINT_ARG(width), JINT_ARG(height))
  if (isQWidget()) {
    JQComponentBridge::setSize(env, width, height);
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::setMaximumSize(JNIEnv *env, jint width,
                                             jint height)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setMaximumSize, QSWING_ENV_ARG, JINT_ARG(width),
                   JINT_ARG(height))
  if (isQWidget()) {
    JQComponentBridge::setMaximumSize(env, width, height);
  } else {
    actionData()->maximumSize = QSize(width, height);
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::setMinimumSize(JNIEnv *env, jint width,
                                             jint height)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setMinimumSize, QSWING_ENV_ARG, JINT_ARG(width),
                   JINT_ARG(height))
  if (isQWidget()) {
    JQComponentBridge::setMinimumSize(env, width, height);
  } else {
    actionData()->minimumSize = QSize(width, height);
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::setFixedSize(JNIEnv *env, jint width, jint height)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setFixedSize, QSWING_ENV_ARG, JINT_ARG(width),
                   JINT_ARG(height))
  if (isQWidget()) {
    JQComponentBridge::setFixedSize(env, width, height);
  } else {
    actionData()->fixedSize = QSize(width, height);
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::setBounds(JNIEnv *env, jint x, jint y, jint width,
                                        jint height)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setBounds, QSWING_ENV_ARG, JINT_ARG(x), JINT_ARG(y),
                   JINT_ARG(width), JINT_ARG(height))
  if (isQWidget()) {
    JQComponentBridge::setBounds(env, x, y, width, height);
  } else {
    actionData()->bounds = QRect(x, y, width, height);
  }
}

/*!
 * \inheritDoc
 */
jobject JQActionComponentBridge::getBackground(JNIEnv *env, jclass colorClass)
{
  Q_ASSERT(env);
  Q_ASSERT(colorClass);
  QSWING_REENTRANT_RETURN(getBackground, jobject, QSWING_ENV_ARG,
                          JCLASS_ARG(colorClass))
  if (isQWidget()) {
    return JQComponentBridge::getBackground(env, colorClass);
  } else {
    if (actionData()->background.isValid()) {
      return QColorAdapter::toJColor(actionData()->background);
    }
    return QColorAdapter::toJColor(QApplication::palette().
                                                       color(QPalette::Window));
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::setBackground(JNIEnv *env, jint argb)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setBackground, QSWING_ENV_ARG, JINT_ARG(argb))
  if (isQWidget()) {
    JQComponentBridge::setBackground(env, argb);
  } else {
    actionData()->background = QColorAdapter(argb);
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::setNullBackground(JNIEnv *env)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setNullBackground, QSWING_ENV_ARG)
  if (isQWidget()) {
    JQComponentBridge::setNullBackground(env);
  } else {
    actionData()->background = QApplication::palette().color(QPalette::Window);
  }
}

/*!
 * \inheritDoc
 */
jobject JQActionComponentBridge::getForeground(JNIEnv *env, jclass colorClass)
{
  Q_ASSERT(env);
  Q_ASSERT(colorClass);
  QSWING_REENTRANT_RETURN(getForeground, jobject, QSWING_ENV_ARG,
                          JCLASS_ARG(colorClass))
  if (isQWidget()) {
    return JQComponentBridge::getForeground(env, colorClass);
  } else {
    if (actionData()->foreground.isValid()) {
      return QColorAdapter::toJColor(actionData()->foreground);
    }
    return QColorAdapter::toJColor(QApplication::palette().
                                                   color(QPalette::WindowText));
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::setForeground(JNIEnv *env, jint argb)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setForeground, QSWING_ENV_ARG, JINT_ARG(argb))
  if (isQWidget()) {
    JQComponentBridge::setForeground(env, argb);
  } else {
    actionData()->foreground = QColorAdapter(argb);
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::setNullForeground(JNIEnv *env)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setNullForeground, QSWING_ENV_ARG)
  if (isQWidget()) {
    JQComponentBridge::setNullForeground(env);
  } else {
    actionData()->foreground = QApplication::palette().
                                                   color(QPalette::WindowText);
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::setOpaque(JNIEnv *env, jboolean opaque)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setOpaque, QSWING_ENV_ARG, JBOOLEAN_ARG(opaque))
  if (isQWidget()) {
    JQComponentBridge::setOpaque(env, opaque);
  } else {
    actionData()->opaque = opaque;
  }
}

/*!
 * \inheritDoc
 */
jobject JQActionComponentBridge::getFont(JNIEnv *env, jclass fontClass)
{
  Q_ASSERT(env);
  Q_ASSERT(fontClass);
  QSWING_REENTRANT_RETURN(getFont, jobject, QSWING_ENV_ARG,
                          JCLASS_ARG(fontClass))
  if (isQWidget()) {
    return JQComponentBridge::getFont(env, fontClass);
  } else {
    return QFontAdapter::toJFont(env, fontClass, action()->font());
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::setFont(JNIEnv *env, jobject font)
{
  Q_ASSERT(env);
  Q_ASSERT(font);
  QSWING_REENTRANT(setFont, QSWING_ENV_ARG, JOBJECT_ARG(font))
  if (isQWidget()) {
    JQComponentBridge::setFont(env, font);
  } else {
    action()->setFont(*QFontAdapter::toQFont(env, font));
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::setStyleSheet(JNIEnv *env, jstring styleSheetText)
{
  Q_ASSERT(env);
  Q_ASSERT(styleSheetText);
  QSWING_REENTRANT(setStyleSheet, QSWING_ENV_ARG, JSTRING_ARG(styleSheetText))
  if (isQWidget()) {
    JQComponentBridge::setStyleSheet(env, styleSheetText);
  } else {
    actionData()->styleSheet = QStringAdapter(env, styleSheetText);
  }
}

/*!
 * \inheritDoc
 */
jint JQActionComponentBridge::getCursor(JNIEnv *env)
{
  if (isQWidget()) {
    return JQComponentBridge::getCursor(env);
  } else {
    return QCursorAdapter::cursorType(actionData()->cursor);
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::setCursor(JNIEnv *env, jint type)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setCursor, QSWING_ENV_ARG, JINT_ARG(type))
  if (isQWidget()) {
    JQComponentBridge::setCursor(env, type);
  } else {
    actionData()->cursor = QCursorAdapter(type);
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::repaint(JNIEnv *env)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(repaint, QSWING_ENV_ARG)
  if (isQWidget()) {
    JQComponentBridge::repaint(env);
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::repaint(JNIEnv *env, jint x, jint y, jint width,
                                      jint height)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(repaint, QSWING_ENV_ARG, JINT_ARG(x), JINT_ARG(y),
                   JINT_ARG(width), JINT_ARG(height))
  if (isQWidget()) {
    JQComponentBridge::repaint(env, x, y, width, height);
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::update(JNIEnv *env)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(update, QSWING_ENV_ARG)
  if (isQWidget()) {
    JQComponentBridge::update(env);
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::update(JNIEnv *env, jint x, jint y, jint width,
                                     jint height)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(update, QSWING_ENV_ARG, JINT_ARG(x), JINT_ARG(y),
                   JINT_ARG(width), JINT_ARG(height))
  if (isQWidget()) {
    JQComponentBridge::update(env, x, y, width, height);
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::setUpdatesEnabled(JNIEnv *env, jboolean enabled)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setUpdatesEnabled, QSWING_ENV_ARG, JBOOLEAN_ARG(enabled))
  if (isQWidget()) {
    JQComponentBridge::setUpdatesEnabled(env, enabled);
  } else {
    actionData()->updatesEnabled = enabled;
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::polish(JNIEnv *env)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(polish, QSWING_ENV_ARG)
  if (isQWidget()) {
    JQComponentBridge::polish(env);
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::setComponentOrientation(JNIEnv *env,
                                                      jint orientation)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setComponentOrientation, QSWING_ENV_ARG,
                   JINT_ARG(orientation))
  if (isQWidget()) {
    JQComponentBridge::setComponentOrientation(env, orientation);
  } else {
    actionData()->orientation = orientation;
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::setToolTipText(JNIEnv *env, jstring text)
{
  Q_ASSERT(env);
  Q_ASSERT(text);
  QSWING_REENTRANT(setToolTipText, QSWING_ENV_ARG, JSTRING_ARG(text))
  if (isQWidget()) {
    widget()->setToolTip(QStringAdapter(env, text));
  } else {
    QStringAdapter toolTip(env, text);
    actionData()->toolTip = toolTip;
    action()->setToolTip(toolTip);
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::setStatusTipText(JNIEnv *env, jstring text)
{
  Q_ASSERT(env);
  Q_ASSERT(text);
  QSWING_REENTRANT(setStatusTipText, QSWING_ENV_ARG, JSTRING_ARG(text))
  if (isQWidget()) {
    widget()->setStatusTip(QStringAdapter(env, text));
  } else {
    action()->setStatusTip(QStringAdapter(env, text));
  }
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::setWhatsThisText(JNIEnv *env, jstring text)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setWhatsThisText, QSWING_ENV_ARG, JSTRING_ARG(text))
  if (isQWidget()) {
    widget()->setWhatsThis(QStringAdapter(env, text));
  } else {
    action()->setWhatsThis(QStringAdapter(env, text));
  }
}

/*^**************************************************************************^*/
/*- JQActionComponentBridge :: Protected Member Functions.                   -*/
/*^**************************************************************************^*/

/*!
 * \brief Deletes QWidget.
 *
 * \return widget the widget to be deleted
 */
void JQActionComponentBridge::deleteQWidget(QWidget *widget)
{
  if (widget) {
    setQObject(0);
    delete widget;
  }
}

/*!
 * \brief Deletes QAction.
 *
 * \return action the action to be deleted
 */
void JQActionComponentBridge::deleteQAction(QAction *action)
{
  setQObject(0);
  JQActionComponentData *data = getActionData(m_action);
  if (data) {
    delete data;
  }
  delete action;
}

/*!
 * \brief Switches to QWidget.
 */
void JQActionComponentBridge::switchToQWidget()
{
  if (!m_widget) {
    if (m_action) {
      m_widget = convertToQWidget(m_action);
      deleteQAction(m_action);
      m_action = 0;
    } else {
      m_widget = createQWidget();
    }
    setQObject(m_widget);
  }
}

/*!
 * \brief Switches to QAction.
 */
void JQActionComponentBridge::switchToQAction()
{
  if (!m_action) {
    if (m_widget) {
      m_action = convertToQAction(m_widget);
      deleteQWidget(m_widget);
      m_widget = 0;
    } else {
      m_action = createQAction();
    }
    setQObject(m_action);
  }
}

/*!
 * \brief Converts QAction into QWidget.
 *
 * \return QAction converted into QWidget
 */
QWidget *JQActionComponentBridge::convertToQWidget(QAction *action)
{
  QWidget *widget = createQWidget();
  m_makeVisible = action->isVisible();
  widget->setEnabled(action->isEnabled());
  if (!action->font().isCopyOf(QApplication::font())) {
    widget->setFont(action->font());
  }
  if (!action->statusTip().isEmpty()) {
    widget->setStatusTip(action->statusTip());
  }
  if (!action->whatsThis().isEmpty()) {
    widget->setWhatsThis(action->whatsThis());
  }
  if (eventEnabled(QSWING_EVENT(MOUSE_MOTION_EVENT_MASK))) {
    widget->setMouseTracking(true);
  }
  JQActionComponentData *data = getActionData(action);
  if (data) {
    if (data->focusable) {
      widget->setFocusPolicy(Qt::StrongFocus);
    } else {
      widget->setFocusPolicy(Qt::NoFocus);
    }
    if (data->bounds.isValid()) {
      widget->setGeometry(data->bounds);
    }
    if (data->maximumSize.isValid()) {
      widget->setMaximumSize(data->maximumSize);
    }
    if (data->minimumSize.isValid()) {
      widget->setMinimumSize(data->minimumSize);
    }
    if (data->fixedSize.isValid()) {
      widget->setFixedSize(data->fixedSize);
    }
    if (data->background.isValid()) {
      QPalette palette(widget->palette());
      palette.setColor(QPalette::Window, data->background);
      widget->setPalette(palette);
    }
    if (data->foreground.isValid()) {
      QPalette palette(widget->palette());
      palette.setColor(QPalette::WindowText, data->foreground);
      widget->setPalette(palette);
    }
    if (!data->toolTip.isEmpty()) {
      widget->setToolTip(data->toolTip);
    }
    if (!data->styleSheet.isEmpty()) {
      widget->setStyleSheet(data->styleSheet);
      QList<QByteArray> dpn = action->dynamicPropertyNames();
      for (int i = 0; i < dpn.size(); i++) {
        if (action->property(dpn.at(i)) == STYLE_SHEET_PROPERTY_VALUE) {
          widget->setProperty(dpn.at(i), STYLE_SHEET_PROPERTY_VALUE);
        }
      }
    }
    widget->setCursor(data->cursor);
    widget->setAutoFillBackground(data->opaque);
    switch(data->orientation) {
      case 1:
        widget->unsetLayoutDirection();
        break;
      case 4:
        widget->setLayoutDirection(Qt::LeftToRight);
        break;
      default:
        widget->setLayoutDirection(Qt::RightToLeft);
        break;
    }
    widget->setUpdatesEnabled(data->updatesEnabled);
  }
  return widget;
}

/*!
 * \brief Converts QWidget into QAction.
 *
 * \return QWidget converted into QAction
 */
QAction *JQActionComponentBridge::convertToQAction(QWidget *widget)
{
  QAction *action = createQAction();
  m_makeVisible = widget->isVisible();
  action->setEnabled(widget->isEnabled());
  action->setFont(widget->font());
  if (!widget->statusTip().isEmpty()) {
    action->setStatusTip(widget->statusTip());
  }
  if (!widget->whatsThis().isEmpty()) {
    action->setWhatsThis(widget->whatsThis());
  }
  action->setVisible(widget->isVisible());
  JQActionComponentData *data = createActionData();
  data->focusable = (widget->focusPolicy() != Qt::NoFocus);
  data->opaque = widget->autoFillBackground();
  data->updatesEnabled = widget->updatesEnabled();
  data->bounds = widget->frameGeometry();
  data->maximumSize = widget->maximumSize();
  data->minimumSize = widget->minimumSize();
  data->background = widget->palette().color(QPalette::Window);
  data->foreground = widget->palette().color(QPalette::WindowText);
  if (!widget->toolTip().isEmpty()) {
    action->setToolTip(widget->toolTip());
    data->toolTip = widget->toolTip();
  }
  data->styleSheet = widget->styleSheet();
  data->cursor = widget->cursor();
  if (!data->styleSheet.isEmpty()) {
    QList<QByteArray> dpn = widget->dynamicPropertyNames();
    for (int i = 0; i < dpn.size(); i++) {
      if (widget->property(dpn.at(i)) == STYLE_SHEET_PROPERTY_VALUE) {
        action->setProperty(dpn.at(i), STYLE_SHEET_PROPERTY_VALUE);
      }
    }
  }
  return action;
}

/*!
 * \brief Creates new action data.
 *
 * \return action data
 */
JQActionComponentData *JQActionComponentBridge::createActionData()
{
  return new JQActionComponentData();
}

/*!
 * \brief Returns \c true if the bridge adaptee is QWidget.
 *
 * \return \c true if the bridge adaptee is QWidget
 */
bool JQActionComponentBridge::isQWidget()
{
  if (m_widget) {
    return true;
  }
  if (m_action) {
    return false;
  }
  m_action = createQAction();
  return false;
}

/*!
 * \brief Returns action data.
 *
 * \return action data
 */
JQActionComponentData *JQActionComponentBridge::actionData()
{
  JQActionComponentData *data = getActionData(m_action);
  if (!data) {
    data = createActionData();
    m_action->setData(qVariantFromValue(static_cast<void *>(data)));
  }
  return data;
}

/*!
 * \brief Returns action data of the specified action.
 *
 * \param action the action
 *
 * \return action data
 */
JQActionComponentData *JQActionComponentBridge::getActionData(QAction *action)
{
  return static_cast<JQActionComponentData *>(
                                        qVariantValue<void *>(action->data()));
}

/*^**************************************************************************^*/
/*- JQActionComponentBridge :: Overridden Function Members.                  -*/
/*^**************************************************************************^*/

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::setParentBridge(JQContainerBridge *parentBridge)
{
  JQComponentBridge::setParentBridge(parentBridge);
  if (m_makeVisible) {
    if (isQWidget()) {
      widget()->setVisible(true);
    } else {
      action()->setVisible(true);
    }
  }
}

/*!
 * \inheritDoc
 */
QWidget *JQActionComponentBridge::qWidget()
{
  switchToQWidget();
  return m_widget;
}

/*!
 * \inheritDoc
 */
QAction *JQActionComponentBridge::qAction()
{
  switchToQAction();
  return m_action;
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::objectDestroyed(QObject *qObj) {
  m_widget = 0;
  JQComponentBridge::objectDestroyed(qObj);
}

/*!
 * \inheritDoc
 */
void JQActionComponentBridge::filterEnabledEvents()
{
  if (isQWidget()) {
    JQComponentBridge::filterEnabledEvents();
  }
}

/*^*****************************************************************************
  File History:

 - 2007-11-09 19:51:03 Slobodan
   Initial version

*****************************************************************************^*/
