/*
 * @(#)JQActionComponentBridge.h  0.2.0 / 2007-11-09
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef JQACTIONCOMPONENTBRIDGE_H
#define JQACTIONCOMPONENTBRIDGE_H

#include "JavaQxQSwing.h"

#include "JQComponentBridge.h"

/*^**************************************************************************^*/
/*- JQActionComponentBridge Class.                                           -*/
/*^**************************************************************************^*/
// TODO: test entire module and add better QAction-QWidget switching support
/*!
 * \brief QAction-Component Data.
 */
class JAVAQX_EXPORT JQActionComponentData
{
  friend class JQActionComponentBridge; // uses all members
protected:
  JQActionComponentData();
public:
  // TODO: implement getters
protected:
  bool focusable;
  bool opaque;
  bool updatesEnabled;
  int orientation;
  QRect bounds;
  QSize maximumSize;
  QSize minimumSize;
  QSize fixedSize;
  QColor background;
  QColor foreground;
  QString toolTip;
  QString styleSheet;
  QCursor cursor;
};

/*!
 * \brief QAction-Component Bridge.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JQActionComponentBridge : public JQComponentBridge
{
  Q_OBJECT
protected:
  JQActionComponentBridge(JNIEnv *env, jobject obj, QAction *action);
  JQActionComponentBridge(JNIEnv *env, jobject obj);
  virtual ~JQActionComponentBridge();
public slots: // native calls
  virtual void setVisible(JNIEnv *env, jboolean visible);
  virtual void showWindow(JNIEnv *env);
  virtual void setEnabled(JNIEnv *env, jboolean enabled);
  virtual void setFocusable(JNIEnv *env, jboolean focusable);
  virtual void requestFocus(JNIEnv *env);
  virtual void setLocation(JNIEnv *env, jint x, jint y);
  virtual jobject getPreferredSize(JNIEnv *env);
  virtual void setSize(JNIEnv *env, jint width, jint height);
  virtual void setMaximumSize(JNIEnv *env, jint width, jint height);
  virtual void setMinimumSize(JNIEnv *env, jint width, jint height);
  virtual void setFixedSize(JNIEnv *env, jint width, jint height);
  virtual void setBounds(JNIEnv *env, jint x, jint y, jint width, jint height);
  virtual jobject getBackground(JNIEnv *env, jclass colorClass);
  virtual void setBackground(JNIEnv *env, jint argb);
  virtual void setNullBackground(JNIEnv *env);
  virtual jobject getForeground(JNIEnv *env, jclass colorClass);
  virtual void setForeground(JNIEnv *env, jint argb);
  virtual void setNullForeground(JNIEnv *env);
  virtual void setOpaque(JNIEnv *env, jboolean opaque);
  virtual jobject getFont(JNIEnv *env, jclass fontClass);
  virtual void setFont(JNIEnv *env, jobject font);
  virtual void setStyleSheet(JNIEnv *env, jstring styleSheetText);
  virtual jint getCursor(JNIEnv *env);
  virtual void setCursor(JNIEnv *env, jint type);
  virtual void repaint(JNIEnv *env);
  virtual void repaint(JNIEnv *env, jint x, jint y, jint width, jint height);
  virtual void update(JNIEnv *env);
  virtual void update(JNIEnv *env, jint x, jint y, jint width, jint height);
  virtual void setUpdatesEnabled(JNIEnv *env, jboolean enabled);
  virtual void polish(JNIEnv *env);
  virtual void setComponentOrientation(JNIEnv *env, jint orientation);
  virtual void setToolTipText(JNIEnv *env, jstring text);
  virtual void setStatusTipText(JNIEnv *env, jstring text);
  virtual void setWhatsThisText(JNIEnv *env, jstring text);
public:
  virtual void setParentBridge(JQContainerBridge *parentBridge);
  virtual QWidget *qWidget();
  virtual QAction *qAction();
protected:
  virtual QWidget *createQWidget() = 0;
  virtual QAction *createQAction() = 0;
protected:
  virtual void deleteQWidget(QWidget *widget);
  virtual void deleteQAction(QAction *action);
  virtual void switchToQWidget();
  virtual void switchToQAction();
  virtual QWidget *convertToQWidget(QAction *action);
  virtual QAction *convertToQAction(QWidget *widget);
  virtual JQActionComponentData *createActionData();
protected:
  virtual void filterEnabledEvents();
protected:
  bool isQWidget();
  JQActionComponentData *actionData();
  JQActionComponentData *getActionData(QAction *action);
protected:
  inline QWidget *widget() const;
  inline QAction *action() const;
protected:
  virtual void objectDestroyed(QObject *qObj);
private:
  bool m_makeVisible;
};

/*^**************************************************************************^*/
/*- JQActionComponentBridge :: Protected Inline Member Functions.            -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns widget data member.
 *
 * \return widget data member
 */
inline QWidget *JQActionComponentBridge::widget() const
{
  return m_widget;
}

/*!
 * \brief Returns action data member.
 *
 * \return action data member
 */
inline QAction *JQActionComponentBridge::action() const
{
  return m_action;
}

#endif //JQACTIONCOMPONENTBRIDGE_H

/*^*****************************************************************************
  File History:

 - 2007-11-09 19:51:13 Slobodan
   Initial version

*****************************************************************************^*/
