/*
 * @(#)JQButtonBridge.cpp  0.2.0 / 2007-08-16
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "JQButtonBridge.h"

/*^**************************************************************************^*/
/*- JQButtonBridge :: Protected Constructor.                                 -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new JQButtonBridge object.
 *
 * \param env the JNIEnv pointer
 * \param obj the JQButton object
 */
JQButtonBridge::JQButtonBridge(JNIEnv *env, jobject obj)
  : JQAbstractButtonBridge(env, obj, new QPushButton())
{
  // empty constructor body
}

/*^**************************************************************************^*/
/*- JQButtonBridge :: Native Calls.                                          -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns button's default status.
 *
 * \return button's default status.
 */
jboolean JQButtonBridge::isDefault(JNIEnv *env)
{
  Q_UNUSED(env);
  return qPushButton()->isDefault();
}

/*!
 * \brief Sets button's default status.
 *
 * \param env the JNIEnv pointer
 * \param defaultCapable \c true if default
 */
void JQButtonBridge::setDefaultCapable(JNIEnv *env, jboolean defaultCapable)
{
  Q_UNUSED(env);
  qPushButton()->setDefault(defaultCapable);
}

/*!
 * \brief Sets button's auto default status.
 *
 * \param env the JNIEnv pointer
 * \param autoDefault \c true if auto default
 */
void JQButtonBridge::setAutoDefault(JNIEnv *env, jboolean autoDefault)
{
  Q_UNUSED(env);
  qPushButton()->setAutoDefault(autoDefault);
}

/*!
 * \brief Returns new instance of the bridge object.
 *
 * \param env the JNIEnv pointer 
 * \param obj the QSwing object
 * 
 * \return new instance of the bridge object
 */
jlong JQButtonBridge::newInstance(JNIEnv *env, jobject obj)
{
  if (JNIQSwingWrapper::isQSwingThread(env)) {
    return reinterpret_cast<jlong>(new JQButtonBridge(env, obj));
  }
  return QSwingUtilitiesBridge::invokeLongAndWait(env, obj, createMID());
}

/*^*****************************************************************************
  File History:

 - 2007-08-16 07:56:37 Slobodan
   Initial version

*****************************************************************************^*/
