/*
 * @(#)JQCheckBoxMenuItemBridge.h  0.2.0 / 2007-11-14
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef JQCHECKBOXMENUITEMBRIDGE_H
#define JQCHECKBOXMENUITEMBRIDGE_H

#include "JavaQxQSwing.h"

#include "JQActionComponentBridge.h"

/*^**************************************************************************^*/
/*- JQCheckBoxMenuItemBridge Class.                                          -*/
/*^**************************************************************************^*/

/*!
 * \brief JQCheckBoxMenuItem Bridge.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT JQCheckBoxMenuItemBridge : public JQActionComponentBridge
{
  Q_OBJECT
protected:
  JQCheckBoxMenuItemBridge(JNIEnv *env, jobject obj);
public slots: // native calls
  void setText(JNIEnv *env, jstring text);
  void setShortcut(JNIEnv *env, jstring shortcut);
  void setIcon(JNIEnv *env, jobject iconSet);
  void setChecked(JNIEnv *env, jboolean checked);
public: // native calls
  static void initialize(JNIEnv *env, jclass cls);
  static jlong newInstance(JNIEnv *env, jobject obj);
public: // native callbacks
  void checkedChanged(jint modifiers, jboolean checked);
protected slots:
  void toggledSlot(bool checked);
  void stateChangedSlot(int state);
protected:
  inline QCheckBox *checkBox() const;
protected:
  virtual QWidget *createQWidget();
  virtual QAction *createQAction();
  virtual void deleteQWidget(QWidget *widget);
  virtual void deleteQAction(QAction *action);
  virtual QWidget *convertToQWidget(QAction *action);
  virtual QAction *convertToQAction(QWidget *widget);
private:
  QShortcut *m_shortcut;
private:
  static jmethodID sm_checkedChangedMID;
};

/*^**************************************************************************^*/
/*- JQCheckBoxMenuItemBridge :: Protected Inline Member Function.            -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns check box member.
 *
 * \return check box member
 */
inline QCheckBox *JQCheckBoxMenuItemBridge::checkBox() const
{
  return static_cast<QCheckBox *>(widget());
}

/*^**************************************************************************^*/
/*- Macro Definition.                                                        -*/
/*^**************************************************************************^*/

#define jqCheckBoxMenuItemBridge \
    (reinterpret_cast<JQCheckBoxMenuItemBridge *>(bridge))

#endif //JQCHECKBOXMENUITEMBRIDGE_H

/*^*****************************************************************************
  File History:

 - 2007-11-14 09:03:27 Slobodan
   Initial version

*****************************************************************************^*/
