/*
 * @(#)JQColorChooserBridge.cpp  0.2.0 / 2007-11-29
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "JQColorChooserBridge.h"

#include "JQComponentBridge.h"

/*^**************************************************************************^*/
/*- JQColorChooserBridge :: Static Native Calls.                             -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns color selected by the user.
 *
 * \param env the JNIEnv pointer
 * \param cls the JQColorChooser class
 * \param parentBridge the parent bridge
 * \param initialColor the initial color
 * 
 * \return color selected by the user
 */
jobject JQColorChooserBridge::getColor(JNIEnv *env, jclass cls,
                                       jlong parentBridge, jint initialColor)
{
  Q_ASSERT(env);
  QSWING_STATIC_REENTRANT_RETURN(JQColorChooserBridge, getColor, jobject,
                                 QSWING_ENV_ARG, JCLASS_ARG(cls),
                                 JLONG_ARG(parentBridge),
                                 JINT_ARG(initialColor))
  QWidget *parent = 0;
  if (parentBridge) {
    parent = jqComponentCast(parentBridge)->qWidget();
  }
  QColor selectedColor = QColorDialog::getColor(QColorAdapter(initialColor),
                                                parent);
  if (selectedColor.isValid()) {
    return QColorAdapter::toJColor(selectedColor);
  }
  return 0;
}

/*^*****************************************************************************
  File History:

 - 2007-11-29 19:15:42 Slobodan
   Initial version

*****************************************************************************^*/
