/*
 * @(#)JQContainerBridge.cpp  0.2.0 / 2007-10-27
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "JQContainerBridge.h"

/*^**************************************************************************^*/
/*- JQContainerBridge :: Protected Constructors.                             -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new JQContainerBridge object.
 *
 * \param env the JNIEnv pointer
 * \param obj the JQContainer object
 * \param widget the widget
 */
JQContainerBridge::JQContainerBridge(JNIEnv *env, jobject obj, QWidget *widget)
  : JQComponentBridge(env, obj, widget)
{
  connectQueued(SIGNAL(validateSignal()), SLOT(validateSlot()));
}

/*!
 * \brief Constructs new JQContainerBridge object.
 *
 * \param env the JNIEnv pointer
 * \param obj the JQContainer object
 */
JQContainerBridge::JQContainerBridge(JNIEnv *env, jobject obj)
  : JQComponentBridge(env, obj)
{
  connectQueued(SIGNAL(validateSignal()), SLOT(validateSlot()));
}

/*^**************************************************************************^*/
/*- JQContainerBridge :: Native Calls.                                       -*/
/*^**************************************************************************^*/

/*!
 * \brief Inserts child.
 *
 * \param env the JNIEnv pointer
 * \param childBridge the child pointer
 * \param index the menu item index
 */
void JQContainerBridge::insertChild(JNIEnv *env, jlong childBridge, jint index)
{
  Q_UNUSED(index);
  Q_ASSERT(env);
  QSWING_REENTRANT(insertChild, QSWING_ENV_ARG, JLONG_ARG(childBridge),
                   JINT_ARG(index))
  JQComponentBridge *childComponentBridge = jqComponentCast(childBridge);
  QWidget *childWidget = childComponentBridge->qWidget();
  QRect oldGeometry = childWidget->geometry();
  setEventFilterEnabled(false);
  childComponentBridge->setEventFilterEnabled(false);
  childWidget->setParent(qWidget());
  childComponentBridge->setParentBridge(this);
  if (oldGeometry != childWidget->geometry()) {
    childWidget->setGeometry(oldGeometry);
  }
  childComponentBridge->setEventFilterEnabled(true);
  setEventFilterEnabled(true);
  if (qWidget()->isVisible()) {
    childWidget->setVisible(true);
  }
}

/*!
 * \brief Removes child.
 *
 * \param env the JNIEnv pointer
 * \param childBridge the child pointer
 */
void JQContainerBridge::removeChild(JNIEnv *env, jlong childBridge)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(removeChild, QSWING_ENV_ARG, JLONG_ARG(childBridge))
  JQComponentBridge *childComponentBridge = jqComponentCast(childBridge);
  QWidget *childWidget = childComponentBridge->qWidget();
  QRect oldGeometry = childWidget->geometry();
  setEventFilterEnabled(false);
  childWidget->setParent(0);
  childComponentBridge->setParentBridge(0);
  if (oldGeometry != childWidget->geometry()) {
    childWidget->setGeometry(oldGeometry);
  }
  setEventFilterEnabled(true);
}

/*!
 * \brief Request for validation.
 *
 * \param env the JNIEnv pointer
 */
void JQContainerBridge::validate(JNIEnv *env)
{
  Q_UNUSED(env);
  emit validateSignal();
}

/*^**************************************************************************^*/
/*- JQContainerBridge :: Static Native Calls.                                -*/
/*^**************************************************************************^*/

/*!
 * \brief Initializes JQContainerBridge class.
 *
 * \param env the JNIEnv pointer
 * \param cls the JQContainer class
 *
 * \exception FatalError if failed
 */
void JQContainerBridge::initialize(JNIEnv *env, jclass cls)
{
  Q_ASSERT(env);
  Q_ASSERT(cls);
  Q_ASSERT(!sm_validateMID);
  if (!INIT_MID(validate, cls, "()V")) {
    FATAL_LOGGED_ERROR("JQContainerBridge initialization failed");
  }
}

/*!
 * \brief Returns new instance of the bridge object
 *
 * \param env the JNIEnv pointer
 * \param obj the QSwing object
 * 
 * \return new instance of the bridge object
 */
jlong JQContainerBridge::newInstance(JNIEnv *env, jobject obj)
{
  if (JNIQSwingWrapper::isQSwingThread(env)) {
    return reinterpret_cast<jlong>(new JQContainerBridge(env, obj));
  }
  return QSwingUtilitiesBridge::invokeLongAndWait(env, obj, createMID());
}

/*^**************************************************************************^*/
/*- JQContainerBridge :: Protected Member Function.                          -*/
/*^**************************************************************************^*/

/*!
 * \brief validates the container
 */
void JQContainerBridge::validateSlot()
{
  jniObject()->callVoidMethod(sm_validateMID);
}

/*^**************************************************************************^*/
/*- JQComponentBridge :: Private Static Data Member.                         -*/
/*^**************************************************************************^*/

jmethodID JQContainerBridge::sm_validateMID = 0;

/*^*****************************************************************************
  File History:

 - 2007-10-27 14:34:00 Slobodan
   Initial version

*****************************************************************************^*/
