/*
 * @(#)JQDesktopBridge.cpp  0.2.0 / 2007-12-23
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "JQDesktopBridge.h"

#include "JQComponentBridge.h"
#include "QSwingImageBridge.h"

/*^**************************************************************************^*/
/*- JQDesktopBridge :: Static Native Calls.                                  -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns the screen size.
 *
 * \param env the JNIEnv pointer
 * \param cls the JQDesktop class
 * 
 * \return the screen size
 */
jobject JQDesktopBridge::getScreenSize(JNIEnv *env, jclass cls)
{
  Q_UNUSED(cls);
  Q_ASSERT(env);
  QSWING_STATIC_REENTRANT_RETURN(JQDesktopBridge, getScreenSize, jobject,
                                 QSWING_ENV_ARG, JCLASS_ARG(cls))
  QRect screenRect = QApplication::desktop()->screenGeometry();
  return DimensionObject::newObject(screenRect.width(), screenRect.height());
}

/*!
 * \brief Returns screen resolution.
 *
 * \param env the JNIEnv pointer
 * \param cls the QSwing class
 *
 * \return screen resolution
 */
int JQDesktopBridge::getScreenResolution(JNIEnv *env, jclass cls)
{
  Q_UNUSED(cls);
  Q_ASSERT(env);
  QSWING_STATIC_REENTRANT_RETURN(JQDesktopBridge, getScreenResolution, int,
                                 QSWING_ENV_ARG, JCLASS_ARG(cls))
  return QApplication::desktop()->physicalDpiY();
}

/*!
 * \brief Returns desktop bounds.
 *
 * \param env the JNIEnv pointer
 * \param cls the java class
 * 
 * \return desktop bounds
 */
jobject JQDesktopBridge::getDesktopBounds(JNIEnv *env, jclass cls)
{
  Q_UNUSED(cls);
  Q_ASSERT(env);
  QSWING_STATIC_REENTRANT_RETURN(JQDesktopBridge, getDesktopBounds, jobject,
                                 QSWING_ENV_ARG, JCLASS_ARG(cls))
  QRect desktopRect = QApplication::desktop()->availableGeometry();
  return RectangleObject::newObject(desktopRect.x(), desktopRect.y(),
                                    desktopRect.width(), desktopRect.height());
}

/*!
 * \brief Returns screen shot of the specified component.
 *
 * \param env the JNIEnv pointer
 * \param cls the JQDesktop class
 * \param componentBridge the component bridge
 * \param imageFormat the image format
 * 
 * \return screen shot of the specified component
 */
jobject JQDesktopBridge::takeScreenshot(JNIEnv *env, jclass cls,
                                        jlong componentBridge,
                                        jstring imageFormat)
{
  Q_ASSERT(env);
  QSWING_STATIC_REENTRANT_RETURN(JQDesktopBridge, takeScreenshot, jobject,
                                 QSWING_ENV_ARG, JCLASS_ARG(cls),
                                 JLONG_ARG(componentBridge),
                                 JSTRING_ARG(imageFormat))
  QWidget *widget;
  if (componentBridge) {
    widget = jqComponentCast(componentBridge)->qWidget();
  } else {
    widget = QApplication::desktop();
  }
  return QSwingImageBridge::newInstance(QPixmap::grabWindow(widget->winId()),
                                        imageFormat);
}

/*^*****************************************************************************
  File History:

 - 2007-12-23 09:51:03 Slobodan
   Initial version

*****************************************************************************^*/
