/*
 * @(#)JQDesktopPaneBridge.h  0.2.0 / 2007-11-19
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef JQDESKTOPPANEBRIDGE_H
#define JQDESKTOPPANEBRIDGE_H

#include "JavaQxQSwing.h"

#include "JQContainerBridge.h"

/*^**************************************************************************^*/
/*- JQDesktopPaneBridge Class.                                               -*/
/*^**************************************************************************^*/

/*!
 * \brief JQDesktopPane Bridge.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT JQDesktopPaneBridge : public JQContainerBridge
{
  Q_OBJECT
protected:
  JQDesktopPaneBridge(JNIEnv *env, jobject obj);
public slots: // native calls
  void insertChild(JNIEnv *env, jlong childBridge, jint index);
  void removeChild(JNIEnv *env, jlong childBridge);
  void setCurrentComponent(JNIEnv *env, jlong componentBridge);
  void selectNextComponent(JNIEnv *env);
  void selectPreviousComponent(JNIEnv *env);
  void closeCurrentComponent(JNIEnv *env);
  void closeAllComponents(JNIEnv *env);
  void cascadeComponents(JNIEnv *env);
  void tileComponents(JNIEnv *env);
public: // native calls
  static void initialize(JNIEnv *env, jclass cls);
  static jlong newInstance(JNIEnv *env, jobject obj);
public: // native callbacks
  void activeComponentChanged(jobject component);
public:
  virtual jobject getBackground(JNIEnv *env, jclass colorClass);
  virtual void setBackground(JNIEnv *env, jint argb);
  virtual void setNullBackground(JNIEnv *env);
public:
  inline QMdiArea *qMdiArea() const;
protected slots:
  void subWindowActivatedSlot(QMdiSubWindow *window);
private:
  static jmethodID sm_activeComponentChangedMID;
};

/*^**************************************************************************^*/
/*- JQDesktopPaneBridge :: Public Inline Member Function.                    -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns QMdiArea adaptee.
 *
 * \return QMdiArea adaptee
 */
inline QMdiArea *JQDesktopPaneBridge::qMdiArea() const
{
  return static_cast<QMdiArea *>(qObject());
}

/*^**************************************************************************^*/
/*- Macro Definition.                                                        -*/
/*^**************************************************************************^*/

#define jqDesktopPaneBridge (reinterpret_cast<JQDesktopPaneBridge *>(bridge))

#endif //JQDESKTOPPANEBRIDGE_H

/*^*****************************************************************************
  File History:

 - 2007-11-19 09:55:17 Slobodan
   Initial version

*****************************************************************************^*/
