/*
 * @(#)JQDialogBridge.cpp  0.2.0 / 2007-11-29
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "JQDialogBridge.h"

/*^**************************************************************************^*/
/*- JQDialogBridge :: Protected Constructor.                                 -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new JQDialogBridge object.
 *
 * \param env the JNIEnv pointer
 * \param obj the JQDialog object
 */
JQDialogBridge::JQDialogBridge(JNIEnv *env, jobject obj)
  : JQWindowBridge(env, obj, new QDialog())
{
  // empty constructor body
}

/*^**************************************************************************^*/
/*- JQDialogBridge :: Native Calls.                                          -*/
/*^**************************************************************************^*/

/*!
 * \brief Starts modal loop of the dialog.
 *
 * \param env the JNIEnv pointer
 * 
 * \return dialog result
 */
jint JQDialogBridge::exec(JNIEnv *env)
{
  Q_ASSERT(env);
  QSWING_REENTRANT_RETURN(exec, jint, QSWING_ENV_ARG)
  return qDialog()->exec();
}

/*!
 * \brief Stops dialog modal loop.
 *
 * \param env the JNIEnv pointer
 * \param result the dialog result
 */
void JQDialogBridge::done(JNIEnv *env, jint result)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(done, QSWING_ENV_ARG, JINT_ARG(result))
  qDialog()->done(result);
}

/*^**************************************************************************^*/
/*- JQDialogBridge :: Static Native Calls.                                   -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns new instance of the bridge object
 *
 * \param env the JNIEnv pointer
 * \param obj the QSwing object
 * 
 * \return new instance of the bridge object
 */
jlong JQDialogBridge::newInstance(JNIEnv *env, jobject obj)
{
  if (JNIQSwingWrapper::isQSwingThread(env)) {
    return reinterpret_cast<jlong>(new JQDialogBridge(env, obj));
  }
  return QSwingUtilitiesBridge::invokeLongAndWait(env, obj, createMID());
}

/*^*****************************************************************************
  File History:

 - 2007-11-29 10:26:17 Slobodan
   Initial version

*****************************************************************************^*/
