/*
 * @(#)JQFileChooserBridge.cpp  0.2.0 / 2007-11-29
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "JQFileChooserBridge.h"

#include "JQComponentBridge.h"

/*^**************************************************************************^*/
/*- JQFileChooserBridge :: Static Native Calls.                              -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns directory selected by the user.
 *
 * \param env the JNIEnv pointer
 * \param cls the JQFileChooser class
 * \param parentBridge the parent bridge
 * \param caption the dialog title
 * \param directory the dialog directory
 * 
 * \return directory selected by the user
 */
jstring JQFileChooserBridge::getExistingDirectoryName(JNIEnv *env, jclass cls,
                                                      jlong parentBridge,
                                                      jstring caption,
                                                      jstring directory)
{
  Q_ASSERT(env);
  QSWING_STATIC_REENTRANT_RETURN(JQFileChooserBridge, getExistingDirectoryName,
                                 jstring, QSWING_ENV_ARG, JCLASS_ARG(cls),
                                 JLONG_ARG(parentBridge), JSTRING_ARG(caption),
                                 JSTRING_ARG(directory))
  QWidget *parent = 0;
  if (parentBridge) {
    parent = jqComponentCast(parentBridge)->qWidget();
  }
  QString selectedDirectory = QFileDialog::getExistingDirectory(parent,
                                             QStringAdapter(env, caption),
                                             QStringAdapter(env, directory));
  if (selectedDirectory.isEmpty()) {
    return 0;
  }
  return QStringAdapter::toJString(env, selectedDirectory);
}

/*!
 * \brief Returns file selected by the user.
 *
 * \param env the JNIEnv pointer
 * \param cls the JQFileChooser class
 * \param parentBridge the parent bridge
 * \param caption the dialog title
 * \param directory the dialog directory
 * \param filter the file filter
 * \param selectedFilter the selected filter
 * 
 * \return file selected by the user
 */
jstring JQFileChooserBridge::getOpenFileName(JNIEnv *env, jclass cls,
                                             jlong parentBridge,
                                             jstring caption, jstring directory,
                                             jstring filter,
                                             jstring selectedFilter)
{
  Q_ASSERT(env);
  QSWING_STATIC_REENTRANT_RETURN(JQFileChooserBridge, getOpenFileName,
                                 jstring, QSWING_ENV_ARG, JCLASS_ARG(cls),
                                 JLONG_ARG(parentBridge), JSTRING_ARG(caption),
                                 JSTRING_ARG(directory), JSTRING_ARG(filter),
                                 JSTRING_ARG(selectedFilter))
  QWidget *parent = 0;
  if (parentBridge) {
    parent = jqComponentCast(parentBridge)->qWidget();
  }
  QStringAdapter currentFilter(env, selectedFilter);
  QString selectedFile = QFileDialog::getOpenFileName(parent,
                                        QStringAdapter(env, caption),
                                        QStringAdapter(env, directory),
                                        QStringAdapter(env, filter),
                                        &currentFilter, 0);
  if (selectedFile.isEmpty()) {
    return 0;
  }
  return QStringAdapter::toJString(env, selectedFile);
}

/*!
 * \brief Returns file selected by the user.
 *
 * \param env the JNIEnv pointer
 * \param cls the JQFileChooser class
 * \param parentBridge the parent bridge
 * \param caption the dialog title
 * \param directory the dialog directory
 * \param filter the file filter
 * \param selectedFilter the selected filter
 * 
 * \return file selected by the user
 */
jstring JQFileChooserBridge::getSaveFileName(JNIEnv *env, jclass cls,
                                             jlong parentBridge,
                                             jstring caption, jstring directory,
                                             jstring filter,
                                             jstring selectedFilter)
{
  Q_ASSERT(env);
  QSWING_STATIC_REENTRANT_RETURN(JQFileChooserBridge, getSaveFileName,
                                 jstring, QSWING_ENV_ARG, JCLASS_ARG(cls),
                                 JLONG_ARG(parentBridge), JSTRING_ARG(caption),
                                 JSTRING_ARG(directory), JSTRING_ARG(filter),
                                 JSTRING_ARG(selectedFilter))
  QWidget *parent = 0;
  if (parentBridge) {
    parent = jqComponentCast(parentBridge)->qWidget();
  }
  QStringAdapter currentFilter(env, selectedFilter);
  QString selectedFile = QFileDialog::getSaveFileName(parent,
                                        QStringAdapter(env, caption),
                                        QStringAdapter(env, directory),
                                        QStringAdapter(env, filter),
                                        &currentFilter, 0);
  if (selectedFile.isEmpty()) {
    return 0;
  }
  return QStringAdapter::toJString(env, selectedFile);
}

/*^*****************************************************************************
  File History:

 - 2007-11-29 20:15:08 Slobodan
   Initial version

*****************************************************************************^*/
