/*
 * @(#)JQFontChooserBridge.cpp  0.2.0 / 2007-11-29
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "JQFontChooserBridge.h"

#include "JQComponentBridge.h"

/*^**************************************************************************^*/
/*- JQFontChooserBridge :: Static Native Calls.                              -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns font selected by the user.
 *
 * \param env the JNIEnv pointer
 * \param cls the JQFontChooser class
 * \param parentBridge the parent widget bridge
 * \param initialFont the initial font
 * \param title the dialog title
 * 
 * \return font selected by the user
 */
jobject JQFontChooserBridge::getFont(JNIEnv *env, jclass cls,
                                     jlong parentBridge, jobject initialFont,
                                     jstring title)
{
  Q_ASSERT(env);
  QSWING_STATIC_REENTRANT_RETURN(JQFontChooserBridge, getFont, jobject,
                                 QSWING_ENV_ARG, JCLASS_ARG(cls),
                                 JLONG_ARG(parentBridge),
                                 JOBJECT_ARG(initialFont),
                                 JSTRING_ARG(title))
  QWidget *parent = 0;
  if (parentBridge) {
    parent = jqComponentCast(parentBridge)->qWidget();
  }
  QFont defaltFont;
  if (initialFont) {
    defaltFont = *QFontAdapter::toQFont(env, initialFont);
  }
  bool accepted;
  QFont selectedFont = QFontDialog::getFont(&accepted, defaltFont, parent,
                                            QStringAdapter(env, title));
  if (accepted) {
    return QFontAdapter::toJFont(selectedFont);
  }
  return 0;
}

/*^*****************************************************************************
  File History:

 - 2007-11-29 18:05:19 Slobodan
   Initial version

*****************************************************************************^*/
