/*
 * @(#)JQFrameBridge.cpp  0.2.0 / 2007-11-06
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "JQFrameBridge.h"

#include "JQMenuBarBridge.h"
#include "JQStatusBarBridge.h"
#include "JQToolBarBridge.h"
#include "QMainWindowAdapter.h"

/*^**************************************************************************^*/
/*- JQFrameBridge :: Protected Constructor.                                  -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new JQFrameBridge object.
 *
 * \param env the JNIEnv pointer
 * \param obj the JQFrame object
 */
JQFrameBridge::JQFrameBridge(JNIEnv *env, jobject obj)
  : JQWindowBridge(env, obj, new QMainWindowAdapter())
{
  // empty constructor body
}

/*^**************************************************************************^*/
/*- JQFrameBridge :: Native Calls.                                           -*/
/*^**************************************************************************^*/

/*!
 * \brief Sets menu bar.
 *
 * \param env the JNIEnv pointer
 * \param menuBarBridge the menu bar bridge
 */
void JQFrameBridge::setMenuBar(JNIEnv *env, jlong menuBarBridge)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setMenuBar, QSWING_ENV_ARG, JLONG_ARG(menuBarBridge))
  if (menuBarBridge) {
    qMainWindow()->setMenuBar(jqMenuBarCast(menuBarBridge)->qMenuBar());
    jqMenuBarCast(menuBarBridge)->setParentBridge(this);
  } else {
    qMainWindow()->setMenuBar(0);
    // note: old menu bar and menu bar bridge are deleted
  }
}

/*!
 * \brief Adds toolbar.
 *
 * \param env the JNIEnv pointer
 * \param toolBarBridge the toolbar bridge 
 */
void JQFrameBridge::addToolBar(JNIEnv *env, jlong toolBarBridge)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(addToolBar, QSWING_ENV_ARG, JLONG_ARG(toolBarBridge))
  qMainWindow()->addToolBar(jqToolBarCast(toolBarBridge)->qToolBar());
  jqToolBarCast(toolBarBridge)->setParentBridge(this);
}

/*!
 * \brief Removes the specified toolbar.
 *
 * \param env the JNIEnv pointer
 * \param toolBarBridge the toolbar bridge 
 */
void JQFrameBridge::removeToolBar(JNIEnv *env, jlong toolBarBridge)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(removeToolBar, QSWING_ENV_ARG, JLONG_ARG(toolBarBridge))
  qMainWindow()->removeToolBar(jqToolBarCast(toolBarBridge)->qToolBar());
  jqToolBarCast(toolBarBridge)->setParentBridge(0);
}

/*!
 * \brief Sets content pane
 *
 * \param env the JNIEnv pointer
 * \param contentPaneBridge the content pane bridge
 */
void JQFrameBridge::setContentPane(JNIEnv *env, jlong contentPaneBridge)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setContentPane, QSWING_ENV_ARG, JLONG_ARG(contentPaneBridge))
  qMainWindow()->setCentralWidget(
                                 jqContainerCast(contentPaneBridge)->qWidget());
  jqContainerCast(contentPaneBridge)->setParentBridge(this);
}

/*!
 * \brief Sets status bar.
 *
 * \param env the JNIEnv pointer
 * \param statusBarBridge the status bar bridge
 */
void JQFrameBridge::setStatusBar(JNIEnv *env, jlong statusBarBridge)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setStatusBar, QSWING_ENV_ARG, JLONG_ARG(statusBarBridge))
  if (statusBarBridge) {
    qMainWindow()->setStatusBar(jqStatusBarCast(statusBarBridge)->qStatusBar());
    jqStatusBarCast(statusBarBridge)->setParentBridge(this);
  } else {
    qMainWindow()->setStatusBar(0);
    // note: old status bar and status bar bridge are deleted
  }
}

/*^**************************************************************************^*/
/*- JQFrameBridge :: Static Native Calls.                                    -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns new instance of the bridge object
 *
 * \param env the JNIEnv pointer
 * \param obj the QSwing object
 * 
 * \return new instance of the bridge object
 */
jlong JQFrameBridge::newInstance(JNIEnv *env, jobject obj)
{
  if (JNIQSwingWrapper::isQSwingThread(env)) {
    return reinterpret_cast<jlong>(new JQFrameBridge(env, obj));
  }
  return QSwingUtilitiesBridge::invokeLongAndWait(env, obj, createMID());
}

/*^*****************************************************************************
  File History:

 - 2007-11-06 19:05:51 JavaQx Native Generator
   Initial version

*****************************************************************************^*/
