/*
 * @(#)JQInternalFrameBridge.h  0.2.0 / 2007-11-19
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef JQINTERNALFRAMEBRIDGE_H
#define JQINTERNALFRAMEBRIDGE_H

#include "JavaQxQSwing.h"

#include "JQWindowBridge.h"

/*^**************************************************************************^*/
/*- JQInternalFrameBridge Class.                                             -*/
/*^**************************************************************************^*/

/*!
 * \brief JQInternalFrame Bridge.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT JQInternalFrameBridge : public JQWindowBridge
{
  Q_OBJECT
protected:
  JQInternalFrameBridge(JNIEnv *env, jobject obj);
public slots: // native calls
  void insertChild(JNIEnv *env, jlong childBridge, jint index);
public: // native calls
  static void initialize(JNIEnv *env, jclass cls);
  static jlong newInstance(JNIEnv *env, jobject obj);
public:
  virtual void setFocusable(JNIEnv *env, jboolean focusable);
  virtual void requestFocus(JNIEnv *env);
  virtual jobject getBackground(JNIEnv *env, jclass colorClass);
  virtual void setBackground(JNIEnv *env, jint argb);
  virtual void setNullBackground(JNIEnv *env);
  virtual jobject getForeground(JNIEnv *env, jclass colorClass);
  virtual void setForeground(JNIEnv *env, jint argb);
  virtual void setNullForeground(JNIEnv *env);
  virtual jobject getFont(JNIEnv *env, jclass fontClass);
  virtual void setFont(JNIEnv *env, jobject font);
  virtual jint getCursor(JNIEnv *env);
  virtual void setCursor(JNIEnv *env, jint type);
  virtual void setComponentOrientation(JNIEnv *env, jint orientation);
  virtual void setToolTipText(JNIEnv *env, jstring text);
  virtual void setStatusTipText(JNIEnv *env, jstring text);
  virtual void setWhatsThisText(JNIEnv *env, jstring text);
public: // native callbacks
  QSize getLayoutPreferredSize();
public:
  inline QMdiSubWindow *qMdiSubWindow() const;
  inline QWidget *qMdiSubWidget() const;
protected:
  virtual bool eventFilter(QObject *obj, QEvent *e);
  virtual void filterEnabledEvents();
  virtual QWidget *paintingWidget();
  friend class JQDesktopPaneBridge; // uses jniObject() function member
private:
  QWidget *m_internalWidget;
private:
  static jmethodID sm_getLayoutPreferredSizeMID;
};

/*^**************************************************************************^*/
/*- JQFrameBridge :: Public Inline Member Functions.                         -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns QMdiSubWindow adaptee.
 *
 * \return QMdiSubWindow adaptee
 */
inline QMdiSubWindow *JQInternalFrameBridge::qMdiSubWindow() const
{
  return static_cast<QMdiSubWindow *>(qObject());
}

/*!
 * \brief Returns internal sub widget.
 *
 * \return internal sub widget
 */
inline QWidget *JQInternalFrameBridge::qMdiSubWidget() const
{
  return m_internalWidget;
}

/*^**************************************************************************^*/
/*- Macro Definition.                                                        -*/
/*^**************************************************************************^*/

#define jqInternalFrameCast(bridge) \
    (reinterpret_cast<JQInternalFrameBridge *>(bridge))
#define jqInternalFrameBridge jqInternalFrameCast(bridge)

#endif //JQINTERNALFRAMEBRIDGE_H

/*^*****************************************************************************
  File History:

 - 2007-11-19 16:04:41 Slobodan
   Initial version

*****************************************************************************^*/
