/*
 * @(#)JQMenuBarBridge.cpp  0.2.0 / 2007-11-07
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "JQMenuBarBridge.h"

#include "JQMenuBridge.h"

/*^**************************************************************************^*/
/*- JQMenuBarBridge :: Protected Constructor.                                -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new JQMenuBarBridge object.
 *
 * \param env the JNIEnv pointer
 * \param obj the QSwing JQMenuBar object
 */
JQMenuBarBridge::JQMenuBarBridge(JNIEnv *env, jobject obj)
  : JQContainerBridge(env, obj, new QMenuBar())
{
  // empty constructor body
}

/*^**************************************************************************^*/
/*- JQMenuBarBridge :: Native Calls.                                         -*/
/*^**************************************************************************^*/

/*!
 * \brief Inserts child.
 *
 * \param env the JNIEnv pointer
 * \param childBridge the child pointer
 * \param index the menu item index
 */
void JQMenuBarBridge::insertChild(JNIEnv *env, jlong childBridge, jint index)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(insertChild, QSWING_ENV_ARG, JLONG_ARG(childBridge),
                   JINT_ARG(index))
  QAction *before = 0;
  if ((index >= 0) && (index < qMenuBar()->actions().size())) {
    before = qMenuBar()->actions().at(index);
  }
  qMenuBar()->insertAction(before, jqComponentCast(childBridge)->qAction());
  jqComponentCast(childBridge)->setParentBridge(this);
}

/*!
 * \brief Removes child.
 *
 * \param env the JNIEnv pointer
 * \param childBridge the child pointer
 */
void JQMenuBarBridge::removeChild(JNIEnv *env, jlong childBridge)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(removeChild, QSWING_ENV_ARG, JLONG_ARG(childBridge))
  qMenuBar()->removeAction(jqComponentCast(childBridge)->qAction());
  jqComponentCast(childBridge)->setParentBridge(0);
}

/*^**************************************************************************^*/
/*- JQMenuBarBridge :: Static Native Calls.                                  -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns new instance of the bridge object
 *
 * \param env the JNIEnv pointer
 * \param obj the QSwing object
 * 
 * \return new instance of the bridge object
 */
jlong JQMenuBarBridge::newInstance(JNIEnv *env, jobject obj)
{
  if (JNIQSwingWrapper::isQSwingThread(env)) {
    return reinterpret_cast<jlong>(new JQMenuBarBridge(env, obj));
  }
  return QSwingUtilitiesBridge::invokeLongAndWait(env, obj, createMID());
}

/*^*****************************************************************************
  File History:

 - 2007-11-07 20:56:40 Slobodan
   Initial version

*****************************************************************************^*/
