/*
 * @(#)JQMenuBridge.cpp  0.2.0 / 2007-11-08
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "JQMenuBridge.h"

#include "QWidgetActionAdapter.h"

/*^**************************************************************************^*/
/*- JQMenuBridge :: Protected Constructor.                                   -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new JQMenuBridge object.
 *
 * \param env the JNIEnv pointer
 * \param obj the QSwing JQMenu object
 */
JQMenuBridge::JQMenuBridge(JNIEnv *env, jobject obj)
  : JQContainerBridge(env, obj, new QMenu())
{
  qMenu()->setSeparatorsCollapsible(false);
}

/*^**************************************************************************^*/
/*- JQMenuBridge :: Native Calls.                                            -*/
/*^**************************************************************************^*/

/*!
 * \brief Sets menu text
 *
 * \param env the JNIEnv pointer
 * \param text the text
 */
void JQMenuBridge::setText(JNIEnv *env, jstring text)
{
  Q_ASSERT(env);
  Q_ASSERT(text);
  QSWING_REENTRANT(setText, QSWING_ENV_ARG, JSTRING_ARG(text))
  qMenu()->setTitle(QStringAdapter(env, text));
}

/*!
 * \brief Inserts child.
 *
 * \param env the JNIEnv pointer
 * \param childBridge the child pointer
 * \param index the menu item index
 */
void JQMenuBridge::insertChild(JNIEnv *env, jlong childBridge, jint index)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(insertChild, QSWING_ENV_ARG, JLONG_ARG(childBridge),
                   JINT_ARG(index))
  QAction *before = 0;
  if ((index >= 0) && (index < qMenu()->actions().size())) {
    before = qMenu()->actions().at(index);
  }
  JQComponentBridge *childComponentBridge = jqComponentCast(childBridge);
  qMenu()->insertAction(before, childComponentBridge->qAction());
  childComponentBridge->setParentBridge(this);
  childComponentBridge->setParent(this);
}

/*!
 * \brief Removes child.
 *
 * \param env the JNIEnv pointer
 * \param childBridge the child pointer
 */
void JQMenuBridge::removeChild(JNIEnv *env, jlong childBridge)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(removeChild, QSWING_ENV_ARG, JLONG_ARG(childBridge))
  JQComponentBridge *childComponentBridge = jqComponentCast(childBridge);
  qMenu()->removeAction(childComponentBridge->qAction());
  childComponentBridge->setParentBridge(0);
  childComponentBridge->setParent(0);
}

/*!
 * \brief Displays menu at specified location.
 *
 * \param env the JNIEnv pointer
 * \param x the x coordinate of the location
 * \param y the y coordinate of the location
 */
void JQMenuBridge::show(JNIEnv *env, jint x, jint y)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(show, QSWING_ENV_ARG, JINT_ARG(x), JINT_ARG(y))
  qMenu()->popup(QPoint(x, y));
}

/*^**************************************************************************^*/
/*- JQMenuBridge :: Static Native Calls.                                     -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns new instance of the bridge object
 *
 * \param env the JNIEnv pointer
 * \param obj the QSwing object
 * 
 * \return new instance of the bridge object
 */
jlong JQMenuBridge::newInstance(JNIEnv *env, jobject obj)
{
  if (JNIQSwingWrapper::isQSwingThread(env)) {
    return reinterpret_cast<jlong>(new JQMenuBridge(env, obj));
  }
  return QSwingUtilitiesBridge::invokeLongAndWait(env, obj, createMID());
}

/*^**************************************************************************^*/
/*- JQMenuBridge :: Overridden Member Function.                              -*/
/*^**************************************************************************^*/

/*!
 * \inheritDoc
 */
QAction *JQMenuBridge::qAction()
{
  return qMenu()->menuAction();
}

/*^*****************************************************************************
  File History:

 - 2007-11-08 11:02:50 Slobodan
   Initial version

*****************************************************************************^*/
