/*
 * @(#)JQMenuItemBridge.h  0.2.0 / 2007-11-09
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef JQMENUITEMBRIDGE_H
#define JQMENUITEMBRIDGE_H

#include "JavaQxQSwing.h"

#include "JQActionComponentBridge.h"
#include "QLabelAdapter.h"

/*^**************************************************************************^*/
/*- JQMenuItemBridge Class.                                                  -*/
/*^**************************************************************************^*/

/*!
 * \brief JQMenuItem Bridge.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT JQMenuItemBridge : public JQActionComponentBridge
{
  Q_OBJECT
protected:
  JQMenuItemBridge(JNIEnv *env, jobject obj);
public slots: // native calls
  void setText(JNIEnv *env, jstring text);
  void setShortcut(JNIEnv *env, jstring shortcut);
  void setIcon(JNIEnv *env, jobject iconSet);
public: // native calls
  static void initialize(JNIEnv *env, jclass cls);
  static jlong newInstance(JNIEnv *env, jobject obj);
public: // native callbacks
  void actionTriggered(jint modifiers);
protected slots:
  void triggeredSlot();
protected:
  inline QLabelAdapter *label() const;
protected:
  virtual QWidget *createQWidget();
  virtual QAction *createQAction();
  virtual void deleteQWidget(QWidget *widget);
  virtual void deleteQAction(QAction *action);
  virtual QWidget *convertToQWidget(QAction *action);
  virtual QAction *convertToQAction(QWidget *widget);
private:
  QShortcut *m_shortcut;
private:
  static jmethodID sm_actionTriggeredMID;
};

/*^**************************************************************************^*/
/*- JQMenuItemBridge :: Protected Inline Member Function .                   -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns label data member.
 *
 * \return label data member
 */
inline QLabelAdapter *JQMenuItemBridge::label() const
{
  return static_cast<QLabelAdapter *>(widget());
}

/*^**************************************************************************^*/
/*- Macro Definition.                                                        -*/
/*^**************************************************************************^*/

#define jqMenuItemBridge (reinterpret_cast<JQMenuItemBridge *>(bridge))

#endif //JQMENUITEMBRIDGE_H

/*^*****************************************************************************
  File History:

 - 2007-11-09 19:21:03 Slobodan
   Initial version

*****************************************************************************^*/
