/*
 * @(#)JQOptionPaneBridge.cpp  0.2.0 / 2007-11-30
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "JQOptionPaneBridge.h"

#include "yu_ac_bg_etf_javaqx_qswing_JQOptionPane.h"

#include "JQComponentBridge.h"

/*^**************************************************************************^*/
/*- Macro Helper.                                                            -*/
/*^**************************************************************************^*/

#define MESSAGE_TYPE(type) yu_ac_bg_etf_javaqx_qswing_JQOptionPane_##type

/*^**************************************************************************^*/
/*- JQOptionPaneBridge :: Static Native Calls.                               -*/
/*^**************************************************************************^*/

/*!
 * \brief Displays message dialog.
 *
 * \param env the JNIEnv pointer
 * \param cls the JQOptionPane class
 * \param messageType the message type
 * \param parentBridge the parent componet
 * \param text the message text
 * \param title the dialog title
 * \param options the options
 * \param defaultOption the default option
 * 
 * \return selected option.
 */
jint JQOptionPaneBridge::showMessage(JNIEnv *env, jclass cls, jint messageType,
                                     jlong parentBridge, jstring text,
                                     jstring title, jint options,
                                     jint defaultOption)
{
  Q_ASSERT(env);
  QSWING_STATIC_REENTRANT_RETURN(JQOptionPaneBridge, showMessage, jint,
                                 QSWING_ENV_ARG, JCLASS_ARG(cls),
                                 JINT_ARG(messageType), JLONG_ARG(parentBridge),
                                 JSTRING_ARG(text), JSTRING_ARG(title),
                                 JINT_ARG(options), JINT_ARG(defaultOption))
  QWidget *parent = 0;
  if (parentBridge) {
    parent = jqComponentCast(parentBridge)->qWidget();
  }
  QMessageBox::StandardButtons buttons = QMessageBox::StandardButtons(options);
  QMessageBox::StandardButton defaultButton =
                                    QMessageBox::StandardButton(defaultOption);
  switch(messageType) {
    case MESSAGE_TYPE(ABOUT_MESSAGE):
      QMessageBox::about(parent, QStringAdapter(env, title),
                         QStringAdapter(env, text));
      break;
    case MESSAGE_TYPE(INFORMATION_MESSAGE):
      return QMessageBox::information(parent, QStringAdapter(env, title),
                                      QStringAdapter(env, text), buttons,
                                      defaultButton);
    case MESSAGE_TYPE(WARNING_MESSAGE):
      return QMessageBox::warning(parent, QStringAdapter(env, title),
                                  QStringAdapter(env, text), buttons,
                                  defaultButton);
    case MESSAGE_TYPE(QUESTION_MESSAGE):
      return QMessageBox::question(parent, QStringAdapter(env, title),
                                   QStringAdapter(env, text), buttons,
                                   defaultButton);
    case MESSAGE_TYPE(ERROR_MESSAGE):
      return QMessageBox::critical(parent, QStringAdapter(env, title),
                                   QStringAdapter(env, text), buttons,
                                   defaultButton);
  }
  return 0;
}
/*^*****************************************************************************
  File History:

 - 2007-11-30 00:50:39 Slobodan
   Initial version

*****************************************************************************^*/
