/*
 * @(#)JQPanelBridge.cpp  0.2.0 / 2007-10-29
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "JQPanelBridge.h"

#include "yu_ac_bg_etf_javaqx_qswing_JQPanel.h"

/*^**************************************************************************^*/
/*- JQPanelBridge :: Protected Constructor.                                  -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new JQPanelBridge object.
 *
 * \param env the JNIEnv pointer
 * \param obj the JQPanel object
 */
JQPanelBridge::JQPanelBridge(JNIEnv *env, jobject obj)
  : JQContainerBridge(env, obj, new QFrame())
{
  // empty constructor body
}

/*^**************************************************************************^*/
/*- JQPanelBridge :: Native Calls.                                           -*/
/*^**************************************************************************^*/

/*!
 * \brief Sets panel type
 *
 * \param env the JNIEnv pointer
 * \param panelType the panel type
 */
void JQPanelBridge::setPanelType(JNIEnv *env, jint panelType)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setPanelType, QSWING_ENV_ARG, JINT_ARG(panelType))
  qFrame()->setFrameShape(QFrame::Shape(panelType));
}

/*!
 * \brief Sets border style.
 *
 * \param env the JNIEnv pointer
 * \param borderStyle the border style
 */
void JQPanelBridge::setBorderStyle(JNIEnv *env, jint borderStyle)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setBorderStyle, QSWING_ENV_ARG, JINT_ARG(borderStyle))
  qFrame()->setFrameShadow(QFrame::Shadow(borderStyle));
}

/*!
 * \brief Sets border width.
 *
 * \param env the JNIEnv pointer
 * \param borderWidth the border width
 */
void JQPanelBridge::setBorderWidth(JNIEnv *env, jint borderWidth)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setBorderWidth, QSWING_ENV_ARG, JINT_ARG(borderWidth))
  qFrame()->setMidLineWidth(borderWidth);
}

/*^**************************************************************************^*/
/*- JQPanelBridge :: Static Native Calls.                                    -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns new instance of the bridge object
 *
 * \param env the JNIEnv pointer
 * \param obj the QSwing object
 * 
 * \return new instance of the bridge object
 */
jlong JQPanelBridge::newInstance(JNIEnv *env, jobject obj)
{
  if (JNIQSwingWrapper::isQSwingThread(env)) {
    return reinterpret_cast<jlong>(new JQPanelBridge(env, obj));
  }
  return QSwingUtilitiesBridge::invokeLongAndWait(env, obj, createMID());
}

/*^*****************************************************************************
  File History:

 - 2007-10-29 08:19:25 JavaQx Native Generator
   Initial version

*****************************************************************************^*/
