/*
 * @(#)JQProgressBarBridge.cpp  0.2.0 / 2007-10-29
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "JQProgressBarBridge.h"

/*^**************************************************************************^*/
/*- JQProgressBarBridge :: Protected Constructor.                            -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new JQProgressBarBridge object.
 *
 * \param env the JNIEnv pointer
 * \param obj JQProgressBar object
 */
JQProgressBarBridge::JQProgressBarBridge(JNIEnv *env, jobject obj)
  : JQComponentBridge(env, obj, new QProgressBar())
{
  qProgressBar()->setAlignment(Qt::AlignCenter);
  qProgressBar()->setTextVisible(false);
}

/*^**************************************************************************^*/
/*- JQProgressBarBridge :: Native Calls.                                     -*/
/*^**************************************************************************^*/

/*!
 * \brief Sets model.
 *
 * \param env the JNIEnv pointer
 * \param minimum the minimum progress value
 * \param maximum the maximum progress value
 * \param value the progress value
 */
void JQProgressBarBridge::setModel(JNIEnv *env, jint minimum, jint maximum,
                                   jint value)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setModel, QSWING_ENV_ARG, JINT_ARG(minimum),
                   JINT_ARG(maximum), JINT_ARG(value))
  qProgressBar()->setMinimum(minimum);
  qProgressBar()->setMaximum(maximum);
  qProgressBar()->setValue(value);
}

/*!
 * \brief Sets progress value.
 *
 * \param env the JNIEnv pointer
 * \param value the progress value
 */
void JQProgressBarBridge::setValue(JNIEnv *env, jint value)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setValue, QSWING_ENV_ARG, JINT_ARG(value))
  qProgressBar()->setValue(value);
}

/*!
 * \brief Sets minimum progress value.
 *
 * \param env the JNIEnv pointer
 * \param minimum the minimum progress value
 */
void JQProgressBarBridge::setMinimum(JNIEnv *env, jint minimum)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setMinimum, QSWING_ENV_ARG, JINT_ARG(minimum))
  qProgressBar()->setMinimum(minimum);
}

/*!
 * \brief Sets maximum progress value.
 *
 * \param env the JNIEnv pointer
 * \param maximum the maximum progress value
 */
void JQProgressBarBridge::setMaximum(JNIEnv *env, jint maximum)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setMaximum, QSWING_ENV_ARG, JINT_ARG(maximum))
  qProgressBar()->setMaximum(maximum);
}

/*!
 * \brief Sets progress bar orientation.
 *
 * \param env the JNIEnv pointer
 * \param orientation the orientation
 */
void JQProgressBarBridge::setOrientation(JNIEnv *env, jint orientation)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setOrientation, QSWING_ENV_ARG, JINT_ARG(orientation))
  switch(orientation) {
    case 0:
      qProgressBar()->setOrientation(Qt::Horizontal);
      break;
    case 1:
      qProgressBar()->setOrientation(Qt::Vertical);
      break;
  }
}

/*!
 * \brief Sets progress string.
 *
 * \param env the JNIEnv pointer
 * \param progressString the progress string
 */
void JQProgressBarBridge::setProgressString(JNIEnv *env, jstring progressString)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setProgressString, QSWING_ENV_ARG,
                   JSTRING_ARG(progressString))
  if (progressString) {
   qProgressBar()->setFormat(QStringAdapter(env, progressString));
  } else {
   qProgressBar()->setFormat("%p%");
  }
}

/*!
 * \brief Set whether or not the progress string is painted.
 *
 * \param env the JNIEnv pointer
 * \param paintString \c true if painted
 */
void JQProgressBarBridge::setStringPainted(JNIEnv *env, jboolean paintString)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setStringPainted, QSWING_ENV_ARG, JBOOLEAN_ARG(paintString))
  qProgressBar()->setTextVisible(paintString);
}

/*^**************************************************************************^*/
/*- JQProgressBarBridge :: Static Native Calls.                              -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns new instance of the bridge object
 *
 * \param env the JNIEnv pointer
 * \param obj the QSwing object
 * 
 * \return new instance of the bridge object
 */
jlong JQProgressBarBridge::newInstance(JNIEnv *env, jobject obj)
{
  if (JNIQSwingWrapper::isQSwingThread(env)) {
    return reinterpret_cast<jlong>(new JQProgressBarBridge(env, obj));
  }
  return QSwingUtilitiesBridge::invokeLongAndWait(env, obj, createMID());
}

/*^*****************************************************************************
  File History:

 - 2007-10-29 08:54:07 JavaQx Native Generator
   Initial version

*****************************************************************************^*/
