/*
 * @(#)JQRadioButtonMenuItemBridge.h  0.2.0 / 2007-11-14
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef JQRADIOBUTTONMENUITEMBRIDGE_H
#define JQRADIOBUTTONMENUITEMBRIDGE_H

#include "JavaQxQSwing.h"

#include "JQActionComponentBridge.h"

/*^**************************************************************************^*/
/*- JQRadioButtonMenuItemBridge Class.                                       -*/
/*^**************************************************************************^*/

/*!
 * \brief JQRadioButtonMenuItem Bridge.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT JQRadioButtonMenuItemBridge : public JQActionComponentBridge
{
  Q_OBJECT
protected:
  JQRadioButtonMenuItemBridge(JNIEnv *env, jobject obj);
public slots: // native calls
  void setText(JNIEnv *env, jstring text);
  void setShortcut(JNIEnv *env, jstring shortcut);
  void setIcon(JNIEnv *env, jobject iconSet);
  void setSelected(JNIEnv *env, jboolean selected);
public: // native calls
  static void initialize(JNIEnv *env, jclass cls);
  static jlong newInstance(JNIEnv *env, jobject obj);
public: // native callbacks
  void selectedChanged(jint modifiers, jboolean selected);
protected slots:
  void toggledSlot(bool checked);
protected:
  inline QRadioButton *radioButton() const;
protected:
  virtual QWidget *createQWidget();
  virtual QAction *createQAction();
  virtual void deleteQWidget(QWidget *widget);
  virtual void deleteQAction(QAction *action);
  virtual QWidget *convertToQWidget(QAction *action);
  virtual QAction *convertToQAction(QWidget *widget);
protected:
  static QActionGroup *actionGroup();
private:
  QShortcut *m_shortcut;
  QActionGroup *m_actionGroup;
private:
  static jmethodID sm_selectedChangedMID;
};

/*^**************************************************************************^*/
/*- JQRadioButtonMenuItemBridge :: Protected Inline Member Function.         -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns radio button member.
 *
 * \return radio button member
 */
inline QRadioButton *JQRadioButtonMenuItemBridge::radioButton() const
{
  return static_cast<QRadioButton *>(widget());
}

/*^**************************************************************************^*/
/*- Macro Definition.                                                        -*/
/*^**************************************************************************^*/

#define jqRadioButtonMenuItemBridge \
    (reinterpret_cast<JQRadioButtonMenuItemBridge *>(bridge))

#endif //JQRADIOBUTTONMENUITEMBRIDGE_H

/*^*****************************************************************************
  File History:

 - 2007-11-14 12:51:05 Slobodan
   Initial version

*****************************************************************************^*/
