/*
 * @(#)JQScrollBarBridge.h  0.2.0 / 2007-11-06
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef JQSCROLLBARBRIDGE_H
#define JQSCROLLBARBRIDGE_H

#include "JavaQxQSwing.h"

#include "JQComponentBridge.h"

/*^**************************************************************************^*/
/*- JQScrollBarBridge Class.                                                 -*/
/*^**************************************************************************^*/

/*!
 * \brief JQScrollBar Bridge.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT JQScrollBarBridge : public JQComponentBridge
{
  Q_OBJECT
protected:
  JQScrollBarBridge(JNIEnv *env, jobject obj);
public slots: // native calls
  void setModel(JNIEnv *env, jint minimum, jint maximum, jint value);
  void setValue(JNIEnv *env, jint value);
  void setMinimum(JNIEnv *env, jint minimum);
  void setMaximum(JNIEnv *env, jint maximum);
  void setOrientation(JNIEnv *env, jint orientation);
  void setUnitIncrement(JNIEnv *env, jint unitIncrement);
  void setBlockIncrement(JNIEnv *env, jint blockIncrement);
public: // native calls
  static void initialize(JNIEnv *env, jclass cls);
  static jlong newInstance(JNIEnv *env, jobject obj);
public: // native callbacks
  void valueChanged(jint value);
  void valueIsAdjusting(jboolean adjusting);
protected slots:
  void valueChangedSlot(int value);
  void sliderPressedSlot();
  void sliderReleasedSlot();
public:
  inline QScrollBar *qScrollBar() const;
private:
  static jmethodID sm_valueChangedMID;
  static jmethodID sm_valueIsAdjustingMID;
};

/*^**************************************************************************^*/
/*- JQScrollBarBridge :: Public Inline Member Function.                      -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns QScrollBar adaptee.
 *
 * \return QScrollBar adaptee
 */
inline QScrollBar *JQScrollBarBridge::qScrollBar() const
{
  return static_cast<QScrollBar *>(qObject());
}

/*^**************************************************************************^*/
/*- Macro Definition.                                                        -*/
/*^**************************************************************************^*/

#define jqScrollBarBridge (reinterpret_cast<JQScrollBarBridge *>(bridge))

#endif //JQSCROLLBARBRIDGE_H

/*^*****************************************************************************
  File History:

 - 2007-11-06 06:51:23 Slobodan
   Initial version

*****************************************************************************^*/
