/*
 * @(#)JQScrollPaneBridge.cpp  0.2.0 / 2007-11-20
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "JQScrollPaneBridge.h"

/*^**************************************************************************^*/
/*- JQScrollPaneBridge :: Protected Constructor.                             -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new JQScrollPaneBridge object.
 *
 * \param env the JNIEnv pointer
 * \param obj the JQScrollPane object
 */
JQScrollPaneBridge::JQScrollPaneBridge(JNIEnv *env, jobject obj)
  : JQComponentBridge(env, obj, new QScrollArea()), m_viewBridge(0)
{
  // empty constructor body
}

/*^**************************************************************************^*/
/*- JQScrollPaneBridge :: Native Calls.                                      -*/
/*^**************************************************************************^*/

/*!
 * \brief Sets view component.
 *
 * \param env the JNIEnv pointer
 * \param viewBridge the view component bridge
 */
void JQScrollPaneBridge::setView(JNIEnv *env, jlong viewBridge)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setView, QSWING_ENV_ARG, JLONG_ARG(viewBridge))
  qScrollArea()->takeWidget();
  if (viewBridge) {
    m_viewBridge = jqComponentCast(viewBridge);
    qScrollArea()->setWidget(m_viewBridge->qWidget());
  } else {
    m_viewBridge = 0;
  }
}

/*^**************************************************************************^*/
/*- JQScrollPaneBridge :: Static Native Calls.                               -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns new instance of the bridge object
 *
 * \param env the JNIEnv pointer
 * \param obj the QSwing object
 * 
 * \return new instance of the bridge object
 */
jlong JQScrollPaneBridge::newInstance(JNIEnv *env, jobject obj)
{
  if (JNIQSwingWrapper::isQSwingThread(env)) {
    return reinterpret_cast<jlong>(new JQScrollPaneBridge(env, obj));
  }
  return QSwingUtilitiesBridge::invokeLongAndWait(env, obj, createMID());
}

/*^**************************************************************************^*/
/*- JQScrollPaneBridge :: Overridden Member Function.                        -*/
/*^**************************************************************************^*/

/*!
 * \inheritDoc
 */
bool JQScrollPaneBridge::filterResizeEvent(QObject *obj, QResizeEvent *e)
{
  bool filtered = JQComponentBridge::filterResizeEvent(obj, e);
  if (m_viewBridge) {
    // TODO: Include scroll bar dimensions
    QWidget *view = qScrollArea()->widget();
    QSize viewportSize = qScrollArea()->maximumViewportSize();
    QSize preferredViewSize = m_viewBridge->getPreferredSize();
    view->resize(viewportSize.expandedTo(preferredViewSize));
  }
  return filtered;
}

/*^*****************************************************************************
  File History:

 - 2007-11-20 19:37:52 Slobodan
   Initial version

*****************************************************************************^*/
