/*
 * @(#)JQSeparatorBridge.h  0.2.0 / 2007-11-09
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef JQSEPARATORBRIDGE_H
#define JQSEPARATORBRIDGE_H

#include "JavaQxQSwing.h"

#include "JQActionComponentBridge.h"
#include "QSeparatorAdapter.h"

/*^**************************************************************************^*/
/*- JQSeparatorBridge Class.                                                 -*/
/*^**************************************************************************^*/

/*!
 * \brief JQSeparator Data.
 */
class JAVAQX_EXPORT JQSeparatorData : public JQActionComponentData
{
  friend class JQSeparatorBridge; // uses all members
protected:
  JQSeparatorData();
public:
  // TODO: implement getters
protected:
  Qt::Orientation orientation;
};

/*!
 * \brief JQSeparator Bridge.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JQSeparatorBridge : public JQActionComponentBridge
{
  Q_OBJECT
protected:
  JQSeparatorBridge(JNIEnv *env, jobject obj);
public slots: // native calls
  void setOrientation(JNIEnv *env, jint orientation);
  void setText(JNIEnv *env, jstring text);
public: // native calls
  static void initialize(JNIEnv *env, jclass cls);
  static jlong newInstance(JNIEnv *env, jobject obj);
public: // native callbacks
  void orientationChanged(jint orientation);
public:
  virtual void setParentBridge(JQContainerBridge *parentBridge);
  virtual void setForeground(JNIEnv *env, jint argb);
  virtual void setNullForeground(JNIEnv *env);
protected slots:
  void orientationChangedSlot(Qt::Orientation orientation);
protected:
  inline JQSeparatorData *separatorActionData();
  inline QSeparatorAdapter *separator() const;
protected:
  virtual QWidget *createQWidget();
  virtual QAction *createQAction();
  virtual QWidget *convertToQWidget(QAction *action);
  virtual QAction *convertToQAction(QWidget *widget);
  virtual JQActionComponentData *createActionData();
private:
  static jmethodID sm_orientationChangedMID;
};

/*^**************************************************************************^*/
/*- JQSeparatorBridge :: Protected Inline Member Functions.                 -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns action data of the separator.
 *
 * \return action data of the separator
 */
inline JQSeparatorData *JQSeparatorBridge::separatorActionData()
{
  return static_cast<JQSeparatorData *>(actionData());
}

/*!
 * \brief Returns separator data member.
 *
 * \return separator data member
 */
inline QSeparatorAdapter *JQSeparatorBridge::separator() const
{
  return static_cast<QSeparatorAdapter *>(widget());
}

/*^**************************************************************************^*/
/*- Macro Definition.                                                        -*/
/*^**************************************************************************^*/

#define jqSeparatorBridge (reinterpret_cast<JQSeparatorBridge *>(bridge))

#endif //JQSEPARATORBRIDGE_H

/*^*****************************************************************************
  File History:

 - 2007-11-09 17:31:07 JavaQx Native Generator
   Initial version

*****************************************************************************^*/
