/*
 * @(#)JQStatusBarBridge.h  0.2.0 / 2007-11-07
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef JQSTATUSBARBRIDGE_H
#define JQSTATUSBARBRIDGE_H

#include "JavaQxQSwing.h"

#include "JQContainerBridge.h"

/*^**************************************************************************^*/
/*- JQStatusBarBridge Class.                                                 -*/
/*^**************************************************************************^*/

/*!
 * \brief JQStatusBar Bridge.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT JQStatusBarBridge : public JQContainerBridge
{
  Q_OBJECT
protected:
  JQStatusBarBridge(JNIEnv *env, jobject obj);
public slots: // native calls
  void showMessage(JNIEnv *env, jstring message, jint timeout);
  void clearMessage(JNIEnv *env);
  void insertChild(JNIEnv *env, jlong childBridge, jint index);
  void insertPermanentChild(JNIEnv *env, jlong childBridge, jint index);
  void removeChild(JNIEnv *env, jlong childBridge);
  void setSizeGripEnabled(JNIEnv *env, jboolean enabled);
public: // native calls
  static void initialize(JNIEnv *env, jclass cls);
  static jlong newInstance(JNIEnv *env, jobject obj);
public: // native callbacks
  void statusMessgeChanged(jstring message);
public:
  inline QStatusBar *qStatusBar() const;
public:
  virtual void setParentBridge(JQContainerBridge *parentBridge);
protected slots:
  void messageChangedSlot(const QString &message);
private:
  static jmethodID sm_statusMessgeChangedMID;
};

/*^**************************************************************************^*/
/*- JQStatusBarBridge :: Public Inline Member Function.                      -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns QStatusBar adaptee.
 *
 * \return QStatusBar adaptee
 */
inline QStatusBar *JQStatusBarBridge::qStatusBar() const
{
  return static_cast<QStatusBar *>(qObject());
}

/*^**************************************************************************^*/
/*- Macro Definitions.                                                       -*/
/*^**************************************************************************^*/

#define jqStatusBarCast(bridge) (reinterpret_cast<JQStatusBarBridge *>(bridge))
#define jqStatusBarBridge jqStatusBarCast(bridge)

#endif //JQSTATUSBARBRIDGE_H

/*^*****************************************************************************
  File History:

 - 2007-11-07 08:45:32 Slobodan
   Initial version

*****************************************************************************^*/
