/*
 * @(#)JQTextAreaBridge.h  0.2.0 / 2007-12-09
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef JQTEXTAREABRIDGE_H
#define JQTEXTAREABRIDGE_H

#include "JavaQxQSwing.h"

#include "JQTextComponentBridge.h"
#include "QTextArea.h"

/*^**************************************************************************^*/
/*- JQTextAreaBridge Class.                                                  -*/
/*^**************************************************************************^*/

/*!
 * \brief JQTextArea Bridge.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT JQTextAreaBridge : public JQTextComponentBridge
{
  Q_OBJECT
protected:
  JQTextAreaBridge(JNIEnv *env, jobject obj);
public slots: // native calls
  void setWrapText(JNIEnv *env, jboolean textWrap);
  void paintComponentView(JNIEnv *env, jlong graphicsPointer);
public: // native calls
  static void initialize(JNIEnv *env, jclass cls);
  static jlong newInstance(JNIEnv *env, jobject obj);
public: // native callbacks
  void paintView(jlong graphicsPointer, jint x, jint y, jint width,
                 jint height);
public:
  inline QTextArea *qTextArea() const;
public:
  virtual void setDocument(JNIEnv *env, jobject document);
  virtual void setEditable(JNIEnv *env, jboolean editable);
  virtual void insertText(JNIEnv *env, jstring text);
  virtual void cut(JNIEnv *env);
  virtual void copy(JNIEnv *env);
  virtual void paste(JNIEnv *env);
  virtual void clear(JNIEnv *env);
  virtual void selectAll(JNIEnv *env);
  virtual jobject getBackground(JNIEnv *env, jclass colorClass);
  virtual void setBackground(JNIEnv *env, jint argb);
  virtual void setNullBackground(JNIEnv *env);
  virtual jint getCursor(JNIEnv *env);
  virtual void setCursor(JNIEnv *env, jint type);
protected:
  virtual void filterEnabledEvents();
private:
  static jmethodID sm_paintViewMID;
};

/*^**************************************************************************^*/
/*- JQTextAreaBridge :: Inline Member Function.                              -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns QTextArea adaptee.
 *
 * \return QTextArea adaptee
 */
inline QTextArea *JQTextAreaBridge::qTextArea() const
{
  return static_cast<QTextArea *>(qObject());
}

/*^**************************************************************************^*/
/*- Macro Definition.                                                        -*/
/*^**************************************************************************^*/

#define jqTextAreaBridge (reinterpret_cast<JQTextAreaBridge *>(bridge))

#endif //JQTEXTAREABRIDGE_H

/*^*****************************************************************************
  File History:

 - 2007-12-09 08:59:51 Slobodan
   Initial version

*****************************************************************************^*/
