/*
 * @(#)JQTextComponentBridge.cpp  0.2.0 / 2007-12-11
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "JQTextComponentBridge.h"

/*^**************************************************************************^*/
/*- JQTextComponentBridge :: Protected Constructor.                          -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new JQTextComponentBridge object.
 *
 * \param env the JNIEnv pointer
 * \param obj the JQTextComponent object
 * \param textComponent the text component
 */
JQTextComponentBridge::JQTextComponentBridge(JNIEnv *env, jobject obj,
                                             QWidget *textComponent)
  : JQComponentBridge(env, obj, textComponent), m_undoAvailable(false),
    m_redoAvailable(false), m_cutAvailable(false), m_copyAvailable(false),
    m_pasteAvailable(false), m_clearAvailable(false),
    m_selectAllAvailable(false)
{
  // empty constructor body
}

/*^**************************************************************************^*/
/*- JQTextComponentBridge :: Static Native Calls.                            -*/
/*^**************************************************************************^*/

/*!
 * \brief Initializes JQTextComponentBridge class.
 *
 * \param env the JNIEnv pointer
 * \param cls the JQTextComponent class
 *
 * \exception FatalError if failed
 */
void JQTextComponentBridge::initialize(JNIEnv *env, jclass cls)
{
  Q_ASSERT(env);
  Q_ASSERT(cls);
  Q_ASSERT (!sm_undoAvailableMID);
  if (!INIT_UMID(undoAvailable, cls, "(Z)V") || 
      !INIT_UMID(redoAvailable, cls, "(Z)V") || 
      !INIT_UMID(cutAvailable, cls, "(Z)V") || 
      !INIT_UMID(copyAvailable, cls, "(Z)V") || 
      !INIT_UMID(pasteAvailable, cls, "(Z)V") || 
      !INIT_UMID(clearAvailable, cls, "(Z)V") ||
      !INIT_UMID(selectAllAvailable, cls, "(Z)V")) {
    FATAL_LOGGED_ERROR("JQTextComponentBridge initialization failed");
  }
}

/*^**************************************************************************^*/
/*- JQTextComponentBridge :: Native Callbacks.                               -*/
/*^**************************************************************************^*/

/*!
 * \brief Calls \c undoAvailable method of the TextDocument object.
 *
 * \param available \c true if available
 */
void JQTextComponentBridge::undoAvailable(jboolean available)
{
  if (m_undoAvailable != (bool)available) {
    m_undoAvailable = (bool)available;
    jniObject()->callVoidMethod(sm_undoAvailableMID, available);
  }
}

/*!
 * \brief Calls \c redoAvailable method of the TextDocument object.
 *
 * \param available \c true if available
 */
void JQTextComponentBridge::redoAvailable(jboolean available)
{
  if (m_redoAvailable != (bool)available) {
    m_redoAvailable = (bool)available;
    jniObject()->callVoidMethod(sm_redoAvailableMID, available);
  }
}

/*!
 * \brief Calls \c cutAvailable method of the TextDocument object.
 *
 * \param available \c true if available
 */
void JQTextComponentBridge::cutAvailable(jboolean available)
{
  if (m_cutAvailable != (bool)available) {
    m_cutAvailable = (bool)available;
    jniObject()->callVoidMethod(sm_cutAvailableMID, available);
  }
}

/*!
 * \brief Calls \c copyAvailable method of the TextDocument object.
 *
 * \param available \c true if available
 */
void JQTextComponentBridge::copyAvailable(jboolean available)
{
  if (m_copyAvailable != (bool)available) {
    m_copyAvailable = (bool)available;
    jniObject()->callVoidMethod(sm_copyAvailableMID, available);
  }
}

/*!
 * \brief Calls \c pasteAvailable method of the TextDocument object.
 *
 * \param available \c true if available
 */
void JQTextComponentBridge::pasteAvailable(jboolean available)
{
  if (m_pasteAvailable != (bool)available) {
    m_pasteAvailable = (bool)available;
    jniObject()->callVoidMethod(sm_pasteAvailableMID, available);
  }
}

/*!
 * \brief Calls \c clearAvailable method of the TextDocument object.
 *
 * \param available \c true if available
 */
void JQTextComponentBridge::clearAvailable(jboolean available)
{
  if (m_clearAvailable != (bool)available) {
    m_clearAvailable = (bool)available;
    jniObject()->callVoidMethod(sm_clearAvailableMID, available);
  }
}

/*!
 * \brief Calls \c selectAllAvailable method of the TextDocument object.
 *
 * \param available \c true if available
 */
void JQTextComponentBridge::selectAllAvailable(jboolean available)
{
  if (m_selectAllAvailable != (bool)available) {
    m_selectAllAvailable = (bool)available;
    jniObject()->callVoidMethod(sm_selectAllAvailableMID, available);
  }
}

/*^**************************************************************************^*/
/*- JQTextComponentBridge :: Protected Member Functions.                     -*/
/*^**************************************************************************^*/

/*!
 * \brief \c undoAvailable slot.
 *
 * \param available \c true if available
 */
void JQTextComponentBridge::undoAvailableSlot(bool available)
{
  undoAvailable(available);
}

/*!
 * \brief \c redAvailable slot.
 *
 * \param available \c true if available
 */
void JQTextComponentBridge::redoAvailableSlot(bool available)
{
  redoAvailable(available);
}

/*!
 * \brief Clipboard \c dataChanged slot.
 */
void JQTextComponentBridge::clipboardDataChanged()
{
  pasteAvailable(!QApplication::clipboard()->text().isEmpty());
}

/*^**************************************************************************^*/
/*- JQTextComponentBridge :: Private Static Data Members.                    -*/
/*^**************************************************************************^*/

jmethodID JQTextComponentBridge::sm_undoAvailableMID = 0;
jmethodID JQTextComponentBridge::sm_redoAvailableMID = 0;
jmethodID JQTextComponentBridge::sm_cutAvailableMID = 0;
jmethodID JQTextComponentBridge::sm_copyAvailableMID = 0;
jmethodID JQTextComponentBridge::sm_pasteAvailableMID = 0;
jmethodID JQTextComponentBridge::sm_clearAvailableMID = 0;
jmethodID JQTextComponentBridge::sm_selectAllAvailableMID = 0;

/*^*****************************************************************************
  File History:

 - 2007-12-11 21:50:00 Slobodan
   Initial version

*****************************************************************************^*/
