/*
 * @(#)JQTextComponentBridge.h  0.2.0 / 2007-12-11
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef JQTEXTCOMPONENTBRIDGE_H
#define JQTEXTCOMPONENTBRIDGE_H

#include "JavaQxQSwing.h"

#include "JQComponentBridge.h"

/*^**************************************************************************^*/
/*- JQTextComponentBridge Class.                                             -*/
/*^**************************************************************************^*/

/*!
 * \brief JQTextComponent Bridge.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT JQTextComponentBridge : public JQComponentBridge
{
  Q_OBJECT
protected:
  JQTextComponentBridge(JNIEnv *env, jobject obj, QWidget *textComponent);
public slots: // native calls
  virtual void setDocument(JNIEnv *env, jobject document) = 0;
  virtual void setEditable(JNIEnv *env, jboolean editable) = 0;
  virtual void insertText(JNIEnv *env, jstring text) = 0;
  virtual void cut(JNIEnv *env) = 0;
  virtual void copy(JNIEnv *env) = 0;
  virtual void paste(JNIEnv *env) = 0;
  virtual void clear(JNIEnv *env) = 0;
  virtual void selectAll(JNIEnv *env) = 0;
public: // native calls
  static void initialize(JNIEnv *env, jclass cls);
public: // native callbacks
  void undoAvailable(jboolean available);
  void redoAvailable(jboolean available);
  void cutAvailable(jboolean available);
  void copyAvailable(jboolean available);
  void pasteAvailable(jboolean available);
  void clearAvailable(jboolean available);
  void selectAllAvailable(jboolean available);
public slots:
  void undoAvailableSlot(bool available);
  void redoAvailableSlot(bool available);
  void clipboardDataChanged();
private:
  bool m_undoAvailable;
  bool m_redoAvailable;
  bool m_cutAvailable;
  bool m_copyAvailable;
  bool m_pasteAvailable;
  bool m_clearAvailable;
  bool m_selectAllAvailable;
private:
  static jmethodID sm_undoAvailableMID;
  static jmethodID sm_redoAvailableMID;
  static jmethodID sm_cutAvailableMID;
  static jmethodID sm_copyAvailableMID;
  static jmethodID sm_pasteAvailableMID;
  static jmethodID sm_clearAvailableMID;
  static jmethodID sm_selectAllAvailableMID;
};

/*^**************************************************************************^*/
/*- Macro Definition.                                                        -*/
/*^**************************************************************************^*/

#define jqTextComponentBridge \
    (reinterpret_cast<JQTextComponentBridge *>(bridge))

#endif //JQTEXTCOMPONENTBRIDGE_H

/*^*****************************************************************************
  File History:

 - 2007-12-11 21:50:00 Slobodan
   Initial version

*****************************************************************************^*/
