/*
 * @(#)JQTextPaneBridge.h  0.2.0 / 2007-12-08
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef JQTEXTPANEBRIDGE_H
#define JQTEXTPANEBRIDGE_H

#include "JavaQxQSwing.h"

#include "JQTextComponentBridge.h"
#include "QTextPane.h"

/*^**************************************************************************^*/
/*- JQTextPaneBridge Class.                                                  -*/
/*^**************************************************************************^*/

/*!
 * \brief JQTextPane Bridge.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT JQTextPaneBridge : public JQTextComponentBridge
{
  Q_OBJECT
protected:
  JQTextPaneBridge(JNIEnv *env, jobject obj);
public slots: // native calls
  void setWrapText(JNIEnv *env, jboolean textWrap);
  void paintComponentView(JNIEnv *env, jlong graphicsPointer);
public: // native calls
  static void initialize(JNIEnv *env, jclass cls);
  static jlong newInstance(JNIEnv *env, jobject obj);
public: // native callbacks
  void paintView(jlong graphicsPointer, jint x, jint y, jint width,
                 jint height);
public:
  inline QTextPane *qTextPane() const;
public:
  virtual void setDocument(JNIEnv *env, jobject document);
  virtual void setEditable(JNIEnv *env, jboolean editable);
  virtual void insertText(JNIEnv *env, jstring text);
  virtual void cut(JNIEnv *env);
  virtual void copy(JNIEnv *env);
  virtual void paste(JNIEnv *env);
  virtual void clear(JNIEnv *env);
  virtual void selectAll(JNIEnv *env);
  virtual jobject getBackground(JNIEnv *env, jclass colorClass);
  virtual void setBackground(JNIEnv *env, jint argb);
  virtual void setNullBackground(JNIEnv *env);
  virtual jint getCursor(JNIEnv *env);
  virtual void setCursor(JNIEnv *env, jint type);
protected:
  virtual void filterEnabledEvents();
private:
  static jmethodID sm_paintViewMID;
};

/*^**************************************************************************^*/
/*- JQTextPaneBridge :: Inline Member Function.                              -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns QTextPane adaptee.
 *
 * \return QTextPane adaptee
 */
inline QTextPane *JQTextPaneBridge::qTextPane() const
{
  return static_cast<QTextPane *>(qObject());
}

/*^**************************************************************************^*/
/*- Macro Definition.                                                        -*/
/*^**************************************************************************^*/

#define jqTextPaneBridge (reinterpret_cast<JQTextPaneBridge *>(bridge))

#endif //JQTEXTPANEBRIDGE_H

/*^*****************************************************************************
  File History:

 - 2007-12-08 20:06:34 Slobodan
   Initial version

*****************************************************************************^*/
