/*
 * @(#)JQToggleButtonBridge.cpp  0.2.0 / 2007-10-26
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "JQToggleButtonBridge.h"

/*^**************************************************************************^*/
/*- JQToggleButtonBridge :: Protected Constructors.                          -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new JQToggleButtonBridge object.
 *
 * \param env the JNIEnv pointer
 * \param obj the JQToggleButton object
 * \param button the button the QAbstractButton object
 */
JQToggleButtonBridge::JQToggleButtonBridge(JNIEnv *env, jobject obj,
                                           QAbstractButton *button)
  : JQAbstractButtonBridge(env, obj, button)
{
  // empty constructor body
}

/*!
 * \brief Constructs new JQToggleButtonBridge object.
 *
 * \param env the JNIEnv pointer
 * \param obj the JQToggleButton object
 */
JQToggleButtonBridge::JQToggleButtonBridge(JNIEnv *env, jobject obj)
  : JQAbstractButtonBridge(env, obj, new QPushButton())
{
  qToggleButton()->setCheckable(true);
}

/*^**************************************************************************^*/
/*- JQToggleButtonBridge :: Native Calls.                                    -*/
/*^**************************************************************************^*/

/*!
 * \brief Selectes/unselects the button.
 *
 * \param env the JNIEnv pointer 
 * \param selected \c true if selected
 */
void JQToggleButtonBridge::setSelected(JNIEnv *env, jboolean selected)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setSelected, QSWING_ENV_ARG, JBOOLEAN_ARG(selected))
  qAbstractButton()->setChecked(selected);
  if (qAbstractButton()->isChecked()) {
    setIconType(QIconAdapter::SelectedIcon);
  } else {
    setIconType(QIconAdapter::DefaultIcon);
  }
}

/*^**************************************************************************^*/
/*- JQToggleButtonBridge :: Static Native Calls.                             -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns new instance of the bridge object
 *
 * \param env the JNIEnv pointer
 * \param obj the QSwing object
 * 
 * \return new instance of the bridge object
 */
jlong JQToggleButtonBridge::newInstance(JNIEnv *env, jobject obj)
{
  if (JNIQSwingWrapper::isQSwingThread(env)) {
    return reinterpret_cast<jlong>(new JQToggleButtonBridge(env, obj));
  }
  return QSwingUtilitiesBridge::invokeLongAndWait(env, obj, createMID());
}

/*^*****************************************************************************
  File History:

 - 2007-10-26 18:03:56 Slobodan
   Initial version

*****************************************************************************^*/
