/*
 * @(#)JQToggleToolButtonBridge.cpp  0.2.0 / 2007-11-18
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "JQToggleToolButtonBridge.h"

#include "JQMenuBridge.h"

/*^**************************************************************************^*/
/*- JQToggleToolButtonBridge :: Protected Constructor.                       -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new JQToggleToolButtonBridge object.
 *
 * \param env the JNIEnv pointer
 * \param obj the JQToggleToolButton object
 */
JQToggleToolButtonBridge::JQToggleToolButtonBridge(JNIEnv *env, jobject obj)
  : JQToggleButtonBridge(env, obj, new QToolButton())
{
  qToggleToolButton()->setCheckable(true);
  qToggleToolButton()->setAutoRaise(true);
  qToggleToolButton()->setFocusPolicy(Qt::NoFocus);
}

/*^**************************************************************************^*/
/*- JQToggleToolButtonBridge :: Native Calls.                                -*/
/*^**************************************************************************^*/

/*!
 * \brief Sets menu.
 *
 * \param env the JNIEnv pointer
 * \param menuBridge the menu bridge pointer
 */
void JQToggleToolButtonBridge::setMenu(JNIEnv *env, jlong menuBridge)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setMenu, QSWING_ENV_ARG, JLONG_ARG(menuBridge))
  if (menuBridge) {
    qToggleToolButton()->setMenu(jqMenuCast(menuBridge)->qMenu());
  } else {
    qToggleToolButton()->setMenu(0);
  }
}

/*!
 * \brief Sets popup mode.
 *
 * \param env the JNIEnv pointer
 * \param popupMode the popup mode
 */
void JQToggleToolButtonBridge::setPopupMode(JNIEnv *env, jint popupMode)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setPopupMode, QSWING_ENV_ARG, JINT_ARG(popupMode))
  qToggleToolButton()->setPopupMode(
                                  QToolButton::ToolButtonPopupMode(popupMode));
}

/*!
 * \brief Sets tool button style.
 *
 * \param env the JNIEnv pointer
 * \param toolButtonStyle the tool button style
 */
void JQToggleToolButtonBridge::setToolButtonStyle(JNIEnv *env,
                                                  jint toolButtonStyle)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setToolButtonStyle, QSWING_ENV_ARG,
                   JINT_ARG(toolButtonStyle))
  qToggleToolButton()->setToolButtonStyle(Qt::ToolButtonStyle(toolButtonStyle));
}

/*^**************************************************************************^*/
/*- JQToggleToolButtonBridge :: Static Native Calls.                         -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns new instance of the bridge object
 *
 * \param env the JNIEnv pointer
 * \param obj the QSwing object
 * 
 * \return new instance of the bridge object
 */
jlong JQToggleToolButtonBridge::newInstance(JNIEnv *env, jobject obj)
{
  if (JNIQSwingWrapper::isQSwingThread(env)) {
    return reinterpret_cast<jlong>(new JQToggleToolButtonBridge(env, obj));
  }
  return QSwingUtilitiesBridge::invokeLongAndWait(env, obj, createMID());
}

/*^*****************************************************************************
  File History:

 - 2007-11-18 09:47:08 Slobodan
   Initial version

*****************************************************************************^*/
