/*
 * @(#)JQToolBarBridge.h  0.2.0 / 2007-11-07
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef JQTOOLBARBRIDGE_H
#define JQTOOLBARBRIDGE_H

#include "JavaQxQSwing.h"

#include "JQContainerBridge.h"

/*^**************************************************************************^*/
/*- JQToolBarBridge Class.                                                   -*/
/*^**************************************************************************^*/

/*!
 * \brief JQToolBar Bridge.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT JQToolBarBridge : public JQContainerBridge
{
  Q_OBJECT
protected:
  JQToolBarBridge(JNIEnv *env, jobject obj);
public slots: // native calls
  void setName(JNIEnv *env, jstring name);
  void insertChild(JNIEnv *env, jlong childBridge, jint index);
  void removeChild(JNIEnv *env, jlong childBridge);
  void setFloatable(JNIEnv *env, jboolean floatable);
  void setOrientation(JNIEnv *env, jint orientation);
  void setIconSize(JNIEnv *env, jint width, jint height);
public: // native calls
  static void initialize(JNIEnv *env, jclass cls);
  static jlong newInstance(JNIEnv *env, jobject obj);
public: // native callbacks
  void orientationChanged(jint orientation);
public:
  inline QToolBar *qToolBar() const;
protected slots:
  void orientationChangedSlot(Qt::Orientation orientation);
private:
  static jmethodID sm_orientationChangedMID;
};

/*^**************************************************************************^*/
/*- JQToolBarBridge :: Public Inline Member Function.                        -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns QToolBar adaptee.
 *
 * \return QToolBar adaptee
 */
inline QToolBar *JQToolBarBridge::qToolBar() const
{
  return static_cast<QToolBar *>(qObject());
}

/*^**************************************************************************^*/
/*- Macro Definitions.                                                       -*/
/*^**************************************************************************^*/

#define jqToolBarCast(bridge) (reinterpret_cast<JQToolBarBridge *>(bridge))
#define jqToolBarBridge jqToolBarCast(bridge)

#endif //JQTOOLBARBRIDGE_H

/*^*****************************************************************************
  File History:

 - 2007-11-07 16:06:14 Slobodan
   Initial version

*****************************************************************************^*/
