/*
 * @(#)JQToolButtonBridge.cpp  0.2.0 / 2007-11-12
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "JQToolButtonBridge.h"

#include "JQMenuBridge.h"

/*^**************************************************************************^*/
/*- JQToolButtonBridge :: Protected Constructor.                             -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new JQToolButtonBridge object.
 *
 * \param env the JNIEnv pointer
 * \param obj the JQToolButton object
 */
JQToolButtonBridge::JQToolButtonBridge(JNIEnv *env, jobject obj)
  : JQAbstractButtonBridge(env, obj, new QToolButton())
{
  qToolButton()->setAutoRaise(true);
  qToolButton()->setFocusPolicy(Qt::NoFocus);
}

/*^**************************************************************************^*/
/*- JQToolButtonBridge :: Native Calls.                                      -*/
/*^**************************************************************************^*/

/*!
 * \brief Sets menu.
 *
 * \param env the JNIEnv pointer
 * \param menuBridge the menu bridge pointer
 */
void JQToolButtonBridge::setMenu(JNIEnv *env, jlong menuBridge)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setMenu, QSWING_ENV_ARG, JLONG_ARG(menuBridge))
  if (menuBridge) {
    qToolButton()->setMenu(jqMenuCast(menuBridge)->qMenu());
  } else {
    qToolButton()->setMenu(0);
  }
}

/*!
 * \brief Sets popup mode.
 *
 * \param env the JNIEnv pointer
 * \param popupMode the popup mode
 */
void JQToolButtonBridge::setPopupMode(JNIEnv *env, jint popupMode)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setPopupMode, QSWING_ENV_ARG, JINT_ARG(popupMode))
  qToolButton()->setPopupMode(QToolButton::ToolButtonPopupMode(popupMode));
}

/*!
 * \brief Sets tool button style.
 *
 * \param env the JNIEnv pointer
 * \param toolButtonStyle the tool button style
 */
void JQToolButtonBridge::setToolButtonStyle(JNIEnv *env, jint toolButtonStyle)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setToolButtonStyle, QSWING_ENV_ARG,
                   JINT_ARG(toolButtonStyle))
  qToolButton()->setToolButtonStyle(Qt::ToolButtonStyle(toolButtonStyle));
}

/*^**************************************************************************^*/
/*- JQToolButtonBridge :: Static Native Calls.                               -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns new instance of the bridge object
 *
 * \param env the JNIEnv pointer
 * \param obj the QSwing object
 * 
 * \return new instance of the bridge object
 */
jlong JQToolButtonBridge::newInstance(JNIEnv *env, jobject obj)
{
  if (JNIQSwingWrapper::isQSwingThread(env)) {
    return reinterpret_cast<jlong>(new JQToolButtonBridge(env, obj));
  }
  return QSwingUtilitiesBridge::invokeLongAndWait(env, obj, createMID());
}

/*^*****************************************************************************
  File History:

 - 2007-11-12 10:36:16 Slobodan
   Initial version

*****************************************************************************^*/
