/*
 * @(#)JQTreeBridge.h  0.2.0 / 2007-12-17
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef JQTREEBRIDGE_H
#define JQTREEBRIDGE_H

#include "JavaQxQSwing.h"

#include "JQComponentBridge.h"
#include "QIconAdapter.h"
#include "QTreeViewAdapter.h"
#include "TreeModel.h"

/*^**************************************************************************^*/
/*- JQTreeBridge Class.                                                      -*/
/*^**************************************************************************^*/

/*!
 * \brief JQTree Bridge.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT JQTreeBridge : public JQComponentBridge
{
  Q_OBJECT
protected:
  JQTreeBridge(JNIEnv *env, jobject obj);
  virtual ~JQTreeBridge();
public: // native calls
  void createIcon(JNIEnv *env, jobject iconSet);
  void setUseModel(JNIEnv *env, jboolean useModel);
public: // native calls
  static void initialize(JNIEnv *env, jclass cls, jclass treeNodeClass);
  static jlong newInstance(JNIEnv *env, jobject obj);
public: // native callbacks
  jobject getRootNode();
  void nodeSelected(jobject node);
  jboolean setNodeIcon(jobject node);
public:
  QIcon *getNodeIcon(jobject node);
public:
  inline QTreeViewAdapter *qTreeView() const;
public:
  virtual jobject getBackground(JNIEnv *env, jclass colorClass);
  virtual void setBackground(JNIEnv *env, jint argb);
  virtual void setNullBackground(JNIEnv *env);
  virtual jint getCursor(JNIEnv *env);
  virtual void setCursor(JNIEnv *env, jint type);
protected slots:
  void selectionChangedSlot(const QItemSelection &selected,
                            const QItemSelection &deselected);
private:
  QIconAdapter *m_nodeIcon;
  TreeModel *m_treeModel;
  QItemSelectionModel *m_treeSelectionModel;
private:
  static jmethodID sm_getRootNodeMID;
  static jmethodID sm_setNodeIconMID;
  static jmethodID sm_nodeSelectedMID;
};

/*^**************************************************************************^*/
/*- JQTreeBridge :: Public Inline Member Function.                           -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns QTreeViewAdapter adaptee.
 *
 * \return QTreeViewAdapter adaptee
 */
inline QTreeViewAdapter *JQTreeBridge::qTreeView() const
{
  return static_cast<QTreeViewAdapter *>(qObject());
}

/*^**************************************************************************^*/
/*- Macro Definition.                                                        -*/
/*^**************************************************************************^*/

#define jqTreeBridge (reinterpret_cast<JQTreeBridge *>(bridge))

#endif //JQTREEBRIDGE_H

/*^*****************************************************************************
  File History:

 - 2007-12-17 14:20:21 Slobodan
   Initial version

*****************************************************************************^*/
