/*
 * @(#)JQWindowBridge.h  0.2.0 / 2007-10-31
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef JQWINDOWBRIDGE_H
#define JQWINDOWBRIDGE_H

#include "JavaQxQSwing.h"

#include <QList>

#include "JQContainerBridge.h"

/*^**************************************************************************^*/
/*- JQWindowBridge Class.                                                    -*/
/*^**************************************************************************^*/

/*!
 * \brief JQWindow Bridge.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT JQWindowBridge : public JQContainerBridge
{
  Q_OBJECT
protected:
  JQWindowBridge(JNIEnv *env, jobject obj, QWidget *widget);
  JQWindowBridge(JNIEnv *env, jobject obj);
  virtual ~JQWindowBridge();
public slots: // native calls
  void setWindowType(JNIEnv *env, jint windowType);
  void setTitle(JNIEnv *env, jstring title);
  void setIconImage(JNIEnv *env, jlong imagePointer);
  void setIconImage(JNIEnv *env, jbyteArray imageData, jint length);
  void setOpacity(JNIEnv *env, jdouble opacity);
  void setAcceptClose(JNIEnv *env, jboolean accept);
  void setModality(JNIEnv *env, jint modality);
  void setState(JNIEnv *env, jint state);
  void setAlwaysOnTop(JNIEnv *env, jboolean alwaysOnTop);
  void setLocationRelativeTo(JNIEnv *env, jlong windowBridge);
  void toFront(JNIEnv *env);
  void toBack(JNIEnv *env);
  void setBorderDecoration(JNIEnv *env, jint borderDecoration);
public: // native calls
  static void initialize(JNIEnv *env, jclass cls);
  static jboolean opacitySupported(JNIEnv *env, jclass cls);
  static jboolean alwaysOnTopSupported(JNIEnv *env, jclass cls);
  static jboolean fullScreenSupported(JNIEnv *env, jclass cls);
  static jboolean windowShapeSupported(JNIEnv *env, jclass cls);
  static jobjectArray getWindows(JNIEnv *env, jclass cls);
  static jobject getActiveWindow(JNIEnv *env, jclass cls);
  static void setWindowOwner(JNIEnv *env, jclass cls, jlong windowBridge,
                             jlong ownerBridge);
  static jlong newInstance(JNIEnv *env, jobject obj);
public: // native callbacks
  void windowOpened();
  void windowClosing();
  void windowClosed();
  void windowActivated();
  void windowDeactivated();
  void windowGainedFocus();
  void windowLostFocus();
  void windowStateChanged(jint oldState, jint newState);
public:
  virtual void showWindow(JNIEnv *env);
protected:
  jint converWindowState(Qt::WindowStates states);
protected:
  virtual bool filterEvent(QObject *obj, QEvent *e);
private:
  bool m_acceptClose;
private:
  static QList<JQWindowBridge *> sm_windows;
  static jclass sm_windowClass;
  static jmethodID sm_windowOpenedMID;
  static jmethodID sm_windowClosingMID;
  static jmethodID sm_windowClosedMID;
  static jmethodID sm_windowActivatedMID;
  static jmethodID sm_windowDeactivatedMID;
  static jmethodID sm_windowGainedFocusMID;
  static jmethodID sm_windowLostFocusMID;
  static jmethodID sm_windowStateChangedMID;
};

/*^**************************************************************************^*/
/*- Macro Definitions.                                                       -*/
/*^**************************************************************************^*/

#define jqWindowCast(bridge) (reinterpret_cast<JQWindowBridge *>(bridge))
#define jqWindowBridge jqWindowCast(bridge)

#endif //JQWINDOWBRIDGE_H

/*^*****************************************************************************
  File History:

 - 2007-10-31 17:36:22 Slobodan
   Initial version

*****************************************************************************^*/
