/*
 * @(#)PrinterBridge.h  0.2.0 / 2007-11-15
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef PRINTERBRIDGE_H
#define PRINTERBRIDGE_H

#include "JavaQxQSwing.h"

/*^**************************************************************************^*/
/*- PrinterBridge Class.                                                     -*/
/*^**************************************************************************^*/

/*!
 * \brief Printer Bridge.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT PrinterBridge : public QObject
{
  Q_OBJECT
protected:
  PrinterBridge(JNIEnv *env, jobject obj);
  virtual ~PrinterBridge();
public slots: // native calls
  void destroy(JNIEnv *env);
  void pageDialog(JNIEnv *env);
  jboolean printerDialog(JNIEnv *env);
public: // native calls
  static void initialize(JNIEnv *env, jclass cls);
  static jlong newInstance(JNIEnv *env, jobject obj);
public:
  inline QPrinter *qPrinter() const;
public:
  static QPrinter *toQPrinter(JNIEnv *env, jobject printer);
private:
  jweak m_wobjref;
  QPrinter *m_printer;
private:
  static jfieldID sm_bridgeFID;
  static jmethodID sm_createMID;
};

/*^**************************************************************************^*/
/*- TextDocumentBridge :: Inline Member Function.                            -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns QPrinter adaptee.
 *
 * \return QPrinter adaptee
 */
inline QPrinter *PrinterBridge::qPrinter() const
{
  return m_printer;
}

/*^**************************************************************************^*/
/*- Macro Definitions.                                                       -*/
/*^**************************************************************************^*/

#define printerCast(bridge) (reinterpret_cast<PrinterBridge *>(bridge))
#define printerBridge printerCast(bridge)

#endif //PRINTERBRIDGE_H

/*^*****************************************************************************
  File History:

 - 2007-11-15 08:27:12 Slobodan
   Initial version

*****************************************************************************^*/
