/*
 * @(#)QSwingBridge.h  0.2.0 / 2007-07-28
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef QSWINGBRIDGE_H
#define QSWINGBRIDGE_H

#include "JavaQxQSwing.h"

/*^**************************************************************************^*/
/*- QSwingBridge Class.                                                      -*/
/*^**************************************************************************^*/

/*!
 * \brief QSwing Bridge.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT QSwingBridge
{
public: // native calls
  static void initialize(JNIEnv *env, jclass cls, jobjectArray args,
                         jclass colorClass, jclass dimensionClass,
                         jclass rectangleClass, jclass fontClass,
                         jclass imageClass, jclass iconSetClass,
                         jclass runnableClass, jclass iteClass,
                         jclass systemColorPaletteClass,
                         jclass systemFontSetClass);
  static void dispose(JNIEnv *env, jclass cls);
  static jint exec(JNIEnv *env, jclass cls, jboolean quitOnLastWindowClosed);
  static void exit(JNIEnv *env, jclass cls, jint returnCode);
  static void flush(JNIEnv *env, jclass cls);
  static void disableNativeLogging(JNIEnv *env, jclass cls);
  static jboolean setTranslation(JNIEnv *env, jclass cls, jstring fileName);
  static void removeTranslation(JNIEnv *env, jclass cls);
  static jstring translate(JNIEnv *env, jclass cls, jstring context,
                           jstring sourceText);
  static jobjectArray availableStyles(JNIEnv *env, jclass systemStyleClass);
  static jboolean setStyle(JNIEnv *env, jclass cls, jstring name);
  static void setStyleSheet(JNIEnv *env, jclass cls, jstring styleSheetText);
  static void setOverrideCursor(JNIEnv *env, jclass cls, jint type);
  static void changeOverrideCursor(JNIEnv *env, jclass cls, jint type);
  static void restoreOverrideCursor(JNIEnv *env, jclass cls);
  static jobjectArray availableThemes(JNIEnv *env, jclass systemThemeClass);
  static void setTheme(JNIEnv *env, jclass cls, jobject colorPalette,
                       jobject fontSet);
  static void setUseSystemTheme(JNIEnv *env, jclass cls,
                                jboolean useSystemTheme);
  static void aboutQt(JNIEnv *env, jclass cls);
  static void aboutQSwing(JNIEnv *env, jclass cls);
  static void setCustomProperty(JNIEnv *env, jclass cls, jstring name,
                                jstring value);
  static ushort getQSwingKeyChar(QKeyEvent *e);
  static jint toQSwingModifiers(Qt::KeyboardModifiers modifiers);
  static Qt::KeyboardModifiers toKeyboardModifiers(int keyCode);
  static jint toQSwingButton(Qt::MouseButton button);
  static jint toQSwingKeyCode(int keyCode);
  static Qt::Alignment toHorizontalAlignment(jint alignment);
  static Qt::Alignment toVerticalAlignment(jint alignment);
public:
  inline static bool isDisposed();
private:
  static bool sm_disposed;
private:
  static const Qt::Alignment HORIZONTAL_ALIGNMENT[];
  static const Qt::Alignment VERTICAL_ALIGNMENT[];
};

/*^**************************************************************************^*/
/*- QSwingBridge :: Public Static Inline Member Function.                    -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns \c true if QSwingBridge is disposed.
 *
 * \return \c true if QSwingBridge is disposed
 */
inline bool QSwingBridge::isDisposed()
{
  return sm_disposed;
}

#endif //QSWINGBRIDGE_H

/*^*****************************************************************************
  File History:

 - 2007-07-28 11:43:10 JavaQx Native Generator
   Initial version

*****************************************************************************^*/
