/*
 * @(#)QSwingUtilitiesBridge.h  0.2.0 / 2007-07-28
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef QSWINGUTILITIESBRIDGE_H
#define QSWINGUTILITIESBRIDGE_H

#include "JavaQxCore.h"

/*^**************************************************************************^*/
/*- QSwingUtilitiesBridge Class.                                             -*/
/*^**************************************************************************^*/

/*!
 * \brief QSwingUtilities Bridge.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT QSwingUtilitiesBridge : public QObject
{
  Q_OBJECT
private:
  QSwingUtilitiesBridge();
  QSwingUtilitiesBridge(const QSwingUtilitiesBridge &);
  ~QSwingUtilitiesBridge();
public: // native calls
  static void invokeLater(JNIEnv *env, jclass cls, jobject target);
  static void invokeAndWait(JNIEnv *env, jclass cls, jobject target);
  static void invokeSafeAndWait(JNIEnv *env, jclass cls, jobject safeTarget);
public: // helper methods
  static void initialize(JNIEnv *env, jclass runnableClass, jclass iteClass);
  static jint invokeIntAndWait(JNIEnv *env, jobject obj, jmethodID mid, ...);
  static jlong invokeLongAndWait(JNIEnv *env, jobject obj, jmethodID mid, ...);
private:
  struct TargetFrame {
    jobject target;
    jthrowable exception;
  };
  struct MethodFrame {
    jobject obj;
    jmethodID mid;
    va_list args;
  };
  struct IntMethodFrame : MethodFrame {
    jint result;
  };
  struct LongMethodFrame : MethodFrame {
    jlong result;
  };
private:
  void invokeLater(jobject target);
  void invokeAndWait(TargetFrame *targetFrame);
  void invokeSafeAndWait(jobject safeTarget);
  void invokeIntAndWait(IntMethodFrame *methodFrame);
  void invokeLongAndWait(LongMethodFrame *methodFrame);
private slots:
  void invokeLaterSlot(jobject target);
  void invokeAndWaitSlot(TargetFrame *targetFrame);
  void invokeIntAndWaitSlot(IntMethodFrame *methodFrame);
  void invokeLongAndWaitSlot(LongMethodFrame *methodFrame);
signals:
  void invokeLaterSignal(jobject target);
  void invokeAndWaitSignal(TargetFrame *targetFrame);
  void invokeSafeAndWaitSignal(jobject safeTarget);
  void invokeIntAndWaitSignal(IntMethodFrame *methodFrame);
  void invokeLongAndWaitSignal(LongMethodFrame *methodFrame);
private:
  static jmethodID sm_runMID;
  static jmethodID sm_iteConstructorMID;
  static QSwingUtilitiesBridge *qSwingUtilitiesBridge;
};

#endif //QSWINGUTILITIESBRIDGE_H

/*^*****************************************************************************
  File History:

 - 2007-07-28 11:43:10 Slobodan
   Initial version

*****************************************************************************^*/
