/*
 * @(#)StyledDocumentBridge.cpp  0.2.0 / 2007-12-19
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "StyledDocumentBridge.h"

#include "StyledDocument.h"

/*^**************************************************************************^*/
/*- StyledDocumentBridge :: Protected Constructor.                           -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new StyledDocumentBridge object.
 *
 * \param env the JNIEnv pointer
 * \param obj the StyledDocument object
 */
StyledDocumentBridge::StyledDocumentBridge(JNIEnv *env, jobject obj)
  : TextDocumentBridge(env, obj, new StyledDocument(this))
{
  // empty constructor body
}

/*^**************************************************************************^*/
/*- StyledDocumentBridge :: Native Calls.                                    -*/
/*^**************************************************************************^*/

/*!
 * \brief Sets text wrap status. 
 *
 * \param env the JNIEnv pointer
 * \param wrapText if \c true the document will wrap the text
 */
void StyledDocumentBridge::setWordWrap(JNIEnv *env, jboolean wrapText)
{
  Q_ASSERT(env);
  QSWING_REENTRANT(setWordWrap, QSWING_ENV_ARG, JBOOLEAN_ARG(wrapText))
  // TODO: Implement
}

/*^**************************************************************************^*/
/*- StyledDocumentBridge :: Static Native Calls.                             -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns new instance of the bridge object
 *
 * \param env the JNIEnv pointer
 * \param obj the QSwing object
 * 
 * \return new instance of the bridge object
 */
jlong StyledDocumentBridge::newInstance(JNIEnv *env, jobject obj)
{
  if (JNIQSwingWrapper::isQSwingThread(env)) {
    return reinterpret_cast<jlong>(new StyledDocumentBridge(env, obj));
  }
  return QSwingUtilitiesBridge::invokeLongAndWait(env, obj, createMID());
}

/*^*****************************************************************************
  File History:

 - 2007-12-19 19:33:13 Slobodan
   Initial version

*****************************************************************************^*/
