/*
 * @(#)TextDocumentBridge.h  0.2.0 / 2007-12-11
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef TEXTDOCUMENTBRIDGE_H
#define TEXTDOCUMENTBRIDGE_H

#include "JavaQxQSwing.h"

#include "QObjectBridge.h"
#include "QTextDocumentAdapter.h"

/*^**************************************************************************^*/
/*- TextDocumentBridge Class.                                                -*/
/*^**************************************************************************^*/

/*!
 * \brief TextDocument Bridge.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT TextDocumentBridge : public QObjectBridge
{
  Q_OBJECT
protected:
  TextDocumentBridge(JNIEnv *env, jobject obj, QTextDocumentAdapter *document);
public slots: // native calls
  void clearText(JNIEnv *env);
  jstring getText(JNIEnv *env);
  void setText(JNIEnv *env, jstring text);
  void appendText(JNIEnv *env, jstring text);
  jboolean isUndoAvailable(JNIEnv *env);
  jboolean isRedoAvailable(JNIEnv *env);
  void undo(JNIEnv *env);
  void redo(JNIEnv *env);
  void setUndoRedoEnabled(JNIEnv *env, jboolean enabled);
  void setUndoRedoListening(JNIEnv *env, jboolean listening);
  jboolean isModified(JNIEnv *env);
  void setModified(JNIEnv *env, jboolean modified);
  void print(JNIEnv *env, jobject printer);
  void setUseHighlighter(JNIEnv *env, jboolean useHighlighter);
  void setFormat(JNIEnv *env, jint start, jint length, jobject format);
public: // native calls
  static void initialize(JNIEnv *env, jclass cls);
public: // native callbacks
  void undoAvailable(jboolean available);
  void redoAvailable(jboolean available);
  void highlightBlock(jint blockStart, jstring blockText);
public:
  inline QTextDocumentAdapter *qTextDocument() const;
public:
  static QTextDocumentAdapter *toQDocument(JNIEnv *env, jobject document);
public:
  virtual void destroy(JNIEnv *env);
protected:
  virtual jfieldID bridgePointerFID() const;
public slots:
  void undoAvailableSlot(bool available);
  void redoAvailableSlot(bool available);
protected:
  inline static jmethodID createMID();
private:
  static jfieldID sm_bridgeFID;
  static jmethodID sm_createMID;
  static jmethodID sm_undoAvailableMID;
  static jmethodID sm_redoAvailableMID;
  static jmethodID sm_highlightBlockMID;
};

/*^**************************************************************************^*/
/*- TextDocumentBridge :: Inline Member Function.                            -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns QTextDocumentAdapter adaptee.
 *
 * \return QTextDocumentAdapter adaptee
 */
inline QTextDocumentAdapter *TextDocumentBridge::qTextDocument() const
{
  return static_cast<QTextDocumentAdapter *>(qObject());
}

/*^**************************************************************************^*/
/*- TextDocumentBridge :: Protected Static Inline Member Function.           -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns createMID.
 *
 * \return createMID
 */
inline jmethodID TextDocumentBridge::createMID()
{
  return sm_createMID;
}

/*^**************************************************************************^*/
/*- Macro Definitions.                                                       -*/
/*^**************************************************************************^*/

#define textDocumentCast(bridge) \
    (reinterpret_cast<TextDocumentBridge *>(bridge))
#define textDocumentBridge textDocumentCast(bridge)

#endif //TEXTDOCUMENTBRIDGE_H

/*^*****************************************************************************
  File History:

 - 2007-12-11 21:49:59 Slobodan
   Initial version

*****************************************************************************^*/
