/*
 * @(#)WhatsThisManagerBridge.cpp  0.2.0 / 2007-12-01
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "WhatsThisManagerBridge.h"

#include "JQComponentBridge.h"

/*^**************************************************************************^*/
/*- WhatsThisManagerBridge :: Static Native Calls.                           -*/
/*^**************************************************************************^*/

/*!
 * \brief Enables/disables \c <what's this> help.
 *
 * \param env the JNIEnv pointer
 * \param cls the java class
 * \param enabled \c true if enabled
 */
void WhatsThisManagerBridge::setEnabled(JNIEnv *env, jclass cls,
                                        jboolean enabled)
{
  Q_UNUSED(env);
  Q_UNUSED(cls);
  sm_enabled = enabled;
}

/*!
 * \brief Displays \c <what's this> help for the specified component.
 *
 * \param env the JNIEnv pointer
 * \param cls the WhatsThisManager class
 * \param text the  what's this text
 * \param x the x-coordinate of the \c <what's this> help
 * \param y the y-coordinate of the \c <what's this> help
 * \param componentBridge the component bridge pointer
 */
void WhatsThisManagerBridge::showText(JNIEnv *env, jclass cls, jstring text,
                                      jint x, jint y, jlong componentBridge)
{
  Q_ASSERT(env);
  QSWING_STATIC_REENTRANT(WhatsThisManagerBridge, showText, QSWING_ENV_ARG,
                          JCLASS_ARG(cls), JSTRING_ARG(text), JINT_ARG(x),
                          JINT_ARG(y), JLONG_ARG(componentBridge))
  if (sm_enabled) {
    QWidget *widget = 0;
    if (componentBridge) {
      widget = jqComponentCast(componentBridge)->qWidget();
      QWhatsThis::showText(widget->mapToGlobal(QPoint(x, y)),
                           QSwingString(text), widget);
    } else {
      QWhatsThis::showText(QPoint(x, y), QSwingString(text));
    }
  }
}

/*!
 * \brief Hides \c <what's this> help.
 *
 * \param env the JNIEnv pointer
 * \param cls the WhatsThisManager class
 */
void WhatsThisManagerBridge::hideText(JNIEnv *env, jclass cls)
{
  Q_ASSERT(env);
  QSWING_STATIC_REENTRANT(WhatsThisManagerBridge, hideText, QSWING_ENV_ARG,
                          JCLASS_ARG(cls))
  QWhatsThis::hideText();
}

/*!
 * \brief Returns \c true if \c <what's this> help is active.
 *
 * \param env the JNIEnv pointer
 * \param cls the WhatsThisManager class
 * 
 * \return 
 */
jboolean WhatsThisManagerBridge::isInWhatsThisMode(JNIEnv *env, jclass cls)
{
  Q_ASSERT(env);
  QSWING_STATIC_REENTRANT_RETURN(WhatsThisManagerBridge, isInWhatsThisMode,
                                 jboolean, QSWING_ENV_ARG, JCLASS_ARG(cls))
  return QWhatsThis::inWhatsThisMode();
}

/*!
 * \brief Activates \c <what's this> help. 
 *
 * \param env the JNIEnv pointer
 * \param cls the WhatsThisManager class
 */
void WhatsThisManagerBridge::enterWhatsThisMode(JNIEnv *env, jclass cls)
{
  if (sm_enabled) {
    Q_ASSERT(env);
    QSWING_STATIC_REENTRANT(WhatsThisManagerBridge, enterWhatsThisMode,
                            QSWING_ENV_ARG, JCLASS_ARG(cls))
    QWhatsThis::enterWhatsThisMode();
  }
}

/*!
 * \brief Deactivates \c <what's this> help. 
 *
 * \param env the JNIEnv pointer
 * \param cls the java class
 */
void WhatsThisManagerBridge::exitWhatsThisMode(JNIEnv *env, jclass cls)
{
  if (sm_enabled) {
    Q_ASSERT(env);
    QSWING_STATIC_REENTRANT(WhatsThisManagerBridge, exitWhatsThisMode,
                            QSWING_ENV_ARG, JCLASS_ARG(cls))
    QWhatsThis::leaveWhatsThisMode();
  }
}

/*^**************************************************************************^*/
/*- JQToolTipBridge :: Private Static Data Member.                           -*/
/*^**************************************************************************^*/

bool WhatsThisManagerBridge::sm_enabled = true;

/*^*****************************************************************************
  File History:

 - 2007-12-01 17:32:37 Slobodan
   Initial version

*****************************************************************************^*/
