/*
 * @(#)WhatsThisManagerBridge.h  0.2.0 / 2007-12-01
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#ifndef WHATSTHISMANAGERBRIDGE_H
#define WHATSTHISMANAGERBRIDGE_H

#include "JavaQxQSwing.h"

/*^**************************************************************************^*/
/*- WhatsThisManagerBridge Class.                                            -*/
/*^**************************************************************************^*/

/*!
 * \brief WhatsThisManager Bridge.
 *
 * \author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * \version 0.2.0
 */
class JAVAQX_EXPORT WhatsThisManagerBridge
{
public: // native calls
  static void setEnabled(JNIEnv *env, jclass cls, jboolean enabled);
  static void showText(JNIEnv *env, jclass cls, jstring text, jint x, jint y,
                       jlong componentBridge);
  static void hideText(JNIEnv *env, jclass cls);
  static jboolean isInWhatsThisMode(JNIEnv *env, jclass cls);
  static void enterWhatsThisMode(JNIEnv *env, jclass cls);
  static void exitWhatsThisMode(JNIEnv *env, jclass cls);
public:
  inline static bool whatsThisEnabled();
private:
  static bool sm_enabled;
};

/*^**************************************************************************^*/
/*- WhatsThisManagerBridge :: Public Static Inline Member Function.          -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns \c true if the whatsThis help is enabled.
 *
 * \return \c true if the whatsThis help is enabled
 */
inline bool WhatsThisManagerBridge::whatsThisEnabled()
{
  return sm_enabled;
}

/*^**************************************************************************^*/
/*- Macro Definition.                                                        -*/
/*^**************************************************************************^*/

#define whatsThisManagerBridge \
    (reinterpret_cast<WhatsThisManagerBridge *>(bridge))

#endif //WHATSTHISMANAGERBRIDGE_H

/*^*****************************************************************************
  File History:

 - 2007-12-01 17:32:37 Slobodan
   Initial version

*****************************************************************************^*/
