/*
 * @(#)DimensionObject.cpp  0.2.0 / 2007-11-11
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include "DimensionObject.h"

#include "JNIQSwingWrapper.h"

/*^**************************************************************************^*/
/*- DimensionObject :: Public Constructor.                                   -*/
/*^**************************************************************************^*/

/*!
 * \brief Constructs new DimensionObject object.
 *
 * \param env the JNIEnv pointer
 * \param obj the QSwing Dimension object
 */
DimensionObject::DimensionObject(JNIEnv *env, jobject obj)
  : GlobalJObject(env, obj)
{
  Q_ASSERT(m_obj);
}

/*^**************************************************************************^*/
/*- DimensionObject :: Public Member Functions.                              -*/
/*^**************************************************************************^*/

/*!
 * \brief Returns width.
 *
 * \param result the result
 *
 * \return \c true if no exception is thrown
 */
bool DimensionObject::getWidth(jint &result)
{
  return JNIWrapper::callIntMethod(m_env, result, m_obj, sm_getWidthMID);
}

/*!
 * \brief Returns width.
 *
 * \param env the JNIEnv pointer
 * \param result the result
 *
 * \return \c true if no exception is thrown
 */
bool DimensionObject::getWidth(JNIEnv *env, jint &result)
{
  return JNIWrapper::callIntMethod(env, result, m_obj, sm_getWidthMID);
}

/*!
 * \brief Returns height.
 *
 * \param result the result
 *
 * \return \c true if no exception is thrown
 */
bool DimensionObject::getHeight(jint &result)
{
  return JNIWrapper::callIntMethod(m_env, result, m_obj, sm_getHeightMID);
}

/*!
 * \brief Returns height.
 *
 * \param env the JNIEnv pointer
 * \param result the result
 *
 * \return \c true if no exception is thrown
 */
bool DimensionObject::getHeight(JNIEnv *env, jint &result)
{
  return JNIWrapper::callIntMethod(env, result, m_obj, sm_getHeightMID);
}

/*^**************************************************************************^*/
/*- DimensionObject :: Public Static Member Function.                        -*/
/*^**************************************************************************^*/

/*!
 * \brief Initializes DimensionObject class.
 *
 * \param env the JNIEnv pointer
 * \param cls the QSwing Dimension class
 *
 * \exception FatalError if failed
 */
void DimensionObject::initialize(JNIEnv *env, jclass cls)
{
  Q_ASSERT(env);
  Q_ASSERT(cls);
  Q_ASSERT(!sm_dimensionClass);
  if (!INIT_CLASS(dimension, cls) ||
      !INIT_CONSTRUCTOR(constructor, cls, "(II)V") ||
      !INIT_MID(getWidth, cls, "()I") ||
      !INIT_MID(getHeight, cls, "()I")) {
    FATAL_LOGGED_ERROR("DimensionObject initialization failed");
  }
}

/*!
 * \brief Creates new QSwing dimension object.
 *
 * \param width the width
 * \param height the height
 * 
 * \return new instance of the QSwing dimension class
 */
jobject DimensionObject::newObject(jint width, jint height)
{
  return JNIQSwingWrapper::newObject(sm_dimensionClass, sm_constructorMID,
                                     width, height);
}

/*^**************************************************************************^*/
/*- DimensionObject :: Private Static Data Members.                          -*/
/*^**************************************************************************^*/

jclass DimensionObject::sm_dimensionClass = 0;
jmethodID DimensionObject::sm_constructorMID = 0;
jmethodID DimensionObject::sm_getWidthMID = 0;
jmethodID DimensionObject::sm_getHeightMID = 0;

/*^*****************************************************************************
  File History:

 - 2007-11-11 13:37:40 Slobodan
   Initial version

*****************************************************************************^*/
