/*
 * @(#)ExceptionTestCase.java  0.1.0 / 31.01.2007
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the Common Public License Version 1.0.
 * A copy of this license is included in the file LICENSE-CPL_V10.txt.
 */
package junit.extensions;

import junit.framework.TestCase;

/**
 * A TestCase that expects an Exception of the class.
 *
 * @author Erich Gamma
 * @author Kent Beck
 * @version 3.8.1 (original)
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.1.0 (lite)
 */
public class ExceptionTestCase extends TestCase {

/*^**************************************************************************^*/
/*- Private Field.                                                           -*/
/*^**************************************************************************^*/

  private final Class expectedException;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new ExceptionTestCase object.
   *
   * @param name the name
   * @param exception the expected exception
   */
  public ExceptionTestCase(String name, Class exception) {
    super(name);
    expectedException = exception;
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * Execute the test method expecting the specified exception or one of its
   * subclasses will be thrown.
   *
   * @throws Throwable on unexpected exception
   */
  protected void runTest() throws Throwable {
    try {
      super.runTest();
      fail("Expected exception " + expectedException); //$NON-NLS-1$
    } catch (Throwable t) {
      if (!expectedException.isAssignableFrom(t.getClass())) {
        throw t;
      }
    }
  }

}

/*^*****************************************************************************
  File History:

 - 31.08.2002 Erich Gamma and Kent Beck
   Original 3.8.1 version

 - 31.01.2007 01:49:30 Slobodan
   Initial lite version

*****************************************************************************^*/
