/*
 * @(#)RepeatedTest.java  0.1.0 / 31.01.2007
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the Common Public License Version 1.0.
 * A copy of this license is included in the file LICENSE-CPL_V10.txt.
 */
package junit.extensions;

import junit.framework.Test;
import junit.framework.TestResult;

/**
 * A Decorator that runs a test repeatedly.
 *
 * @author Erich Gamma
 * @author Kent Beck
 * @version 3.8.1 (original)
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.1.0 (lite)
 */
public class RepeatedTest extends TestDecorator { // NOPMD

/*^**************************************************************************^*/
/*- Private Field.                                                           -*/
/*^**************************************************************************^*/

  private final int repeatCount;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new RepeatedTest object.
   *
   * @param test the test
   * @param repeat the repeat count
   *
   * @throws IllegalArgumentException if repeat is less then 0
   */
  public RepeatedTest(Test test, int repeat) {
    super(test);
    if (repeat < 0) {
      throw new IllegalArgumentException(
                  "Repetition count must be > 0"); //$NON-NLS-1$
    }
    repeatCount = repeat;
  }

/*^**************************************************************************^*/
/*- Overridden Methods.                                                      -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public String toString() {
    return super.toString() + "(repeated)"; //$NON-NLS-1$
  }

  /**
   * {@inheritDoc}
   */
  public int countTestCases() {
    return super.countTestCases() * repeatCount;
  }

  /**
   * {@inheritDoc}
   */
  public void run(TestResult result) {
    for (int i = 0; i < repeatCount; i++) {
      if (result.shouldStop()) {
        break;
      }
      super.run(result);
    }
  }

}

/*^*****************************************************************************
  File History:

 - 31.08.2002 Erich Gamma and Kent Beck
   Original 3.8.1 version

 - 31.01.2007 01:09:51 Slobodan
   Initial lite version

*****************************************************************************^*/
