/*
 * @(#)TestDecorator.java  0.1.0 / 31.01.2007
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the Common Public License Version 1.0.
 * A copy of this license is included in the file LICENSE-CPL_V10.txt.
 */
package junit.extensions;

import junit.framework.Assert;
import junit.framework.Test;
import junit.framework.TestResult;

/**
 * A Decorator for Tests. Use TestDecorator as the base class for defining new
 * test decorators. Test decorator subclasses can be introduced to add behaviour
 * before or after a test is run.
 *
 * @author Erich Gamma
 * @author Kent Beck
 * @version 3.8.1 (original)
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.1.0 (lite)
 */
public class TestDecorator extends Assert implements Test {

/*^**************************************************************************^*/
/*- Protected Field.                                                         -*/
/*^**************************************************************************^*/

  protected Test fTest;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new TestDecorator object.
   *
   * @param test the test
   */
  public TestDecorator(Test test) {
    fTest = test;
  }

/*^**************************************************************************^*/
/*- Public Methods.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Returns the test.
   *
   * @return the test
   */
  public Test getTest() {
    return fTest;
  }

  /**
   * The basic run behaviour.
   *
   * @param result the test result
   */
  public void basicRun(TestResult result) {
    fTest.run(result);
  }

/*^**************************************************************************^*/
/*- Overridden Methods.                                                      -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public String toString() {
    return fTest.toString();
  }

  /**
   * {@inheritDoc}
   */
  public int countTestCases() {
    return fTest.countTestCases();
  }

  /**
   * {@inheritDoc}
   */
  public void run(TestResult result) {
    basicRun(result);
  }

}

/*^*****************************************************************************
  File History:

 - 31.08.2002 Erich Gamma and Kent Beck
   Original 3.8.1 version

 - 31.01.2007 01:04:49 Slobodan
   Initial lite version

*****************************************************************************^*/
