/*
 * @(#)TestSetup.java  0.1.0 / 31.01.2007
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the Common Public License Version 1.0.
 * A copy of this license is included in the file LICENSE-CPL_V10.txt.
 */
package junit.extensions;

import junit.framework.Protectable;
import junit.framework.Test;
import junit.framework.TestResult;

/**
 * A Decorator to set up and tear down additional fixture state. Subclass
 * TestSetup and insert it into your tests when you want to set up additional
 * state once before the tests are run.
 *
 * @author Erich Gamma
 * @author Kent Beck
 * @version 3.8.1 (original)
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.1.0 (lite)
 */
public class TestSetup extends TestDecorator {

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new TestSetup object.
   *
   * @param test the test
   */
  public TestSetup(Test test) {
    super(test);
  }

/*^**************************************************************************^*/
/*- Protected Methods.                                                       -*/
/*^**************************************************************************^*/

  /**
   * Sets up the fixture. Override to set up additional fixture state.
   *
   * @throws Exception if any exception is thrown
   */
  protected void setUp() throws Exception {
    // empty implementation
  }

  /**
   * Tears down the fixture. Override to tear down the additional fixture state.
   *
   * @throws Exception if any exception is thrown
   */
  protected void tearDown() throws Exception {
    // empty implementation
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public void run(TestResult result) {
    TestSetupProtectable tps = new TestSetupProtectable(this, result);
    tps.run();
  }

/*^**************************************************************************^*/
/*- Inner Class.                                                             -*/
/*^**************************************************************************^*/

  /**
   * Protectable TestSetup.
   */
  private static class TestSetupProtectable implements Protectable {
    private final TestSetup testSetup;
    private final TestResult result;
    public TestSetupProtectable(TestSetup testSetup, TestResult result) {
      this.testSetup = testSetup;
      this.result = result;
    }
    public void run() {
      result.runProtected(testSetup, this);
    }
    public void protect() throws Throwable  {
      testSetup.setUp();
      testSetup.basicRun(result);
      testSetup.tearDown();
    }
  }

}

/*^*****************************************************************************
  File History:

 - 31.08.2002 Erich Gamma and Kent Beck
   Original 3.8.1 version

 - 31.01.2007 01:21:11 Slobodan
   Initial lite version

*****************************************************************************^*/
