/*
 * @(#)ComparisonFailure.java  0.1.0 / 30.01.2007
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the Common Public License Version 1.0.
 * A copy of this license is included in the file LICENSE-CPL_V10.txt.
 */
package junit.framework;

/**
 * Thrown when an assert equals for Strings failed.
 * (Inspired by a patch from Alex Chaffee mailto:alex@purpletech.com)
 *
 * @author Erich Gamma
 * @author Kent Beck
 * @version 3.8.1 (original)
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.1.0 (lite)
 */
public class ComparisonFailure extends AssertionFailedError { // NOPMD

/*^**************************************************************************^*/
/*- Private Fields.                                                          -*/
/*^**************************************************************************^*/

  private final String expected;
  private final String actual;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs a comparison failure.
   *
   * @param message the identifying message or <tt>null</tt>
   * @param expected the expected string value
   * @param actual the actual string value
   */
  public ComparisonFailure(String message, String expected, String actual) {
    super(message);
    this.expected = expected;
    this.actual = actual;
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * Returns "..." in place of common prefix and "..." in place of common suffix
   * between expected and actual.
   *
   * @return "..." in place of common prefix and "..." in place of common suffix
   *         between expected and actual
   */
  public String getMessage() { // NOPMD
    /** @todo  Could be reimplemented */
    if (expected == null || actual == null) {
      return Assert.format(super.getMessage(), expected, actual);
    }
    int end = Math.min(expected.length(), actual.length());
    int i = 0;
    for (; i < end; i++) {
      if (expected.charAt(i) != actual.charAt(i)) {
        break;
      }
    }
    int j = expected.length() - 1;
    int k = actual.length() - 1;
    for (; k >= i && j >= i; k--, j--) {
      if (expected.charAt(j) != actual.charAt(k)) {
        break;
      }
    }
    String a;
    String e;
    // equal strings
    if (j < i && k < i) {
      e = expected;
      a = actual;
    } else {
      e = expected.substring(i, j + 1);
      a = actual.substring(i, k + 1);
      if (i <= end && i > 0) {
        e = "..." + e; // NOPMD
        a = "..." + a;
      }
      if (j < expected.length() - 1) {
        e = e + "...";
      }
      if (k < actual.length() - 1) {
        a = a + "...";
      }
    }
    return Assert.format(super.getMessage(), e, a);
  }
}

/*^*****************************************************************************
  File History:

 - 31.08.2002 Erich Gamma and Kent Beck
   Original 3.8.1 version

 - 30.01.2007 20:10:28 Slobodan
   Initial lite version

*****************************************************************************^*/
