/*
 * @(#)TestListener.java  0.1.0 / 30.01.2007
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the Common Public License Version 1.0.
 * A copy of this license is included in the file LICENSE-CPL_V10.txt.
 */
package junit.framework;

/**
 * Test progress listener.
 *
 * @author Erich Gamma
 * @author Kent Beck
 * @version 3.8.1 (original)
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.1.0 (lite)
 */
public interface TestListener {

  /**
   * Notifies listener that a test has started.
   *
   * @param test the test
   */
  public void startTest(Test test);

  /**
   * Notifies listener that a test has ended.
   *
   * @param test the test
   */
  public void endTest(Test test);

  /**
   * Notifies listener that an error has occurred.
   *
   * @param test the test
   * @param t the throwable
   */
  public void addError(Test test, Throwable t);

  /**
   * Notifies listener that a failure has occurred.
   *
   * @param test the test
   * @param afe the assertion failed error
   */
  public void addFailure(Test test, AssertionFailedError afe);

}

/*^*****************************************************************************
  File History:

 - 31.08.2002 Erich Gamma and Kent Beck
   Original 3.8.1 version

 - 30.01.2007 20:37:48 Slobodan
   Initial lite version

*****************************************************************************^*/
