/*
 * @(#)TestRunner.java  0.1.0 / 14.02.2007
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the Common Public License Version 1.0.
 * A copy of this license is included in the file LICENSE-CPL_V10.txt.
 */
package junit.textui;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;

import junit.framework.TestResult;
import junit.framework.TestSuite;

/**
 * Command line test runner.
 *
 * @author Erich Gamma
 * @author Kent Beck
 * @version 3.8.1 (original)
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.1.0 (lite)
 */
public final class TestRunner  {

/*^**************************************************************************^*/
/*- Private Static Final Field.                                              -*/
/*^**************************************************************************^*/

  private static final Class[] ZERO_ARRAY_CLASS = new Class[0];

/*^**************************************************************************^*/
/*- Private Constructor.                                                     -*/
/*^**************************************************************************^*/

 /**
  * Class has no instances.
  */
  private TestRunner() {
  }

/*^**************************************************************************^*/
/*- Private Methods.                                                         -*/
/*^**************************************************************************^*/

  private boolean run(String suiteClassName) throws TestSuiteException {
    TestSuite suite = createTestSuite(suiteClassName);
    ResultPrinter printer = new ResultPrinter();
    TestResult result = new TestResult();
    printer.beginTestSuite(suite);
    result.addListener(printer);
    long time = System.currentTimeMillis();
    suite.run(result);
    time = System.currentTimeMillis() - time;
    printer.endTest(result, time);
    return result.wasSuccessful();
  }

  private TestSuite createTestSuite(String suiteClassName)
                                                    throws TestSuiteException {
    Class testClass;
    try {
      testClass = Class.forName(suiteClassName);
    } catch (ClassNotFoundException cnfe) {
      throw new TestSuiteException("Class not found: " + //$NON-NLS-1$
                                   suiteClassName);
    } catch (Exception e) {
      throw new TestSuiteException("Error: " + e); //$NON-NLS-1$
    }
    Method suiteMethod;
    try {
      suiteMethod = testClass.getMethod("suite", //$NON-NLS-1$
                                        ZERO_ARRAY_CLASS);
    } catch (Exception e) {
      return new TestSuite(testClass);
    }
    if (!Modifier.isStatic(suiteMethod.getModifiers())) {
      throw new TestSuiteException("suite() is not static"); //$NON-NLS-1$
    }
    try {
      return (TestSuite)suiteMethod.invoke(null, ZERO_ARRAY_CLASS);
    } catch (InvocationTargetException ite) {
      throw new TestSuiteException("invoke suite() failed: " + //$NON-NLS-1$
                                   ite.getTargetException());
    } catch (IllegalAccessException iae) {
      throw new TestSuiteException("invoke suite() failed"); //$NON-NLS-1$
    }
  }

/*^**************************************************************************^*/
/*- Inner Class.                                                             -*/
/*^**************************************************************************^*/

  private static class TestSuiteException extends Exception {
    public TestSuiteException(String message) {
      super(message);
    }
  }

/*^**************************************************************************^*/
/*- Main Method.                                                             -*/
/*^**************************************************************************^*/

  /**
   * Runs specified test. Only args[0] can specify test.
   *
   * @param args the arguments
   */
  public static void main(String[] args) {
    if ((args != null) && (args.length == 1)) {
      TestRunner testRunner = new TestRunner();
      try {
        if (testRunner.run(args[0])) {
          System.exit(0);
        }
        System.exit(1);
      } catch (Throwable t) {
        System.err.println(t.getMessage()); // NOPMD
      }
    }
    System.exit(-1);
  }

}

/*^*****************************************************************************
  File History:

 - 31.08.2002 Erich Gamma and Kent Beck
   Original 3.8.1 version

 - 14.02.2007 19:30:34 Slobodan
   Initial version

*****************************************************************************^*/
