/*
 * @(#)NativeFileParts.java  0.2.0 / 2007-02-28
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.tools.ng;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Iterator;

/**
 * Native File Parts.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class NativeFileParts implements NativeFilePart {

/*^**************************************************************************^*/
/*- Private Field.                                                           -*/
/*^**************************************************************************^*/

  private final ArrayList parts;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new NativeFileParts object.
   */
  public NativeFileParts() {
    parts = new ArrayList();
  }

/*^**************************************************************************^*/
/*- Public Methods.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Adds native file part.
   *
   * @param part NativeFilePart
   */
  public void add(NativeFilePart part) {
    parts.add(part);
  }

  /**
   * Returns native file part at specified index.
   *
   * @param index the index
   *
   * @return native file part at specified index
   */
  public NativeFilePart get(int index) {
    return (NativeFilePart)parts.get(index);
  }

  /**
   * Removes native file part at specified index.
   *
   * @param index the index
   *
   * @return native file part at specified index
   */
  public NativeFilePart remove(int index) {
    return (NativeFilePart)parts.remove(index);
  }

  /**
   * Removes native file part.
   *
   * @param part the native file part
   *
   * @return <tt>true</tt> if the collection contained the specified part.
   */
  public boolean remove(NativeFilePart part) {
    return parts.remove(part);
  }

  /**
   * Returns the number of the parts.
   *
   * @return the number of the parts
   */
  public int size() {
    return parts.size();
  }

  /**
   * Returns iterator over the parts.
   *
   * @return iterator over the parts
   */
  public Iterator iterator() {
    return parts.iterator();
  }

/*^**************************************************************************^*/
/*- NativeFilePart Interface Implementation.                                 -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public void store(PrintWriter pw) throws IOException {
    ArrayList parts = this.parts;
    for (int i = 0; i < parts.size(); i++) {
      NativeFilePart nativeFilePart = (NativeFilePart)parts.get(i);
      nativeFilePart.store(pw);
    }
  }

}

/*^*****************************************************************************
  File History:

 - 2007-02-28 16:25:36 Slobodan
   Initial version

*****************************************************************************^*/
