/*
 * @(#)NativeGeneratorTask.java  0.2.0 / 2007-04-06
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.tools.ng;

import java.io.IOException;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;
import org.apache.tools.ant.types.Path;

import org.apache.tools.ant.launch.Launcher;

/**
 * Native Generator Ant Task.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class NativeGeneratorTask extends Task {

/*^**************************************************************************^*/
/*- Private Fields.                                                          -*/
/*^**************************************************************************^*/

  private boolean verbose;
  private Path srcDir;
  private String jniDir;
  private String bridgeDir;

/*^**************************************************************************^*/
/*- Public Methods.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Sets verbose mode.
   *
   * @param verbose the verbose
   */
  public void setVerbose(boolean verbose) {
    this.verbose = verbose;
  }

  /**
   * Sets source directory.
   *
   * @param srcDir the source directory
   */
  public void setSrcDir(Path srcDir) {
    if (this.srcDir == null) {
      this.srcDir = srcDir;
    } else {
      this.srcDir.append(srcDir);
    }
  }

  /**
   * Sets JNI direcotry.
   *
   * @param jniDir the JNI direcotry
   */
  public void setJniDir(String jniDir) {
    this.jniDir = jniDir;
  }

  /**
   * Sets Bridge direcotry.
   *
   * @param bridgeDir the Bridge direcotry
   */
  public void setBridgeDir(String bridgeDir) {
    this.bridgeDir = bridgeDir;
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public void execute() throws BuildException {
    if (srcDir == null) {
      throw new BuildException("Attribute srcDir is required"); //$NON-NLS-1$
    }
    if (jniDir == null) {
      throw new BuildException("Attribute jniDir is required"); //$NON-NLS-1$
    }
    NativeGenerator generator = NativeGenerator.getInstance();
    generator.setVerbose(verbose);
    String[] src = srcDir.list();
    for (int i = 0; i < src.length; i++) {
      generator.addSourceTree(getProject().resolveFile(src[i]));
    }
    generator.setJniFolder(getProject().resolveFile(jniDir));
    if (bridgeDir != null) {
      generator.setBridgeFolder(getProject().resolveFile(bridgeDir));
    }
    try {
      generator.generate();
    } catch (IOException ioe) {
      throw new BuildException(ioe);
    }
  }

/*^**************************************************************************^*/
/*- Main Method.                                                             -*/
/*^**************************************************************************^*/

  /**
   * Main test method.
   *
   * @param args the arguments
   */
  public static void main(String[] args) {
    Launcher.main(args);
  }

}

/*^*****************************************************************************
  File History:

 - 2007-04-06 11:58:56 Slobodan
   Initial version

*****************************************************************************^*/
