/*
 * @(#)JQBridge.java  0.2.0 / 2007-03-12
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.tools.ng.bridge;

import java.io.File;
import java.io.IOException;

import com.thoughtworks.qdox.model.JavaClass;

/**
 * JavaQx-Qt Bridge Generator.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class JQBridge {

/*^**************************************************************************^*/
/*- Private Fields.                                                          -*/
/*^**************************************************************************^*/

  private final JQBridgeHFile bridgeHFile;
  private final JQBridgeCppFile bridgeCppFile;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JQBridge object.
   *
   * @param bridgeFolder the bridge folder
   * @param javaClass  the qdox java class
   */
  public JQBridge(File bridgeFolder, JavaClass javaClass) {
    bridgeHFile = new JQBridgeHFile(bridgeFolder, javaClass);
    bridgeCppFile = new JQBridgeCppFile(bridgeFolder, javaClass);
  }

/*^**************************************************************************^*/
/*- Public Method.                                                           -*/
/*^**************************************************************************^*/

  /**
   * Loads bridge files.
   *
   * @throws IOException if any I/O exception occurred
   */
  public void load() throws IOException {
    bridgeHFile.load();
    bridgeCppFile.load();
  }

  /**
   * Stores bridge files.
   *
   * @throws IOException if any I/O exception occurred
   */
  public void store() throws IOException {
    bridgeHFile.store();
    bridgeCppFile.store();
  }

}

/*^*****************************************************************************
  File History:

 - 2007-03-12 11:26:30 Slobodan
   Initial version

*****************************************************************************^*/
