/*
 * @(#)JQBridgeClassImplementation.java  0.2.0 / 2007-03-13
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.tools.ng.bridge;

import java.io.IOException;
import java.io.PrintWriter;

import com.thoughtworks.qdox.model.JavaClass;
import com.thoughtworks.qdox.model.JavaMethod;

import yu.ac.bg.etf.javaqx.tools.ng.AbstractNativeFile;
import yu.ac.bg.etf.javaqx.tools.ng.NativeFileText;
import yu.ac.bg.etf.javaqx.tools.ng.Utils;

/**
 * Bridge Class Implementation.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
class JQBridgeClassImplementation extends NativeFileText {

/*^**************************************************************************^*/
/*- Private Field.                                                           -*/
/*^**************************************************************************^*/

  private final JavaClass javaClass;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JQBridgeClassImplementation object.
   *
   * @param nativeFile the native file
   * @param javaClass the qdox java class
   */
  public JQBridgeClassImplementation(AbstractNativeFile nativeFile,
                                     JavaClass javaClass) {
    super(nativeFile);
    this.javaClass = javaClass;
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected void storeContent(PrintWriter pw) throws IOException {
    storeIncludes(pw);
    storeJniCalls(pw);
    storeCallBacks(pw);
  }

/*^**************************************************************************^*/
/*- Private Methods.                                                         -*/
/*^**************************************************************************^*/

  private void storeIncludes(PrintWriter pw) throws IOException {
    pw.print("#include \""); //$NON-NLS-1$
    pw.print(Utils.getBridgeName(javaClass));
    pw.println(".h\""); //$NON-NLS-1$
    pw.println();
  }

  private void storeJniCalls(PrintWriter pw) throws IOException {
    String bridgeObjectName = Utils.getBridgeObjectName(javaClass);
    JavaMethod[] methods = javaClass.getMethods();
    boolean[] implementedMethods = new boolean[methods.length];
    for (int i = 0; i < methods.length; i++) {
      JavaMethod method = methods[i];
      if (method.isNative()) {
        String bridgeObject = Utils.getNativeTagParameter(method,
                                                 "bridgeObject"); //$NON-NLS-1$
        implementedMethods[i] =
            ((Utils.getNativeTagParameter(method,
                                          "code") != null) || //$NON-NLS-1$
             ((bridgeObject != null) &&
              !bridgeObjectName.equals(bridgeObject)));
      }
    }
    boolean labeled = false;
    for (int i = 0; i < methods.length; i++) {
      JavaMethod method = methods[i];
      if (!implementedMethods[i] && method.isNative() && !method.isStatic() &&
          "_create".equals(method.getName())) { //$NON-NLS-1$
        if (!labeled) {
          Utils.printBlockComment(pw, Utils.getBridgeName(javaClass) +
                                  " :: Protected Constructor."); //$NON-NLS-1$
          labeled = true;
        }
        pw.println(Utils.getBridgeConstructorComment(method));
        pw.println(Utils.getBridgeConstructorImplementation(method));
      }
    }
    labeled = false;
    for (int i = 0; i < methods.length; i++) {
      JavaMethod method = methods[i];
      if (!implementedMethods[i] && method.isNative() && !method.isStatic() &&
          !"_create".equals(method.getName())) { //$NON-NLS-1$
        if (!labeled) {
          Utils.printBlockComment(pw, Utils.getBridgeName(javaClass) +
                                  " :: Native Calls."); //$NON-NLS-1$
          labeled = true;
        }
        pw.println(Utils.getBridgeMethodComment(method));
        pw.println(Utils.getBridgeMethodImplementation(method));
      }
    }
    labeled = false;
    for (int i = 0; i < methods.length; i++) {
      JavaMethod method = methods[i];
      if (!implementedMethods[i] && method.isNative() && method.isStatic()) {
        if (!labeled) {
          Utils.printBlockComment(pw, Utils.getBridgeName(javaClass) +
                                  " :: Static Native Calls."); //$NON-NLS-1$
          labeled = true;
        }
        pw.println(Utils.getBridgeMethodComment(method));
        pw.println(Utils.getBridgeMethodImplementation(method));
      }
    }
    for (int i = 0; i < methods.length; i++) {
      JavaMethod method = methods[i];
      if (!implementedMethods[i] && method.isNative() && !method.isStatic() &&
          "_create".equals(method.getName())) {
        if (!labeled) {
          Utils.printBlockComment(pw, Utils.getBridgeName(javaClass) +
                                  " :: Static Native Calls."); //$NON-NLS-1$
          labeled = true;
        }
        pw.println(Utils.getNativeCallNewInstanceMethodComment(method));
        pw.println(Utils.getNativeCallNewInstanceMethodImplementation(method));
      }
    }
  }

  private void storeCallBacks(PrintWriter pw) throws IOException {
    JavaMethod[] methods = javaClass.getMethods();
    boolean labeled = false;
    for (int i = 0; i < methods.length; i++) {
      JavaMethod method = methods[i];
      String methodName = method.getName();
      if (!method.isNative() && (methodName.charAt(0) == '_') &&
          !"true".equals(Utils.getNativeTagParameter(method, //$NON-NLS-1$
                                                 "overridden"))) { //$NON-NLS-1$
        if (!labeled) {
          Utils.printBlockComment(pw, Utils.getBridgeName(javaClass) +
                                  " :: Native Callbacks."); //$NON-NLS-1$
          labeled = true;
        }
        pw.println(Utils.getBridgeMethodComment(method));
        pw.println(Utils.getCallbackMethodImplementation(method));
      }
    }
  }

}

/*^*****************************************************************************
  File History:

 - 2007-03-13 00:10:02 Slobodan
   Initial version

*****************************************************************************^*/
