/*
 * @(#)JQBridgeCppFile.java  0.2.0 / 2007-03-01
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.tools.ng.bridge;

import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;

import com.thoughtworks.qdox.model.JavaClass;

import yu.ac.bg.etf.javaqx.tools.ng.AbstractNativeFile;
import yu.ac.bg.etf.javaqx.tools.ng.NativeFileFooter;
import yu.ac.bg.etf.javaqx.tools.ng.NativeFileHeader;
import yu.ac.bg.etf.javaqx.tools.ng.NativeFileParts;
import yu.ac.bg.etf.javaqx.tools.ng.NativeFileText;
import yu.ac.bg.etf.javaqx.tools.ng.NativeGenerator;
import yu.ac.bg.etf.javaqx.tools.ng.Utils;

/**
 * Bridge Implementation File.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
class JQBridgeCppFile extends AbstractNativeFile {

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JQBridgeCppFile object.
   *
   * @param bridgeFolder the bridge folder
   * @param javaClass the qdox java class
   */
  public JQBridgeCppFile(File bridgeFolder, JavaClass javaClass) {
    super(bridgeFolder, Utils.getBridgeName(javaClass) + ".cpp", //$NON-NLS-1$
          javaClass, true);
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected NativeFileParts createParts() {
    NativeFileParts parts = new NativeFileParts();
    parts.add(new NativeFileHeader(this));
    parts.add(new JQBridgeClassImplementation(this, getJavaClass()));
    parts.add(new NativeFileFooter(this));
    return parts;
  }

  /**
   * {@inheritDoc}
   */
  protected NativeFileParts loadParts(BufferedReader br) throws IOException {
    NativeFileParts parts = new NativeFileParts();
    String bridgeName = Utils.getBridgeName(getJavaClass());
    StringBuffer sb = new StringBuffer(80);
    String line;
    int state = 0;
    while ((line = br.readLine()) != null) {
      if (line.startsWith("/*- " + bridgeName + //$NON-NLS-1$
                          " :: Native Calls")) { //$NON-NLS-1$
        state = 1;
      } else if (line.startsWith("/*- " + bridgeName + //$NON-NLS-1$
                                 " :: Static Native Calls")) { //$NON-NLS-1$
        state = 3;
      } else if (line.startsWith("/*- " + bridgeName + //$NON-NLS-1$
                                 " :: Native Callbacks")) { //$NON-NLS-1$
        state = 5;
      } else if (line.startsWith("/*^*")) { //$NON-NLS-1$
        switch (state) {
          case 0:
            parts.add(new NativeFileText(this, sb.toString()));
            sb.setLength(0);
            break;
          case 1:
            state = 2;
            break;
          case 2:
            parts.add(new NativeCallsImplementation(this, sb.toString(),
                                                    getJavaClass()));
            sb.setLength(0);
            break;
          case 3:
            state = 4;
            break;
          case 4:
            parts.add(new NativeCallsImplementation(this, sb.toString(),
                                                    getJavaClass()));
            sb.setLength(0);
            break;
          case 5:
            state = 6;
            break;
          case 6:
            parts.add(new NativeCallbacksImplementation(this, sb.toString(),
                                                        getJavaClass()));
            state = 7;
            sb.setLength(0);
            break;
        }
      }
      sb.append(line);
      sb.append(NativeGenerator.getInstance().getNewLine());
    }
    parts.add(new NativeFileText(this, sb.toString()));
    return parts;
  }

}

/*^*****************************************************************************
  File History:

 - 2007-03-01 10:16:48 Slobodan
   Initial version

*****************************************************************************^*/
