/*
 * @(#)JQBridgeHFile.java  0.2.0 / 2007-03-01
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.tools.ng.bridge;

import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;

import com.thoughtworks.qdox.model.JavaClass;

import yu.ac.bg.etf.javaqx.tools.ng.AbstractNativeFile;
import yu.ac.bg.etf.javaqx.tools.ng.NativeFileFooter;
import yu.ac.bg.etf.javaqx.tools.ng.NativeFileHeader;
import yu.ac.bg.etf.javaqx.tools.ng.NativeFileParts;
import yu.ac.bg.etf.javaqx.tools.ng.NativeFileText;
import yu.ac.bg.etf.javaqx.tools.ng.NativeGenerator;
import yu.ac.bg.etf.javaqx.tools.ng.Utils;

/**
 * Bridge Header File.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
class JQBridgeHFile extends AbstractNativeFile {

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JQBridgeHFile object.
   *
   * @param bridgeFolder the bridge folder
   * @param javaClass the qdox java class
   */
  public JQBridgeHFile(File bridgeFolder, JavaClass javaClass) {
    super(bridgeFolder, Utils.getBridgeName(javaClass) + ".h", //$NON-NLS-1$
          javaClass, true);
  }

/*^**************************************************************************^*/
/*- Overridden Methods.                                                      -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected NativeFileParts createParts() {
    NativeFileParts parts = new NativeFileParts();
    parts.add(new NativeFileHeader(this));
    parts.add(new JQBridgeHFileStart(this, getJavaClass()));
    parts.add(new JQBridgeClassDeclaration(this, getJavaClass()));
    parts.add(new JQBridgeHFileEnd(this, getJavaClass()));
    parts.add(new NativeFileFooter(this));
    return parts;
  }

  /**
   * {@inheritDoc}
   */
  protected NativeFileParts loadParts(BufferedReader br) throws IOException {
    NativeFileParts parts = new NativeFileParts();
    String newLine = NativeGenerator.getInstance().getNewLine();
    StringBuffer sb = new StringBuffer(80);
    String line;
    int state = 0;
    while ((line = br.readLine()) != null) {
      if (line.endsWith("// native calls")) { //$NON-NLS-1$
        switch (state) {
          case 0:
            parts.add(new NativeFileText(this, sb.toString()));
            break;
          case 1:
            parts.add(new NativeCallsDeclaration(this, sb.toString(),
                                                 getJavaClass()));
            break;
          case 2:
            parts.add(new NativeCallbacksDeclaration(this, sb.toString(),
                                                     getJavaClass()));
            break;
        }
        state = 1;
        sb.setLength(0);
      } else if (line.endsWith("// native callbacks")) { //$NON-NLS-1$
        switch (state) {
          case 0:
            parts.add(new NativeFileText(this, sb.toString()));
            break;
          case 1:
            parts.add(new NativeCallsDeclaration(this, sb.toString(),
                                                 getJavaClass()));
            break;
          case 2:
            parts.add(new NativeCallbacksDeclaration(this, sb.toString(),
                                                     getJavaClass()));
            break;
        }
        state = 2;
        sb.setLength(0);
      } else if ((line.length() > 0) && (line.charAt(0) != ' ') &&
                 (line.charAt(0) != '/')) {
        switch (state) {
          case 1:
            parts.add(new NativeCallsDeclaration(this, sb.toString(),
                                                 getJavaClass()));
            state = 0;
            sb.setLength(0);
            break;
          case 2:
            parts.add(new NativeCallbacksDeclaration(this, sb.toString(),
                                                     getJavaClass()));
            state = 0;
            sb.setLength(0);
            break;
        }
      }
      sb.append(line);
      sb.append(newLine);
    }
    parts.add(new NativeFileText(this, sb.toString()));
    return parts;
  }

}

/*^*****************************************************************************
  File History:

 - 2007-03-01 10:16:58 Slobodan
   Initial version

*****************************************************************************^*/
