/*
 * @(#)NativeCallbacksDeclaration.java  0.2.0 / 2007-07-08
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.tools.ng.bridge;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;

import com.thoughtworks.qdox.model.JavaClass;
import com.thoughtworks.qdox.model.JavaMethod;

import yu.ac.bg.etf.javaqx.tools.ng.AbstractNativeFile;
import yu.ac.bg.etf.javaqx.tools.ng.NativeGenerator;
import yu.ac.bg.etf.javaqx.tools.ng.Utils;

/**
 * Native Callbacks Declaration.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
class NativeCallbacksDeclaration extends NativeDeclarationBlock {

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new NativeCallbacksDeclaration object.
   *
   * @param nativeFile the abstract native file
   * @param text the text
   * @param javaClass the java class
   */
  public NativeCallbacksDeclaration(AbstractNativeFile nativeFile, String text,
                                    JavaClass javaClass) {
    super(nativeFile, text, javaClass);
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public void store(PrintWriter pw) throws IOException {
    pw.println("public: // native callbacks"); //$NON-NLS-1$
    ArrayList textMethods = getMethodDeclarationsFromText();
    JavaMethod[] methods = getJavaClass().getMethods();
    for (int i = 0; i < methods.length; i++) {
      JavaMethod method = methods[i];
      if (!method.isNative() && !method.isAbstract() &&
          method.getName().startsWith("_")) { //$NON-NLS-1$
        String methodDeclaration = Utils.getCallbackMethodDeclaration(method);
        int mdi = textMethods.indexOf(methodDeclaration);
        if (mdi >= 0) {
          textMethods.remove(mdi);
        }
        pw.println(methodDeclaration);
      }
    }
    for (int i = 0; i < textMethods.size(); i++) {
      String methodText = (String)textMethods.get(i);
      if (methodText.startsWith("  ")) { //$NON-NLS-1$
        String newLine = NativeGenerator.getInstance().getNewLine();
        methodText = methodText.replaceAll(newLine,
                                           newLine + "//"); //$NON-NLS-1$
        pw.print("//"); //$NON-NLS-1$
      }
      pw.println(methodText);
    }
  }

}

/*^*****************************************************************************
  File History:

 - 2007-07-08 11:57:34 Slobodan
   Initial version

*****************************************************************************^*/
