/*
 * @(#)NativeCallbacksImplementation.java  0.2.0 / 2007-07-20
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.tools.ng.bridge;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;

import com.thoughtworks.qdox.model.JavaClass;
import com.thoughtworks.qdox.model.JavaMethod;

import yu.ac.bg.etf.javaqx.tools.ng.AbstractNativeFile;
import yu.ac.bg.etf.javaqx.tools.ng.NativeGenerator;
import yu.ac.bg.etf.javaqx.tools.ng.Utils;

/**
 * Native Callbacks Implementation.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
class NativeCallbacksImplementation extends NativeImplementationBlock {

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new NativeCallbacksDeclaration object.
   *
   * @param nativeFile the abstract native file
   * @param text the text
   * @param javaClass the java class
   */
  public NativeCallbacksImplementation(AbstractNativeFile nativeFile,
                                       String text, JavaClass javaClass) {
    super(nativeFile, text, javaClass);
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public void store(PrintWriter pw) throws IOException {
    //super.store(pw);
    String bridgeObjectName = Utils.getBridgeObjectName(getJavaClass());
    ArrayList textMethods = getMethodImplementationsFromText();
    JavaMethod[] methods = getJavaClass().getMethods();
    boolean[] overriddenMethods = new boolean[methods.length];
    boolean labeled = false;
    for (int i = 0; i < methods.length; i++) {
      JavaMethod method = methods[i];
      overriddenMethods[i] = (!method.isNative() && !method.isAbstract() &&
                              (method.getName().charAt(0) == '_') &&
                              !"true".equals( //$NON-NLS-1$
                              Utils.getNativeTagParameter(method,
                                                 "overridden")));//$NON-NLS-1$
    }
    for (int i = 0; i < methods.length; i++) {
      JavaMethod method = methods[i];
      if (overriddenMethods[i]) {
        if (!labeled) {
          Utils.printBlockComment(pw, Utils.getBridgeName(getJavaClass()) +
                                  " :: Native Callbacks."); //$NON-NLS-1$
          labeled = true;
        }
        String methodImplementation =
                                 Utils.getCallbackMethodImplementation(method);
        int mdi = Utils.getMethodImplementationIndex(textMethods,
                                                     methodImplementation);
        if (mdi < 0) {
          pw.println(Utils.getBridgeMethodComment(method));
          pw.println(methodImplementation);
        } else {
          pw.println(textMethods.get(mdi));
          textMethods.remove(mdi);
        }
      }
    }
    String newLine = NativeGenerator.getInstance().getNewLine();
    String methodStart = " */" + newLine; //$NON-NLS-1$
    int methodStartLength = methodStart.length();
    String methodEnd = newLine + "}"; //$NON-NLS-1$
    int methodEndLength = methodEnd.length();
    for (int i = 0; i < textMethods.size(); i++) {
      StringBuffer methodText = new StringBuffer((String)textMethods.get(i));
      int startIndex = methodText.indexOf(methodStart);
      int endIndex = methodText.indexOf(methodEnd);
      if (methodText.charAt(startIndex + methodStartLength) == '/') {
        pw.println(methodText);
      } else {
        methodText = methodText.insert(endIndex + methodEndLength,
                                       "*/"); //$NON-NLS-1$
        methodText = methodText.insert(startIndex + methodStartLength,
                                       "/*"); //$NON-NLS-1$
        pw.println(methodText);
      }
    }
  }

}

/*^*****************************************************************************
  File History:

 - 2007-07-20 12:22:12 Slobodan
   Initial version

*****************************************************************************^*/
