/*
 * @(#)NativeCallsDeclaration.java  0.2.0 / 2007-07-08
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.tools.ng.bridge;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;

import com.thoughtworks.qdox.model.JavaClass;
import com.thoughtworks.qdox.model.JavaMethod;

import yu.ac.bg.etf.javaqx.tools.ng.AbstractNativeFile;
import yu.ac.bg.etf.javaqx.tools.ng.NativeGenerator;
import yu.ac.bg.etf.javaqx.tools.ng.Utils;

/**
 * Native Calls Declaration.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
class NativeCallsDeclaration extends NativeDeclarationBlock {

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new NativeCallsDeclaration object.
   *
   * @param nativeFile the abstract native file
   * @param text the text
   * @param javaClass the java class
   */
  public NativeCallsDeclaration(AbstractNativeFile nativeFile, String text,
                                JavaClass javaClass) {
    super(nativeFile, text, javaClass);
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public void store(PrintWriter pw) throws IOException {
    String bridgeObjectName = Utils.getBridgeObjectName(getJavaClass());
    ArrayList textMethods = getMethodDeclarationsFromText();
    JavaMethod[] methods = getJavaClass().getMethods();
    boolean[] implementedMethods = new boolean[methods.length];
    for (int i = 0; i < methods.length; i++) {
      JavaMethod method = methods[i];
      if (method.isNative()) {
        String bridgeObject = Utils.getNativeTagParameter(method,
                                                 "bridgeObject"); //$NON-NLS-1$
        implementedMethods[i] =
            ((Utils.getNativeTagParameter(method,
                                          "code") != null) || //$NON-NLS-1$
             ((bridgeObject != null) &&
              !bridgeObjectName.equals(bridgeObject)));
      }
    }
    if (getText().indexOf(" static ") >= 0) { // $NON-NLS-1$
      pw.println("public: // native calls"); //$NON-NLS-1$
      for (int i = 0; i < methods.length; i++) {
        JavaMethod method = methods[i];
        if (!implementedMethods[i] && method.isNative() && method.isStatic()) {
          String methodDeclaration =
                          Utils.getNativeCallStaticMethodDeclaration(method);
          int mdi = textMethods.indexOf(methodDeclaration);
          if (mdi >= 0) {
            textMethods.remove(mdi);
          }
          pw.println(methodDeclaration);
        }
      }
      for (int i = 0; i < methods.length; i++) {
        JavaMethod method = methods[i];
        if (!implementedMethods[i] && method.isNative() && !method.isStatic() &&
            "_create".equals(method.getName())) { //$NON-NLS-1$
          String methodDeclaration =
                     Utils.getNativeCallNewInstanceMethodDeclaration(method);
          int mdi = textMethods.indexOf(methodDeclaration);
          if (mdi >= 0) {
            textMethods.remove(mdi);
          }
          pw.println(methodDeclaration);
        }
      }
    } else {
      String bridgeConstructorName = "  " + //$NON-NLS-1$
                                     Utils.getBridgeName(getJavaClass()) +
                                     "("; //$NON-NLS-1$
      if (getText().indexOf(bridgeConstructorName) >= 0) {
        pw.println("protected:"); //$NON-NLS-1$
        for (int i = 0; i < methods.length; i++) {
          JavaMethod method = methods[i];
          if (!implementedMethods[i] && method.isNative() &&
              !method.isStatic() &&
              "_create".equals(method.getName())) { //$NON-NLS-1$
            String methodDeclaration = Utils.
                                        getBridgeConstructorDeclaration(method);
            int mdi = textMethods.indexOf(methodDeclaration);
            if (mdi >= 0) {
              textMethods.remove(mdi);
            }
            pw.println(methodDeclaration);
          }
        }
      } else {
        if (getText().startsWith("public: // native calls")) { // $NON-NLS-1$
          pw.println("public: // native calls"); //$NON-NLS-1$
          for (int i = 0; i < methods.length; i++) {
            JavaMethod method = methods[i];
            if (!implementedMethods[i] && method.isNative() &&
                !method.isStatic() &&
                !"_create".equals(method.getName())) { //$NON-NLS-1$
              String methodDeclaration =
                                  Utils.getNativeCallMethodDeclaration(method);
              int mdi = textMethods.indexOf(methodDeclaration);
              if (mdi >= 0) {
                textMethods.remove(mdi);
              }
              pw.println(methodDeclaration);
            }
          }
        } else {
          pw.println("public slots: // native calls"); //$NON-NLS-1$
          for (int i = 0; i < methods.length; i++) {
            JavaMethod method = methods[i];
            if (!implementedMethods[i] && method.isNative() &&
                !method.isStatic() &&
                !"_create".equals(method.getName())) { //$NON-NLS-1$
              String methodDeclaration =
                                  Utils.getNativeCallMethodDeclaration(method);
              int mdi = textMethods.indexOf(methodDeclaration);
              if (mdi >= 0) {
                textMethods.remove(mdi);
              }
              pw.println(methodDeclaration);
            }
          }
        }
      }
    }
    String newLine = NativeGenerator.getInstance().getNewLine();
    String newLineComment =  newLine + "//"; //$NON-NLS-1$
    for (int i = 0; i < textMethods.size(); i++) {
      String methodText = (String)textMethods.get(i);
      if (methodText.startsWith("  ")) { //$NON-NLS-1$
        methodText = methodText.replaceAll(newLine, newLineComment);
        pw.print("//"); //$NON-NLS-1$
      }
      pw.println(methodText);
    }
  }

}

/*^*****************************************************************************
  File History:

 - 2007-07-08 11:54:04 Slobodan
   Initial version

*****************************************************************************^*/
