/*
 * @(#)NativeCallsImplementation.java  0.2.0 / 2007-07-20
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.tools.ng.bridge;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;

import com.thoughtworks.qdox.model.JavaClass;
import com.thoughtworks.qdox.model.JavaMethod;

import yu.ac.bg.etf.javaqx.tools.ng.AbstractNativeFile;
import yu.ac.bg.etf.javaqx.tools.ng.NativeGenerator;
import yu.ac.bg.etf.javaqx.tools.ng.Utils;

/**
 * Native Calls Implementation.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
class NativeCallsImplementation extends NativeImplementationBlock {

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new NativeCallsImplementation object.
   *
   * @param nativeFile the abstract native file
   * @param text the text
   * @param javaClass the java class
   */
  public NativeCallsImplementation(AbstractNativeFile nativeFile, String text,
                                   JavaClass javaClass) {
    super(nativeFile, text, javaClass);
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public void store(PrintWriter pw) throws IOException {
    String bridgeObjectName = Utils.getBridgeObjectName(getJavaClass());
    ArrayList textMethods = getMethodImplementationsFromText();
    JavaMethod[] methods = getJavaClass().getMethods();
    boolean[] implementedMethods = new boolean[methods.length];
    for (int i = 0; i < methods.length; i++) {
      JavaMethod method = methods[i];
      if (method.isNative()) {
        String bridgeObject = Utils.getNativeTagParameter(method,
                                                 "bridgeObject"); //$NON-NLS-1$
        implementedMethods[i] =
            ((Utils.getNativeTagParameter(method,
                                          "code") != null) || //$NON-NLS-1$
             ((bridgeObject != null) &&
              !bridgeObjectName.equals(bridgeObject)));
      }
    }
    if (getText().indexOf(" :: Static Native Calls") >= 0) { // $NON-NLS-1$
      Utils.printBlockComment(pw, Utils.getBridgeName(getJavaClass()) +
                              " :: Static Native Calls."); //$NON-NLS-1$
      for (int i = 0; i < methods.length; i++) {
        JavaMethod method = methods[i];
        if (!implementedMethods[i] && method.isNative() && method.isStatic()) {
          String methodImplementation =
                                 Utils.getBridgeMethodImplementation(method);
          int mdi = Utils.getMethodImplementationIndex(textMethods,
                                                       methodImplementation);
          if (mdi < 0) {
            pw.println(Utils.getBridgeMethodComment(method));
            pw.println(methodImplementation);
          } else {
            pw.println(textMethods.get(mdi));
            textMethods.remove(mdi);
          }
        }
      }
      for (int i = 0; i < methods.length; i++) {
        JavaMethod method = methods[i];
        if (!implementedMethods[i] && method.isNative() && !method.isStatic() &&
            "_create".equals(method.getName())) { //$NON-NLS-1$
          String methodImplementation =
                  Utils.getNativeCallNewInstanceMethodImplementation(method);
          int mdi = Utils.getMethodImplementationIndex(textMethods,
                                                       methodImplementation);
          if (mdi < 0) {
            pw.println(Utils.getBridgeMethodComment(method));
            pw.println(methodImplementation);
          } else {
            pw.println(textMethods.get(mdi));
            textMethods.remove(mdi);
          }
        }
      }
    } else {
      Utils.printBlockComment(pw, Utils.getBridgeName(getJavaClass()) +
                              " :: Native Calls."); //$NON-NLS-1$
      for (int i = 0; i < methods.length; i++) {
        JavaMethod method = methods[i];
        if (!implementedMethods[i] && method.isNative() && !method.isStatic() &&
            !"_create".equals(method.getName())) {
          String methodImplementation =
                                    Utils.getBridgeMethodImplementation(method);
          int mdi = Utils.getMethodImplementationIndex(textMethods,
                                                       methodImplementation);
          if (mdi < 0) {
            pw.println(Utils.getBridgeMethodComment(method));
            pw.println(methodImplementation);
          } else {
            pw.println(textMethods.get(mdi));
            textMethods.remove(mdi);
          }
        }
      }
    }
    String newLine = NativeGenerator.getInstance().getNewLine();
    String methodStart = " */" + newLine; //$NON-NLS-1$
    int methodStartLength = methodStart.length();
    String methodEnd = newLine + "}"; //$NON-NLS-1$
    int methodEndLength = methodEnd.length();
    for (int i = 0; i < textMethods.size(); i++) {
      StringBuffer methodText = new StringBuffer((String)textMethods.get(i));
      int startIndex = methodText.indexOf(methodStart);
      int endIndex = methodText.indexOf(methodEnd);
      if (methodText.charAt(startIndex + methodStartLength) == '/') {
        pw.println(methodText);
      } else {
        methodText = methodText.insert(endIndex + methodEndLength,
                                       "*/"); //$NON-NLS-1$
        methodText = methodText.insert(startIndex + methodStartLength,
                                       "/*"); //$NON-NLS-1$
        pw.println(methodText);
      }
    }
  }

}

/*^*****************************************************************************
  File History:

 - 2007-07-20 12:26:54 Slobodan
   Initial version

*****************************************************************************^*/
