/*
 * @(#)NativeDeclarationBlock.java  0.2.0 / 2007-07-12
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.tools.ng.bridge;

import java.util.ArrayList;

import com.thoughtworks.qdox.model.JavaClass;

import yu.ac.bg.etf.javaqx.tools.ng.AbstractNativeFile;
import yu.ac.bg.etf.javaqx.tools.ng.NativeFileText;
import yu.ac.bg.etf.javaqx.tools.ng.NativeGenerator;

/**
 * Native Declaration Block.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
class NativeDeclarationBlock extends NativeFileText {

/*^**************************************************************************^*/
/*- Private Field.                                                           -*/
/*^**************************************************************************^*/

  private final JavaClass javaClass;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new NativeDeclarationBlock object.
   *
   * @param nativeFile the abstract native file
   * @param text the text
   * @param javaClass the java class
   */
  public NativeDeclarationBlock(AbstractNativeFile nativeFile, String text,
                                JavaClass javaClass) {
    super(nativeFile, text);
    this.javaClass = javaClass;
  }

/*^**************************************************************************^*/
/*- Protected Methods.                                                       -*/
/*^**************************************************************************^*/

  /**
   * Returns JavaClass object.
   *
   * @return JavaClass object
   */
  protected JavaClass getJavaClass() {
    return javaClass;
  }

  /**
   * Returns method declarations form text.
   *
   * @return method declarations form text
   */
  protected ArrayList getMethodDeclarationsFromText() {
    String text = getText();
    ArrayList list = new ArrayList();
    if (text != null) {
      int i = 0;
      int methodStart = 0;
      int state = 0;
      String newLine = NativeGenerator.getInstance().getNewLine();
      int newLineLength = newLine.length();
      char newLineLastChar = newLine.charAt(newLineLength - 1);
      int textLength = text.length();
      while (i < textLength) {
        char c = text.charAt(i);
        switch (state) {
          case 0:
            if (c == newLineLastChar) {
              state = 1;
              i++;
              methodStart = i;
            } else {
              i++;
            }
            break;
          case 1:
            if (c == ';') {
              state = 2;
            } else if (c == '/') {
              state = 3;
            }
            i++;
            break;
          case 2:
            list.add(text.substring(methodStart, i));
            i += newLineLength;
            methodStart = i;
            state = 1;
            break;
          case 3:
            if (c == newLineLastChar) {
              list.add(text.substring(methodStart, i - 1));
              i++;
              methodStart = i;
              state = 1;
            } else {
              i++;
            }
            break;
        }
      }
    }
    return list;
  }

}

/*^*****************************************************************************
  File History:

 - 2007-07-12 10:37:19 Slobodan
   Initial version

*****************************************************************************^*/
