/*
 * @(#)JniCppFile.java  0.2.0 / 2007-03-01
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.tools.ng.jni;

import java.io.File;
import java.util.HashMap;

import com.thoughtworks.qdox.model.JavaClass;
import com.thoughtworks.qdox.model.JavaMethod;

import yu.ac.bg.etf.javaqx.tools.ng.AbstractNativeFile;
import yu.ac.bg.etf.javaqx.tools.ng.NativeFileFooter;
import yu.ac.bg.etf.javaqx.tools.ng.NativeFileHeader;
import yu.ac.bg.etf.javaqx.tools.ng.NativeFileParts;
import yu.ac.bg.etf.javaqx.tools.ng.Utils;

/**
 * JNI Implementation File.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class JniCppFile extends AbstractNativeFile {

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JniCppFile object.
   *
   * @param jniFolder the JNI folder
   * @param javaClass the qdox java class
   */
  public JniCppFile(File jniFolder, JavaClass javaClass) {
    super(jniFolder, Utils.getMangledClassName(javaClass) +
          ".cpp", javaClass); //$NON-NLS-1$
  }

/*^**************************************************************************^*/
/*- Overridden Methods.                                                      -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected NativeFileParts createParts() {
    NativeFileParts parts = new NativeFileParts();
    parts.add(new NativeFileHeader(this));
    parts.add(new JniCppFileStart(this, getJavaClass()));
    JavaMethod[] methods = getJavaClass().getMethods();
    HashMap methodsHash = new HashMap((2 * methods.length) + 1);
    HashMap overridenMethods = (HashMap)methodsHash.clone();
    for (int i = 0; i < methods.length; i++) {
      String methodName = methods[i].getName();
      if (!overridenMethods.containsKey(methodName)) {
        if (methodsHash.containsKey(methodName)) {
          overridenMethods.put(methodName, methodName);
        } else {
          methodsHash.put(methodName, methodName);
        }
      }
    }
    methodsHash.clear();
    for (int i = 0; i < methods.length; i++) {
      JavaMethod method = methods[i];
      if (method.isNative()) {
        boolean overridden = overridenMethods.containsKey(method.getName());
        parts.add(new JniFileMethodImplementation(this, method, overridden));
      }
    }
    parts.add(new NativeFileFooter(this));
    return parts;
  }

}

/*^*****************************************************************************
  File History:

 - 2007-03-01 10:17:07 Slobodan
   Initial version

*****************************************************************************^*/
