/*
 * @(#)JniHFileStart.java  0.2.0 / 2007-03-06
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.tools.ng.jni;

import java.io.IOException;
import java.io.PrintWriter;

import com.thoughtworks.qdox.model.DocletTag;
import com.thoughtworks.qdox.model.JavaClass;

import yu.ac.bg.etf.javaqx.tools.ng.AbstractNativeFile;
import yu.ac.bg.etf.javaqx.tools.ng.NativeFileText;
import yu.ac.bg.etf.javaqx.tools.ng.Utils;

/**
 * JNI Header File Start.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class JniCppFileStart extends NativeFileText {

/*^**************************************************************************^*/
/*- Private Field.                                                           -*/
/*^**************************************************************************^*/

  private final JavaClass javaClass;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JniCppFileStart object.
   *
   * @param nativeFile the native file
   * @param javaClass the qdox java class
   */
  public JniCppFileStart(AbstractNativeFile nativeFile, JavaClass javaClass) {
    super(nativeFile);
    this.javaClass = javaClass;
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected void storeContent(PrintWriter pw) throws IOException {
    pw.print("#include \""); //$NON-NLS-1$
    pw.print(Utils.getMangledClassName(javaClass));
    pw.println(".h\""); //$NON-NLS-1$
    pw.println();
    DocletTag tag = javaClass.getTagByName("javaqx.native"); //$NON-NLS-1$
    String includes = null;
    if (tag != null) {
      includes = tag.getNamedParameter("includes"); //$NON-NLS-1$
    }
    if (includes == null) {
      pw.print("#include \""); //$NON-NLS-1$
      pw.print(javaClass.getName() + "Bridge");
      pw.println(".h\""); //$NON-NLS-1$
    } else {
      String[] include = includes.split(",");
      for (int i = 0; i < include.length; i++) {
        String header = include[i];
        if (header.lastIndexOf('.') >= 0) {
          pw.print("#include \""); //$NON-NLS-1$
          pw.print(header);
          pw.println("\"");
        } else {
          pw.print("#include <"); //$NON-NLS-1$
          pw.print(header);
          pw.println(">");
        }
      }
    }
    pw.println();
    pw.println("/*"); //$NON-NLS-1$
    pw.print(" * "); //$NON-NLS-1$
    pw.print("Native implementation for: "); //$NON-NLS-1$
    pw.println(javaClass.getFullyQualifiedName());
    pw.println(" * "); //$NON-NLS-1$
    pw.println(" * WARNING: DO NOT EDIT THIS FILE " + //$NON-NLS-1$
               "- it is machine generated"); //$NON-NLS-1$
    pw.println(" */"); //$NON-NLS-1$
    pw.println();
  }

}

/*^*****************************************************************************
  File History:

 - 2007-03-06 13:00:53 Slobodan
   Initial version

*****************************************************************************^*/
