/*
 * @(#)JniFileMethod.java  0.2.0 / 2007-03-01
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.tools.ng.jni;

import java.io.IOException;
import java.io.PrintWriter;

import com.thoughtworks.qdox.model.JavaMethod;

import yu.ac.bg.etf.javaqx.tools.ng.AbstractNativeFile;
import yu.ac.bg.etf.javaqx.tools.ng.NativeFileText;
import yu.ac.bg.etf.javaqx.tools.ng.Utils;

/**
 * JNI File Method.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public abstract class JniFileMethod extends NativeFileText { // NOPMD

/*^**************************************************************************^*/
/*- Private Fileds.                                                          -*/
/*^**************************************************************************^*/

  private final JavaMethod method;
  private final boolean overridden;

/*^**************************************************************************^*/
/*- Public Constructors.                                                     -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JniFileMethod object.
   *
   * @param nativeFile the native file
   * @param method the java method
   * @param overridden <tt>true</tt> if the method is overridden
   */
  public JniFileMethod(AbstractNativeFile nativeFile, JavaMethod method,
                       boolean overridden) {
    super(nativeFile);
    if (method == null) {
      throw new IllegalArgumentException("Null java method"); //$NON-NLS-1$
    }
    this.method = method;
    this.overridden = overridden;
  }

/*^**************************************************************************^*/
/*- Protected Methods.                                                       -*/
/*^**************************************************************************^*/

  /**
   * Returns parameters of the method.
   *
   * @param javaMethod the method
   *
   * @return parameters of the method
   */
  protected abstract String[] getMethodParameters(JavaMethod javaMethod);

  /**
   * Stores body of the method.
   *
   * @param pw the print writer
   */
  protected abstract void storeBody(PrintWriter pw);

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected void storeContent(PrintWriter pw) throws IOException {
    pw.print("JNIEXPORT "); //$NON-NLS-1$
    pw.print(Utils.getJniType(method.getReturns()));
    pw.println(" JNICALL"); //$NON-NLS-1$
    pw.println(Utils.getJniMethodName(method, overridden));
    pw.print("  ("); //$NON-NLS-1
    String[] args = getMethodParameters(method);
    for (int i = 0; i < args.length; i++) {
      if (i > 0) {
        pw.print(", "); //$NON-NLS-1
      }
      pw.print(args[i]);
    }
    pw.print(")"); //$NON-NLS-1
    storeBody(pw);
    pw.println();
  }

}

/*^*****************************************************************************
  File History:

 - 2007-03-01 19:43:36 Slobodan
   Initial version

*****************************************************************************^*/
