/*
 * @(#)JniFileMethodDeclaration.java  0.2.0 / 2007-03-08
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.tools.ng.jni;

import java.io.PrintWriter;

import com.thoughtworks.qdox.model.JavaMethod;
import com.thoughtworks.qdox.model.JavaParameter;

import yu.ac.bg.etf.javaqx.tools.ng.AbstractNativeFile;
import yu.ac.bg.etf.javaqx.tools.ng.Utils;

/**
 * JNI File Method Declaration.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class JniFileMethodDeclaration extends JniFileMethod {

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JniFileMethod object.
   *
   * @param nativeFile the native file
   * @param method the java method
   * @param overridden <tt>true</tt> if the method is overridden
   */
  public JniFileMethodDeclaration(AbstractNativeFile nativeFile,
                                  JavaMethod method, boolean overridden) {
    super(nativeFile, method, overridden);
  }

/*^**************************************************************************^*/
/*- Overridden Methods.                                                      -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected String[] getMethodParameters(JavaMethod javaMethod) {
    JavaParameter[] params = javaMethod.getParameters();
    String[] args = new String[params.length + 2];
    args[0] = "JNIEnv *"; //$NON-NLS-1$
    if (javaMethod.isStatic()) {
      args[1] = "jclass"; //$NON-NLS-1$
    } else {
      args[1] = "jobject"; //$NON-NLS-1$
    }
    for (int i = 0; i < params.length; i++) {
      args[i + 2] = Utils.getJniType(params[i].getType());
    }
    return args;
  }

  /**
   * {@inheritDoc}
   */
  protected void storeBody(PrintWriter pw) {
    pw.println(";"); //$NON-NLS-1
  }

}

/*^*****************************************************************************
  File History:

 - 2007-03-08 13:49:16 Slobodan
   Initial version

*****************************************************************************^*/
