/*
 * @(#)JniFileMethodImplementation.java  0.2.0 / 2007-03-08
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.tools.ng.jni;

import java.io.PrintWriter;

import com.thoughtworks.qdox.model.DocletTag;
import com.thoughtworks.qdox.model.JavaMethod;
import com.thoughtworks.qdox.model.JavaParameter;

import yu.ac.bg.etf.javaqx.tools.ng.AbstractNativeFile;
import yu.ac.bg.etf.javaqx.tools.ng.NativeGenerator;
import yu.ac.bg.etf.javaqx.tools.ng.Utils;

/**
 * JNI File Method Implementation.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class JniFileMethodImplementation extends JniFileMethod {

/*^**************************************************************************^*/
/*- Private Filed.                                                           -*/
/*^**************************************************************************^*/

  private final String body;

/*^**************************************************************************^*/
/*- Public Constructors.                                                     -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JniFileMethod object.
   *
   * @param nativeFile the native file
   * @param method the java method
   * @param overridden <tt>true</tt> if the method is overridden
   */
  public JniFileMethodImplementation(AbstractNativeFile nativeFile,
                                     JavaMethod method, boolean overridden) {
    super(nativeFile, method, overridden);
    this.body = getBody(method);
  }

/*^**************************************************************************^*/
/*- Overridden Methods.                                                      -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected String[] getMethodParameters(JavaMethod javaMethod) {
    JavaParameter[] params = javaMethod.getParameters();
    String[] args = new String[params.length + 2];
    String code = Utils.getNativeTagParameter(javaMethod, "code"); //$NON-NLS-1$
    if (Utils.parameterUsed(code, "env")) { //$NON-NLS-1$
      args[0] = "JNIEnv *env"; //$NON-NLS-1$
    } else {
      args[0] = "JNIEnv *"; //$NON-NLS-1$
    }
    if (javaMethod.isStatic()) {
      if (Utils.parameterUsed(code, "cls")) { //$NON-NLS-1$
        args[1] = "jclass cls"; //$NON-NLS-1$
      } else {
        args[1] = "jclass"; //$NON-NLS-1$
      }
    } else {
      if ("_create".equals(javaMethod.getName())) {
        args[1] = "jobject obj"; //$NON-NLS-1$
      } else {
        args[1] = "jobject"; //$NON-NLS-1$
      }
    }
    for (int i = 0; i < params.length; i++) {
      if (Utils.parameterUsed(code, params[i].getName())) {
        args[i + 2] = Utils.getJniType(params[i].getType()) +
                      " " + params[i].getName(); //$NON-NLS-1$
      } else {
        args[i + 2] = Utils.getJniType(params[i].getType());
      }
    }
    return args;
  }

  /**
   * {@inheritDoc}
   */
  protected void storeBody(PrintWriter pw) {
    pw.println();
    pw.println("{"); //$NON-NLS-1$
    pw.print("  "); //$NON-NLS-1
    pw.println(body);
    pw.println("}"); //$NON-NLS-1$
  }

/*^**************************************************************************^*/
/*- Private Staic Method.                                                    -*/
/*^**************************************************************************^*/

  private static String getBody(JavaMethod method) {
    StringBuffer sb = new StringBuffer();
    String code = Utils.getNativeTagParameter(method, "code"); //$NON-NLS-1$
    if (code == null) {
      if (NativeGenerator.generateBridge(method.getParentClass())) {
        if (!"void".equals(method.getReturns().getValue())) { //$NON-NLS-1$
          sb.append("return "); //$NON-NLS-1$
        }
        int startParamIndex = 1;
        if (method.isStatic()) {
          sb.append(Utils.getBridgeName(method.getParentClass()));
          sb.append(':'); // NOPMD
          sb.append(':'); // NOPMD
          sb.append(Utils.getBridgeMethodName(method));
        } else if ("_create".equals(method.getName())) {
          sb.append(Utils.getBridgeName(method.getParentClass()));
          sb.append("::newInstance"); //$NON-NLS-1$
          startParamIndex = 0;
        } else {
          String bridgeObject = Utils.getNativeTagParameter(method,
                                                 "bridgeObject"); //$NON-NLS-1$
          if (bridgeObject == null) {
            bridgeObject = Utils.getBridgeObjectName(method.getParentClass());
          }
          sb.append(bridgeObject);
          sb.append('-'); // NOPMD
          sb.append('>'); // NOPMD
          sb.append(Utils.getBridgeMethodName(method));
        }
        sb.append("(env"); //$NON-NLS-1$
        if (method.isStatic()) {
          startParamIndex = 0;
          sb.append(", cls"); //$NON-NLS-1$
        } else if ("_create".equals(method.getName())) {
          sb.append(", obj"); //$NON-NLS-1$
        }
        JavaParameter[] params = method.getParameters();
        for (int i = startParamIndex; i < params.length; i++) {
          sb.append(','); // NOPMD
          sb.append(' '); // NOPMD
          sb.append(params[i].getName());
        }
        sb.append(')'); // NOPMD
        sb.append(';'); // NOPMD
      } else {
        if (!"void".equals(method.getReturns().getValue())) { //$NON-NLS-1$
          sb.append("return 0;"); //$NON-NLS-1$
        }
      }
    } else {
      sb.append(code);
    }
    return sb.toString();
  }

}

/*^*****************************************************************************
  File History:

 - 2007-03-08 13:49:22 Slobodan
   Initial version

*****************************************************************************^*/
