/*
 * @(#)JniHFile.java  0.2.0 / 2007-02-28
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.tools.ng.jni;

import java.io.File;
import java.util.HashMap;

import com.thoughtworks.qdox.model.JavaClass;
import com.thoughtworks.qdox.model.JavaField;
import com.thoughtworks.qdox.model.JavaMethod;

import yu.ac.bg.etf.javaqx.tools.ng.AbstractNativeFile;
import yu.ac.bg.etf.javaqx.tools.ng.NativeFileFooter;
import yu.ac.bg.etf.javaqx.tools.ng.NativeFileHeader;
import yu.ac.bg.etf.javaqx.tools.ng.NativeFileParts;
import yu.ac.bg.etf.javaqx.tools.ng.NativeFileText;
import yu.ac.bg.etf.javaqx.tools.ng.Utils;

/**
 * JNI H File.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class JniHFile extends AbstractNativeFile {

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JniHFile object.
   *
   * @param jniFolder the jni folder
   * @param javaClass the qdox java class
   */
  public JniHFile(File jniFolder, JavaClass javaClass) {
    super(jniFolder, Utils.getMangledClassName(javaClass) + ".h", //$NON-NLS-1$
          javaClass);
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected NativeFileParts createParts() {
    NativeFileParts parts = new NativeFileParts();
    parts.add(new NativeFileHeader(this));
    parts.add(new JniHFileStart(this, getJavaClass()));
    JavaField[] fields = getJavaClass().getFields();
    boolean addSeparator = false;
    for (int i = 0; i < fields.length; i++) {
      JavaField field = fields[i];
      if (field.isStatic() && field.isFinal() && !field.isPrivate()) {
        parts.add(new JniHFileConstant(this, field));
        addSeparator = true;
      }
    }
    if (addSeparator) {
      parts.add(NativeFileText.getSeparator(this));
    }
    JavaMethod[] methods = getJavaClass().getMethods();
    HashMap methodsHash = new HashMap((2 * methods.length) + 1);
    HashMap overridenMethods = (HashMap)methodsHash.clone();
    for (int i = 0; i < methods.length; i++) {
      String methodName = methods[i].getName();
      if (!overridenMethods.containsKey(methodName)) {
        if (methodsHash.containsKey(methodName)) {
          overridenMethods.put(methodName, methodName);
        } else {
          methodsHash.put(methodName, methodName);
        }
      }
    }
    methodsHash.clear();
    for (int i = 0; i < methods.length; i++) {
      JavaMethod method = methods[i];
      if (method.isNative()) {
        parts.add(new JniHFileMethodComment(this, method));
        parts.add(new JniFileMethodDeclaration(this, method,
                          overridenMethods.containsKey(method.getName())));
      }
    }
    parts.add(new JniHFileEnd(this, getJavaClass()));
    parts.add(new NativeFileFooter(this));
    return parts;
  }

}

/*^*****************************************************************************
  File History:

 - 2007-02-28 13:45:54 Slobodan
   Initial version

*****************************************************************************^*/
