/*
 * @(#)JniHFileMethodComment.java  0.2.0 / 2007-03-06
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.tools.ng.jni;

import java.io.IOException;
import java.io.PrintWriter;

import com.thoughtworks.qdox.model.JavaMethod;

import yu.ac.bg.etf.javaqx.tools.ng.AbstractNativeFile;
import yu.ac.bg.etf.javaqx.tools.ng.NativeFileText;
import yu.ac.bg.etf.javaqx.tools.ng.Utils;

/**
 * Comment of the JNI Header File Method.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class JniHFileMethodComment extends NativeFileText {

/*^**************************************************************************^*/
/*- Private Field.                                                           -*/
/*^**************************************************************************^*/

  private JavaMethod javaMethod;

/*^**************************************************************************^*/
/*- Public Constructors.                                                     -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JniHFileMethodComment object.
   *
   * @param nativeFile the native file
   * @param javaMethod the java method
   */
  public JniHFileMethodComment(AbstractNativeFile nativeFile,
                               JavaMethod javaMethod) {
    super(nativeFile);
    this.javaMethod = javaMethod;
  }

  /**
   * Constructs new JniHFileMethodComment object.
   *
   * @param nativeFile the native file
   * @param content header's content
   */
  public JniHFileMethodComment(AbstractNativeFile nativeFile, String content) {
    super(nativeFile, content);
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected void storeContent(PrintWriter pw) throws IOException {
    pw.println("/*"); //$NON-NLS-1$
    pw.print(" * Class:     "); //$NON-NLS-1$
    pw.println(Utils.getMangledClassName(javaMethod.getParentClass()));
    pw.print(" * Method:    "); //$NON-NLS-1$
    pw.println(javaMethod.getName());
    pw.print(" * Signature: "); //$NON-NLS-1$
    pw.println(Utils.getSignature(javaMethod));
    pw.println(" */"); //$NON-NLS-1$
  }

}

/*^*****************************************************************************
  File History:

 - 2007-03-06 10:57:45 Slobodan
   Initial version

*****************************************************************************^*/
