/*
 * @(#)JniHFileStart.java  0.2.0 / 2007-03-06
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.tools.ng.jni;

import java.io.IOException;
import java.io.PrintWriter;

import com.thoughtworks.qdox.model.JavaClass;

import yu.ac.bg.etf.javaqx.tools.ng.AbstractNativeFile;
import yu.ac.bg.etf.javaqx.tools.ng.NativeFileText;
import yu.ac.bg.etf.javaqx.tools.ng.Utils;

/**
 * JNI Header File Start.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class JniHFileStart extends NativeFileText {

/*^**************************************************************************^*/
/*- Private Field.                                                           -*/
/*^**************************************************************************^*/

  private final JavaClass javaClass;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JniHFileStart object.
   *
   * @param nativeFile the native file
   * @param javaClass the qdox java class
   */
  public JniHFileStart(AbstractNativeFile nativeFile, JavaClass javaClass) {
    super(nativeFile);
    this.javaClass = javaClass;
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected void storeContent(PrintWriter pw) throws IOException {
    pw.print("#ifndef "); //$NON-NLS-1$
    String guard = Utils.getMangledClassName(javaClass).toUpperCase(); //NOFB
    guard = guard + "_H"; //$NON-NLS-1$
    pw.println(guard);
    pw.print("#define "); //$NON-NLS-1$
    pw.println(guard);
    pw.println();
    pw.println("#include <jni.h>"); //$NON-NLS-1$
    pw.println();
    pw.println("#ifdef __cplusplus"); //$NON-NLS-1$
    pw.println("extern \"C\" {"); //$NON-NLS-1$
    pw.println("#endif // __cplusplus"); //$NON-NLS-1$
    pw.println();
    pw.println("/*"); //$NON-NLS-1$
    pw.print(" * Header file for: "); //$NON-NLS-1$
    pw.println(Utils.getMangledClassName(javaClass));
    pw.println(" * "); //$NON-NLS-1$
    pw.println(" * WARNING: DO NOT EDIT THIS FILE " + //$NON-NLS-1$
               "- it is machine generated"); //$NON-NLS-1$
    pw.println(" */"); //$NON-NLS-1$
    pw.println();
  }

}

/*^*****************************************************************************
  File History:

 - 2007-03-06 13:00:53 Slobodan
   Initial version

*****************************************************************************^*/
