/*
 * @(#)JQComponent.java  0.2.0 / 03.10.2006
 *
 * Copyright (c) 2006, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac;

import java.beans.PropertyChangeListener;
import java.util.HashMap;
import java.util.Locale;
import java.util.ResourceBundle;

/**
 * The base class of all QSwing components.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 *
 * @javaqx.native
 *    generate="jni,bridge"
 */
public abstract class JQComponent {

/*^**************************************************************************^*/
/*- Public Static Field.                                                     -*/
/*^**************************************************************************^*/

  public static final int STATIC_CONST = 20;

/*^**************************************************************************^*/
/*- Static Initialization.                                                   -*/
/*^**************************************************************************^*/

  static {
    _initialize(JQComponent.class);
  }

/*^**************************************************************************^*/
/*- Package-Private Fields.                                                  -*/
/*^**************************************************************************^*/

  String name;
  boolean enabled;
  boolean visible;
  boolean windowShown;
  boolean valid;
  long eventMask;
  boolean preferredSizeSet;
  boolean resizable;
  boolean opaque;
  boolean cursorSet;
  boolean updatesEnabled;
  boolean backgroundSet;
  boolean foregroundSet;
  boolean fontSet;
  Locale locale;
  String resourceBundleName;
  String toolTipText;
  String statusTipText;
  String whatsThisText;
  HashMap clientProperties;

/*^**************************************************************************^*/
/*- Package-Private Fields (used by "native" code).                          -*/
/*^**************************************************************************^*/

  long _bridge;

/*^**************************************************************************^*/
/*- Protected Field.                                                         -*/
/*^**************************************************************************^*/


/*^**************************************************************************^*/
/*- Protected Constructors.                                                  -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JQComponent object.
   */
  protected JQComponent() {
    this(true);
  }

  /**
   * Constructs new JQComponent object.
   *
   * @param name the component name
   */
  protected JQComponent(String name) {
    this(true);
    if (name != null) {
      this.name = name;
      _setName(_bridge, name);
    }
  }

  /**
   * Constructs new JQComponent object.
   * <p>
   *   WARNING: Do not call this constructor if you don't implement native
   *            constructor.
   * </p>
   *
   * @param initNative initialize native constructor
   */
  protected JQComponent(boolean initNative) {
    enabled = true;
    visible = true;
    valid = true;
    resizable = true;
    updatesEnabled = true;
    if (initNative) {
      _bridge = _create();
    }
  }

/*^**************************************************************************^*/
/*- Public Methods.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Returns the name of the component.
   *
   * @return the name of the component
   */
  public String getName() {
    return name;
  }

  /**
   * Sets the name of the component.
   *
   * @param name the component name
   */
  public void setName(String name) {
    String oldName = this.name;
    if (oldName == null) {
      if (name == null) {
        return;
      }
    } else {
      if (oldName.equals(name)) {
        return;
      }
    }
    _setName(_bridge, name);
    this.name = name;
  }

  /**
   * Returns <tt>true</tt> if the component is visible.
   *
   * @return <tt>true</tt> if the component is visible
   */
  public boolean isVisible() {
    return visible;
  }

  /**
   * Sets new visibility state.
   *
   * @param visible the new visibility state
   */
  public void setVisible(boolean visible) {
  }

  /**
   * Returns <tt>true</tt> if the component is enabled.
   *
   * @return <tt>true</tt> if the component is enabled
   */
  public boolean isEnabled() {
    return enabled;
  }

  /**
   * Enables or disables the component.
   *
   * @param enabled if <tt>true</tt> the component is enabled; otherwise the
   *                component is disabled
   */
  public void setEnabled(boolean enabled) {
    if (this.enabled != enabled) {
      _setEnabled(_bridge, enabled);
    }
  }

  /**
   * Returns <tt>true</tt> if the component is resizable.
   *
   * @return <tt>true</tt> if the component is resizable
   */
  public boolean isResizable() {
    return resizable;
  }

  /**
   * Sets resizable status.
   *
   * @param resizable if <tt>true</tt> the component is resizable; otherwise
   *                  <tt>false</tt>
   */
  public void setResizable(boolean resizable) {
    if (this.resizable != resizable) {
      if (resizable) {
      } else {
      }
    }
  }


  protected final void disposeObject() {
    if (_bridge != 0) {
     _destroy(_bridge);
     _bridge = 0;
    }
  }

/*^**************************************************************************^*/
/*- Package-Privte Methods.                                                  -*/
/*^**************************************************************************^*/

  /*!
   * @javaqx.native.callback
   */
  void _filterEvents() {
  }

/*^**************************************************************************^*/
/*- Native Code.                                                             -*/
/*^**************************************************************************^*/

  /**
   * Native Peer.
   *
   * @javaqx.native.peer
   *    name="JQComponentPeer"
   *    method="int isVisible();"
   *    method="void setVisible(JNIEnv *env, bool visible);"
   *
   * Native Bridge.
   *
   * @javaqx.native.bridge
   *    name="JQComponentBridge"
   *    method="int isVisible();"
   *    method="void setVisible(JNIEnv *env, bool visible);"
   *
   * Native Adapter.
   *
   * @javaqx.native.adapter
   *    name="Adapter"
   *    method="int isVisible();"
   *    method="void setVisible(bool visible);"
   */

/*^**************************************************************************^*/
/*- Package-Privte Native Method.                                            -*/
/*^**************************************************************************^*/

  native long _create();

/*^**************************************************************************^*/
/*- Package-Privte Static Native Methods.                                    -*/
/*^**************************************************************************^*/


  native void _postEvent(long bridge, int eventType);

  native void _setEnabledEvents(long bridge, long events);

  native void _setName(long bridge, String name);

  native void _setVisible(long bridge, boolean visible);

  //native void _showWindow(long bridge);

  native int _getWidth(long bridge);

  native void _setEnabled(long bridge, boolean enabled);

  native void _repaint(long bridge);

  static native void _destroy(long bridge);

/*^**************************************************************************^*/
/*- Privte Static Native Method.                                             -*/
/*^**************************************************************************^*/

  private static native void _initialize(Class dimensionClass);

/*^**************************************************************************^*/
/*- Inner Class.                                                             -*/
/*^**************************************************************************^*/

  /**
   * JVM Shutdown Hook.
   */
  private final class Finalizer implements Runnable {
    public void run() {
    }
  }

}

/*^*****************************************************************************
  File History:

 - 17.03.2006 21:42:45 Slobodan
   Initial version

*****************************************************************************^*/
