/*
 * @(#)JQLabel.java  0.2.0 / May 28, 2006
 *
 * Copyright (c) 2006, ETF and contributors. All rights reserved.
 *
 * The contents of this file are subject to the LGPL, version 2.1, license
 * distributed with the source code in the file LICENSE.txt
 */
package yu.ac;

/**
 * Label Component.
 *
 * @javaqx.native
 *    generate="jni,bridge"
 *
 * @javaqx.jni
 *    generate="header,body"
 *
 * @javaqx.bridge
 *    name="JQLabelBridge"
 *    object="jqLabelBridge"
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class JQLabel extends JQComponent {

/*^**************************************************************************^*/
/*- Public Static Fields.                                                    -*/
/*^**************************************************************************^*/

  /**
   * Plain text format.
   */
  public static final int PLAIN_TEXT = 0;

  /**
   * Rich text format.
   */
  public static final int RICH_TEXT = 1;

  /**
   * Auto text format.
   */
  public static final int AUTO_TEXT = 2;

/*^**************************************************************************^*/
/*- Pacakge-Private Static Fields.                                           -*/
/*^**************************************************************************^*/

  static final int PACKAGE_FIELD_1 = 1;

  static final int PACKAGE_FIELD_2 = 2;

/*^**************************************************************************^*/
/*- Static Initialization.                                                   -*/
/*^**************************************************************************^*/

  static {
    _initialize();
  }

/*^**************************************************************************^*/
/*- Package-Private Field.                                                   -*/
/*^**************************************************************************^*/

  String text;
  int textFormat;
  boolean wrapText;
  int horizontalAlignment;
  int verticalAlignment;

/*^**************************************************************************^*/
/*- Public Constructors.                                                     -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JQLabel object.
   *
   * @param text the text
   */
  public JQLabel(String text) {
    super(false);
    //verticalAlignment = CENTER;
    //horizontalAlignment = LEADING;
    textFormat = AUTO_TEXT;
    this.text = text;
    //_jqn_handle = _create(text);
  }

  /**
   * Constructs new JQLabel object.
   */
  public JQLabel() {
    this(null);
  }

/*^**************************************************************************^*/
/*- Public Methods.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Returns text.
   *
   * @return text
   */
  public String getText() {
    return text;
  }

  /**
   * Sets text.
   *
   * @param text the text
   */
  public void setText(String text) {
    String oldText = this.text;
    if (oldText == null) {
      if (text == null) {
        return;
      }
    } else {
      if (oldText.equals(text)) {
        return;
      }
    }
    //checkDisposed();
    _setText(_bridge, text);
    this.text = text;
    //firePropertyChange(PROPERTY_TEXT, oldText, text);
  }

  /**
   * Retruns text format.
   *
   * @return text foramt
   */
  public int getTextFormat() {
    return textFormat;
  }

  /**
   * Sets text format.
   * <p>Valid values are: <tt>PLAIN_TEXT</tt>,
   *                      <tt>RICH_TEXT</tt> and
   *                      <tt>AUTO_TEXT</tt>.
   * <br/>
   * Default is: <tt>AUTO_TEXT</tt>.
   * </p>
   *
   * @param textFormat the new text format
   */
  public void setTextFormat(int textFormat) {
    int oldTextFormat = this.textFormat;
    if (oldTextFormat != textFormat) {
      //checkDisposed();
      this.textFormat = checkTextFormatKey(textFormat,
                          "Invlid text format"); //$NON-NLS-1$);
      _setTextFormat(_bridge, textFormat);
      //firePropertyChange(PROPERTY_TEXT_FORMAT, oldTextFormat, textFormat);
    }
  }

  /**
   * Returns <tt>true</tt> if the label is wrapping text.
   *
   * @return <tt>true</tt> if the label is wrapping text
   */
  public boolean isWrapText() {
    return wrapText;
  }

  /**
   * Sets wrap text status.
   *
   * @param wrapText if <tt>true</tt> the label will wrap text
   */
  public void setWrapText(boolean wrapText) {
    boolean oldWrapText = this.wrapText;
    if (oldWrapText != wrapText) {
      //checkDisposed();
      //_setWordWrap(_bridge, wrapText);
      this.wrapText = wrapText;
      //firePropertyChange(PROPERTY_WRAP_TEXT, oldWrapText, wrapText);
    }
  }

  /**
   * Returns horizontal alignment.
   *
   * @return horizontal alignment
   */
  public int getHorizontalAlignment() {
    return horizontalAlignment;
  }

  /**
   * Sets horizontal alignment.
   * <p>Valid values are: <tt>LEFT</tt>,
   *                      <tt>CENTER</tt>,
   *                      <tt>RIGHT</tt>,
   *                      <tt>LEADING</tt> and
   *                      <tt>TRAILING</tt>.
   * <br/>
   * Default is: <tt>LEADING</tt>.
   * </p>
   *
   * @param alignment the horizontal alignment
   */
  public void setHorizontalAlignment(int alignment) {
    int oldHorizontalAlignment = horizontalAlignment;
    if (oldHorizontalAlignment != alignment) {
      //checkDisposed();
      horizontalAlignment = checkHorizontalKey(alignment,
                              "Invlid horizontal alignment"); //$NON-NLS-1$
      _setAlignment(_bridge, alignment, verticalAlignment);
      //firePropertyChange(PROPERTY_HORIZONTAL_ALIGNMENT, oldHorizontalAlignment,
                //         alignment);
    }
  }

  /**
   * Returns vertical alignment.
   *
   * @return vertical alignment
   */
  public int getVerticalAlignment() {
    return verticalAlignment;
  }

  /**
   * Sets vertical alignment.
   * <p>Valid values are: <tt>TOP</tt>,
   *                      <tt>CENTER</tt> and
   *                      <tt>BOTTOM</tt>.
   * <br/>
   * Default is: <tt>CENTER</tt>.
   * </p>
   *
   * @param alignment the vertical alignment
   */
  public void setVerticalAlignment(int alignment) {
    int oldVerticalAlignment = verticalAlignment;
    if (oldVerticalAlignment != alignment) {
      //checkDisposed();
      verticalAlignment = checkVerticalKey(alignment,
                            "Invlid vertical alignment"); //$NON-NLS-1$
      _setAlignment(_bridge, horizontalAlignment, alignment);
      //firePropertyChange(PROPERTY_VERTICAL_ALIGNMENT, oldVerticalAlignment,
          //               alignment);
    }
  }

/*^**************************************************************************^*/
/*- Protected Methods.                                                       -*/
/*^**************************************************************************^*/

  /**
   * Checks horizontal alignment key.
   *
   * @param key the key
   * @param message the error message
   *
   * @return alignment key
   *
   * @throws <tt>IllegalArgumentException</tt> if key is invalid
   */
  protected int checkHorizontalKey(int key, String message) {
    //if ((key == LEFT) || (key == CENTER) || (key == RIGHT) ||
    //    (key == LEADING) || (key == TRAILING)) {
      return key;
    //} else {
    //  throw new IllegalArgumentException(message);
    //}
  }

  /**
   * Checks vertical alignment key.
   *
   * @param key the key
   * @param message the error message
   *
   * @return alignment key
   *
   * @throws <tt>IllegalArgumentException</tt> if key is invalid
   */
  protected int checkVerticalKey(int key, String message) {
    //if ((key == TOP) || (key == CENTER) || (key == BOTTOM)) {
      return key;
    //} else {
      //throw new IllegalArgumentException(message);
    //}
  }

  /**
   * Checks text format key.
   *
   * @param key the key
   * @param message the error message
   *
   * @return alignment key
   *
   * @throws <tt>IllegalArgumentException</tt> if key is invalid
   */
  protected int checkTextFormatKey(int key, String message) {
    if ((key == PLAIN_TEXT) || (key == RICH_TEXT) || (key == AUTO_TEXT)) {
      return key;
    } else {
      throw new IllegalArgumentException(message);
    }
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  public void updateLocalization() {
    //super.updateLocalization();
    if (text != null) {
      _setText(_bridge, text);
    }
  }

/*^**************************************************************************^*/
/*- Native Callbacks.                                                        -*/
/*^**************************************************************************^*/

  void _labelChanged() {
  }

  void _labelChanged2(int i) {
  }


/*^**************************************************************************^*/
/*- Native Methods.                                                          -*/
/*^**************************************************************************^*/

  native long _create();

  native void _setText(long bridge, String text);

  native String _getText(long brige);

  native void _setTextFormat(long bridge, int textFormat);

  native void _setWordWrap(long bridge, boolean wordWrap);

  native void _setAlignment(long bridge, int ha, int va);

  static native void _initialize();

}
