/*
 * @(#)main.cpp  0.2.0 / 2007-12-26
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
#include <QtGui>

/*!
 * \brief Returns screenshot rectangle.
 *
 * \param image the screenshot image
 *
 * \return screenshot rectangle
 */
QRect findScreenshotRectangle(const QImage &image)
{
  QRgb white = qRgba(255, 255, 255, 255);
  int imageWidth = image.width();
  int imageHeight = image.height();
  int xStart = 2;
  int yStart = 0;
  int xEnd = 2;
  int yEnd = 60;
  for (int i = 0; i < 160; ++i) {
    if (image.pixel(900, i) == white) {
      break;
    } else {
      yStart++;
    }
  }
  for (int i = imageHeight - yEnd; i > imageHeight - 160; --i) {
    if (image.pixel(900, i) == white) {
      break;
    } else {
      yEnd++;
    }
  }
  imageWidth = imageWidth - xEnd;
  imageHeight = imageHeight - yEnd;
  int x1 = imageWidth;
  int y1 = imageHeight;
  int x2 = xStart;
  int y2 = yStart;
  for (int j = yStart; j < imageHeight; j++) {
    for (int i = xStart; i < imageWidth; i++) {
      if (image.pixel(i, j) != white) {
        if (i < x1) {
          x1 = i;
        } 
        if (i > x2) {
          x2 = i;
        }
        if (j < y1) {
          y1 = j;
        } 
        if (j > y2) {
          y2 = j;
        }
      }
    }
  }
  return QRect(x1, y1, x2 - x1, y2 - y1);
}

/*!
 * \brief Screenshot extractor. Extracts screenshots form TestGUI tests.
 *
 * \param argc the number of arguments
 * \param argv the arguments
 *
 * \return exit code
 */
int main(int argc, char *argv[])
{
  QApplication a(argc, argv);
  QString source = "../../bin/screenshots";
  QString destination = "../../doc/html/images/screenshots";
  QDir screenshotsDir(source); 
  QDir destinationDir(destination);
  if (!destinationDir.exists()) {
    destinationDir.mkpath(".");
  }
  QStringList allScreenshots = screenshotsDir.entryList(QDir::NoDotAndDotDot |
                                                        QDir::Dirs);
  for (int i = 0; i < allScreenshots.size(); i++) {
    QDir platformScreenshots(
                         screenshotsDir.absoluteFilePath(allScreenshots.at(i)));
    QStringList screenshots = platformScreenshots.entryList(QDir::Files);
    for (int j = 0; j < screenshots.size(); j++) {
      QString imageName = screenshots.at(j);
      if (imageName.endsWith(".png", Qt::CaseInsensitive)) {
        QImage image(platformScreenshots.absoluteFilePath(imageName));
        if (!image.isNull()) {
          image = image.copy(findScreenshotRectangle(image));
          imageName = allScreenshots.at(i) + "-" + screenshots.at(j);
          if (!image.save(destinationDir.absoluteFilePath(imageName))) {
            qDebug() << "Could not save image";
          }
          int scaleWidth;
          if (image.width() <= 100) {
            scaleWidth = 0.76 * image.width();
          } else {
            scaleWidth = 100;
          }
          image = image.scaledToWidth(scaleWidth, Qt::SmoothTransformation);
          imageName.insert(imageName.lastIndexOf('.'), "-small");
          image.save(destinationDir.absoluteFilePath(imageName));
        }
      }
    }
  }
  return 0;
}

/*^*****************************************************************************
  File History:

 - 2007-12-26 08:26:04 Slobodan
   Initial version

*****************************************************************************^*/
