/*
 * @(#)ScrollPaneDemo.java  0.2.0 / 2007-11-20
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.demo.qswingset;

import yu.ac.bg.etf.javaqx.qswing.JQButton;
import yu.ac.bg.etf.javaqx.qswing.JQComponent;
import yu.ac.bg.etf.javaqx.qswing.JQContainer;
import yu.ac.bg.etf.javaqx.qswing.JQProgressBar;
import yu.ac.bg.etf.javaqx.qswing.JQTextArea;
import yu.ac.bg.etf.javaqx.qswing.JQTimer;
import yu.ac.bg.etf.javaqx.qswing.events.ActionEvent;
import yu.ac.bg.etf.javaqx.qswing.events.ActionListener;
import yu.ac.bg.etf.javaqx.qswing.layouts.BorderLayout;
import yu.ac.bg.etf.javaqx.qswing.layouts.formlayout.CellConstraints;
import yu.ac.bg.etf.javaqx.qswing.layouts.formlayout.FormLayout;

/**
 * Demonstration of the JQProgressBar class.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class ProgressBarDemo extends DemoModule {

/*^**************************************************************************^*/
/*- Private Field.                                                           -*/
/*^**************************************************************************^*/

  private JQTimer timer;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new ProgressBarDemo object.
   */
  public ProgressBarDemo() {
    super("ProgressBar Demo", "Demonstration of the JQProgressBar class.");
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected JQComponent buildDemoComponent() {
    final String text = getText("ProgressBarDemo.text");
    JQContainer panel = new JQContainer(new BorderLayout());

    final JQTextArea textArea = new JQTextArea();
    textArea.setEditable(false);
    panel.add(textArea, BorderLayout.CENTER);

    FormLayout layout = new FormLayout(
                "p:g, max(180dlu;p), 4dlu, p, 4dlu, p, p:g", "5dlu, p, 4dlu");
    JQContainer progressPanel = new JQContainer(layout);
    CellConstraints cc = new CellConstraints();
    final JQProgressBar progressBar = new JQProgressBar();
    progressBar.setMaximum(text.length());
    progressPanel.add(progressBar, cc.xy(2, 2));
    final JQButton startButton = new JQButton("Start Loading Text");
    final JQButton stopButton = new JQButton("Stop Loading Text");
    startButton.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        startButton.setEnabled(false);
        if (progressBar.getValue() == text.length()) {
          textArea.clearText();
          progressBar.setValue(0);
        }
        timer = new JQTimer(18, new ActionListener() {
          public void actionPerformed(ActionEvent e) {
            int index = progressBar.getValue();
            if (index < text.length()) {
              textArea.appendText(text.substring(index, ++index));
              progressBar.setValue(index);
            } else {
              stopButton.setEnabled(false);
              timer.stop();
              timer = null;
              startButton.setEnabled(true);
            }
          }
        });
        timer.start();
        stopButton.setEnabled(true);
      }
    });
    stopButton.setEnabled(false);
    stopButton.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        stopButton.setEnabled(false);
        timer.stop();
        timer = null;
        startButton.setEnabled(true);
      }
    });
    progressPanel.add(startButton, cc.xy(4, 2));
    progressPanel.add(stopButton, cc.xy(6, 2));
    panel.add(progressPanel, BorderLayout.SOUTH);

    return panel;
  }

/*^**************************************************************************^*/
/*- Main Method.                                                             -*/
/*^**************************************************************************^*/

  /**
   * Starts demo as standalone appliation.
   *
   * @param args the application arguments
   */
  public static void main(String[] args) {
    new ProgressBarDemo().show();
  }

}

/*^*****************************************************************************
  File History:

 - 2007-11-20 20:56:17 Slobodan
   Initial version

*****************************************************************************^*/
