/*
 * @(#)SplitPaneDemo.java  0.2.0 / 2007-12-04
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.demo.qswingset;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

import yu.ac.bg.etf.javaqx.qswing.ImageIcon;
import yu.ac.bg.etf.javaqx.qswing.JQCheckBox;
import yu.ac.bg.etf.javaqx.qswing.JQComponent;
import yu.ac.bg.etf.javaqx.qswing.JQContainer;
import yu.ac.bg.etf.javaqx.qswing.JQLabel;
import yu.ac.bg.etf.javaqx.qswing.JQOptionPane;
import yu.ac.bg.etf.javaqx.qswing.JQRadioButton;
import yu.ac.bg.etf.javaqx.qswing.JQSplitPane;
import yu.ac.bg.etf.javaqx.qswing.JQTextField;
import yu.ac.bg.etf.javaqx.qswing.QSwing;
import yu.ac.bg.etf.javaqx.qswing.SelectableGroup;
import yu.ac.bg.etf.javaqx.qswing.events.ActionEvent;
import yu.ac.bg.etf.javaqx.qswing.events.ActionListener;
import yu.ac.bg.etf.javaqx.qswing.layouts.BorderLayout;
import yu.ac.bg.etf.javaqx.qswing.layouts.formlayout.CellConstraints;
import yu.ac.bg.etf.javaqx.qswing.layouts.formlayout.FormLayout;

/**
 * Demonstration of the JQSplitPane class.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class SplitPaneDemo extends DemoModule {

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new SplitPaneDemo object.
   */
  public SplitPaneDemo() {
    super("SplitPane Demo", "Demonstration of the JQSplitPane class.");
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected JQComponent buildDemoComponent() {
    JQContainer panel = new JQContainer(new BorderLayout());
    panel.setInsets(2, 2, 2, 2);

    final JQSplitPane splitPane = new JQSplitPane();
    String imageName = "resources/images/splitpane/earth.png";
    ImageIcon earthImage = new ImageIcon(loadResource(imageName));
    final JQLabel earthLabel = new JQLabel(earthImage);
    earthLabel.setMinimumSize(20, 20);
    earthLabel.setBorderWidth(JQLabel.BORDER_TYPE_STANDARD);
    earthLabel.setBorderStyle(JQLabel.BORDER_STYLE_SUNKEN);
    imageName = "resources/images/splitpane/moon.png";
    ImageIcon moonImage = new ImageIcon(loadResource(imageName));
    final JQLabel moonLabel = new JQLabel(moonImage);
    moonLabel.setMinimumSize(20, 20);
    moonLabel.setBorderWidth(JQLabel.BORDER_TYPE_STANDARD);
    moonLabel.setBorderStyle(JQLabel.BORDER_STYLE_SUNKEN);
    splitPane.setLeftComponent(earthLabel);
    splitPane.setRightComponent(moonLabel);
    panel.add(splitPane);

    FormLayout layout = new FormLayout(
                                 "p:g, l:p, 4dlu, l:p, 6dlu, r:p, 4dlu, p, p:g",
                                 "10dlu, p, 4dlu, p, 4dlu, p, 14dlu");
    JQContainer bottomPanel = new JQContainer(layout);
    CellConstraints cc = new CellConstraints();
    SelectableGroup sg = new SelectableGroup();
    JQRadioButton horizontalSplit = new JQRadioButton("Horizontal split");
    horizontalSplit.addActionListener(new ActionListener() {
        public void actionPerformed(ActionEvent e) {
          splitPane.setOrientation(JQSplitPane.HORIZONTAL);
        }
      });
    horizontalSplit.setSelected(true);
    sg.add(horizontalSplit);
    bottomPanel.add(horizontalSplit, cc.xy(2, 2));
    JQRadioButton verticalSplit = new JQRadioButton("Vertical split");
    verticalSplit.addActionListener(new ActionListener() {
        public void actionPerformed(ActionEvent e) {
          splitPane.setOrientation(JQSplitPane.VERTICAL);
        }
      });
    sg.add(verticalSplit);
    bottomPanel.add(verticalSplit, cc.xy(2, 4));
    final JQCheckBox continuousLayout = new JQCheckBox("Continuous layout");
    continuousLayout.addActionListener(new ActionListener() {
        public void actionPerformed(ActionEvent e) {
          splitPane.setContinuousLayout(continuousLayout.isSelected());
        }
      });
    continuousLayout.setSelected(true);
    bottomPanel.add(continuousLayout, cc.xy(4, 2));
    final JQCheckBox oneTouchExpandable = new JQCheckBox(
                                                      "One-touch expandable");
    oneTouchExpandable.addActionListener(new ActionListener() {
        public void actionPerformed(ActionEvent e) {
          splitPane.setOneTouchExpandable(oneTouchExpandable.isSelected());
        }
      });
    bottomPanel.add(oneTouchExpandable, cc.xy(4, 4));
    bottomPanel.add(new JQLabel("Divider size"), cc.xy(6, 2));
    bottomPanel.add(new JQLabel("First component's min. size"), cc.xy(6, 4));
    bottomPanel.add(new JQLabel("Second component's min. size"), cc.xy(6, 6));
    final JQTextField dividerWidth =
                    new JQTextField(String.valueOf(splitPane.getDividerSize()));
    dividerWidth.setHorizontalAlignment(JQTextField.RIGHT);
    dividerWidth.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        try {
          splitPane.setDividerSize(Integer.parseInt(dividerWidth.getText()));
        } catch (Exception ex) {
          JQOptionPane.showErrorMessage(splitPane, "Invalid divider size.",
                                        "Error");
        }
      }
    });
    QSwing.addPropertyChangeListener(QSwing.PROPERTY_STYLE,
                                     new PropertyChangeListener() {
      public void propertyChange(PropertyChangeEvent e) {
        dividerWidth.setText(String.valueOf(splitPane.getDividerSize()));
      }
    });
    bottomPanel.add(dividerWidth, cc.xy(8, 2));
    final JQTextField minimumEarthLabelWidth =
        new JQTextField(String.valueOf(earthLabel.getMinimumSize().getWidth()));
    minimumEarthLabelWidth.setHorizontalAlignment(JQTextField.RIGHT);
    minimumEarthLabelWidth.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        try {
          int minimumSize = Integer.parseInt(minimumEarthLabelWidth.getText());
          earthLabel.setMinimumSize(minimumSize, minimumSize);
        } catch (Exception ex) {
          JQOptionPane.showErrorMessage(splitPane, "Invalid minimum size.",
                                        "Error");
        }
      }
    });
    bottomPanel.add(minimumEarthLabelWidth, cc.xy(8, 4));
    final JQTextField minimumMoonLabelWidth =
        new JQTextField(String.valueOf(moonLabel.getMinimumSize().getWidth()));
    minimumMoonLabelWidth.setHorizontalAlignment(JQTextField.RIGHT);
    minimumMoonLabelWidth.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        try {
          int minimumSize = Integer.parseInt(minimumMoonLabelWidth.getText());
          moonLabel.setMinimumSize(minimumSize, minimumSize);
        } catch (Exception ex) {
          JQOptionPane.showErrorMessage(splitPane, "Invalid minimum size.",
                                        "Error");
        }
      }
    });
    bottomPanel.add(minimumMoonLabelWidth, cc.xy(8, 6));
    panel.add(bottomPanel, BorderLayout.SOUTH);

    return panel;
  }

/*^**************************************************************************^*/
/*- Main Method.                                                             -*/
/*^**************************************************************************^*/

  /**
   * Starts demo as standalone appliation.
   *
   * @param args the application arguments
   */
  public static void main(String[] args) {
    new SplitPaneDemo().show();
  }

}

/*^*****************************************************************************
  File History:

 - 2007-12-04 22:43:05 Slobodan
   Initial version

*****************************************************************************^*/
