/*
 * @(#)ToolTipDemo.java  0.2.0 / 2007-11-30
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.demo.qswingset;

import yu.ac.bg.etf.javaqx.qswing.ImageIcon;
import yu.ac.bg.etf.javaqx.qswing.JQCheckBox;
import yu.ac.bg.etf.javaqx.qswing.JQComponent;
import yu.ac.bg.etf.javaqx.qswing.JQContainer;
import yu.ac.bg.etf.javaqx.qswing.JQLabel;
import yu.ac.bg.etf.javaqx.qswing.JQScrollPane;
import yu.ac.bg.etf.javaqx.qswing.JQSeparator;
import yu.ac.bg.etf.javaqx.qswing.JQToolButton;
import yu.ac.bg.etf.javaqx.qswing.JQToolTip;
import yu.ac.bg.etf.javaqx.qswing.WhatsThisManager;
import yu.ac.bg.etf.javaqx.qswing.events.ActionEvent;
import yu.ac.bg.etf.javaqx.qswing.events.ActionListener;
import yu.ac.bg.etf.javaqx.qswing.events.QSwingEvent;
import yu.ac.bg.etf.javaqx.qswing.graphics.Color;
import yu.ac.bg.etf.javaqx.qswing.graphics.Font;
import yu.ac.bg.etf.javaqx.qswing.layouts.formlayout.CellConstraints;
import yu.ac.bg.etf.javaqx.qswing.layouts.formlayout.FormLayout;

/**
 * Demonstration of the tooltips.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class ToolTipDemo extends DemoModule {

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new ToolTipDemo object.
   */
  public ToolTipDemo() {
    super("ToolTip Demo", "Demonstration of the tooltips.");
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected JQComponent buildDemoComponent() {
    FormLayout layout = new FormLayout("p:g, c:p, 8dlu, p, 4dlu, p, p:g",
                                       "f:p, 4dlu, p");
    JQContainer panel = new JQContainer(layout);
    panel.setWhatsThisText(
            "<p style='white-space:pre'>Demonstration of the <i>tooltips</i> " +
            "based on <br>the silly <b>ToolTip</b> demo from SwingSet2.</p>");
    panel.setBackground(Color.WHITE);
    panel.setInsets(32, 24, 16, 16);
    CellConstraints cc = new CellConstraints();

    panel.add(new ToolTipDemoLabel(), cc.xy(2, 1));
    JQLabel label = new JQLabel("Move and hold mouse pointer over the image.");
    label.setFont(label.getFont().deriveFont(Font.BOLD));
    panel.add(label, cc.xy(2, 3));
    panel.add(new JQSeparator(JQSeparator.VERTICAL), cc.xy(4, 1));

    JQContainer toolsPanel = new JQContainer(new FormLayout("p",
                                                            "p, 4dlu, p"));
    JQCheckBox toolTipsEnabled = new JQCheckBox("ToolTips Enabled");
    toolTipsEnabled.setSelected(true);
    toolTipsEnabled.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        JQToolTip.setToolTipsEnabled(((JQCheckBox)e.getSource()).isSelected());
      }
    });
    toolsPanel.add(toolTipsEnabled, cc.xy(1, 1));
    String imageName = "resources/images/tooltip/WhatsThis.png";
    JQToolButton whatsThisButton = new JQToolButton(
                       new ImageIcon(loadResource(imageName)), "What's This?");
    whatsThisButton.setToolButtonStyle(JQToolButton.STYLE_TEXT_BESIDE_ICON);
    whatsThisButton.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        WhatsThisManager.enterWhatsThisMode();
      }
    });
    toolsPanel.add(whatsThisButton, cc.xy(1, 3));
    panel.add(toolsPanel, cc.xy(6, 1));

    return new JQScrollPane(panel);
  }

/*^**************************************************************************^*/
/*- Inner Class.                                                             -*/
/*^**************************************************************************^*/

  /**
   * ToolTip Demo Label.
   */
  class ToolTipDemoLabel extends JQLabel {
    private boolean moo;
    private boolean milk;
    private boolean tail;
    public ToolTipDemoLabel() {
      String imageName = "resources/images/tooltip/Cow.png";
      setIcon(new ImageIcon(loadResource(imageName)));
      enableEvents(QSwingEvent.LOCATION_TOOL_TIP_MASK);
    }
    public String getToolTipText(int x, int y) {
      if ((x > 30) && (x < 60) && (y > 60) && (y < 85)) {
        if (!moo) {
          moo = true;
          milk = false;
          tail = false;
          return "<html><center><font color=blue size=+2>" +
                 "Mooooooo</font></center></html>";
        }
      } else if ((x > 150) && (x < 260) && (y > 90) && (y < 145)) {
        if (!milk) {
          milk = true;
          moo = false;
          tail = false;
          return "<html><center><font face=AvantGarde size=+1 color=blue>" +
                 "Got Milk?</font></center></html>";
        }
      } else if ((x > 280) && (x < 300) && (y > 20) && (y < 175)) {
        if (!tail) {
          tail = true;
          moo = false;
          milk = false;
          return "<html><em><b>tail.</b></em></html>";
        }
      } else if (moo || milk || tail) {
        moo = false;
        tail = false;
        milk = false;
        return "<html>In <font color=green size=+2>QSwing!</font>, tooltips " +
               "can use HTML to <ul><li>Have Lists<li><b>Bold</b> text<li>" +
               "<em>emphasized</em> text<li>text with <font color=red>Color" +
               "</font><li>text in different <font size=+3>sizes</font><li>" +
               "<font face=Courier>and Fonts</font></ul>And they can be " +
               "multi-line, too.</html>";
      }
      return null;
    }
  }

/*^**************************************************************************^*/
/*- Main Method.                                                             -*/
/*^**************************************************************************^*/

  /**
   * Starts demo as standalone appliation.
   *
   * @param args the application arguments
   */
  public static void main(String[] args) {
    new ToolTipDemo().show();
  }

}

/*^*****************************************************************************
  File History:

 - 2007-11-30 19:37:02 Slobodan
   Initial version

*****************************************************************************^*/
