/*
 * @(#)TreeDemo.java  0.2.0 / 2007-12-18
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.demo.qswingset;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;

import yu.ac.bg.etf.javaqx.qswing.JQComponent;
import yu.ac.bg.etf.javaqx.qswing.JQTree;
import yu.ac.bg.etf.javaqx.qswing.tree.DefaultMutableTreeNode;
import yu.ac.bg.etf.javaqx.qswing.tree.DefaultTreeModel;

/**
 * Demonstration of the JQTree class.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class TreeDemo extends DemoModule {

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new TreeDemo object.
   */
  public TreeDemo() {
    super("Tree Demo", "Demonstration of the JQTree class.");
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected JQComponent buildDemoComponent() {
    return new JQTree(buildTreeModel());
  }

/*^**************************************************************************^*/
/*- Private Method.                                                          -*/
/*^**************************************************************************^*/

  private DefaultTreeModel buildTreeModel() {
    BufferedReader reader = null;
    try {
      DefaultMutableTreeNode top = new DefaultMutableTreeNode("Music");
      DefaultMutableTreeNode catagory = null;
      DefaultMutableTreeNode artist = null;
      DefaultMutableTreeNode record = null;
      InputStream is = getClass().getResourceAsStream("resources/Tree.txt");
      InputStreamReader isr = new InputStreamReader(is);
      reader = new BufferedReader(isr);
      String line = reader.readLine();
      while (line != null) {
        char linetype = line.charAt(0);
        switch (linetype) {
          case 'C':
            catagory = new DefaultMutableTreeNode(line.substring(2));
            top.add(catagory);
            break;
          case 'A':
            if (catagory != null) {
              artist = new DefaultMutableTreeNode(line.substring(2));
              catagory.add(artist);
            }
            break;
          case 'R':
            if (artist != null) {
              record = new DefaultMutableTreeNode(line.substring(2));
              artist.add(record);
            }
            break;
          case 'S':
            if (record != null) {
              record.add(new DefaultMutableTreeNode(line.substring(2)));
            }
            break;
          default:
            break;
        }
        line = reader.readLine();
      }
      return new DefaultTreeModel(top);
    } catch (IOException e) {
      return new DefaultTreeModel(new DefaultMutableTreeNode("Invalid Tree"));
    } finally {
      if (reader != null) {
        try {
          reader.close();
        } catch (IOException ioe) {
        }
      }
    }
  }

/*^**************************************************************************^*/
/*- Main Method.                                                             -*/
/*^**************************************************************************^*/

  /**
   * Starts demo as standalone appliation.
   *
   * @param args the application arguments
   */
  public static void main(String[] args) {
    new TreeDemo().show();
  }

}

/*^*****************************************************************************
  File History:

 - 2007-12-18 09:34:17 Slobodan
   Initial version

*****************************************************************************^*/
