/*
 * @(#)JQCheckBoxMenuItem.java  0.2.0 / 2007-05-04
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing;

import yu.ac.bg.etf.javaqx.qswing.events.ActionEvent;
import yu.ac.bg.etf.javaqx.qswing.properties.JQCheckBoxMenuItemProperties;

/**
 * CheckBox Menu Item.
 *
 * @javaqx.native
 *    generate="header"
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class JQCheckBoxMenuItem extends JQMenuItem
                                implements JQCheckBoxMenuItemProperties {

/*^**************************************************************************^*/
/*- Static Initialization.                                                   -*/
/*^**************************************************************************^*/

  static {
    _initialize();
  }

/*^**************************************************************************^*/
/*- Private Field.                                                           -*/
/*^**************************************************************************^*/

  private boolean checked;

/*^**************************************************************************^*/
/*- Public Constructors.                                                     -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JQCheckBoxMenuItem object.
   */
  public JQCheckBoxMenuItem() {
    // empty constructor body
  }

  /**
   * Constructs new JQCheckBoxMenuItem object.
   *
   * @param text the text
   */
  public JQCheckBoxMenuItem(String text) {
    super(text);
  }

/*^**************************************************************************^*/
/*- Public Methods.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Returns <tt>true</tt> if menu item is checked.
   *
   * @return <tt>true</tt> if menu item is checked
   */
  public boolean isChecked() {
    return checked;
  }

  /**
   * Checks/unchecks menu item.
   *
   * @param checked if <tt>true</tt> menu item is checked
   */
  public void setChecked(boolean checked) {
    if (this.checked != checked) {
      disposedCheck();
      _setChecked(_bridge, checked);
    }
  }

  /**
   * Returns selected icon.
   *
   * @return selected icon
   */
  public Icon getSelectedIcon() {
    if (iconSet != null) {
      return iconSet.getSelectedIcon();
    }
    return null;
  }

  /**
   * Sets selected icon.
   *
   * @param icon the selected icon
   */
  public void setSelectedIcon(Icon icon) {
    disposedCheck();
    if (icon == null) {
      if (iconSet != null) {
        iconSet.setSelectedIcon(null, null);
        if (iconSet.isEmpty()) {
          _setIcon(_bridge, null);
          iconSet = null;
        }
      }
    } else {
      if (iconSet == null) {
        iconSet = new QSwingIconSet(this);
        _setIcon(_bridge, iconSet);
      }
      iconSet.setSelectedIcon(icon, null);
    }
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected String paramString() {
    StringBuffer sb = new StringBuffer(super.paramString());
    if (checked) {
      sb.append(",checked"); //$NON-NLS-1$
    }
    return sb.toString();
  }

/*^**************************************************************************^*/
/*- Native Callback.                                                         -*/
/*^**************************************************************************^*/

  void _checkedChanged(int modifiers, boolean checked) {
    final boolean oldChecked = this.checked;
    if (oldChecked != checked) {
      this.checked = checked;
      firePropertyChange(PROPERTY_CHECKED, oldChecked, checked);
      fireActionPerformed(new ActionEvent(this, ActionEvent.ACTION_PERFORMED,
                                          getActionCommand(),
                                          System.currentTimeMillis(),
                                          modifiers));
    }
  }

/*^**************************************************************************^*/
/*- Package-Private Native Methods.                                          -*/
/*^**************************************************************************^*/

  native long _create();

  native void _setText(long bridge, String text);

  native void _setShortcut(long bridge, String shortcut);

  native void _setIcon(long bridge, QSwingIconSet iconSet);

  native void _setChecked(long bridge, boolean checked);

/*^**************************************************************************^*/
/*- Private Static Native Method.                                            -*/
/*^**************************************************************************^*/

  private static native void _initialize();

}

/*^*****************************************************************************
  File History:

 - 2007-05-04 18:49:27 Slobodan
   Initial version

*****************************************************************************^*/
