/*
 * @(#)JQRadioButtonMenuItem.java  0.2.0 / 2007-05-04
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing;

import yu.ac.bg.etf.javaqx.qswing.events.ActionEvent;
import yu.ac.bg.etf.javaqx.qswing.properties.JQRadioButtonMenuItemProperties;

/**
 * RadioButton Menu Item.
 *
 * @javaqx.native
 *    generate="header"
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class JQRadioButtonMenuItem extends JQMenuItem
                                   implements JQRadioButtonMenuItemProperties,
                                              Selectable {

/*^**************************************************************************^*/
/*- Static Initialization.                                                   -*/
/*^**************************************************************************^*/

  static {
    _initialize();
  }

/*^**************************************************************************^*/
/*- Package-Private Fields.                                                  -*/
/*^**************************************************************************^*/

  private boolean selected;
  private SelectableGroup selectableGroup;

/*^**************************************************************************^*/
/*- Public Constructors.                                                     -*/
/*^**************************************************************************^*/

  /**
   * Constructs new JQRadioButtonMenuItem object.
   */
  public JQRadioButtonMenuItem() {
    this(null);
  }

  /**
   * Constructs new JQRadioButtonMenuItem object.
   *
   * @param text the text
   */
  public JQRadioButtonMenuItem(String text) {
    super(text);
  }

/*^**************************************************************************^*/
/*- Selectable Interface Implementation.                                     -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public boolean isSelected() {
    return selected;
  }

  /**
   * {@inheritDoc}
   */
  public void setSelected(boolean selected) {
    if (this.selected != selected) {
      disposedCheck();
      _setSelected(_bridge, selected);
    }
  }

  /**
   * {@inheritDoc}
   */
  public SelectableGroup getSelectableGroup() {
    return selectableGroup;
  }

  /**
   * {@inheritDoc}
   */
  public void setSelectableGroup(SelectableGroup selectableGroup) {
    this.selectableGroup = selectableGroup;
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  protected String paramString() {
    StringBuffer sb = new StringBuffer(super.paramString());
    if (selected) {
      sb.append(",selected"); //$NON-NLS-1$
    }
    return sb.toString();
  }

/*^**************************************************************************^*/
/*- Native Callback.                                                        -*/
/*^**************************************************************************^*/

  void _selectedChanged(int modifiers, boolean selected) {
    final boolean oldSelected = this.selected;
    if (oldSelected != selected) {
      this.selected = selected;
      firePropertyChange(PROPERTY_SELECTED, oldSelected, selected);
      fireActionPerformed(new ActionEvent(this, ActionEvent.ACTION_PERFORMED,
                                          getActionCommand(),
                                          System.currentTimeMillis(),
                                          modifiers));
      if ((selectableGroup != null) && selected) {
        selectableGroup.setSelected(this);
      }
    }
  }

/*^**************************************************************************^*/
/*- Package-Private Native Methods.                                          -*/
/*^**************************************************************************^*/

  native long _create();

  native void _setText(long bridge, String text);

  native void _setShortcut(long bridge, String shortcut);

  native void _setIcon(long bridge, QSwingIconSet iconSet);

  native void _setSelected(long bridge, boolean selected);

/*^**************************************************************************^*/
/*- Private Static Native Method.                                            -*/
/*^**************************************************************************^*/

  private static native void _initialize();

}

/*^*****************************************************************************
  File History:

 - 2007-05-04 18:54:20 Slobodan
   Initial version

*****************************************************************************^*/
