/*
 * @(#)ComponentEvent.java  0.2.0 / 2007-09-26
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing.events;

import yu.ac.bg.etf.javaqx.qswing.JQComponent;
import yu.ac.bg.etf.javaqx.qswing.graphics.Rectangle;

/**
 * Component Event.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class ComponentEvent extends QSwingEvent {

/*^**************************************************************************^*/
/*- Public Static Fields.                                                    -*/
/*^**************************************************************************^*/

  /**
   * Component moved id.
   */
  public static final int COMPONENT_MOVED = 100;

  /**
   * Component resized id.
   */
  public static final int COMPONENT_RESIZED = 101;

  /**
   * Component shown id.
   */
  public static final int COMPONENT_SHOWN = 102;

  /**
   * Component hidden id.
   */
  public static final int COMPONENT_HIDDEN = 103;

/*^**************************************************************************^*/
/*- Private Static Final Field.                                              -*/
/*^**************************************************************************^*/

  private static final long serialVersionUID = -9130577327143770008L;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new ComponentEvent object.
   *
   * @param source the source component of the event
   * @param id the event id
   *
   * @throws IllegalArgumentException if the source is <tt>null</tt>
   */
  public ComponentEvent(JQComponent source, int id) {
    super(source, id);
  }

/*^**************************************************************************^*/
/*- Public Method.                                                           -*/
/*^**************************************************************************^*/

  /**
   * Returns the source component of the event.
   *
   * @return the source component of the event
   */
  public JQComponent getComponent() {
    return (JQComponent)source;
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public String paramString() {
    String paramString;
    switch (id) {
     case COMPONENT_MOVED:
       paramString = "COMPONENT_MOVED"; //$NON-NLS-1$
       if (source instanceof JQComponent) {
         Rectangle bounds = ((JQComponent)source).getBounds();
         paramString = paramString + " (" + bounds.getX() + //$NON-NLS-1$
                       ',' + bounds.getY() + ' ' + bounds.getWidth() + 'x' +
                       bounds.getHeight() + ')';
       }
       return paramString;
     case COMPONENT_RESIZED:
       paramString = "COMPONENT_RESIZED"; //$NON-NLS-1$
       if (source instanceof JQComponent) {
         Rectangle bounds = ((JQComponent)source).getBounds();
         paramString = paramString + " (" + bounds.getX() + //$NON-NLS-1$
                       ',' + bounds.getY() + ' ' + bounds.getWidth() + 'x' +
                       bounds.getHeight() + ')';
       }
       return paramString;
      case COMPONENT_SHOWN:
        return "COMPONENT_SHOWN"; //$NON-NLS-1$
      case COMPONENT_HIDDEN:
        return "COMPONENT_HIDDEN"; //$NON-NLS-1$
      default:
        return "unknown type"; //$NON-NLS-1$
    }
  }

}

/*^*****************************************************************************
  File History:

 - 2007-09-26 13:45:43 Slobodan
   Initial version

*****************************************************************************^*/
