/*
 * @(#)ContainerEvent.java  0.2.0 / 2007-09-27
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing.events;

import yu.ac.bg.etf.javaqx.qswing.JQComponent;
import yu.ac.bg.etf.javaqx.qswing.JQContainer;

/**
 * Container Event.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class ContainerEvent extends ComponentEvent {

/*^**************************************************************************^*/
/*- Public Static Fields.                                                    -*/
/*^**************************************************************************^*/

  /**
   * Component added id.
   */
  public static final int COMPONENT_ADDED = 300;

  /**
   * Component removed id.
   */
  public static final int COMPONENT_REMOVED = 301;

/*^**************************************************************************^*/
/*- Private Static Final Field.                                              -*/
/*^**************************************************************************^*/

  private static final long serialVersionUID = -3296089800823997049L;

/*^**************************************************************************^*/
/*- Private Field.                                                           -*/
/*^**************************************************************************^*/

  private final transient JQComponent child;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new FocusEvent object.
   *
   * @param source the source container of the event
   * @param id the event id
   * @param child the child component
   *
   * @throws IllegalArgumentException if the source is <tt>null</tt>
   * @throws IllegalArgumentException if the child is <tt>null</tt>
   */
  public ContainerEvent(JQContainer source, int id, JQComponent child) {
    super(source, id);
    if (child == null) {
      throw new IllegalArgumentException("Null child"); //$NON-NLS-1$
    }
    this.child = child;
  }

/*^**************************************************************************^*/
/*- Public Methods.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Returns the source container of the event.
   *
   * @return the source container of the event
   */
  public JQContainer getContainer() {
    return (JQContainer)source;
  }

  /**
   * Returns the component that was added or removed.
   *
   * @return the component that was added or removed
   */
  public JQComponent getChild() {
    return child;
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public String paramString() {
    String idString;
    switch(getID()) {
      case COMPONENT_ADDED:
        idString = "COMPONENT_ADDED"; //$NON-NLS-1$
        break;
      case COMPONENT_REMOVED:
        idString = "COMPONENT_REMOVED"; //$NON-NLS-1$
        break;
      default:
        idString = "unknown type"; //$NON-NLS-1$
    }
    return idString + ",child=" + child.getName(); //$NON-NLS-1$
  }

}

/*^*****************************************************************************
  File History:

 - 2007-09-27 20:37:55 Slobodan
   Initial version

*****************************************************************************^*/
