/*
 * @(#)FocusEvent.java  0.2.0 / 2007-09-27
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing.events;

import yu.ac.bg.etf.javaqx.qswing.JQComponent;

/**
 * Focus Event.
 * <p>
 *   <tt>NOTE: This class is not full compatible with
 *             <em>java.awt.event.FocusEvent</em> class!</tt>
 * </p>
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class FocusEvent extends ComponentEvent {

/*^**************************************************************************^*/
/*- Public Static Fields.                                                    -*/
/*^**************************************************************************^*/

  /**
   * Focus gained id.
   */
  public static final int FOCUS_GAINED = 1004;

  /**
   * Focus lost id.
   */
  public static final int FOCUS_LOST = 1005;

/*^**************************************************************************^*/
/*- Private Static Final Field.                                              -*/
/*^**************************************************************************^*/

  private static final long serialVersionUID = -9169728506732292185L;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new FocusEvent object.
   *
   * @param source the source component of the event
   * @param id the event id
   *
   * @throws IllegalArgumentException if the source is <tt>null</tt>
   */
  public FocusEvent(JQComponent source, int id) {
    super(source, id);
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public String paramString() {
    switch(id) {
      case FOCUS_GAINED:
        return "FOCUS_GAINED"; //$NON-NLS-1$
      case FOCUS_LOST:
        return "FOCUS_LOST"; //$NON-NLS-1$
      default:
        return "unknown type"; //$NON-NLS-1$
    }
  }

}

/*^*****************************************************************************
  File History:

 - 2007-09-27 20:07:58 Slobodan
   Initial version

*****************************************************************************^*/
