/*
 * @(#)MouseWheelEvent.java  0.2.0 / 2007-09-26
 *
 * Copyright (c) 2007, ETF and contributors. All rights reserved.
 *
 * This software is licensed under the LGPL, version 2.1, license.
 * A copy of the license is included in the file LICENSE-LGPL.txt.
 */
package yu.ac.bg.etf.javaqx.qswing.events;

import yu.ac.bg.etf.javaqx.qswing.JQComponent;

/**
 * Mouse Wheel Event.
 *
 * @author Slobodan Vrkacevic (slobodan.vrkacevic@gmail.com)
 * @version 0.2.0
 */
public class MouseWheelEvent extends MouseEvent {

/*^**************************************************************************^*/
/*- Public Static Fields.                                                    -*/
/*^**************************************************************************^*/

  /**
   * Scrolling by units (lines).
   */
  public static final int WHEEL_UNIT_SCROLL = 0;

  /**
   * Scrolling by blocks (pages).
   */
  public static final int WHEEL_BLOCK_SCROLL = 1;

/*^**************************************************************************^*/
/*- Private Static Final Field.                                              -*/
/*^**************************************************************************^*/

  private static final long serialVersionUID = 3037678193870011504L;

/*^**************************************************************************^*/
/*- Private Fields.                                                          -*/
/*^**************************************************************************^*/

  private final int scrollType;
  private final int scrollAmount;
  private final int wheelRotation;

/*^**************************************************************************^*/
/*- Public Constructor.                                                      -*/
/*^**************************************************************************^*/

  /**
   * Constructs new MouseWheelEvent object.
   *
   * @param source the source component
   * @param id the event id
   * @param when the time the event occurred
   * @param modifiers the modifiers
   * @param x the x coordinate of the mouse point
   * @param y the y coordinate of the mouse point
   * @param clickCount the click count
   * @param scrollType the scroll type
   * @param scrollAmount the scroll amount
   * @param wheelRotation the wheel rotation
   *
   * @throws IllegalArgumentException if the source is <tt>null</tt>
   */
  public MouseWheelEvent(JQComponent source, int id, long when, int modifiers,
                         int x, int y, int clickCount, int scrollType,
                         int scrollAmount, int wheelRotation) {
    super(source, id, when, modifiers, x, y, clickCount);
    this.scrollType = scrollType;
    this.scrollAmount = scrollAmount;
    this.wheelRotation = wheelRotation;
  }

/*^**************************************************************************^*/
/*- Public Methods.                                                          -*/
/*^**************************************************************************^*/

  /**
   * Returns scroll type.
   *
   * @return scroll type
   */
  public int getScrollType() {
    return scrollType;
  }

  /**
   * Returns scroll amount.
   *
   * @return scroll amount
   */
  public int getScrollAmount() {
    return scrollAmount;
  }

  /**
   * Returns wheel rotation.
   *
   * @return wheel rotation
   */
  public int getWheelRotation() {
    return wheelRotation;
  }

  /**
   * Returns the number of units to scroll.
   *
   * @return the number of units to scroll
   */
  public int getUnitsToScroll() {
    return scrollAmount * wheelRotation;
  }

/*^**************************************************************************^*/
/*- Overridden Method.                                                       -*/
/*^**************************************************************************^*/

  /**
   * {@inheritDoc}
   */
  public String paramString() {
    StringBuffer sb = new StringBuffer(160);
    sb.append(super.paramString());
    sb.append(",scrollType="); //$NON-NLS-1$
    switch (getScrollType()) {
      case WHEEL_UNIT_SCROLL:
        sb.append("WHEEL_UNIT_SCROLL"); //$NON-NLS-1$
        break;
      case WHEEL_BLOCK_SCROLL:
        sb.append("WHEEL_BLOCK_SCROLL"); //$NON-NLS-1$
        break;
      default:
        sb.append("unknown scroll type"); //$NON-NLS-1$
        break;
    }
    sb.append(",scrollAmount="); //$NON-NLS-1$
    sb.append(getScrollAmount());
    sb.append(",wheelRotation="); //$NON-NLS-1$
    sb.append(getWheelRotation());
    return sb.toString();
  }

}

/*^*****************************************************************************
  File History:

 - 2007-09-26 15:11:49 Slobodan
   Initial version

*****************************************************************************^*/
